(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[      8683,        307]
NotebookOptionsPosition[      7391,        266]
NotebookOutlinePosition[      7936,        285]
CellTagsIndexPosition[      7893,        282]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Cap 5.3 Aid ", "Title"],

Cell[BoxData[
 RowBox[{"<<", "Graphics`PlotField`"}]], "Input"],

Cell[BoxData[
 RowBox[{"p1", "=", 
  RowBox[{"PlotVectorField", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        RowBox[{"x1", "^", "3"}]}], " ", "-", " ", 
       RowBox[{"4", " ", "x1"}], " ", "-", " ", "x2"}], ",", 
      RowBox[{"3", " ", "x1"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"x1", ",", 
      RowBox[{"-", "3"}], ",", "1"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"x2", ",", 
      RowBox[{"-", "6"}], ",", "6"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"PlotPoints", "\[Rule]", "20"}]}], "]"}]}]], "Input"],

Cell["\<\
Solve for the equation of the nullclines.
In this case, one nullcline is obviously x1=0.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"Solve", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      RowBox[{"x1", "^", "3"}]}], " ", "-", " ", 
     RowBox[{"4", " ", "x1"}], " ", "-", " ", "x2"}], "\[Equal]", "0"}], ",", 
   "x2"}], "]"}]], "Input"],

Cell["\<\
The intersection points of the nullclines are the equilibria; here there's \
only one.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"Solve", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        RowBox[{"x1", "^", "3"}]}], " ", "-", " ", 
       RowBox[{"4", " ", "x1"}], " ", "-", " ", "x2"}], "\[Equal]", "0"}], 
     ",", 
     RowBox[{
      RowBox[{"3", "  ", "x1"}], "\[Equal]", "0"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x1", ",", "x2"}], "}"}]}], "]"}]], "Input"],

Cell["a plot of the nullclines", "Text"],

Cell[BoxData[
 RowBox[{"p2", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"0", ",", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "4"}], " ", "x1"}], "-", 
       SuperscriptBox["x1", "3"]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"x1", ",", 
      RowBox[{"-", "3"}], ",", "1"}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "6"}], ",", "6"}], "}"}]}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Hue", "[", ".6", "]"}], ",", 
         RowBox[{"Thickness", "[", ".01", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Hue", "[", ".4", "]"}], ",", 
         RowBox[{"Thickness", "[", ".01", "]"}]}], "}"}]}], "}"}]}]}], 
   "]"}]}]], "Input"],

Cell["the equilibrium point", "Text"],

Cell[BoxData[
 RowBox[{"p3", "=", 
  RowBox[{"ListPlot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "6"}], ",", "6"}], "}"}]}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Hue", "[", "1", "]"}], ",", 
       RowBox[{"PointSize", "[", ".03", "]"}]}], "}"}]}]}], "]"}]}]], "Input"],

Cell["The nullclines and the vector field.", "Text"],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"p1", ",", "p2", ",", "p3"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "6"}], ",", "6"}], "}"}]}], ",", 
   RowBox[{"Axes", "\[Rule]", "True"}]}], "]"}]], "Input"],

Cell["Calculate the Jacobian", "Text"],

Cell[BoxData[
 RowBox[{"J", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          RowBox[{"x1", "^", "3"}]}], " ", "-", " ", 
         RowBox[{"4", " ", "x1"}], " ", "-", " ", "x2"}], ",", "x1"}], "]"}], 
      ",", 
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          RowBox[{"x1", "^", "3"}]}], " ", "-", " ", 
         RowBox[{"4", " ", "x1"}], " ", "-", " ", "x2"}], ",", "x2"}], 
       "]"}]}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"{", " ", 
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{"3", " ", "x1"}], ",", "x1"}], "]"}], ",", 
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{"3", " ", "x1"}], ",", "x2"}], "]"}]}], "}"}]}], 
   "}"}]}]], "Input"],

Cell["\<\
and evaluate at the fixed point.  The associated linearized system (which \
approximate the perturbations y) is y'=Ay.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"A", " ", "=", " ", 
  RowBox[{"J", "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x2", "\[Rule]", "0"}], ",", 
     RowBox[{"x1", "\[Rule]", "0"}]}], "}"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"Eigensystem", "[", "A", "]"}]], "Input"],

Cell["\<\
A has eigenvalue -3 with eigenvector {-1,1} and eigenvalue -1 with \
eigenvector {-1,3}.
Thus, the perturbations are approximated by\
\>", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"plist", "=", 
   RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"For", "[", 
  RowBox[{
   RowBox[{"c1", "=", 
    RowBox[{"-", "1"}]}], ",", 
   RowBox[{"c1", "\[LessEqual]", "1"}], ",", 
   RowBox[{"c1", "++"}], ",", "\[IndentingNewLine]", 
   RowBox[{"For", "[", 
    RowBox[{
     RowBox[{"c2", "=", 
      RowBox[{"-", "1"}]}], ",", 
     RowBox[{"c2", "\[LessEqual]", "1"}], ",", 
     RowBox[{"c2", "++"}], ",", "\[IndentingNewLine]", 
     RowBox[{"plist", "=", 
      RowBox[{"Append", "[", 
       RowBox[{"plist", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"-", " ", "c1"}], " ", 
            RowBox[{"Exp", "[", 
             RowBox[{
              RowBox[{"-", "3"}], "t"}], "]"}]}], "-", 
           RowBox[{"c2", " ", 
            RowBox[{"Exp", "[", 
             RowBox[{"-", "t"}], "]"}]}]}], ",", 
          RowBox[{
           RowBox[{"c1", " ", 
            RowBox[{"Exp", "[", 
             RowBox[{
              RowBox[{"-", "3"}], "t"}], "]"}]}], "+", 
           RowBox[{"c2", "*", "3", "  ", 
            RowBox[{"Exp", "[", 
             RowBox[{"-", "t"}], "]"}]}]}]}], "}"}]}], "]"}]}]}], "]"}]}], 
  "]"}]}], "Input"],

Cell[BoxData["plist"], "Input"],

Cell[BoxData[
 RowBox[{"p4", "=", 
  RowBox[{"ParametricPlot", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", "plist", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "8"}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", "3"}], "}"}]}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"p1", ",", "p2", ",", "p3", ",", "p4"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "3"}], ",", "3"}], "}"}]}], ",", 
   RowBox[{"Axes", "\[Rule]", "True"}]}], "]"}]], "Input"]
}, Open  ]]
},
WindowSize->{664, 605},
WindowMargins->{{24, Automatic}, {Automatic, 7}},
FrontEndVersion->"8.0 for Microsoft Windows (64-bit) (November 7, 2010)",
StyleDefinitions->"Default.nb",
MacintoshSystemPageSetup -> \
"00<0001804P000000]P2:?oQon82n@960dL5:0?l0080001804P000000]P2:001\n\
0000I00000400`<300000BL?00400@0000000000000006P801T1T00000000000\n\
00000000000000000000000000000000"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 29, 0, 83, "Title"],
Cell[611, 24, 63, 1, 31, "Input"],
Cell[677, 27, 587, 17, 52, "Input"],
Cell[1267, 46, 112, 3, 47, "Text"],
Cell[1382, 51, 249, 8, 31, "Input"],
Cell[1634, 61, 110, 3, 29, "Text"],
Cell[1747, 66, 422, 14, 31, "Input"],
Cell[2172, 82, 40, 0, 29, "Text"],
Cell[2215, 84, 861, 28, 55, "Input"],
Cell[3079, 114, 37, 0, 29, "Text"],
Cell[3119, 116, 482, 15, 31, "Input"],
Cell[3604, 133, 52, 0, 29, "Text"],
Cell[3659, 135, 299, 9, 31, "Input"],
Cell[3961, 146, 38, 0, 29, "Text"],
Cell[4002, 148, 845, 28, 52, "Input"],
Cell[4850, 178, 142, 3, 29, "Text"],
Cell[4995, 183, 198, 6, 31, "Input"],
Cell[5196, 191, 64, 1, 31, "Input"],
Cell[5263, 194, 156, 4, 46, "Text"],
Cell[5422, 200, 1261, 38, 91, "Input"],
Cell[6686, 240, 31, 0, 27, "Input"],
Cell[6720, 242, 342, 10, 27, "Input"],
Cell[7065, 254, 310, 9, 27, "Input"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

