(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     62314,       2011]*)
(*NotebookOutlinePosition[     63371,       2045]*)
(*  CellTagsIndexPosition[     63327,       2041]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Roots of Complex Values", "Title"],

Cell["Therese Shelton & Kendall Richards", "Subtitle"],

Cell[TextData[{
  "Load the graphics package just once per ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " session."
}], "Subsubsection"],

Cell["<<Graphics`Graphics`", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
To plot the Mth roots of a complex number
z={R Cos[theta], R Sin[theta]},
enter desired values for M, R, and theta.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
You can change these parameter values in the yellow box and \
re-execute.  \
\>", "Subsubsection"],

Cell[TextData[{
  "For instance, if M=4, R=3, and theta=Pi/2, we find the fourth roots of 3 \
",
  Cell[BoxData[
      \(\[ExponentialE]\^\(\[ImaginaryI]\ \[Pi]/2\)\)]]
}], "Text"],

Cell["\<\
M=4;
R=3;
theta=Pi/2;\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}},
  Background->RGBColor[1, 1, 0]],

Cell["\<\
p3=ListPlot[{{R Cos[theta],R Sin[theta]}},
  AspectRatio->Automatic, 
  Prolog->AbsolutePointSize[6],
  DisplayFunction->Identity,
  PlotStyle->RGBColor[1,0,0]];\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\

p2=PolarPlot[R^(1/M), {t,0,2 Pi},
  DisplayFunction->Identity,
  PlotStyle->RGBColor[0,.5,0]];\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
  
p1=ListPlot[
  Table[{R^(1/M) Cos[(theta+2 m Pi)/M],
        R^(1/M) Sin[(theta+2 m Pi)/M]},
        {m,0,M-1}],
  AspectRatio->Automatic,
  Prolog->AbsolutePointSize[8],
  DisplayFunction->Identity,
  PlotStyle->RGBColor[0,.1,.5]];\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
The original complex number is in red.  Its roots are in blue and \
are equidistant on the green circle.\
\>", "Subsubsection"],

Cell[CellGroupData[{

Cell["\<\
Show[p1,p2,p3,
  DisplayFunction->$DisplayFunction]\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.63976 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.499998 0.361828 0.515234 0.361828 [
[.13817 .50273 -6 -9 ]
[.13817 .50273 6 0 ]
[.31908 .50273 -12 -9 ]
[.31908 .50273 12 0 ]
[.68091 .50273 -9 -9 ]
[.68091 .50273 9 0 ]
[.86183 .50273 -3 -9 ]
[.86183 .50273 3 0 ]
[.4875 .15341 -12 -4.5 ]
[.4875 .15341 0 4.5 ]
[.4875 .87706 -6 -4.5 ]
[.4875 .87706 0 4.5 ]
[.4875 1.23889 -6 -4.5 ]
[.4875 1.23889 0 4.5 ]
[.4875 1.60072 -6 -4.5 ]
[.4875 1.60072 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1.63976 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.13817 .51523 m
.13817 .52148 L
s
[(-1)] .13817 .50273 0 1 Mshowa
.31908 .51523 m
.31908 .52148 L
s
[(-0.5)] .31908 .50273 0 1 Mshowa
.68091 .51523 m
.68091 .52148 L
s
[(0.5)] .68091 .50273 0 1 Mshowa
.86183 .51523 m
.86183 .52148 L
s
[(1)] .86183 .50273 0 1 Mshowa
.125 Mabswid
.17435 .51523 m
.17435 .51898 L
s
.21054 .51523 m
.21054 .51898 L
s
.24672 .51523 m
.24672 .51898 L
s
.2829 .51523 m
.2829 .51898 L
s
.35527 .51523 m
.35527 .51898 L
s
.39145 .51523 m
.39145 .51898 L
s
.42763 .51523 m
.42763 .51898 L
s
.46382 .51523 m
.46382 .51898 L
s
.53618 .51523 m
.53618 .51898 L
s
.57236 .51523 m
.57236 .51898 L
s
.60855 .51523 m
.60855 .51898 L
s
.64473 .51523 m
.64473 .51898 L
s
.7171 .51523 m
.7171 .51898 L
s
.75328 .51523 m
.75328 .51898 L
s
.78946 .51523 m
.78946 .51898 L
s
.82564 .51523 m
.82564 .51898 L
s
.10199 .51523 m
.10199 .51898 L
s
.06581 .51523 m
.06581 .51898 L
s
.02962 .51523 m
.02962 .51898 L
s
.89801 .51523 m
.89801 .51898 L
s
.93419 .51523 m
.93419 .51898 L
s
.97037 .51523 m
.97037 .51898 L
s
.25 Mabswid
0 .51523 m
1 .51523 L
s
.5 .15341 m
.50625 .15341 L
s
[(-1)] .4875 .15341 1 0 Mshowa
.5 .87706 m
.50625 .87706 L
s
[(1)] .4875 .87706 1 0 Mshowa
.5 1.23889 m
.50625 1.23889 L
s
[(2)] .4875 1.23889 1 0 Mshowa
.5 1.60072 m
.50625 1.60072 L
s
[(3)] .4875 1.60072 1 0 Mshowa
.125 Mabswid
.5 .22577 m
.50375 .22577 L
s
.5 .29814 m
.50375 .29814 L
s
.5 .3705 m
.50375 .3705 L
s
.5 .44287 m
.50375 .44287 L
s
.5 .5876 m
.50375 .5876 L
s
.5 .65996 m
.50375 .65996 L
s
.5 .73233 m
.50375 .73233 L
s
.5 .8047 m
.50375 .8047 L
s
.5 .94943 m
.50375 .94943 L
s
.5 1.02179 m
.50375 1.02179 L
s
.5 1.09416 m
.50375 1.09416 L
s
.5 1.16652 m
.50375 1.16652 L
s
.5 1.31125 m
.50375 1.31125 L
s
.5 1.38362 m
.50375 1.38362 L
s
.5 1.45599 m
.50375 1.45599 L
s
.5 1.52835 m
.50375 1.52835 L
s
.5 .08104 m
.50375 .08104 L
s
.5 .00867 m
.50375 .00867 L
s
.25 Mabswid
.5 0 m
.5 1.63976 L
s
0 0 m
1 0 L
1 1.63976 L
0 1.63976 L
closepath
clip
newpath
0 .1 .5 r
8 Mabswid
.93994 .69746 Mdot
.31777 .95518 Mdot
.06005 .333 Mdot
.68223 .07529 Mdot
0 .5 0 r
.5 Mabswid
.97619 .51523 m
.97618 .51893 L
.97614 .52229 L
.97606 .52617 L
.97597 .52983 L
.97572 .53635 L
.97536 .54342 L
.97483 .55119 L
.97414 .55943 L
.97253 .57417 L
.97039 .58932 L
.96795 .60345 L
.96081 .6353 L
.95129 .66721 L
.94065 .69575 L
.91017 .75714 L
.87673 .80649 L
.83352 .85512 L
.78673 .89542 L
.73155 .93134 L
.7028 .94608 L
.67066 .95979 L
.64214 .96972 L
.61017 .97851 L
.5949 .98187 L
.57842 .98492 L
.5641 .98709 L
.54845 .98895 L
.53926 .9898 L
.53074 .99043 L
.52259 .99089 L
.51847 .99107 L
.51392 .99122 L
.50983 .99132 L
.50609 .99139 L
.50197 .99142 L
.4999 .99143 L
.49764 .99142 L
.49381 .99139 L
.48973 .99131 L
.48587 .99122 L
.48236 .9911 L
.47512 .99078 L
.46715 .99029 L
.45109 .98891 L
.43626 .98714 L
.42244 .98507 L
.39155 .97891 L
.3589 .97004 L
.32884 .9596 L
Mistroke
.29695 .94597 L
.24178 .91533 L
.19207 .87847 L
.14489 .8325 L
.10369 .77923 L
.07215 .72428 L
.05955 .69624 L
.04825 .66583 L
.03956 .6367 L
.03328 .60975 L
.02828 .58032 L
.02631 .56402 L
.0256 .55651 L
.02497 .54854 L
.02454 .54172 L
.02436 .5381 L
.02418 .5342 L
.02406 .53063 L
.02396 .52736 L
.02389 .52423 L
.02384 .52094 L
.02381 .51734 L
.02381 .5135 L
.02384 .50988 L
.02388 .5066 L
.02397 .50273 L
.0241 .49853 L
.02443 .49094 L
.02486 .48352 L
.02546 .47556 L
.02688 .46123 L
.02913 .44426 L
.03171 .42884 L
.03905 .3957 L
.04818 .36483 L
.07174 .30702 L
.10012 .25666 L
.13486 .20956 L
.17963 .16292 L
.22702 .12505 L
.28309 .09131 L
.3408 .06644 L
.37094 .05686 L
.38817 .05236 L
.40459 .0487 L
.41978 .04585 L
.43635 .04331 L
.45149 .04152 L
.4655 .04029 L
.47334 .03979 L
Mistroke
.48068 .03943 L
.48489 .03928 L
.48874 .03917 L
.49087 .03913 L
.49319 .03909 L
.49538 .03906 L
.49741 .03905 L
.49954 .03904 L
.50184 .03905 L
.50401 .03906 L
.50601 .03908 L
.5098 .03914 L
.5138 .03924 L
.5181 .03939 L
.52212 .03956 L
.53124 .04007 L
.5394 .04067 L
.54693 .04136 L
.56393 .04335 L
.57886 .04562 L
.59461 .04854 L
.62161 .05483 L
.65091 .06359 L
.70722 .08649 L
.76408 .11898 L
.81405 .15728 L
.86069 .20433 L
.89804 .25384 L
.92672 .30389 L
.94037 .33403 L
.95129 .36327 L
.95954 .39042 L
.9665 .41963 L
.9707 .44312 L
.97256 .45654 L
.97395 .46914 L
.97494 .48074 L
.97559 .49134 L
.97585 .49721 L
.97596 .5003 L
.97605 .5036 L
.97612 .50677 L
.97616 .50964 L
.97618 .51252 L
.97619 .51523 L
Mfstroke
1 0 0 r
8 Mabswid
.5 1.60072 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{175, 286.938},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002_00017Q000`40O003h00OEgoo00<007ooOol0
EGoo001GOol00`00Oomoo`1EOol005Moo`03001oogoo05Eoo`00Egoo00<007ooOol0EGoo001GOol0
0`00Oomoo`1EOol005Moo`03001oogoo05Eoo`00Egoo00<007ooOol0EGoo001:OolJ0N1;Ool004Eo
o`D1h0eoo`03001oogoo00Yoo`L1h4Aoo`00@Woo0`7P4Woo00<007ooOol04Goo0`7P1goo101_=Woo
000nOol40N0EOol00`00Oomoo`0DOol30N03Ool606leOol003Yoo`@1h1Uoo`03001oogoo01Moo`81
h0P0KcAoo`00>7oo0P7P7Goo00<007ooOol06Goo0`7P1@1_=7oo000fOol20N0OOol00`00Oomoo`0I
Ool306l20N0306ldOol003Aoo`81h25oo`03001oogoo01Uoo`D0K`<1h3Aoo`00<Woo0P7P8goo00<0
07ooOol06Woo1P1_00=oo`7P0N00<Woo000`Ool20N0UOol00`00Oomoo`0KOol406l4Ool00`7POomo
o`0_Ool002ioo`81h2Moo`03001oogoo02Aoo`81h2moo`00;Goo00<1h7ooOol09goo00<007ooOol0
9Woo00<1h7ooOol0;7oo000[Ool20N0ZOol00`00Oomoo`0WOol20N0/Ool002Uoo`81h2aoo`03001o
ogoo02Uoo`030N1oogoo02Uoo`00:7oo00<1h7ooOol0;7oo00<007ooOol0:Woo0P7P:Goo000VOol2
0N0_Ool00`00Oomoo`0/Ool00`7POomoo`0VOol002Eoo`030N1oogoo02moo`03001oogoo02eoo`81
h2Ioo`0097oo00<1h7ooOol0:7oo0`001Goo00<007ooOol0;goo00<1h7ooOol08goo000ROol20N0/
Ool00`00Oomoo`04Ool00`00Oomoo`0`Ool20N0SOol0025oo`030N1oogoo02Aoo`D000=oo`03001o
ogoo00Aoo`03001oogoo039oo`030N1oogoo021oo`0087oo00<1h7ooOol0;Goo00<007ooOol017oo
0P00=7oo00<1h7ooOol07goo000OOol00`7POomoo`0^Ool00`00Oomoo`04Ool00`00Oomoo`0dOol0
0`7POomoo`0NOol001ioo`030N1oogoo02ioo`8000Ioo`03001oogoo03Eoo`030N1oogoo01eoo`00
7Goo00<1h7ooOol0<7oo00<007ooOol017oo00<007ooOol0=Woo00<1h7ooOol077oo000LOol00`7P
Oomoo`0hOol00`00Oomoo`0gOol00`7POomoo`0KOol001]oo`030N1oogoo03Uoo`03001oogoo03Qo
o`030N1oogoo01Yoo`006Woo00<1h7ooOol0>Woo00<007ooOol0>Goo00<1h7ooOol06Goo000IOol0
0`7POomoo`0kOol00`00Oomoo`0jOol00`7POomoo`0HOol001Qoo`030N1oogoo03aoo`03001oogoo
03]oo`030N1oogoo01Moo`005goo00<1h7ooOol0?Goo00<007ooOol0>goo00<1h7ooOol05goo000G
Ool00`7POomoo`0mOol00`00Oomoo`0lOol00`7POomoo`0FOol001Ioo`030N1oogoo03ioo`03001o
ogoo03eoo`030N1oogoo01Eoo`005Goo00<1h7ooOol0?goo00<007ooOol0?Woo00<1h7ooOol057oo
000EOol00`7POomoo`0oOol00`00Oomoo`0oOol00`7POomoo`0COol001Aoo`030N1oogoo041oo`03
001oogoo03moo`030N1oogoo01=oo`004goo00<1h7ooOol0@Goo00<007ooOol0@7oo00<1h7ooOol0
4Woo000COol00`7POomoo`11Ool00`00Oomoo`11Ool00`7POomoo`0AOol0019oo`030N1oogoo049o
o`03001oogoo049oo`030N1oogoo011oo`004Goo00<1h7ooOol0@goo00<007ooOol0@Woo00<1h7oo
Ool047oo000AOol00`7POomoo`13Ool00`00Oomoo`13Ool00`7POomoo`0?Ool0011oo`030N1oogoo
04Aoo`03001oogoo04=oo`030N1oogoo00moo`003goo00<1h7ooOol0AGoo00<007ooOol0A7oo00<1
h7ooOol03Woo000?Ool00`7POomoo`15Ool00`00Oomoo`15Ool00`7POomoo`0=Ool000ioo`030N1o
ogoo04Ioo`03001oogoo04Eoo`030N1oogoo00eoo`003Woo00<1h7ooOol0AWoo00<007ooOol0AWoo
00<1h7ooOol037oo000=Ool00`7POomoo`17Ool00`00Oomoo`16Ool00`7POomoo`0<Ool000aoo`03
0N1oogoo04Qoo`03001oogoo04Moo`030N1oogoo00]oo`0027oo101_00<1h7ooOol0B7oo00<007oo
Ool0Agoo00<1h7ooOol02goo0007Ool406l00`7P06moo`19Ool00`00Oomoo`18Ool00`7POomoo`0:
Ool000Ioo`D0K`030N00K`1_04Uoo`03001oogoo04Qoo`030N1oogoo00Yoo`001Woo1@1_00<1h01_
06l0BGoo00<007ooOol0B7oo00<1h7ooOol02Woo0006Ool406l0107P06l0K`1_BGoo00<007ooOol0
BGoo00<1h7ooOol02Goo0006Ool406l0107P06l0K`1_BGoo00<007ooOol0BGoo00<1h7ooOol02Goo
0007Ool206l0107P06l0K`1_BWoo00<007ooOol0BWoo00<1h7ooOol027oo0008Ool0101_0N00K`1_
Bgoo00<007ooOol0BWoo00<1h7ooOol027oo0009Ool00`7POomoo`1;Ool00`00Oomoo`1:Ool00`7P
Oomoo`08Ool000Qoo`030N1oogoo04aoo`03001oogoo04]oo`030N1oogoo00Moo`0027oo00<1h7oo
Ool0C7oo00<007ooOol0Bgoo00<1h7ooOol01goo0007Ool00`7POomoo`1=Ool00`00Oomoo`1;Ool0
0`7POomoo`07Ool000Moo`030N1oogoo04eoo`03001oogoo04aoo`030N1oogoo00Ioo`001goo00<1
h7ooOol0CGoo00<007ooOol0C7oo00<1h7ooOol01Woo0006Ool00`7POomoo`1>Ool00`00Oomoo`1<
Ool00`7POomoo`06Ool000Ioo`030N1oogoo04ioo`03001oogoo04aoo`030N1oogoo00Ioo`001Woo
00<1h7ooOol0CWoo00<007ooOol0CGoo00<1h7ooOol01Goo0006Ool00`7POomoo`1>Ool00`00Oomo
o`1=Ool00`7POomoo`05Ool000Eoo`030N1oogoo04moo`03001oogoo04eoo`030N1oogoo00Eoo`00
1Goo00<1h7ooOol0Cgoo00<007ooOol0CWoo00<1h7ooOol017oo0005Ool00`7POomoo`1?Ool00`00
Oomoo`1>Ool00`7POomoo`04Ool000Eoo`030N1oogoo04moo`03001oogoo04ioo`030N1oogoo00Ao
o`001Goo00<1h7ooOol0Cgoo00<007ooOol0CWoo00<1h7ooOol017oo0005Ool00`7POomoo`1?Ool0
0`00Oomoo`1>Ool00`7POomoo`04Ool000Eoo`030N1oogoo04moo`03001oogoo04ioo`030N1oogoo
00Aoo`0017oo00<1h7ooOol04Woo0`005goo0P0017oo00<007ooOol00Woo0`005Woo00<007ooOol0
5Goo0P0017oo00<007ooOol00Woo0`005Woo0`004goo00<1h7ooOol00goo0004Ool00`7POomoo`0C
Ool00`00Oomoo`0EOol01000Oomoo`001goo00D007ooOomoo`0001Eoo`03001oogoo01Aoo`04001o
ogoo0007Ool01@00Oomoogoo00005Woo00<007ooOol04Woo00<1h7ooOol00goo0004Ool00`7POomo
o`0;Ool50003Ool00`00Oomoo`0>Ool50002Ool01000Oomoo`002goo00<007ooOol04goo00<007oo
Ool057oo00@007ooOol000]oo`03001oogoo01Aoo`03001oogoo019oo`030N1oogoo00=oo`0017oo
00<1h7ooOol04goo00<007ooOol05Goo00@007ooOol000]oo`03001oogoo01=oo`03001oogoo01Ao
o`04001oogoo000;Ool00`00Oomoo`0DOol00`00Oomoo`0BOol00`7POomoo`03Ool000Aoo`030N1o
ogoo01=oo`03001oogoo01Eoo`04001oogoo0007Ool4000FOol00`00Oomoo`0DOol01000Oomoo`00
1goo10005goo00<007ooOol04Woo00<1h7ooOol00goo0004Ool00`7POomoo`0BOol2000GOol01000
Oomoo`001goo00<007ooOol05goo00<007ooOol057oo00@007ooOol000Moo`03001oogoo01Moo`80
01Aoo`030N1oogoo00=oo`0017oo00<1h7ooOol04goo00<007ooOol05Woo0P0027oo1@005Goo00<0
07ooOol05Goo0P0027oo1@005Woo00<007ooOol04Woo00<1h7ooOol00goo0004Ool00`7POomoo`1@
Ool00`00Oomoo`1?Ool00`7POomoo`03Ool000Aoo`030N1oogoo051oo`03001oogoo04moo`030N1o
ogoo00=oo`0017oo00<1h7ooOol0D7oo00<007ooOol0Cgoo00<1h7ooOol00goo0004Ool00`7POomo
o`1@Ool00`00Oomoo`1?Ool00`7POomoo`03Ool000@000030N0000000:8000030N00000000<00000
17oo00<1h7ooOol04Goo00<007ooOol077oo00<007ooOol07Goo00<007ooOol077oo00<007ooOol0
77oo00<007ooOol04Goo00<1h7ooOol00goo0004Ool00`7POomoo`1@Ool00`00Oomoo`1?Ool00`7P
Oomoo`03Ool000Aoo`030N1oogoo051oo`03001oogoo04moo`030N1oogoo00=oo`0017oo00<1h7oo
Ool0D7oo00<007ooOol0Cgoo00<1h7ooOol00goo0004Ool00`7POomoo`1@Ool00`00Oomoo`1?Ool0
0`7POomoo`03Ool000Aoo`030N1oogoo051oo`03001oogoo04moo`030N1oogoo00=oo`0017oo00<1
h7ooOol0D7oo00<007ooOol0Cgoo00<1h7ooOol00goo0004Ool00`7POomoo`1@Ool00`00Oomoo`1?
Ool00`7POomoo`03Ool000Aoo`030N1oogoo051oo`03001oogoo04moo`030N1oogoo00=oo`0017oo
00<1h7ooOol0D7oo00<007ooOol0Cgoo00<1h7ooOol00goo0004Ool00`7POomoo`1@Ool00`00Oomo
o`1?Ool00`7POomoo`03Ool000Aoo`030N1oogoo051oo`03001oogoo04ioo`030N1oogoo00Aoo`00
17oo00<1h7ooOol0D7oo00<007ooOol0CWoo00<1h7ooOol017oo0005Ool00`7POomoo`1?Ool00`00
Oomoo`1>Ool00`7POomoo`04Ool000Eoo`030N1oogoo04moo`03001oogoo04ioo`030N1oogoo00Ao
o`001Goo00<1h7ooOol0Cgoo00<007ooOol0CWoo00<1h7ooOol017oo0005Ool00`7POomoo`1?Ool0
0`00Oomoo`1>Ool00`7POomoo`04Ool000Eoo`030N1oogoo04moo`03001oogoo04eoo`030N1oogoo
00Eoo`001Woo00<1h7ooOol0CWoo00<007ooOol0CGoo00<1h7ooOol01Goo0006Ool00`7POomoo`1>
Ool00`00Oomoo`1=Ool00`7POomoo`05Ool000Ioo`030N1oogoo04ioo`03001oogoo04eoo`030N1o
ogoo00Eoo`001Woo00<1h7ooOol0CWoo00<007ooOol0C7oo00<1h7ooOol01Woo0007Ool00`7POomo
o`1=Ool00`00Oomoo`1<Ool00`7POomoo`06Ool000Moo`030N1oogoo04eoo`03001oogoo04aoo`03
0N1oogoo00Ioo`001goo00<1h7ooOol0CGoo00<007ooOol0Bgoo00<1h7ooOol01goo0008Ool00`7P
Oomoo`1<Ool00`00Oomoo`1;Ool00`7POomoo`07Ool000Qoo`030N1oogoo04aoo`03001oogoo04]o
o`030N1oogoo00Moo`002Goo00<1h7ooOol0Bgoo00<007ooOol0B7oo0P1_00<1h01_Ool027oo0009
Ool00`7POomoo`1;Ool00`00Oomoo`17Ool306l00`7P06l0K`08Ool000Uoo`030N1oogoo04]oo`03
001oogoo04Ioo`@0K`040N00K`1_06l7Ool000Yoo`030N1oogoo04Yoo`03001oogoo04Ioo`<0K`03
0N00K`1_0080K`Moo`002Woo00<1h7ooOol0BWoo00<007ooOol0AWoo0`1_00<1h01_06l00P1_1goo
000;Ool00`7POomoo`19Ool00`00Oomoo`16Ool206l00`7P06l0K`0306l7Ool000]oo`030N1oogoo
04Uoo`03001oogoo04Moo`0306l1h01_00<0K`Qoo`002goo00<1h7ooOol0BGoo00<007ooOol0Agoo
00<1h01_06l00P1_2Goo000<Ool00`7POomoo`18Ool00`00Oomoo`17Ool00`7POomoo`0;Ool000ao
o`030N1oogoo04Qoo`03001oogoo04Ioo`030N1oogoo00aoo`003Goo00<1h7ooOol0Agoo00<007oo
Ool0AWoo00<1h7ooOol037oo000>Ool00`7POomoo`16Ool00`00Oomoo`16Ool00`7POomoo`0<Ool0
00ioo`030N1oogoo04Ioo`03001oogoo04Eoo`030N1oogoo00eoo`003goo00<1h7ooOol0AGoo00<0
07ooOol0AGoo00<1h7ooOol03Goo000@Ool00`7POomoo`14Ool00`00Oomoo`14Ool00`7POomoo`0>
Ool0011oo`030N1oogoo04Aoo`03001oogoo04Aoo`030N1oogoo00ioo`004Goo00<1h7ooOol0@goo
00<007ooOol0@goo00<1h7ooOol03goo000BOol00`7POomoo`12Ool00`00Oomoo`12Ool00`7POomo
o`0@Ool0019oo`030N1oogoo049oo`03001oogoo045oo`030N1oogoo015oo`004goo00<1h7ooOol0
@Goo00<007ooOol0@Goo00<1h7ooOol04Goo000DOol00`7POomoo`10Ool00`00Oomoo`10Ool00`7P
Oomoo`0BOol001Aoo`030N1oogoo041oo`03001oogoo03moo`030N1oogoo01=oo`005Goo00<1h7oo
Ool0?goo00<007ooOol0?Woo00<1h7ooOol057oo000FOol00`7POomoo`0nOol00`00Oomoo`0nOol0
0`7POomoo`0DOol001Moo`030N1oogoo03eoo`03001oogoo03eoo`030N1oogoo01Eoo`005goo00<1
h7ooOol0?Goo00<007ooOol0?7oo00<1h7ooOol05Woo000HOol00`7POomoo`0lOol00`00Oomoo`0k
Ool00`7POomoo`0GOol001Uoo`030N1oogoo03]oo`03001oogoo03Yoo`030N1oogoo01Qoo`006Woo
00<1h7ooOol0>Woo00<007ooOol0>Woo00<1h7ooOol067oo000KOol00`7POomoo`0iOol00`00Oomo
o`0iOol00`7POomoo`0IOol001aoo`030N1oogoo03Qoo`03001oogoo03Qoo`030N1oogoo01Yoo`00
7Goo00<1h7ooOol0=goo00<007ooOol0=Woo0P7P7Goo000NOol00`7POomoo`0^Ool30005Ool00`00
Oomoo`0eOol00`7POomoo`0MOol001moo`030N1oogoo02ioo`03001oogoo00Aoo`03001oogoo03Ao
o`030N1oogoo01ioo`0087oo00<1h7ooOol0;Goo00<007ooOol017oo0P00<goo0P7P8Goo000QOol2
0N0]Ool00`00Oomoo`04Ool00`00Oomoo`0aOol00`7POomoo`0QOol002=oo`030N1oogoo02Yoo`03
001oogoo00Aoo`03001oogoo031oo`030N1oogoo029oo`0097oo0P7P:Goo0P001Woo00<007ooOol0
;goo00<1h7ooOol08goo000VOol00`7POomoo`0WOol00`00Oomoo`04Ool00`00Oomoo`0]Ool20N0V
Ool002Moo`81h2ioo`03001oogoo02aoo`030N1oogoo02Ioo`00:Goo00<1h7ooOol0:goo00<007oo
Ool0:Woo0P7P:Goo000ZOol20N0[Ool00`00Oomoo`0YOol00`7POomoo`0YOol002aoo`81h2Uoo`03
001oogoo02Moo`81h2aoo`00;Woo0P7P9goo00<007ooOol09Woo00<1h7ooOol0;7oo000`Ool00`7P
Oomoo`0TOol00`00Oomoo`0TOol20N0_Ool0035oo`81h09oo`@0Kaioo`03001oogoo025oo`<1h35o
o`00<goo0P7P1@1_7Goo00<007ooOol07goo0P7P=7oo000cOol206l20N0406lLOol00`00Oomoo`0M
Ool20N0fOol003=oo`@0K`81h080Kaaoo`03001oogoo01]oo`81h3Qoo`00<goo1P1_0P7P77oo00<0
07ooOol06Goo0P7P>Woo000cOol806l30N0IOol00`00Oomoo`0FOol30N0lOol003Aoo`H0K`Aoo`@1
h1Eoo`03001oogoo01=oo`<1h3moo`00=Goo101_2Goo1P7P3goo00<007ooOol03goo107P@Woo0018
Ool30N0<Ool00`00Oomoo`09Ool60N16Ool004]ooaP1h4aoo`00Egoo00<007ooOol0EGoo001GOol0
0`00Oomoo`1EOol005Moo`03001oogoo05Eoo`00Egoo00<007ooOol0EGoo001GOol00`00Oomoo`1E
Ool005Moo`03001oogoo05Eoo`00Egoo00<007ooOol0EGoo001GOol00`00Oomoo`1EOol005Moo`03
001oogoo05Eoo`00Egoo00<007ooOol0EGoo001GOol00`00Oomoo`1EOol005Moo`03001oogoo05Eo
o`00Egoo00<007ooOol0EGoo001GOol00`00Oomoo`1EOol005Moo`03001oogoo05Eoo`00Egoo00<0
07ooOol0EGoo001GOol00`00Oomoo`1EOol005Moo`03001oogoo05Eoo`00Egoo00<007ooOol0EGoo
001GOol00`00Oomoo`1EOol005Moo`03001oogoo05Eoo`00Egoo00<007ooOol0EGoo001GOol00`00
Oomoo`1EOol005Moo`03001oogoo05Eoo`00Egoo00<007ooOol0EGoo001GOol00`00Oomoo`1EOol0
05Moo`03001oogoo05Eoo`00Egoo00<007ooOol0EGoo001GOol00`00Oomoo`1EOol005Moo`03001o
ogoo05Eoo`00Egoo00<007ooOol0EGoo001GOol00`00Oomoo`1EOol005Moo`03001oogoo05Eoo`00
Egoo00<007ooOol0EGoo001GOol00`00Oomoo`1EOol005Moo`03001oogoo05Eoo`00Egoo00<007oo
Ool0EGoo001GOol00`00Oomoo`1EOol005Moo`03001oogoo05Eoo`00Egoo00<007ooOol0EGoo001>
Ool50004Ool00`00Oomoo`1EOol004moo`04001oogoo0004Ool00`00Oomoo`1EOol0051oo`03001o
ogoo00Aoo`8005Ioo`00DGoo00<007ooOol00goo00<007ooOol0EGoo001>Ool01@00Oomoogoo0000
17oo00<007ooOol0EGoo001>Ool01@00Oomoogoo000017oo00<007ooOol0EGoo001?Ool30005Ool0
0`00Oomoo`1EOol005Moo`03001oogoo05Eoo`00Egoo00<007ooOol0EGoo001GOol00`00Oomoo`1E
Ool005Moo`03001oogoo05Eoo`00Egoo00<007ooOol0EGoo001GOol00`00Oomoo`1EOol005Moo`03
001oogoo05Eoo`00Egoo00<007ooOol0EGoo001GOol00`00Oomoo`1EOol005Moo`03001oogoo05Eo
o`00Egoo00<007ooOol0EGoo001GOol00`00Oomoo`1EOol005Moo`03001oogoo05Eoo`00Egoo00<0
07ooOol0EGoo001GOol00`00Oomoo`1EOol005Moo`03001oogoo05Eoo`00Egoo00<007ooOol0EGoo
001GOol00`00Oomoo`1EOol005Moo`03001oogoo05Eoo`00Egoo00<007ooOol0EGoo001GOol00`00
Oomoo`1EOol005Moo`03001oogoo05Eoo`00Egoo00<007ooOol0EGoo001GOol00`00Oomoo`1EOol0
05Moo`03001oogoo05Eoo`00Egoo00<007ooOol0EGoo001GOol00`00Oomoo`1EOol005Moo`03001o
ogoo05Eoo`00Egoo00<007ooOol0EGoo001GOol00`00Oomoo`1EOol005Moo`03001oogoo05Eoo`00
Egoo00<007ooOol0EGoo001GOol00`00Oomoo`1EOol005Moo`03001oogoo05Eoo`00Egoo00<007oo
Ool0EGoo001GOol00`00Oomoo`1EOol005Moo`03001oogoo05Eoo`00Egoo00<007ooOol0EGoo001G
Ool00`00Oomoo`1EOol005Moo`03001oogoo05Eoo`00Egoo00<007ooOol0EGoo001GOol00`00Oomo
o`1EOol005Moo`03001oogoo05Eoo`00Egoo00<007ooOol0EGoo001GOol00`00Oomoo`1EOol005Mo
o`03001oogoo05Eoo`00Egoo00<007ooOol0EGoo001GOol00`00Oomoo`1EOol005Moo`03001oogoo
05Eoo`00Egoo00<007ooOol0EGoo001GOol00`00Oomoo`1EOol005Moo`03001oogoo05Eoo`00Egoo
00<007ooOol0EGoo001GOol00`00Oomoo`1EOol005Moo`03001oogoo05Eoo`00EGoo17`0EWoo001?
Ool30002Ool6O01EOol004ioo`05001oogooOol00008O01DOol0059oo`03001l07`000Il05Aoo`00
D7oo0P0000=oog`0O0001W`0E7oo001BOol00`00O01l0006O01DOol004ioo`06001oogooOol007oo
1W`0EGoo001?Ool30003Ool4O01FOol005Moo`03001oogoo05Eoo`00Egoo00<007ooOol0EGoo001G
Ool00`00Oomoo`1EOol00001\
\>"],
  ImageRangeCache->{{{0, 174}, {285.938, 0}} -> {-1.38188, -1.42892, \
0.0158837, 0.0158837}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["theta2=-theta;", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
p32=ListPlot[{{R Cos[theta2],R Sin[theta2]}},
  AspectRatio->Automatic, 
  Prolog->AbsolutePointSize[6],
  DisplayFunction->Identity,
  PlotStyle->RGBColor[1,0,0]];\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\

p22=PolarPlot[R^(1/M), {t,0,2 Pi},
  DisplayFunction->Identity,
  PlotStyle->RGBColor[0,.5,0]];\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
  
p12=ListPlot[
  Table[{R^(1/M) Cos[(theta2+2 m Pi)/M],
        R^(1/M) Sin[(theta2+2 m Pi)/M]},
        {m,0,M-1}],
  AspectRatio->Automatic,
  Prolog->AbsolutePointSize[8],
  DisplayFunction->Identity,
  PlotStyle->RGBColor[0,.1,.5]];\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
The complex conjugate of the original complex number is in red.  \
Its roots are in blue and are again equidistant on the green circle.\
\>", \
"Subsubsection"],

Cell[CellGroupData[{

Cell["\<\
Show[p12,p22,p32,
  DisplayFunction->$DisplayFunction]\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.63976 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.499998 0.361828 1.12453 0.361828 [
[.13817 1.11203 -6 -9 ]
[.13817 1.11203 6 0 ]
[.31908 1.11203 -12 -9 ]
[.31908 1.11203 12 0 ]
[.68091 1.11203 -9 -9 ]
[.68091 1.11203 9 0 ]
[.86183 1.11203 -3 -9 ]
[.86183 1.11203 3 0 ]
[.4875 .03904 -12 -4.5 ]
[.4875 .03904 0 4.5 ]
[.4875 .40087 -12 -4.5 ]
[.4875 .40087 0 4.5 ]
[.4875 .7627 -12 -4.5 ]
[.4875 .7627 0 4.5 ]
[.4875 1.48635 -6 -4.5 ]
[.4875 1.48635 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1.63976 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.13817 1.12453 m
.13817 1.13078 L
s
[(-1)] .13817 1.11203 0 1 Mshowa
.31908 1.12453 m
.31908 1.13078 L
s
[(-0.5)] .31908 1.11203 0 1 Mshowa
.68091 1.12453 m
.68091 1.13078 L
s
[(0.5)] .68091 1.11203 0 1 Mshowa
.86183 1.12453 m
.86183 1.13078 L
s
[(1)] .86183 1.11203 0 1 Mshowa
.125 Mabswid
.17435 1.12453 m
.17435 1.12828 L
s
.21054 1.12453 m
.21054 1.12828 L
s
.24672 1.12453 m
.24672 1.12828 L
s
.2829 1.12453 m
.2829 1.12828 L
s
.35527 1.12453 m
.35527 1.12828 L
s
.39145 1.12453 m
.39145 1.12828 L
s
.42763 1.12453 m
.42763 1.12828 L
s
.46382 1.12453 m
.46382 1.12828 L
s
.53618 1.12453 m
.53618 1.12828 L
s
.57236 1.12453 m
.57236 1.12828 L
s
.60855 1.12453 m
.60855 1.12828 L
s
.64473 1.12453 m
.64473 1.12828 L
s
.7171 1.12453 m
.7171 1.12828 L
s
.75328 1.12453 m
.75328 1.12828 L
s
.78946 1.12453 m
.78946 1.12828 L
s
.82564 1.12453 m
.82564 1.12828 L
s
.10199 1.12453 m
.10199 1.12828 L
s
.06581 1.12453 m
.06581 1.12828 L
s
.02962 1.12453 m
.02962 1.12828 L
s
.89801 1.12453 m
.89801 1.12828 L
s
.93419 1.12453 m
.93419 1.12828 L
s
.97037 1.12453 m
.97037 1.12828 L
s
.25 Mabswid
0 1.12453 m
1 1.12453 L
s
.5 .03904 m
.50625 .03904 L
s
[(-3)] .4875 .03904 1 0 Mshowa
.5 .40087 m
.50625 .40087 L
s
[(-2)] .4875 .40087 1 0 Mshowa
.5 .7627 m
.50625 .7627 L
s
[(-1)] .4875 .7627 1 0 Mshowa
.5 1.48635 m
.50625 1.48635 L
s
[(1)] .4875 1.48635 1 0 Mshowa
.125 Mabswid
.5 .11141 m
.50375 .11141 L
s
.5 .18377 m
.50375 .18377 L
s
.5 .25614 m
.50375 .25614 L
s
.5 .3285 m
.50375 .3285 L
s
.5 .47324 m
.50375 .47324 L
s
.5 .5456 m
.50375 .5456 L
s
.5 .61797 m
.50375 .61797 L
s
.5 .69033 m
.50375 .69033 L
s
.5 .83506 m
.50375 .83506 L
s
.5 .90743 m
.50375 .90743 L
s
.5 .97979 m
.50375 .97979 L
s
.5 1.05216 m
.50375 1.05216 L
s
.5 1.19689 m
.50375 1.19689 L
s
.5 1.26926 m
.50375 1.26926 L
s
.5 1.34162 m
.50375 1.34162 L
s
.5 1.41399 m
.50375 1.41399 L
s
.5 1.55872 m
.50375 1.55872 L
s
.5 1.63108 m
.50375 1.63108 L
s
.25 Mabswid
.5 0 m
.5 1.63976 L
s
0 0 m
1 0 L
1 1.63976 L
0 1.63976 L
closepath
clip
newpath
0 .1 .5 r
8 Mabswid
.93994 .94229 Mdot
.68223 1.56447 Mdot
.06005 1.30676 Mdot
.31777 .68458 Mdot
0 .5 0 r
.5 Mabswid
.97619 1.12453 m
.97618 1.12822 L
.97614 1.13158 L
.97606 1.13546 L
.97597 1.13912 L
.97572 1.14564 L
.97536 1.15271 L
.97483 1.16049 L
.97414 1.16872 L
.97253 1.18346 L
.97039 1.19861 L
.96795 1.21274 L
.96081 1.24459 L
.95129 1.2765 L
.94065 1.30504 L
.91017 1.36643 L
.87673 1.41578 L
.83352 1.46441 L
.78673 1.50472 L
.73155 1.54063 L
.7028 1.55537 L
.67066 1.56908 L
.64214 1.57901 L
.61017 1.5878 L
.5949 1.59116 L
.57842 1.59422 L
.5641 1.59638 L
.54845 1.59825 L
.53926 1.5991 L
.53074 1.59972 L
.52259 1.60018 L
.51847 1.60036 L
.51392 1.60051 L
.50983 1.60062 L
.50609 1.60068 L
.50197 1.60071 L
.4999 1.60072 L
.49764 1.60071 L
.49381 1.60068 L
.48973 1.60061 L
.48587 1.60051 L
.48236 1.60039 L
.47512 1.60007 L
.46715 1.59958 L
.45109 1.5982 L
.43626 1.59643 L
.42244 1.59436 L
.39155 1.5882 L
.3589 1.57933 L
.32884 1.56889 L
Mistroke
.29695 1.55526 L
.24178 1.52462 L
.19207 1.48776 L
.14489 1.44179 L
.10369 1.38853 L
.07215 1.33358 L
.05955 1.30553 L
.04825 1.27512 L
.03956 1.246 L
.03328 1.21904 L
.02828 1.18962 L
.02631 1.17331 L
.0256 1.1658 L
.02497 1.15783 L
.02454 1.15101 L
.02436 1.14739 L
.02418 1.14349 L
.02406 1.13992 L
.02396 1.13665 L
.02389 1.13352 L
.02384 1.13023 L
.02381 1.12663 L
.02381 1.1228 L
.02384 1.11917 L
.02388 1.11589 L
.02397 1.11202 L
.0241 1.10783 L
.02443 1.10023 L
.02486 1.09281 L
.02546 1.08485 L
.02688 1.07052 L
.02913 1.05355 L
.03171 1.03814 L
.03905 1.00499 L
.04818 .97412 L
.07174 .91631 L
.10012 .86595 L
.13486 .81885 L
.17963 .77222 L
.22702 .73434 L
.28309 .7006 L
.3408 .67573 L
.37094 .66615 L
.38817 .66165 L
.40459 .65799 L
.41978 .65514 L
.43635 .65261 L
.45149 .65081 L
.4655 .64958 L
.47334 .64908 L
Mistroke
.48068 .64872 L
.48489 .64857 L
.48874 .64847 L
.49087 .64842 L
.49319 .64838 L
.49538 .64836 L
.49741 .64834 L
.49954 .64833 L
.50184 .64834 L
.50401 .64835 L
.50601 .64837 L
.5098 .64843 L
.5138 .64853 L
.5181 .64868 L
.52212 .64885 L
.53124 .64936 L
.5394 .64997 L
.54693 .65065 L
.56393 .65264 L
.57886 .65491 L
.59461 .65783 L
.62161 .66412 L
.65091 .67288 L
.70722 .69578 L
.76408 .72827 L
.81405 .76657 L
.86069 .81362 L
.89804 .86313 L
.92672 .91318 L
.94037 .94332 L
.95129 .97256 L
.95954 .99971 L
.9665 1.02892 L
.9707 1.05241 L
.97256 1.06583 L
.97395 1.07843 L
.97494 1.09003 L
.97559 1.10063 L
.97585 1.1065 L
.97596 1.10959 L
.97605 1.11289 L
.97612 1.11606 L
.97616 1.11893 L
.97618 1.12181 L
.97619 1.12452 L
Mfstroke
1 0 0 r
8 Mabswid
.5 .03904 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{175, 286.938},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002_00017Q000`40O003h00OEgoo00<007ooOol0
EGoo001GOol00`00Oomoo`1EOol005Moo`03001oogoo05Eoo`00EGoo17`0EWoo001?Ool30002Ool6
O01EOol004ioo`05001oogooOol00008O01DOol004Qoo`D000Eoo`03001l07`000Il05Aoo`00D7oo
0P0000=oog`0O0001W`0E7oo001BOol00`00O01l0006O01DOol004ioo`06001oogooOol007oo1W`0
EGoo001?Ool30003Ool4O01FOol005Moo`03001oogoo05Eoo`00Egoo00<007ooOol0EGoo001GOol0
0`00Oomoo`1EOol005Moo`03001oogoo05Eoo`00Egoo00<007ooOol0EGoo001GOol00`00Oomoo`1E
Ool005Moo`03001oogoo05Eoo`00Egoo00<007ooOol0EGoo001GOol00`00Oomoo`1EOol005Moo`03
001oogoo05Eoo`00Egoo00<007ooOol0EGoo001GOol00`00Oomoo`1EOol005Moo`03001oogoo05Eo
o`00Egoo00<007ooOol0EGoo001GOol00`00Oomoo`1EOol005Moo`03001oogoo05Eoo`00Egoo00<0
07ooOol0EGoo001GOol00`00Oomoo`1EOol005Moo`03001oogoo05Eoo`00Egoo00<007ooOol0EGoo
001GOol00`00Oomoo`1EOol005Moo`03001oogoo05Eoo`00Egoo00<007ooOol0EGoo001GOol00`00
Oomoo`1EOol005Moo`03001oogoo05Eoo`00Egoo00<007ooOol0EGoo001GOol00`00Oomoo`1EOol0
05Moo`03001oogoo05Eoo`00Egoo00<007ooOol0EGoo001GOol00`00Oomoo`1EOol005Moo`03001o
ogoo05Eoo`00Egoo00<007ooOol0EGoo001GOol00`00Oomoo`1EOol005Moo`03001oogoo05Eoo`00
Egoo00<007ooOol0EGoo001GOol00`00Oomoo`1EOol005Moo`03001oogoo05Eoo`00Egoo00<007oo
Ool0EGoo001GOol00`00Oomoo`1EOol005Moo`03001oogoo05Eoo`00Egoo00<007ooOol0EGoo001G
Ool00`00Oomoo`1EOol005Moo`03001oogoo05Eoo`00Egoo00<007ooOol0EGoo001GOol00`00Oomo
o`1EOol005Moo`03001oogoo05Eoo`00Egoo00<007ooOol0EGoo001GOol00`00Oomoo`1EOol005Mo
o`03001oogoo05Eoo`00Egoo00<007ooOol0EGoo001GOol00`00Oomoo`1EOol005Moo`03001oogoo
05Eoo`00Egoo00<007ooOol0EGoo001GOol00`00Oomoo`1EOol005Moo`03001oogoo05Eoo`00Egoo
00<007ooOol0EGoo001>Ool50004Ool00`00Oomoo`1EOol004moo`04001oogoo0004Ool00`00Oomo
o`1EOol004Qoo`D000=oo`03001oogoo00Aoo`03001oogoo05Eoo`00DGoo00<007ooOol00goo0P00
EWoo001>Ool01@00Oomoogoo000017oo00<007ooOol0EGoo001>Ool01@00Oomoogoo000017oo00<0
07ooOol0EGoo001?Ool30005Ool00`00Oomoo`1EOol005Moo`03001oogoo05Eoo`00Egoo00<007oo
Ool0EGoo001GOol00`00Oomoo`1EOol005Moo`03001oogoo05Eoo`00Egoo00<007ooOol0EGoo001G
Ool00`00Oomoo`1EOol005Moo`03001oogoo05Eoo`00Egoo00<007ooOol0EGoo001GOol00`00Oomo
o`1EOol005Moo`03001oogoo05Eoo`00Egoo00<007ooOol0EGoo001GOol00`00Oomoo`1EOol005Mo
o`03001oogoo05Eoo`00Egoo00<007ooOol0EGoo001GOol00`00Oomoo`1EOol005Moo`03001oogoo
05Eoo`00Egoo00<007ooOol0EGoo001GOol00`00Oomoo`1EOol005Moo`03001oogoo05Eoo`00Egoo
00<007ooOol0EGoo001GOol00`00Oomoo`1EOol005Moo`03001oogoo05Eoo`00Egoo00<007ooOol0
EGoo001GOol00`00Oomoo`1EOol005Moo`03001oogoo05Eoo`00Egoo00<007ooOol0EGoo001GOol0
0`00Oomoo`1EOol005Moo`03001oogoo05Eoo`00Egoo00<007ooOol0EGoo001GOol00`00Oomoo`1E
Ool005Moo`03001oogoo05Eoo`00Egoo00<007ooOol0EGoo001GOol00`00Oomoo`1EOol005Moo`03
001oogoo05Eoo`00Egoo00<007ooOol0EGoo001GOol00`00Oomoo`1EOol005Moo`03001oogoo05Eo
o`00Egoo00<007ooOol0EGoo001GOol00`00Oomoo`1EOol004YooaX1h4]oo`00AGoo1@7P3Goo00<0
07ooOol02Woo1`7PA7oo000eOol406l9Ool30N0BOol00`00Oomoo`0AOol30N11Ool003Aoo`H0K`Ao
o`@1h1Eoo`03001oogoo01Aoo`<1h3ioo`00<goo1`1_107P6Goo00<007ooOol05goo0P7P?7oo000c
Ool506l20N000`1_Oomoo`0JOol00`00Oomoo`0IOol30N0iOol003=oo`<0K`81h0<0Kaaoo`03001o
ogoo01aoo`81h3Moo`00<goo00<0K`7P0N001@1_77oo00<007ooOol07Woo0`7P=7oo000bOol20N06
06lMOol00`00Oomoo`0QOol20N0bOol0031oo`81h0=oo`@0Kaioo`03001oogoo02=oo`030N1oogoo
02moo`00;Woo0P7P9goo00<007ooOol097oo0P7P;goo000]Ool00`7POomoo`0WOol00`00Oomoo`0V
Ool00`7POomoo`0/Ool002]oo`81h2Yoo`03001oogoo02Moo`81h2aoo`00:Goo0P7P;7oo00<007oo
Ool0:Goo00<1h7ooOol0:Goo000XOol00`7POomoo`0/Ool00`00Oomoo`0ZOol20N0YOol002Ioo`81
h2moo`03001oogoo02aoo`030N1oogoo02Ioo`009Goo00<1h7ooOol0;goo00<007ooOol0;Goo0P7P
9Woo000TOol00`7POomoo`0XOol30005Ool00`00Oomoo`0_Ool00`7POomoo`0SOol0029oo`81h2ao
o`03001oogoo00Aoo`03001oogoo031oo`81h2=oo`008Goo00<1h7ooOol097oo1@000goo00<007oo
Ool017oo00<007ooOol0<Woo00<1h7ooOol087oo000POol00`7POomoo`0]Ool00`00Oomoo`04Ool2
000dOol00`7POomoo`0OOol001moo`030N1oogoo02ioo`03001oogoo00Aoo`03001oogoo03Aoo`03
0N1oogoo01ioo`007Woo00<1h7ooOol0;Woo0P001Woo00<007ooOol0=Goo00<1h7ooOol07Goo000M
Ool00`7POomoo`0`Ool00`00Oomoo`04Ool00`00Oomoo`0fOol00`7POomoo`0LOol001aoo`030N1o
ogoo03Qoo`03001oogoo03Moo`030N1oogoo01]oo`006goo00<1h7ooOol0>Goo00<007ooOol0>7oo
00<1h7ooOol06Woo000JOol00`7POomoo`0jOol00`00Oomoo`0iOol00`7POomoo`0IOol001Uoo`03
0N1oogoo03]oo`03001oogoo03Yoo`030N1oogoo01Qoo`0067oo00<1h7ooOol0?7oo00<007ooOol0
>goo00<1h7ooOol05goo000GOol00`7POomoo`0mOol00`00Oomoo`0kOol00`7POomoo`0GOol001Mo
o`030N1oogoo03eoo`03001oogoo03aoo`030N1oogoo01Ioo`005Woo00<1h7ooOol0?Woo00<007oo
Ool0?Goo00<1h7ooOol05Goo000EOol00`7POomoo`0oOol00`00Oomoo`0nOol00`7POomoo`0DOol0
01Eoo`030N1oogoo03moo`03001oogoo03moo`030N1oogoo01=oo`0057oo00<1h7ooOol0@7oo00<0
07ooOol0?goo00<1h7ooOol04goo000COol00`7POomoo`11Ool00`00Oomoo`10Ool00`7POomoo`0B
Ool001=oo`030N1oogoo045oo`03001oogoo045oo`030N1oogoo015oo`004Woo00<1h7ooOol0@Woo
00<007ooOol0@Woo00<1h7ooOol047oo000AOol00`7POomoo`13Ool00`00Oomoo`12Ool00`7POomo
o`0@Ool0015oo`030N1oogoo04=oo`03001oogoo04=oo`030N1oogoo00moo`0047oo00<1h7ooOol0
A7oo00<007ooOol0@goo00<1h7ooOol03goo000?Ool00`7POomoo`15Ool00`00Oomoo`14Ool00`7P
Oomoo`0>Ool000moo`030N1oogoo04Eoo`03001oogoo04Eoo`030N1oogoo00eoo`003Woo00<1h7oo
Ool0AWoo00<007ooOol0AGoo00<1h7ooOol03Goo000>Ool00`7POomoo`16Ool00`00Oomoo`16Ool0
0`7POomoo`0<Ool000eoo`030N1oogoo04Moo`03001oogoo04Ioo`030N1oogoo00aoo`0037oo00<1
h7ooOol0B7oo00<007ooOol0Agoo00<1h7ooOol02goo000<Ool00`7POomoo`18Ool00`00Oomoo`17
Ool00`7P06l0K`0206l9Ool000]oo`030N1oogoo04Uoo`03001oogoo04Moo`0306l1h01_00<0K`Qo
o`002goo00<1h7ooOol0BGoo00<007ooOol0AWoo0P1_00<1h01_06l00`1_1goo000;Ool00`7POomo
o`19Ool00`00Oomoo`16Ool206l00`7P06l0K`0306l7Ool000Yoo`030N1oogoo04Yoo`03001oogoo
04Ioo`<0K`030N00K`1_0080K`Moo`002Woo00<1h7ooOol0BWoo00<007ooOol0AWoo0`1_00<1h01_
06l00P1_1goo0009Ool00`7POomoo`1;Ool00`00Oomoo`17Ool306l00`7P06l0K`08Ool000Uoo`03
0N1oogoo04]oo`03001oogoo04Qoo`80K`030N00Kgoo00Qoo`002Goo00<1h7ooOol0Bgoo00<007oo
Ool0BWoo00<1h7ooOol027oo0008Ool00`7POomoo`1<Ool00`00Oomoo`1;Ool00`7POomoo`07Ool0
00Qoo`030N1oogoo04aoo`03001oogoo04]oo`030N1oogoo00Moo`001goo00<1h7ooOol0CGoo00<0
07ooOol0Bgoo00<1h7ooOol01goo0007Ool00`7POomoo`1=Ool00`00Oomoo`1<Ool00`7POomoo`06
Ool000Moo`030N1oogoo04eoo`03001oogoo04aoo`030N1oogoo00Ioo`001Woo00<1h7ooOol0CWoo
00<007ooOol0C7oo00<1h7ooOol01Woo0006Ool00`7POomoo`1>Ool00`00Oomoo`1<Ool00`7POomo
o`06Ool000Ioo`030N1oogoo04ioo`03001oogoo04eoo`030N1oogoo00Eoo`001Woo00<1h7ooOol0
CWoo00<007ooOol0CGoo00<1h7ooOol01Goo0006Ool00`7POomoo`1>Ool00`00Oomoo`1=Ool00`7P
Oomoo`05Ool000Eoo`030N1oogoo04moo`03001oogoo04ioo`030N1oogoo00Aoo`001Goo00<1h7oo
Ool0Cgoo00<007ooOol0CWoo00<1h7ooOol017oo0005Ool00`7POomoo`1?Ool00`00Oomoo`1>Ool0
0`7POomoo`04Ool000Eoo`030N1oogoo04moo`03001oogoo04ioo`030N1oogoo00Aoo`001Goo00<1
h7ooOol0Cgoo00<007ooOol0CWoo00<1h7ooOol017oo0005Ool00`7POomoo`1?Ool00`00Oomoo`1>
Ool00`7POomoo`04Ool000Aoo`030N1oogoo019oo`<001Moo`8000Aoo`03001oogoo009oo`<001Io
o`03001oogoo01Eoo`8000Aoo`03001oogoo009oo`<001Ioo`<001=oo`030N1oogoo00=oo`0017oo
00<1h7ooOol04goo00<007ooOol05Goo00@007ooOol000Moo`05001oogooOol0000EOol00`00Oomo
o`0DOol01000Oomoo`001goo00D007ooOomoo`0001Ioo`03001oogoo019oo`030N1oogoo00=oo`00
17oo00<1h7ooOol02goo1@000goo00<007ooOol03Woo1@000Woo00@007ooOol000]oo`03001oogoo
01=oo`03001oogoo01Aoo`04001oogoo000;Ool00`00Oomoo`0DOol00`00Oomoo`0BOol00`7POomo
o`03Ool000Aoo`030N1oogoo01=oo`03001oogoo01Eoo`04001oogoo000;Ool00`00Oomoo`0COol0
0`00Oomoo`0DOol01000Oomoo`002goo00<007ooOol057oo00<007ooOol04Woo00<1h7ooOol00goo
0004Ool00`7POomoo`0COol00`00Oomoo`0EOol01000Oomoo`001goo10005Woo00<007ooOol057oo
00@007ooOol000Moo`@001Moo`03001oogoo019oo`030N1oogoo00=oo`0017oo00<1h7ooOol04Woo
0P005goo00@007ooOol000Moo`03001oogoo01Moo`03001oogoo01Aoo`04001oogoo0007Ool00`00
Oomoo`0GOol2000DOol00`7POomoo`03Ool000Aoo`030N1oogoo01=oo`03001oogoo01Ioo`8000Qo
o`D001Eoo`03001oogoo01Eoo`8000Qoo`D001Ioo`03001oogoo019oo`030N1oogoo00=oo`0017oo
00<1h7ooOol0D7oo00<007ooOol0Cgoo00<1h7ooOol00goo0004Ool00`7POomoo`1@Ool00`00Oomo
o`1?Ool00`7POomoo`03Ool000Aoo`030N1oogoo051oo`03001oogoo04moo`030N1oogoo00=oo`00
17oo00<1h7ooOol0D7oo00<007ooOol0Cgoo00<1h7ooOol00goo000400000`7P0000002R00000`7P
00000003000000Aoo`030N1oogoo015oo`03001oogoo01aoo`03001oogoo01eoo`03001oogoo01ao
o`03001oogoo01aoo`03001oogoo015oo`030N1oogoo00=oo`0017oo00<1h7ooOol0D7oo00<007oo
Ool0Cgoo00<1h7ooOol00goo0004Ool00`7POomoo`1@Ool00`00Oomoo`1?Ool00`7POomoo`03Ool0
00Aoo`030N1oogoo051oo`03001oogoo04moo`030N1oogoo00=oo`0017oo00<1h7ooOol0D7oo00<0
07ooOol0Cgoo00<1h7ooOol00goo0004Ool00`7POomoo`1@Ool00`00Oomoo`1?Ool00`7POomoo`03
Ool000Aoo`030N1oogoo051oo`03001oogoo04moo`030N1oogoo00=oo`0017oo00<1h7ooOol0D7oo
00<007ooOol0Cgoo00<1h7ooOol00goo0004Ool00`7POomoo`1@Ool00`00Oomoo`1?Ool00`7POomo
o`03Ool000Aoo`030N1oogoo051oo`03001oogoo04moo`030N1oogoo00=oo`0017oo00<1h7ooOol0
D7oo00<007ooOol0Cgoo00<1h7ooOol00goo0004Ool00`7POomoo`1@Ool00`00Oomoo`1>Ool00`7P
Oomoo`04Ool000Aoo`030N1oogoo051oo`03001oogoo04ioo`030N1oogoo00Aoo`001Goo00<1h7oo
Ool0Cgoo00<007ooOol0CWoo00<1h7ooOol017oo0005Ool00`7POomoo`1?Ool00`00Oomoo`1>Ool0
0`7POomoo`04Ool000Eoo`030N1oogoo04moo`03001oogoo04ioo`030N1oogoo00Aoo`001Goo00<1
h7ooOol0Cgoo00<007ooOol0CWoo00<1h7ooOol017oo0005Ool00`7POomoo`1?Ool00`00Oomoo`1=
Ool00`7POomoo`05Ool000Ioo`030N1oogoo04ioo`03001oogoo04eoo`030N1oogoo00Eoo`001Woo
00<1h7ooOol0CWoo00<007ooOol0CGoo00<1h7ooOol01Goo0006Ool00`7POomoo`1>Ool00`00Oomo
o`1=Ool00`7POomoo`05Ool000Ioo`030N1oogoo04ioo`03001oogoo04aoo`030N1oogoo00Ioo`00
1goo00<1h7ooOol0CGoo00<007ooOol0C7oo00<1h7ooOol01Woo0007Ool00`7POomoo`1=Ool00`00
Oomoo`1<Ool00`7POomoo`06Ool000Moo`030N1oogoo04eoo`03001oogoo04]oo`030N1oogoo00Mo
o`0027oo00<1h7ooOol0C7oo00<007ooOol0Bgoo00<1h7ooOol01goo0008Ool00`7POomoo`1<Ool0
0`00Oomoo`1;Ool00`7POomoo`07Ool000Qoo`0406l1h01_06m;Ool00`00Oomoo`1:Ool00`7POomo
o`08Ool000Moo`80K`040N00K`1_06m:Ool00`00Oomoo`1:Ool00`7POomoo`08Ool000Ioo`<0K`03
0N00K`1_0080KdUoo`03001oogoo04Yoo`030N1oogoo00Qoo`001Woo101_00@1h01_06l0KdUoo`03
001oogoo04Uoo`030N1oogoo00Uoo`001Woo101_00@1h01_06l0KdUoo`03001oogoo04Uoo`030N1o
ogoo00Uoo`001Woo1@1_00<1h01_06l0BGoo00<007ooOol0B7oo00<1h7ooOol02Woo0007Ool406l0
0`7P06moo`19Ool00`00Oomoo`18Ool00`7POomoo`0:Ool000Qoo`<0K`030N1oogoo04Uoo`03001o
ogoo04Moo`030N1oogoo00]oo`0037oo00<1h7ooOol0B7oo00<007ooOol0Agoo00<1h7ooOol02goo
000<Ool00`7POomoo`18Ool00`00Oomoo`16Ool00`7POomoo`0<Ool000eoo`030N1oogoo04Moo`03
001oogoo04Ioo`030N1oogoo00aoo`003Woo00<1h7ooOol0AWoo00<007ooOol0AWoo00<1h7ooOol0
37oo000>Ool00`7POomoo`16Ool00`00Oomoo`15Ool00`7POomoo`0=Ool000moo`030N1oogoo04Eo
o`03001oogoo04Eoo`030N1oogoo00eoo`0047oo00<1h7ooOol0A7oo00<007ooOol0A7oo00<1h7oo
Ool03Woo000@Ool00`7POomoo`14Ool00`00Oomoo`14Ool00`7POomoo`0>Ool0015oo`030N1oogoo
04=oo`03001oogoo04=oo`030N1oogoo00moo`004Woo00<1h7ooOol0@Woo00<007ooOol0@Woo00<1
h7ooOol047oo000BOol00`7POomoo`12Ool00`00Oomoo`11Ool00`7POomoo`0AOol001=oo`030N1o
ogoo045oo`03001oogoo045oo`030N1oogoo015oo`0057oo00<1h7ooOol0@7oo00<007ooOol0@7oo
00<1h7ooOol04Woo000DOol00`7POomoo`10Ool00`00Oomoo`0oOol00`7POomoo`0COol001Eoo`03
0N1oogoo03moo`03001oogoo03ioo`030N1oogoo01Aoo`005Woo00<1h7ooOol0?Woo00<007ooOol0
?Woo00<1h7ooOol057oo000GOol00`7POomoo`0mOol00`00Oomoo`0mOol00`7POomoo`0EOol001Mo
o`030N1oogoo03eoo`03001oogoo03aoo`030N1oogoo01Ioo`0067oo00<1h7ooOol0?7oo00<007oo
Ool0>goo00<1h7ooOol05goo000IOol00`7POomoo`0kOol00`00Oomoo`0jOol00`7POomoo`0HOol0
01Yoo`030N1oogoo03Yoo`03001oogoo03Yoo`030N1oogoo01Qoo`006goo00<1h7ooOol0>Goo00<0
07ooOol0>Goo00<1h7ooOol06Goo000LOol00`7POomoo`0hOol00`00Oomoo`0hOol00`7POomoo`0J
Ool001eoo`030N1oogoo03Moo`03001oogoo03Ioo`81h1eoo`007Woo00<1h7ooOol0;Woo0`001Goo
00<007ooOol0=Goo00<1h7ooOol07Goo000OOol00`7POomoo`0^Ool00`00Oomoo`04Ool00`00Oomo
o`0dOol00`7POomoo`0NOol0021oo`030N1oogoo02eoo`03001oogoo00Aoo`8003=oo`81h25oo`00
8Goo0P7P;Goo00<007ooOol017oo00<007ooOol0<Goo00<1h7ooOol08Goo000SOol00`7POomoo`0Z
Ool00`00Oomoo`04Ool00`00Oomoo`0`Ool00`7POomoo`0ROol002Aoo`81h2Uoo`8000Ioo`03001o
ogoo02moo`030N1oogoo02=oo`009Woo00<1h7ooOol09goo00<007ooOol017oo00<007ooOol0;Goo
0P7P9Woo000WOol20N0^Ool00`00Oomoo`0/Ool00`7POomoo`0VOol002Uoo`030N1oogoo02]oo`03
001oogoo02Yoo`81h2Uoo`00:Woo0P7P:goo00<007ooOol0:Goo00<1h7ooOol0:Goo000/Ool20N0Y
Ool00`00Oomoo`0WOol20N0/Ool002ioo`81h2Moo`03001oogoo02Ioo`030N1oogoo02aoo`00<7oo
00<1h7ooOol097oo00<007ooOol097oo0P7P;goo000aOol20N0TOol00`00Oomoo`0KOol406l3Ool2
0N0aOol003=oo`81h29oo`03001oogoo01Yoo`H0K`03Ool1h7oo039oo`00=Goo0P7P87oo00<007oo
Ool06Goo1P1_0P7P=7oo000gOol20N0NOol00`00Oomoo`0IOol306l30N0206ldOol003Uoo`81h1ao
o`03001oogoo01Uoo`<1h0D0KcAoo`00>goo0`7P6Goo00<007ooOol05Woo0`7P201_=7oo000nOol4
0N0EOol00`00Oomoo`0COol30N04Ool606leOol0049oo`H1h0moo`03001oogoo00moo`@1h0Qoo`@0
KcIoo`00B7oo0`7P37oo00<007ooOol02Goo1P7PAWoo001;OolH0N1<Ool005Moo`03001oogoo05Eo
o`00Egoo00<007ooOol0EGoo001GOol00`00Oomoo`1EOol005Moo`03001oogoo05Eoo`00Egoo00<0
07ooOol0EGoo001GOol00`00Oomoo`1EOol005Moo`03001oogoo05Eoo`00\
\>"],
  ImageRangeCache->{{{0, 174}, {285.938, 0}} -> {-1.38188, -3.11285, \
0.0158837, 0.0158837}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["\<\
Here we see both the complex number and its conjugate and all their \
roots.\
\>", "Subsubsection"],

Cell[CellGroupData[{

Cell["\<\
Show[p12,p22,p32,p1,p2,p3,
  DisplayFunction->$DisplayFunction]\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 2.27951 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.499998 0.361828 1.13976 0.361828 [
[.13817 1.12726 -6 -9 ]
[.13817 1.12726 6 0 ]
[.31908 1.12726 -12 -9 ]
[.31908 1.12726 12 0 ]
[.68091 1.12726 -9 -9 ]
[.68091 1.12726 9 0 ]
[.86183 1.12726 -3 -9 ]
[.86183 1.12726 3 0 ]
[.4875 .05427 -12 -4.5 ]
[.4875 .05427 0 4.5 ]
[.4875 .4161 -12 -4.5 ]
[.4875 .4161 0 4.5 ]
[.4875 .77793 -12 -4.5 ]
[.4875 .77793 0 4.5 ]
[.4875 1.50158 -6 -4.5 ]
[.4875 1.50158 0 4.5 ]
[.4875 1.86341 -6 -4.5 ]
[.4875 1.86341 0 4.5 ]
[.4875 2.22524 -6 -4.5 ]
[.4875 2.22524 0 4.5 ]
[ 0 0 0 0 ]
[ 1 2.27951 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.13817 1.13976 m
.13817 1.14601 L
s
[(-1)] .13817 1.12726 0 1 Mshowa
.31908 1.13976 m
.31908 1.14601 L
s
[(-0.5)] .31908 1.12726 0 1 Mshowa
.68091 1.13976 m
.68091 1.14601 L
s
[(0.5)] .68091 1.12726 0 1 Mshowa
.86183 1.13976 m
.86183 1.14601 L
s
[(1)] .86183 1.12726 0 1 Mshowa
.125 Mabswid
.17435 1.13976 m
.17435 1.14351 L
s
.21054 1.13976 m
.21054 1.14351 L
s
.24672 1.13976 m
.24672 1.14351 L
s
.2829 1.13976 m
.2829 1.14351 L
s
.35527 1.13976 m
.35527 1.14351 L
s
.39145 1.13976 m
.39145 1.14351 L
s
.42763 1.13976 m
.42763 1.14351 L
s
.46382 1.13976 m
.46382 1.14351 L
s
.53618 1.13976 m
.53618 1.14351 L
s
.57236 1.13976 m
.57236 1.14351 L
s
.60855 1.13976 m
.60855 1.14351 L
s
.64473 1.13976 m
.64473 1.14351 L
s
.7171 1.13976 m
.7171 1.14351 L
s
.75328 1.13976 m
.75328 1.14351 L
s
.78946 1.13976 m
.78946 1.14351 L
s
.82564 1.13976 m
.82564 1.14351 L
s
.10199 1.13976 m
.10199 1.14351 L
s
.06581 1.13976 m
.06581 1.14351 L
s
.02962 1.13976 m
.02962 1.14351 L
s
.89801 1.13976 m
.89801 1.14351 L
s
.93419 1.13976 m
.93419 1.14351 L
s
.97037 1.13976 m
.97037 1.14351 L
s
.25 Mabswid
0 1.13976 m
1 1.13976 L
s
.5 .05427 m
.50625 .05427 L
s
[(-3)] .4875 .05427 1 0 Mshowa
.5 .4161 m
.50625 .4161 L
s
[(-2)] .4875 .4161 1 0 Mshowa
.5 .77793 m
.50625 .77793 L
s
[(-1)] .4875 .77793 1 0 Mshowa
.5 1.50158 m
.50625 1.50158 L
s
[(1)] .4875 1.50158 1 0 Mshowa
.5 1.86341 m
.50625 1.86341 L
s
[(2)] .4875 1.86341 1 0 Mshowa
.5 2.22524 m
.50625 2.22524 L
s
[(3)] .4875 2.22524 1 0 Mshowa
.125 Mabswid
.5 .12664 m
.50375 .12664 L
s
.5 .19901 m
.50375 .19901 L
s
.5 .27137 m
.50375 .27137 L
s
.5 .34374 m
.50375 .34374 L
s
.5 .48847 m
.50375 .48847 L
s
.5 .56083 m
.50375 .56083 L
s
.5 .6332 m
.50375 .6332 L
s
.5 .70556 m
.50375 .70556 L
s
.5 .8503 m
.50375 .8503 L
s
.5 .92266 m
.50375 .92266 L
s
.5 .99503 m
.50375 .99503 L
s
.5 1.06739 m
.50375 1.06739 L
s
.5 1.21212 m
.50375 1.21212 L
s
.5 1.28449 m
.50375 1.28449 L
s
.5 1.35685 m
.50375 1.35685 L
s
.5 1.42922 m
.50375 1.42922 L
s
.5 1.57395 m
.50375 1.57395 L
s
.5 1.64632 m
.50375 1.64632 L
s
.5 1.71868 m
.50375 1.71868 L
s
.5 1.79105 m
.50375 1.79105 L
s
.5 1.93578 m
.50375 1.93578 L
s
.5 2.00814 m
.50375 2.00814 L
s
.5 2.08051 m
.50375 2.08051 L
s
.5 2.15287 m
.50375 2.15287 L
s
.25 Mabswid
.5 0 m
.5 2.27951 L
s
0 0 m
1 0 L
1 2.27951 L
0 2.27951 L
closepath
clip
newpath
0 .1 .5 r
8 Mabswid
.93994 .95753 Mdot
.68223 1.5797 Mdot
.06005 1.32199 Mdot
.31777 .69981 Mdot
0 .5 0 r
.5 Mabswid
.97619 1.13976 m
.97618 1.14345 L
.97614 1.14681 L
.97606 1.15069 L
.97597 1.15435 L
.97572 1.16087 L
.97536 1.16794 L
.97483 1.17572 L
.97414 1.18395 L
.97253 1.19869 L
.97039 1.21385 L
.96795 1.22797 L
.96081 1.25982 L
.95129 1.29173 L
.94065 1.32028 L
.91017 1.38167 L
.87673 1.43101 L
.83352 1.47964 L
.78673 1.51995 L
.73155 1.55586 L
.7028 1.5706 L
.67066 1.58432 L
.64214 1.59424 L
.61017 1.60303 L
.5949 1.6064 L
.57842 1.60945 L
.5641 1.61162 L
.54845 1.61348 L
.53926 1.61433 L
.53074 1.61496 L
.52259 1.61541 L
.51847 1.61559 L
.51392 1.61575 L
.50983 1.61585 L
.50609 1.61591 L
.50197 1.61595 L
.4999 1.61595 L
.49764 1.61594 L
.49381 1.61591 L
.48973 1.61584 L
.48587 1.61574 L
.48236 1.61562 L
.47512 1.6153 L
.46715 1.61482 L
.45109 1.61343 L
.43626 1.61166 L
.42244 1.60959 L
.39155 1.60344 L
.3589 1.59457 L
.32884 1.58413 L
Mistroke
.29695 1.57049 L
.24178 1.53986 L
.19207 1.50299 L
.14489 1.45702 L
.10369 1.40376 L
.07215 1.34881 L
.05955 1.32076 L
.04825 1.29035 L
.03956 1.26123 L
.03328 1.23428 L
.02828 1.20485 L
.02631 1.18854 L
.0256 1.18104 L
.02497 1.17306 L
.02454 1.16625 L
.02436 1.16262 L
.02418 1.15872 L
.02406 1.15515 L
.02396 1.15188 L
.02389 1.14875 L
.02384 1.14546 L
.02381 1.14187 L
.02381 1.13803 L
.02384 1.13441 L
.02388 1.13112 L
.02397 1.12725 L
.0241 1.12306 L
.02443 1.11546 L
.02486 1.10804 L
.02546 1.10008 L
.02688 1.08575 L
.02913 1.06878 L
.03171 1.05337 L
.03905 1.02022 L
.04818 .98936 L
.07174 .93155 L
.10012 .88119 L
.13486 .83409 L
.17963 .78745 L
.22702 .74958 L
.28309 .71583 L
.3408 .69096 L
.37094 .68139 L
.38817 .67688 L
.40459 .67322 L
.41978 .67037 L
.43635 .66784 L
.45149 .66604 L
.4655 .66482 L
.47334 .66431 L
Mistroke
.48068 .66396 L
.48489 .6638 L
.48874 .6637 L
.49087 .66365 L
.49319 .66361 L
.49538 .66359 L
.49741 .66357 L
.49954 .66357 L
.50184 .66357 L
.50401 .66358 L
.50601 .6636 L
.5098 .66367 L
.5138 .66377 L
.5181 .66391 L
.52212 .66408 L
.53124 .66459 L
.5394 .6652 L
.54693 .66588 L
.56393 .66788 L
.57886 .67014 L
.59461 .67306 L
.62161 .67936 L
.65091 .68811 L
.70722 .71102 L
.76408 .7435 L
.81405 .7818 L
.86069 .82885 L
.89804 .87837 L
.92672 .92841 L
.94037 .95855 L
.95129 .9878 L
.95954 1.01495 L
.9665 1.04416 L
.9707 1.06764 L
.97256 1.08107 L
.97395 1.09367 L
.97494 1.10526 L
.97559 1.11586 L
.97585 1.12173 L
.97596 1.12483 L
.97605 1.12812 L
.97612 1.13129 L
.97616 1.13416 L
.97618 1.13704 L
.97619 1.13976 L
Mfstroke
1 0 0 r
8 Mabswid
.5 .05427 Mdot
0 .1 .5 r
.93994 1.32199 Mdot
.31777 1.5797 Mdot
.06005 .95753 Mdot
.68223 .69981 Mdot
0 .5 0 r
.5 Mabswid
.97619 1.13976 m
.97618 1.14345 L
.97614 1.14681 L
.97606 1.15069 L
.97597 1.15435 L
.97572 1.16087 L
.97536 1.16794 L
.97483 1.17572 L
.97414 1.18395 L
.97253 1.19869 L
.97039 1.21385 L
.96795 1.22797 L
.96081 1.25982 L
.95129 1.29173 L
.94065 1.32028 L
.91017 1.38167 L
.87673 1.43101 L
.83352 1.47964 L
.78673 1.51995 L
.73155 1.55586 L
.7028 1.5706 L
.67066 1.58432 L
.64214 1.59424 L
.61017 1.60303 L
.5949 1.6064 L
.57842 1.60945 L
.5641 1.61162 L
.54845 1.61348 L
.53926 1.61433 L
.53074 1.61496 L
.52259 1.61541 L
.51847 1.61559 L
.51392 1.61575 L
.50983 1.61585 L
.50609 1.61591 L
.50197 1.61595 L
.4999 1.61595 L
.49764 1.61594 L
.49381 1.61591 L
.48973 1.61584 L
.48587 1.61574 L
.48236 1.61562 L
.47512 1.6153 L
.46715 1.61482 L
.45109 1.61343 L
.43626 1.61166 L
.42244 1.60959 L
.39155 1.60344 L
.3589 1.59457 L
.32884 1.58413 L
Mistroke
.29695 1.57049 L
.24178 1.53986 L
.19207 1.50299 L
.14489 1.45702 L
.10369 1.40376 L
.07215 1.34881 L
.05955 1.32076 L
.04825 1.29035 L
.03956 1.26123 L
.03328 1.23428 L
.02828 1.20485 L
.02631 1.18854 L
.0256 1.18104 L
.02497 1.17306 L
.02454 1.16625 L
.02436 1.16262 L
.02418 1.15872 L
.02406 1.15515 L
.02396 1.15188 L
.02389 1.14875 L
.02384 1.14546 L
.02381 1.14187 L
.02381 1.13803 L
.02384 1.13441 L
.02388 1.13112 L
.02397 1.12725 L
.0241 1.12306 L
.02443 1.11546 L
.02486 1.10804 L
.02546 1.10008 L
.02688 1.08575 L
.02913 1.06878 L
.03171 1.05337 L
.03905 1.02022 L
.04818 .98936 L
.07174 .93155 L
.10012 .88119 L
.13486 .83409 L
.17963 .78745 L
.22702 .74958 L
.28309 .71583 L
.3408 .69096 L
.37094 .68139 L
.38817 .67688 L
.40459 .67322 L
.41978 .67037 L
.43635 .66784 L
.45149 .66604 L
.4655 .66482 L
.47334 .66431 L
Mistroke
.48068 .66396 L
.48489 .6638 L
.48874 .6637 L
.49087 .66365 L
.49319 .66361 L
.49538 .66359 L
.49741 .66357 L
.49954 .66357 L
.50184 .66357 L
.50401 .66358 L
.50601 .6636 L
.5098 .66367 L
.5138 .66377 L
.5181 .66391 L
.52212 .66408 L
.53124 .66459 L
.5394 .6652 L
.54693 .66588 L
.56393 .66788 L
.57886 .67014 L
.59461 .67306 L
.62161 .67936 L
.65091 .68811 L
.70722 .71102 L
.76408 .7435 L
.81405 .7818 L
.86069 .82885 L
.89804 .87837 L
.92672 .92841 L
.94037 .95855 L
.95129 .9878 L
.95954 1.01495 L
.9665 1.04416 L
.9707 1.06764 L
.97256 1.08107 L
.97395 1.09367 L
.97494 1.10526 L
.97559 1.11586 L
.97585 1.12173 L
.97596 1.12483 L
.97605 1.12812 L
.97612 1.13129 L
.97616 1.13416 L
.97618 1.13704 L
.97619 1.13976 L
Mfstroke
1 0 0 r
8 Mabswid
.5 2.22524 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{125, 284.938},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40001m000171000`40O003h00O?Woo00<007ooOol0
?7oo000nOol00`00Oomoo`0lOol003ioo`03001oogoo03aoo`00?7oo17`0?Goo000gOol300000goo
O01l0004O00lOol003Ioo`04001oogooOol8O00kOol0031oo`D000Eoo`Ql03]oo`00>7oo0P0027`0
>goo000jOol8O00kOol003Ioo`05001oogooOol00006O00lOol003Moo`<0009oo`Al03eoo`00?Woo
00<007ooOol0?7oo000nOol00`00Oomoo`0lOol003ioo`03001oogoo03aoo`00?Woo00<007ooOol0
?7oo000nOol00`00Oomoo`0lOol003ioo`03001oogoo03aoo`00?Woo00<007ooOol0?7oo000nOol0
0`00Oomoo`0lOol003ioo`03001oogoo03aoo`00?Woo00<007ooOol0?7oo000nOol00`00Oomoo`0l
Ool003ioo`03001oogoo03aoo`00?Woo00<007ooOol0?7oo000nOol00`00Oomoo`0lOol003ioo`03
001oogoo03aoo`00?Woo00<007ooOol0?7oo000nOol00`00Oomoo`0lOol003ioo`03001oogoo03ao
o`00?Woo00<007ooOol0?7oo000nOol00`00Oomoo`0lOol003ioo`03001oogoo03aoo`00?Woo00<0
07ooOol0?7oo000nOol00`00Oomoo`0lOol003ioo`03001oogoo03aoo`00?Woo00<007ooOol0?7oo
000nOol00`00Oomoo`0lOol003ioo`03001oogoo03aoo`00?Woo00<007ooOol0?7oo000nOol00`00
Oomoo`0lOol003ioo`03001oogoo03aoo`00?Woo00<007ooOol0?7oo000nOol00`00Oomoo`0lOol0
03ioo`03001oogoo03aoo`00?Woo00<007ooOol0?7oo000nOol00`00Oomoo`0lOol003ioo`03001o
ogoo03aoo`00?Woo00<007ooOol0?7oo000nOol00`00Oomoo`0lOol003Ioo`D000=oo`03001oogoo
03aoo`00=goo00@007ooOol000=oo`03001oogoo03aoo`00<7oo1@000goo00<007ooOol00goo00<0
07ooOol0?7oo000iOol00`00Oomoo`02Ool00`00Oomoo`0lOol003Ioo`05001oogooOol00003Ool0
0`00Oomoo`0lOol003Ioo`05001oogooOol00003Ool00`00Oomoo`0lOol003Moo`<000Aoo`03001o
ogoo03aoo`00?Woo00<007ooOol0?7oo000nOol00`00Oomoo`0lOol003ioo`03001oogoo03aoo`00
?Woo00<007ooOol0?7oo000nOol00`00Oomoo`0lOol003ioo`03001oogoo03aoo`00?Woo00<007oo
Ool0?7oo000nOol00`00Oomoo`0lOol003ioo`03001oogoo03aoo`00?Woo00<007ooOol0?7oo000n
Ool00`00Oomoo`0lOol003ioo`03001oogoo03aoo`00?Woo00<007ooOol0?7oo000nOol00`00Oomo
o`0lOol003ioo`03001oogoo03aoo`00?Woo00<007ooOol0?7oo000nOol00`00Oomoo`0lOol003io
o`03001oogoo03aoo`00?Woo00<007ooOol0?7oo000nOol00`00Oomoo`0lOol003ioo`03001oogoo
03aoo`00?Woo00<007ooOol0?7oo000nOol00`00Oomoo`0lOol003ioo`03001oogoo03aoo`00?Woo
00<007ooOol0?7oo000nOol00`00Oomoo`0lOol003aoo`@1h3eoo`009Goo101_2Woo2P7P00=oo`00
0N002@7P2Woo101_9Woo000TOol606l5Ool40N0;Ool00`00Oomoo`08Ool60N03Ool606lUOol002=o
o`P0K`04Ool1h07P0N0?Ool00`00Oomoo`0>Ool00`7POol0K`0706lTOol002=oo`H0K`<1h19oo`03
001oogoo00moo`<1h0H0KbAoo`008goo0`1_0`7P0P1_4goo00<007ooOol047oo0P1_0`7P0`1_97oo
000SOol00`1_0N01h00506lCOol00`00Oomoo`0@Ool506l30N0TOol0029oo`81h0H0KaAoo`03001o
ogoo015oo`H0K`03Ool1h07P029oo`0087oo0P7P0goo101_5Goo00<007ooOol04Woo101_17oo00<1
h7ooOol07goo000OOol00`7POomoo`0LOol00`00Oomoo`0KOol20N0OOol001eoo`81h1moo`03001o
ogoo01eoo`81h1eoo`006goo0P7P8Goo00<007ooOol07goo00<1h7ooOol06Woo000JOol00`7POomo
o`0JOol30004Ool00`00Oomoo`0POol00`7POomoo`0IOol001Uoo`030N1oogoo01aoo`03001oogoo
00=oo`03001oogoo025oo`030N1oogoo01Qoo`0067oo00<1h7ooOol05Goo1@000goo00<007ooOol0
0goo00<007ooOol08Woo00<1h7ooOol05goo000GOol00`7POomoo`0NOol00`00Oomoo`03Ool00`00
Oomoo`0SOol00`7POomoo`0FOol001Ioo`030N1oogoo01moo`03001oogoo00=oo`03001oogoo02Ao
o`030N1oogoo01Eoo`005Goo00<1h7ooOol07goo0P001Goo00<007ooOol09Goo00<1h7ooOol057oo
000DOol00`7POomoo`0QOol00`00Oomoo`03Ool00`00Oomoo`0VOol00`7POomoo`0COol001=oo`03
0N1oogoo02Qoo`03001oogoo02Moo`030N1oogoo019oo`004Woo00<1h7ooOol0:Goo00<007ooOol0
:7oo00<1h7ooOol04Goo000AOol00`7POomoo`0ZOol00`00Oomoo`0YOol00`7POomoo`0@Ool0011o
o`030N1oogoo02]oo`03001oogoo02Uoo`030N1oogoo011oo`0047oo00<1h7ooOol0:goo00<007oo
Ool0:Woo00<1h7ooOol03goo000?Ool00`7POomoo`0/Ool00`00Oomoo`0[Ool00`7POomoo`0>Ool0
00ioo`030N1oogoo02eoo`03001oogoo02aoo`030N1oogoo00eoo`003Goo00<1h7ooOol0;Woo00<0
07ooOol0;Goo00<1h7ooOol037oo000<Ool00`7POomoo`0_Ool00`00Oomoo`0^Ool00`7POomoo`0;
Ool000aoo`030N1oogoo02moo`03001oogoo02ioo`030N1oogoo00]oo`002goo00<1h7ooOol0<7oo
00<007ooOol0;goo00<1h7ooOol02Woo000;Ool00`7POomoo`0`Ool00`00Oomoo`0_Ool00`7POomo
o`0:Ool000Yoo`030N1oogoo035oo`03001oogoo031oo`030N1oogoo00Uoo`002Goo00<1h7ooOol0
<Woo00<007ooOol0<7oo00<1h7ooOol02Goo0005Ool406l00`7POomoo`0bOol00`00Oomoo`0aOol0
0`7P06l0K`0206l6Ool000Aoo`@0K`030N00Kgoo03=oo`03001oogoo035oo`030N00K`1_00<0K`Eo
o`000goo1@1_00<1h01_06l0<goo00<007ooOol0<7oo0P1_00<1h01_06l00`1_17oo0003Ool406l0
107P06l0K`1_<goo00<007ooOol0<7oo0P1_00<1h01_06l00`1_17oo0003Ool406l0107P06l0K`1_
<goo00<007ooOol0<7oo0`1_00<1h01_06l00P1_17oo0003Ool306l00`7P06l0K`0206lcOol00`00
Oomoo`0`Ool306l00`7P06l0K`0206l4Ool000Aoo`80K`040N00K`1_06ldOol00`00Oomoo`0aOol2
06l0107P06l0K`1_1Goo0005Ool0101_0N00K`1_=Goo00<007ooOol0<Woo0P1_00<1h01_Ool01Goo
0005Ool00`7POomoo`0fOol00`00Oomoo`0dOol00`7POomoo`05Ool000Eoo`030N1oogoo03Ioo`03
001oogoo03Aoo`030N1oogoo00Eoo`001Goo00<1h7ooOol0=Woo00<007ooOol0=Goo00<1h7ooOol0
17oo0004Ool00`7POomoo`0gOol00`00Oomoo`0eOol00`7POomoo`04Ool000Aoo`030N1oogoo03Mo
o`03001oogoo03Eoo`030N1oogoo00Aoo`0017oo00<1h7ooOol0=goo00<007ooOol0=Goo00<1h7oo
Ool017oo0004Ool00`7POomoo`0gOol00`00Oomoo`0fOol00`7POomoo`03Ool000=oo`030N1oogoo
03Qoo`03001oogoo03Ioo`030N1oogoo00=oo`000goo00<1h7ooOol0>7oo00<007ooOol0=Woo00<1
h7ooOol00goo0003Ool00`7POomoo`0<Ool3000>Ool20004Ool00`00Oomoo`02Ool3000=Ool00`00
Oomoo`0<Ool20004Ool00`00Oomoo`02Ool3000=Ool3000=Ool00`7POomoo`02Ool000=oo`030N1o
ogoo00eoo`03001oogoo00aoo`04001oogoo0007Ool01@00Oomoogoo000037oo00<007ooOol02goo
00@007ooOol000Moo`05001oogooOol0000=Ool00`00Oomoo`0<Ool00`7POomoo`02Ool000=oo`03
0N1oogoo00Eoo`D000=oo`03001oogoo00Eoo`D0009oo`04001oogoo000;Ool00`00Oomoo`0:Ool0
0`00Oomoo`0;Ool01000Oomoo`002goo00<007ooOol02goo00<007ooOol037oo00<1h7ooOol00Woo
0003Ool00`7POomoo`0=Ool00`00Oomoo`0<Ool01000Oomoo`002goo00<007ooOol02Woo00<007oo
Ool02goo00@007ooOol000]oo`03001oogoo00]oo`03001oogoo00aoo`030N1oogoo009oo`000goo
00<1h7ooOol03Goo00<007ooOol037oo00@007ooOol000Moo`@000eoo`03001oogoo00]oo`04001o
ogoo0007Ool4000>Ool00`00Oomoo`0<Ool00`7POomoo`02Ool000=oo`030N1oogoo00aoo`8000io
o`04001oogoo0007Ool00`00Oomoo`0>Ool00`00Oomoo`0;Ool01000Oomoo`001goo00<007ooOol0
3Woo0P003Woo00<1h7ooOol00Woo0003Ool00`7POomoo`0=Ool00`00Oomoo`0=Ool20008Ool5000<
Ool00`00Oomoo`0<Ool20008Ool5000=Ool00`00Oomoo`0<Ool00`7POomoo`02Ool0009oo`81h3Yo
o`03001oogoo03Moo`81h0=oo`000Woo00<1h7ooOol0>Goo00<007ooOol0>7oo00<1h7ooOol00Goo
0002Ool00`7POomoo`0iOol00`00Oomoo`0hOol00`7POomoo`01Ool0008000030N00000007@00003
0N000000004000000Woo00<1h7ooOol0>Goo00<007ooOol0>7oo00<1h7ooOol00Goo0003Ool00`7P
Oomoo`0hOol00`00Oomoo`0gOol00`7POomoo`02Ool000=oo`030N1oogoo03Qoo`03001oogoo03Mo
o`030N1oogoo009oo`000goo00<1h7ooOol0>7oo00<007ooOol0=goo00<1h7ooOol00Woo0003Ool0
0`7POomoo`0hOol00`00Oomoo`0gOol00`7POomoo`02Ool000=oo`030N1oogoo03Qoo`03001oogoo
03Moo`030N1oogoo009oo`000goo00<1h7ooOol0>7oo00<007ooOol0=goo00<1h7ooOol00Woo0003
Ool00`7POomoo`0hOol00`00Oomoo`0gOol00`7POomoo`02Ool000=oo`030N1oogoo03Qoo`03001o
ogoo03Moo`030N1oogoo009oo`0017oo00<1h7ooOol0=goo00<007ooOol0=goo00<1h7ooOol00Woo
0004Ool00`7POomoo`0gOol00`00Oomoo`0gOol00`7POomoo`02Ool000Aoo`030N1oogoo03Moo`03
001oogoo03Moo`030N1oogoo009oo`0017oo00<1h7ooOol0=goo00<007ooOol0=Woo00<1h7ooOol0
0goo0004Ool00`7POomoo`0gOol00`00Oomoo`0fOol00`7POomoo`03Ool000Aoo`030N1oogoo03Mo
o`03001oogoo03Ioo`030N1oogoo00=oo`0017oo00<1h7ooOol0=goo00<007ooOol0=Goo00<1h7oo
Ool017oo0005Ool00`7POomoo`0fOol00`00Oomoo`0eOol00`7POomoo`04Ool000Eoo`030N1oogoo
03Ioo`03001oogoo03Aoo`030N1oogoo00Eoo`001Goo00@1h01_06l0KcEoo`03001oogoo039oo`80
K`030N00Kgoo00Eoo`0017oo0P1_00@1h01_06l0KcAoo`03001oogoo035oo`<0K`030N00K`1_00Eo
o`000goo0`1_00<1h01_06l00P1_<goo00<007ooOol0<7oo0`1_00<1h01_06l00P1_17oo0003Ool4
06l0107P06l0K`1_<goo00<007ooOol0<7oo0`1_00<1h01_06l00P1_17oo0003Ool406l0107P06l0
K`1_<goo00<007ooOol0<7oo0`1_00<1h01_06l00P1_17oo0003Ool506l00`7P06l0K`0cOol00`00
Oomoo`0`Ool206l00`7P06l0K`0306l4Ool000Aoo`@0K`030N00Kgoo03=oo`03001oogoo035oo`03
06l1h01_00<0K`Eoo`001Goo0`1_00<1h7ooOol0<goo00<007ooOol0<Goo00<1h01_06l00P1_1Woo
0009Ool00`7POomoo`0bOol00`00Oomoo`0aOol00`7POomoo`08Ool000Uoo`030N1oogoo039oo`03
001oogoo031oo`030N1oogoo00Uoo`002Woo00<1h7ooOol0<Goo00<007ooOol0<7oo00<1h7ooOol0
2Goo000;Ool00`7POomoo`0`Ool00`00Oomoo`0_Ool00`7POomoo`0:Ool000]oo`030N1oogoo031o
o`03001oogoo02moo`030N1oogoo00Yoo`0037oo00<1h7ooOol0;goo00<007ooOol0;Woo00<1h7oo
Ool02goo000<Ool00`7POomoo`0_Ool00`00Oomoo`0]Ool00`7POomoo`0<Ool000eoo`030N1oogoo
02ioo`03001oogoo02eoo`030N1oogoo00aoo`003Woo00<1h7ooOol0;Goo00<007ooOol0;7oo00<1
h7ooOol03Goo000?Ool00`7POomoo`0/Ool00`00Oomoo`0[Ool00`7POomoo`0>Ool000moo`030N1o
ogoo02aoo`03001oogoo02]oo`030N1oogoo00ioo`0047oo00<1h7ooOol0:goo00<007ooOol0:Woo
00<1h7ooOol03goo000AOol00`7POomoo`0ZOol00`00Oomoo`0YOol00`7POomoo`0@Ool0019oo`03
0N1oogoo02Uoo`03001oogoo02Qoo`030N1oogoo015oo`004goo00<1h7ooOol0:7oo00<007ooOol0
9goo00<1h7ooOol04Woo000DOol00`7POomoo`0POol30004Ool00`00Oomoo`0UOol20N0EOol001Eo
o`030N1oogoo021oo`03001oogoo00=oo`03001oogoo02Aoo`030N1oogoo01Eoo`005Woo00<1h7oo
Ool07goo00<007ooOol00goo00<007ooOol08goo00<1h7ooOol05Woo000GOol20N0OOol00`00Oomo
o`03Ool00`00Oomoo`0ROol00`7POomoo`0GOol001Uoo`030N1oogoo01aoo`03001oogoo00=oo`03
001oogoo025oo`030N1oogoo01Qoo`006Woo0P7P6goo0P001Goo00<007ooOol07goo0P7P6goo000L
Ool00`7POomoo`0IOol00`00Oomoo`03Ool00`00Oomoo`0MOol20N0MOol001eoo`81h1moo`03001o
ogoo01aoo`030N1oogoo01eoo`007goo0P7P7Goo00<007ooOol06Woo0P7P87oo000QOol0107POomo
ogoo101_5Goo00<007ooOol04Woo101_0Woo0P7P8Woo000ROol20N0606lDOol00`00Oomoo`0AOol6
06l00`7POomoo`0ROol002=oo`0306l1h07P00D0Ka=oo`03001oogoo011oo`D0K`81h00306moogoo
029oo`008goo0`1_0P7P0`1_4goo00<007ooOol047oo0`1_0P7P0`1_97oo000SOol506l30N0COol0
0`00Oomoo`0@Ool30N0506lTOol002=oo`P0K`@1h0moo`03001oogoo00aoo`@1h0P0KbAoo`0097oo
1P1_1Goo107P2goo00<007ooOol01goo1@7P1Goo1P1_9Goo000UOol406l:Ool80N03Ool00`00Oomo
o`070N0;Ool406lVOol003]oo`H1h3aoo`00?Woo00<007ooOol0?7oo000nOol00`00Oomoo`0lOol0
03ioo`03001oogoo03aoo`00?Woo00<007ooOol0?7oo000nOol00`00Oomoo`0lOol003ioo`03001o
ogoo03aoo`00?Woo00<007ooOol0?7oo000nOol00`00Oomoo`0lOol003ioo`03001oogoo03aoo`00
?Woo00<007ooOol0?7oo000nOol00`00Oomoo`0lOol003ioo`03001oogoo03aoo`00?Woo00<007oo
Ool0?7oo000nOol00`00Oomoo`0lOol003ioo`03001oogoo03aoo`00?Woo00<007ooOol0?7oo000n
Ool00`00Oomoo`0lOol003ioo`03001oogoo03aoo`00?Woo00<007ooOol0?7oo000nOol00`00Oomo
o`0lOol003ioo`03001oogoo03aoo`00?Woo00<007ooOol0?7oo000nOol00`00Oomoo`0lOol003io
o`03001oogoo03aoo`00?Woo00<007ooOol0?7oo000nOol00`00Oomoo`0lOol003ioo`03001oogoo
03aoo`00=Woo1@000goo00<007ooOol0?7oo000gOol01000Oomoo`000goo00<007ooOol0?7oo000h
Ool00`00Oomoo`03Ool00`00Oomoo`0lOol003Uoo`03001oogoo009oo`03001oogoo03aoo`00=Woo
00D007ooOomoo`0000=oo`03001oogoo03aoo`00=Woo00D007ooOomoo`0000=oo`03001oogoo03ao
o`00=goo0`0017oo00<007ooOol0?7oo000nOol00`00Oomoo`0lOol003ioo`03001oogoo03aoo`00
?Woo00<007ooOol0?7oo000nOol00`00Oomoo`0lOol003ioo`03001oogoo03aoo`00?Woo00<007oo
Ool0?7oo000nOol00`00Oomoo`0lOol003ioo`03001oogoo03aoo`00?Woo00<007ooOol0?7oo000n
Ool00`00Oomoo`0lOol003ioo`03001oogoo03aoo`00?Woo00<007ooOol0?7oo000nOol00`00Oomo
o`0lOol003ioo`03001oogoo03aoo`00?Woo00<007ooOol0?7oo000nOol00`00Oomoo`0lOol003io
o`03001oogoo03aoo`00?Woo00<007ooOol0?7oo000nOol00`00Oomoo`0lOol003ioo`03001oogoo
03aoo`00?Woo00<007ooOol0?7oo000nOol00`00Oomoo`0lOol003ioo`03001oogoo03aoo`00?Woo
00<007ooOol0?7oo000nOol00`00Oomoo`0lOol003ioo`03001oogoo03aoo`00?Woo00<007ooOol0
?7oo000nOol00`00Oomoo`0lOol003ioo`03001oogoo03aoo`00?Woo00<007ooOol0?7oo000nOol0
0`00Oomoo`0lOol003ioo`03001oogoo03aoo`00?Woo00<007ooOol0?7oo000nOol00`00Oomoo`0l
Ool003ioo`03001oogoo03aoo`00?Woo00<007ooOol0?7oo000nOol00`00Oomoo`0lOol003aoo`Al
03eoo`00=goo0`0000=oog`0O00017`0?7oo000fOol01000Oomoogoo27`0>goo000jOol8O00kOol0
03Qoo`8000Ql03]oo`00>Woo27`0>goo000fOol01@00Oomoogoo00001W`0?7oo000gOol30002Ool4
O00mOol003ioo`03001oogoo03aoo`00?Woo00<007ooOol0?7oo000nOol00`00Oomoo`0lOol00001
\
\>"],
  ImageRangeCache->{{{0, 124}, {283.938, 0}} -> {-1.38188, -3.16428, \
0.0222885, 0.0222885}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 832}, {0, 604}},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{520, 482},
WindowMargins->{{17, Automatic}, {Automatic, 41}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
MacintoshSystemPageSetup->"\<\
00<0001804P000000]P2:?oQon82n@960dL5:0?l0080001804P000000]P2:001
0000I00000400`<300000BL?00400@0000000000000006P801T1T00000000000
00000000000000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 40, 0, 98, "Title"],
Cell[1760, 51, 54, 0, 61, "Subtitle"],
Cell[1817, 53, 148, 5, 42, "Subsubsection"],
Cell[1968, 60, 70, 1, 27, "Input"],
Cell[2041, 63, 172, 5, 62, "Text"],
Cell[2216, 70, 108, 3, 42, "Subsubsection"],
Cell[2327, 75, 180, 5, 30, "Text"],
Cell[2510, 82, 112, 6, 73, "Input"],
Cell[2625, 90, 219, 7, 87, "Input"],
Cell[2847, 99, 153, 6, 72, "Input"],
Cell[3003, 107, 293, 11, 147, "Input"],
Cell[3299, 120, 137, 3, 58, "Subsubsection"],

Cell[CellGroupData[{
Cell[3461, 127, 109, 4, 42, "Input"],
Cell[3573, 133, 18266, 540, 295, 5364, 376, "GraphicsData", "PostScript", \
"Graphics"],
Cell[21842, 675, 130, 3, 26, "Output"]
}, Open  ]],
Cell[21987, 681, 64, 1, 27, "Input"],
Cell[22054, 684, 222, 7, 87, "Input"],
Cell[22279, 693, 154, 6, 72, "Input"],
Cell[22436, 701, 296, 11, 147, "Input"],
Cell[22735, 714, 170, 4, 58, "Subsubsection"],

Cell[CellGroupData[{
Cell[22930, 722, 112, 4, 42, "Input"],
Cell[23045, 728, 18466, 540, 295, 5528, 376, "GraphicsData", "PostScript", \
"Graphics"],
Cell[41514, 1270, 130, 3, 26, "Output"]
}, Open  ]],
Cell[41659, 1276, 109, 3, 42, "Subsubsection"],

Cell[CellGroupData[{
Cell[41793, 1283, 121, 4, 42, "Input"],
Cell[41917, 1289, 20248, 714, 293, 8504, 564, "GraphicsData", "PostScript", \
"Graphics"],
Cell[62168, 2005, 130, 3, 26, "Output"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

