(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    141259,       4727]
NotebookOptionsPosition[    128250,       4354]
NotebookOutlinePosition[    128666,       4372]
CellTagsIndexPosition[    128623,       4369]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Consider", " ", "the", " ", "one"}], "-", 
   RowBox[{
   "parameter", " ", "family", " ", "of", " ", "DE", " ", "systems", " ", 
    RowBox[{"x", "'"}]}]}], "=", 
  RowBox[{
   RowBox[{"A", ".", "x"}], " ", "where", " ", "A", " ", "is", " ", 
   RowBox[{
    RowBox[{"(", GridBox[{
       {"0", 
        RowBox[{"-", "5"}]},
       {"1", "\[Alpha]"}
      }], ")"}], ".", "  ", "Find"}], " ", "critical", " ", 
   RowBox[{"values", ".", "  ", "Describe"}], " ", 
   RowBox[{"behaviors", "."}]}]}]], "Subsubtitle"],

Cell[CellGroupData[{

Cell["Initial set up", "Section",
 CellFrame->{{0, 0}, {0, 2}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"A", "[", "\[Alpha]_", "]"}], ":=", 
  RowBox[{"(", GridBox[{
     {"0", 
      RowBox[{"-", "5"}]},
     {"1", "\[Alpha]"}
    }], ")"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"Eigensystem", "[", 
  RowBox[{"A", "[", "\[Alpha]", "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Solve", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"-", "20"}], "+", 
     SuperscriptBox["\[Alpha]", "2"]}], "\[Equal]", "0"}], ",", "\[Alpha]"}], 
  "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"N", "[", "%", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "20"}], "+", 
    SuperscriptBox["\[Alpha]", "2"]}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Alpha]", ",", 
     RowBox[{"-", "10"}], ",", "10"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{3.435203633671875*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["one real root", "Section",
 CellFrame->{{0, 0}, {0, 2}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"case", 
    RowBox[{"(", "1", ")"}]}], ":", 
   RowBox[{
    RowBox[{"-", "20"}], "+", 
    SuperscriptBox["\[Alpha]", "2"]}]}], "=", "0."}], "\n", 
 RowBox[{
  RowBox[{"\[Alpha]", "=", 
   RowBox[{
    RowBox[{"-", "2"}], 
    SqrtBox["5"]}]}], ",", 
  RowBox[{"2", " ", 
   RowBox[{
    SqrtBox["5"], ".", "For"}], " ", "each", " ", "of", " ", "these", " ", 
   "values", " ", "of", " ", "\[Alpha]"}], ",", 
  RowBox[{
  "the", " ", "resulting", " ", "system", " ", "of", " ", "DEs", " ", "has", 
   " ", "one", " ", "eigenvalue", " ", "that", " ", "is", " ", 
   RowBox[{"repeated", ".", "Since"}], " ", "A", " ", "is", " ", "not", " ", 
   "Hermitian", " ", "for", " ", "any", " ", "\[Alpha]"}], ",", 
  RowBox[{
  "we", " ", "are", " ", "not", " ", "guaranteed", " ", "a", " ", "full", " ",
    "set", " ", "of", " ", "linearly", " ", "independent", " ", 
   RowBox[{"eigenvectors", ".", "This"}], " ", "case", " ", "occurs", " ", 
   "at", " ", "isolated", " ", 
   RowBox[{"points", ".", "Therefore"}]}], ",", 
  RowBox[{
  "behavior", " ", "on", " ", "either", " ", "side", " ", "of", " ", "these", 
   " ", "points", " ", "will", " ", "determine", " ", "whether", " ", "or", 
   " ", "not", " ", "these", " ", "are", " ", "critical", " ", 
   RowBox[{"points", ".", "The"}], " ", "analysis", " ", "of", " ", 
   "behavior", " ", "is", " ", "given", " ", "in", " ", "the", " ", "but", 
   " ", "would", " ", "skip", " ", "it", " ", "if", " ", "we", " ", "were", 
   " ", "only", " ", "interested", " ", "in", " ", "the", " ", "critical", 
   " ", 
   RowBox[{"values", "."}]}]}]}], "Text",
 TextAlignment->Left],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  RowBox[{"\[Alpha]", "=", 
   RowBox[{
    RowBox[{"-", "2"}], 
    SqrtBox["5"]}]}]],
  TextAlignment->Left],
 " gory detail"
}], "Subsection",
 CellFrame->{{0, 0}, {0, 0.5}}],

Cell[CellGroupData[{

Cell["solution from the eigenmethod", "Subsubsection"],

Cell[BoxData[{
 RowBox[{"Clear", "[", "\[Alpha]", "]"}], "\[IndentingNewLine]", 
 RowBox[{"\[Alpha]", "=", 
  RowBox[{
   RowBox[{"-", "2"}], 
   SqrtBox["5"]}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"A", "[", "\[Alpha]", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Eigensystem", "[", 
  RowBox[{"A", "[", "\[Alpha]", "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
  "The", " ", "only", " ", "solution", " ", "to", " ", "the", " ", "DE", " ", 
   "from", " ", "this", " ", "method", " ", "is", "   ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", " ", 
      SqrtBox["5"]}], " ", "t"}]], 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      SqrtBox["5"], ",", "1"}], "}"}], ".", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", "To"}], " ", "find", " ", "a", " ", "second"}], 
  ",", 
  RowBox[{"linearly", " ", "independent", " ", "solution"}], ",", 
  RowBox[{
  "we", " ", "use", " ", "the", " ", "generalized", " ", "eigenvector", " ", 
   RowBox[{"method", "."}]}]}]], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["solution from the generalized eigenmethod", "Subsubsection"],

Cell[BoxData[
 RowBox[{"Solve", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"A", "[", "\[Alpha]", "]"}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"-", 
          SqrtBox["5"]}], ")"}], " ", 
        RowBox[{"IdentityMatrix", "[", "2", "]"}]}]}], ")"}], ".", 
     RowBox[{"{", 
      RowBox[{"\[Eta]1", ",", "\[Eta]2"}], "}"}]}], "==", 
    RowBox[{"{", 
     RowBox[{
      SqrtBox["5"], ",", "1"}], "}"}]}], ",", "\[Eta]1"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1", "+", 
      RowBox[{
       SqrtBox["5"], " ", "\[Eta]2"}]}], ",", "\[Eta]2"}], "}"}], " ", "=", 
   " ", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "0"}], "}"}], " ", "+", " ", 
    RowBox[{"\[Eta]2", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        SqrtBox["5"], ",", "1"}], "}"}], ".", "\[IndentingNewLine]", 
      "WLOG"}]}]}]}], ",", " ", 
  RowBox[{
  "let", " ", "the", " ", "generalized", " ", "eigenvector", " ", "be", " ", 
   RowBox[{"{", 
    RowBox[{"1", ",", "0"}], "}"}]}], ",", " ", 
  RowBox[{
   RowBox[{
   "which", " ", "is", " ", "the", " ", "part", " ", "of", " ", "the", " ", 
    "above", " ", "which", " ", "is", " ", "linearly", " ", "independent", 
    " ", "from", " ", "the", " ", 
    RowBox[{"eigenvector", ".", "\[IndentingNewLine]", "The"}], " ", "second",
     " ", "solution", " ", "is", "       ", "t", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", " ", 
       SqrtBox["5"]}], " ", "t"}]], 
    RowBox[{"{", 
     RowBox[{
      SqrtBox["5"], ",", "1"}], "}"}]}], " ", "+", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", " ", 
       SqrtBox["5"]}], " ", "t"}]], 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "0"}], "}"}], " ", ".", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", "One"}], " ", "may", " ", "check", " ", "linear", 
    " ", "independence", " ", "of", " ", "these", " ", 
    RowBox[{"solutions", ".", "  ", "Write"}], " ", "the", " ", "solutions", "  ",
     "as", " ", "columns", " ", "of", " ", "a", " ", 
    RowBox[{"matrix", ".", " ", "The"}], " ", "determinant", " ", "is", " ", 
    "not", " ", 
    RowBox[{"zero", ".", "  ", "This"}], " ", "is", " ", "a", " ", 
    "fundamental", " ", 
    RowBox[{"matrix", "."}]}]}]}]], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["a fundamental matrix", "Subsubsection"],

Cell[BoxData[
 RowBox[{"MatrixForm", "[", 
  RowBox[{"Transpose", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", " ", 
         SqrtBox["5"]}], " ", "t"}]], 
      RowBox[{"{", 
       RowBox[{
        SqrtBox["5"], ",", "1"}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"t", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", " ", 
          SqrtBox["5"]}], " ", "t"}]], 
       RowBox[{"{", 
        RowBox[{
         SqrtBox["5"], ",", "1"}], "}"}]}], " ", "+", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", " ", 
          SqrtBox["5"]}], " ", "t"}]], 
       RowBox[{"{", 
        RowBox[{"1", ",", "0"}], "}"}]}]}]}], " ", "}"}], "]"}], 
  "]"}]], "Input"],

Cell[BoxData[{
 RowBox[{"Clear", "[", "\[CapitalPsi]", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[CapitalPsi]", "[", "t_", "]"}], ":=", 
  TagBox[
   RowBox[{"(", "\[NoBreak]", GridBox[{
      {
       RowBox[{
        SqrtBox["5"], " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", 
           SqrtBox["5"]}], " ", "t"}]]}], 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", 
           SqrtBox["5"]}], " ", "t"}]], "+", 
        RowBox[{
         SqrtBox["5"], " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", 
            SqrtBox["5"]}], " ", "t"}]], " ", "t"}]}]},
      {
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", 
          SqrtBox["5"]}], " ", "t"}]], 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", 
           SqrtBox["5"]}], " ", "t"}]], " ", "t"}]}
     }], "\[NoBreak]", ")"}],
   MatrixForm[#]& ]}]}], "Input"],

Cell[BoxData[
 RowBox[{"Det", "[", 
  RowBox[{"\[CapitalPsi]", "[", "t", "]"}], "]"}]], "Input"],

Cell["Note that a fundamental matrix also solves the DE.", "Text",
 FontFamily->"Courier"],

Cell[BoxData[
 RowBox[{"D", "[", 
  RowBox[{
   RowBox[{"\[CapitalPsi]", "[", "t", "]"}], ",", "t"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"A", "[", "\[Alpha]", "]"}], ".", 
  RowBox[{"\[CapitalPsi]", "[", "t", "]"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["general solution, behavior", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{
  "The", " ", "general", " ", "solution", " ", "is", "      ", "c1", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", " ", 
      SqrtBox["5"]}], " ", "t"}]], 
   RowBox[{"{", 
    RowBox[{
     SqrtBox["5"], ",", "1"}], "}"}]}], " ", "+", " ", 
  RowBox[{"c2", 
   RowBox[{
    RowBox[{"(", "  ", 
     RowBox[{
      RowBox[{"t", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", " ", 
          SqrtBox["5"]}], " ", "t"}]], 
       RowBox[{"{", 
        RowBox[{
         SqrtBox["5"], ",", "1"}], "}"}]}], " ", "+", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", " ", 
          SqrtBox["5"]}], " ", "t"}]], 
       RowBox[{"{", 
        RowBox[{"1", ",", "0"}], "}"}]}]}], ")"}], " ", "."}]}]}]], "Text"],

Cell[BoxData[
 RowBox[{"Expand", "[", " ", 
  RowBox[{
   RowBox[{"c1", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", " ", 
       SqrtBox["5"]}], " ", "t"}]], 
    RowBox[{"{", 
     RowBox[{
      SqrtBox["5"], ",", "1"}], "}"}]}], " ", "+", " ", 
   RowBox[{"c2", " ", 
    RowBox[{"(", " ", 
     RowBox[{
      RowBox[{"t", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", " ", 
          SqrtBox["5"]}], " ", "t"}]], 
       RowBox[{"{", 
        RowBox[{
         SqrtBox["5"], ",", "1"}], "}"}]}], " ", "+", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", " ", 
          SqrtBox["5"]}], " ", "t"}]], 
       RowBox[{"{", 
        RowBox[{"1", ",", "0"}], "}"}]}]}], ")"}]}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Limit", "[", 
  RowBox[{"%", ",", 
   RowBox[{"t", "\[Rule]", " ", "\[Infinity]"}]}], "]"}]], "Input"],

Cell["components of x[t] and y[t]", "Text"],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", 
        SqrtBox["5"]}], " ", "t"}]], ",", " ", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", 
         SqrtBox["5"]}], " ", "t"}]], " ", "t"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "4"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<t\>\"", ",", "\"\<components\>\""}], "}"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{3.435203664828125*^9}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
   "Note", " ", "that", " ", "for", " ", "both", " ", "of", " ", "these", " ",
     "solutions"}], ",", " ", 
   RowBox[{"for", " ", "any", " ", "c1", " ", "and", " ", "c2"}], ",", "  ", 
   RowBox[{
   "all", " ", "functions", " ", "that", " ", "make", " ", "up", " ", "both", 
    " ", 
    RowBox[{"x", "[", "t", "]"}], " ", "and", " ", 
    RowBox[{"y", "[", "t", "]"}], " ", "tend", " ", "to", " ", "zero", " ", 
    "as", " ", "t", " ", 
    RowBox[{"increases", ".", "  ", "Thus"}]}], ",", 
   RowBox[{
    RowBox[{"in", " ", "the", " ", "x"}], "-", 
    RowBox[{"y", " ", "plane"}]}], ",", " ", 
   RowBox[{
   "all", " ", "trajectories", " ", "tend", " ", "to", " ", "the", " ", 
    "origin"}], ",", " ", 
   RowBox[{"regardless", " ", "of", " ", "initial", " ", 
    RowBox[{"conditions", ".", "  ", "The"}], " ", "origin", " ", "is", " ", 
    "a", " ", "stable", " ", "node", " ", "for", " ", "this", " ", "value", 
    " ", "of", " ", 
    RowBox[{
    "\[Alpha]", ".", "  ", "\[IndentingNewLine]", "\[IndentingNewLine]", 
     "The"}], " ", "node", " ", "is", " ", "improper", " ", "since", " ", 
    "the", " ", "single", " ", "eigenvalue", " ", "did", " ", "not", " ", 
    "yield", " ", "a", " ", "full", " ", "set", " ", "of", " ", "linearly", 
    " ", "independent", " ", 
    RowBox[{"eigenvectors", ".", "\[IndentingNewLine]"}]}]}]}]], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{
      SqrtBox["5"], " ", "c1", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", 
         SqrtBox["5"]}], " ", "t"}]]}], "+", 
     RowBox[{"c2", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", 
         SqrtBox["5"]}], " ", "t"}]]}], "+", 
     RowBox[{
      SqrtBox["5"], " ", "c2", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", 
         SqrtBox["5"]}], " ", "t"}]], " ", "t"}]}], ",", 
    RowBox[{
     RowBox[{"c1", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", 
         SqrtBox["5"]}], " ", "t"}]]}], "+", 
     RowBox[{"c2", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", 
         SqrtBox["5"]}], " ", "t"}]], " ", "t"}]}]}], "}"}], "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"c1", "\[Rule]", "1"}], ",", 
    RowBox[{"c2", "\[Rule]", "1"}]}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", 
        SqrtBox["5"]}], " ", "t"}]], "+", 
     RowBox[{
      SqrtBox["5"], " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", 
         SqrtBox["5"]}], " ", "t"}]]}], "+", 
     RowBox[{
      SqrtBox["5"], " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", 
         SqrtBox["5"]}], " ", "t"}]], " ", "t"}]}], ",", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", 
        SqrtBox["5"]}], " ", "t"}]], "+", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", 
         SqrtBox["5"]}], " ", "t"}]], " ", "t"}]}]}], "}"}], "/.", 
  RowBox[{"t", "\[Rule]", "0"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"N", "[", "%", "]"}]], "Input"],

Cell[TextData[{
 "Note that this trajectory begins at ",
 Cell[BoxData[
  RowBox[{"(", 
   RowBox[{
    RowBox[{"1", "+", 
     SqrtBox["5"]}], ",", "1"}], ")"}]]],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{"ParametricPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", 
         SqrtBox["5"]}], " ", "t"}]], "+", 
      RowBox[{
       SqrtBox["5"], " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", 
          SqrtBox["5"]}], " ", "t"}]]}], "+", 
      RowBox[{
       SqrtBox["5"], " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", 
          SqrtBox["5"]}], " ", "t"}]], " ", "t"}]}], ",", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", 
         SqrtBox["5"]}], " ", "t"}]], "+", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", 
          SqrtBox["5"]}], " ", "t"}]], " ", "t"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "4"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"x", "[", "t", "]"}], ",", 
      RowBox[{"y", "[", "t", "]"}]}], "}"}]}], ",", 
   RowBox[{
   "PlotLabel", "\[Rule]", "\"\<phase plane for one trajectory\>\""}]}], 
  "]"}]], "Input",
 CellChangeTimes->{3.43520367759375*^9}],

Cell["This trajectory tends toward the origin.", "Text"],

Cell["phase plane for one trajectory", "Text"],

Cell[BoxData[
 RowBox[{"ParametricPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", 
         SqrtBox["5"]}], " ", "t"}]], "+", 
      RowBox[{
       SqrtBox["5"], " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", 
          SqrtBox["5"]}], " ", "t"}]]}], "+", 
      RowBox[{
       SqrtBox["5"], " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", 
          SqrtBox["5"]}], " ", "t"}]], " ", "t"}]}], ",", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", 
         SqrtBox["5"]}], " ", "t"}]], "+", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", 
          SqrtBox["5"]}], " ", "t"}]], " ", "t"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "10"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<x[t]\>\"", ",", "\"\<y[t]\>\""}], "}"}]}]}], "]"}]], "Input",\

 CellChangeTimes->{3.435203683609375*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"fcnlist", "=", 
   RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{"AppendTo", "[", 
    RowBox[{"fcnlist", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         SqrtBox["5"], " ", "c1", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", 
            SqrtBox["5"]}], " ", "t"}]]}], "+", 
        RowBox[{"c2", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", 
            SqrtBox["5"]}], " ", "t"}]]}], "+", 
        RowBox[{
         SqrtBox["5"], " ", "c2", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", 
            SqrtBox["5"]}], " ", "t"}]], " ", "t"}]}], ",", 
       RowBox[{
        RowBox[{"c1", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", 
            SqrtBox["5"]}], " ", "t"}]]}], "+", 
        RowBox[{"c2", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", 
            SqrtBox["5"]}], " ", "t"}]], " ", "t"}]}]}], "}"}]}], "]"}], ",", 
   
   RowBox[{"{", 
    RowBox[{"c1", ",", 
     RowBox[{"-", "2"}], ",", "2", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"c2", ",", 
     RowBox[{"-", "2"}], ",", "2", ",", "2"}], "}"}]}], 
  "]"}], "\[IndentingNewLine]", "fcnlist"}], "Input"],

Cell["phase plane for several trajectories", "Text"],

Cell[BoxData[{
 RowBox[{"Clear", "[", "p5", "]"}], "\[IndentingNewLine]", 
 RowBox[{"p5", "=", 
  RowBox[{"ParametricPlot", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", "fcnlist", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "10"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<x[t]\>\"", ",", "\"\<y[t]\>\""}], "}"}]}]}], 
   "]"}]}]}], "Input",
 CellChangeTimes->{3.43520369325*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["direction field", "Subsubsection"],

Cell["\<\
Load the Graphics`PlotField` package BEFORE trying to generate the direction \
field.Load the package once perMathematicasession.If you change \
anything,generate the direction field again.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"<<", "Graphics`PlotField`"}]], "Input",
 ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Remember that we obtain the coordinates of the direction field from \
{x'[t],y'[t]},which is given by the matrix product A.{x[t],y[t]}.To avoid \
confusing the {x,y} used here with ones plotted elsewhere,we'll call these \
{x1,y1}.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"A", "[", "\[Alpha]", "]"}], ".", 
  RowBox[{"{", 
   RowBox[{"x1", ",", "y1"}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "5"}], " ", "y1"}], ",", 
   RowBox[{"x1", "-", 
    RowBox[{"2", " ", 
     SqrtBox["5"], " ", "y1"}]}]}], "}"}]], "Input"],

Cell[BoxData[{
 RowBox[{"Clear", "[", "p4", "]"}], "\[IndentingNewLine]", 
 RowBox[{"p4", "=", 
  RowBox[{"PlotVectorField", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "5"}], " ", "y1"}], ",", 
      RowBox[{"x1", "-", 
       RowBox[{"2", " ", 
        SqrtBox["5"], " ", "y1"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"x1", ",", 
      RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"y1", ",", 
      RowBox[{"-", "4"}], ",", "4"}], "}"}]}], "]"}]}]}], "Input",
 CellChangeTimes->{3.43520370553125*^9},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"p5", ",", "p4"}], "}"}], ",", 
   RowBox[{"Axes", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "4"}], ",", "4"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<x[t]\>\"", ",", "\"\<y[t]\>\""}], "}"}]}], ",", 
   RowBox[{"AspectRatio", "\[Rule]", "Automatic"}]}], "]"}]], "Input",
 CellChangeTimes->{3.43520371096875*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["describe the system,using appropriate vocabulary.", "Subsubsection"],

Cell[TextData[{
 "Consider the system z'=",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"0", ",", 
      RowBox[{"-", "5"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"1", ",", 
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       SqrtBox["5"]}]}], "}"}]}], "}"}]]],
 "z.\nThe origin is a stable improper node.\n\nFrom the eigenvalue alone:  \
Since the eigenvalue is real and repeated and did not yield a full set of \
linearly independent eigenvectors, the origin is an improper node.  Since the \
eigenvalue is negative, the node is stable.\n\nFurthermore, the {t,x[t]} and \
{t,y[t]} graphs tend to zero, indicating that as time progresses, the x and y \
components of the x-y graph approach the origin, yielding stability.  In \
addition, the direction field indicates that the trajectories rotate \
counterclockwise toward the origin, again yielding stability."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["THE fundamental matrix", "Subsubsection"],

Cell["\<\
Take any fundamental matrix \[CapitalPsi][t] and compute \
\[CapitalPsi][t].Inverse[\[CapitalPsi][0]]:\
\>", "Text",
 FontFamily->"Courier"],

Cell[BoxData[
 RowBox[{"\[CapitalPsi]", "[", "0", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Inverse", "[", 
  RowBox[{"\[CapitalPsi]", "[", "0", "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[CapitalPsi]", "[", "t", "]"}], ".", 
  RowBox[{"Inverse", "[", 
   RowBox[{"\[CapitalPsi]", "[", "0", "]"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"Expand", "[", "%", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"MatrixForm", "[", "%", "]"}]], "Input"],

Cell[BoxData[{
 RowBox[{"Clear", "[", "\[CapitalPhi]", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[CapitalPhi]", "[", "t_", "]"}], ":=", 
  TagBox[
   RowBox[{"(", "\[NoBreak]", GridBox[{
      {
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          SqrtBox["5"], " ", "t"}]], "-", 
        RowBox[{
         SqrtBox["5"], " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           SqrtBox["5"], " ", "t"}]], " ", "t"}]}], 
       RowBox[{
        RowBox[{"-", "5"}], " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          SqrtBox["5"], " ", "t"}]], " ", "t"}]},
      {
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          SqrtBox["5"], " ", "t"}]], " ", "t"}], 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          SqrtBox["5"], " ", "t"}]], "+", 
        RowBox[{
         SqrtBox["5"], " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           SqrtBox["5"], " ", "t"}]], " ", "t"}]}]}
     }], "\[NoBreak]", ")"}],
   MatrixForm[#]& ]}]}], "Input"],

Cell["Check the properties of THE fundamental matrix:", "Text",
 FontFamily->"Courier"],

Cell["Its columns are linearly independent:", "Text",
 FontFamily->"Courier"],

Cell[BoxData[
 RowBox[{"Det", "[", 
  RowBox[{"\[CapitalPhi]", "[", "t", "]"}], "]"}]], "Input"],

Cell["THE fundamental matrix also solves the DE:", "Text",
 FontFamily->"Courier"],

Cell[BoxData[
 RowBox[{"D", "[", 
  RowBox[{
   RowBox[{"\[CapitalPhi]", "[", "t", "]"}], ",", "t"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"A", "[", 
   RowBox[{
    RowBox[{"-", "2"}], 
    SqrtBox["5"]}], "]"}], ".", 
  RowBox[{"\[CapitalPhi]", "[", "t", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"Expand", "[", "%", "]"}]], "Input"],

Cell["At t0=0,it is the identity matrix:", "Text",
 FontFamily->"Courier"],

Cell[BoxData[
 RowBox[{"\[CapitalPhi]", "[", "0", "]"}]], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  RowBox[{"\[Alpha]", "=", 
   RowBox[{"2", 
    SqrtBox["5"]}]}]],
  TextAlignment->Left],
 " gory detail"
}], "Subsection",
 CellFrame->{{0, 0}, {0, 0.5}}],

Cell[CellGroupData[{

Cell["solution from the eigenmethod", "Subsubsection"],

Cell[BoxData[{
 RowBox[{"Clear", "[", "\[Alpha]", "]"}], "\[IndentingNewLine]", 
 RowBox[{"\[Alpha]", "=", 
  RowBox[{"2", 
   SqrtBox["5"]}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"A", "[", "\[Alpha]", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Eigensystem", "[", 
  RowBox[{"A", "[", "\[Alpha]", "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
  "The", " ", "only", " ", "solution", " ", "to", " ", "the", " ", "DE", " ", 
   "from", " ", "this", " ", "method", " ", "is", "   ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", 
      SqrtBox["5"]}], " ", "t"}]], 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", 
       SqrtBox["5"]}], ",", "1"}], "}"}], ".", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", "To"}], " ", "find", " ", "a", " ", "second"}], 
  ",", 
  RowBox[{"linearly", " ", "independent", " ", "solution"}], ",", 
  RowBox[{
  "we", " ", "use", " ", "the", " ", "generalized", " ", "eigenvector", " ", 
   RowBox[{"method", "."}]}]}]], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["solution from the generalized eigenmethod", "Subsubsection"],

Cell[BoxData[
 RowBox[{"Solve", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"A", "[", "\[Alpha]", "]"}], "-", 
       RowBox[{
        RowBox[{"(", 
         SqrtBox["5"], ")"}], 
        RowBox[{"IdentityMatrix", "[", "2", "]"}]}]}], ")"}], ".", 
     RowBox[{"{", 
      RowBox[{"\[Eta]1", ",", "\[Eta]2"}], "}"}]}], "==", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", 
       SqrtBox["5"]}], ",", "1"}], "}"}]}], ",", "\[Eta]1"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1", "-", 
      RowBox[{
       SqrtBox["5"], " ", "\[Eta]2"}]}], ",", "\[Eta]2"}], "}"}], " ", "=", 
   " ", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "0"}], "}"}], " ", "+", " ", 
    RowBox[{"\[Eta]2", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         SqrtBox["5"]}], ",", "1"}], "}"}], ".", "\[IndentingNewLine]", 
      "WLOG"}]}]}]}], ",", " ", 
  RowBox[{
  "let", " ", "the", " ", "generalized", " ", "eigenvector", " ", "be", " ", 
   RowBox[{"{", 
    RowBox[{"1", ",", "0"}], "}"}]}], ",", " ", 
  RowBox[{
   RowBox[{
   "which", " ", "is", " ", "the", " ", "part", " ", "of", " ", "the", " ", 
    "above", " ", "which", " ", "is", " ", "linearly", " ", "independent", 
    " ", "from", " ", "the", " ", 
    RowBox[{"eigenvector", ".", "\[IndentingNewLine]", "The"}], " ", "second",
     " ", "solution", " ", "is", "       ", "t", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      SqrtBox["5"], " ", "t"}]], 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", 
       SqrtBox["5"]}], ",", "1"}], "}"}]}], " ", "+", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      SqrtBox["5"], " ", "t"}]], 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "0"}], "}"}], " ", ".", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", "One"}], " ", "may", " ", "check", " ", "linear", 
    " ", "independence", " ", "of", " ", "these", " ", 
    RowBox[{"solutions", ".", "  ", "Write"}], " ", "the", " ", "solutions", "  ",
     "as", " ", "columns", " ", "of", " ", "a", " ", 
    RowBox[{"matrix", ".", " ", "The"}], " ", "determinant", " ", "is", " ", 
    "not", " ", 
    RowBox[{"zero", ".", "  ", "This"}], " ", "is", " ", "a", " ", 
    "fundamental", " ", 
    RowBox[{"matrix", "."}]}]}]}]], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["a fundamental matrix", "Subsubsection"],

Cell[BoxData[
 RowBox[{"MatrixForm", "[", 
  RowBox[{"Transpose", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        SqrtBox["5"], " ", "t"}]], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         SqrtBox["5"]}], ",", "1"}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"t", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         SqrtBox["5"], " ", "t"}]], 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          SqrtBox["5"]}], ",", "1"}], "}"}]}], " ", "+", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         SqrtBox["5"], " ", "t"}]], 
       RowBox[{"{", 
        RowBox[{"1", ",", "0"}], "}"}]}]}]}], " ", "}"}], "]"}], 
  "]"}]], "Input"],

Cell[BoxData[{
 RowBox[{"Clear", "[", "\[CapitalPsi]", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[CapitalPsi]", "[", "t_", "]"}], ":=", 
  TagBox[
   RowBox[{"(", "\[NoBreak]", GridBox[{
      {
       RowBox[{
        RowBox[{"-", 
         SqrtBox["5"]}], " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          SqrtBox["5"], " ", "t"}]]}], 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          SqrtBox["5"], " ", "t"}]], "-", 
        RowBox[{
         SqrtBox["5"], " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           SqrtBox["5"], " ", "t"}]], " ", "t"}]}]},
      {
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         SqrtBox["5"], " ", "t"}]], 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          SqrtBox["5"], " ", "t"}]], " ", "t"}]}
     }], "\[NoBreak]", ")"}],
   MatrixForm[#]& ]}]}], "Input"],

Cell[BoxData[
 RowBox[{"Det", "[", 
  RowBox[{"\[CapitalPsi]", "[", "t", "]"}], "]"}]], "Input"],

Cell["Note that a fundamental matrix also solves the DE.", "Text",
 FontFamily->"Courier"],

Cell[BoxData[
 RowBox[{"D", "[", 
  RowBox[{
   RowBox[{"\[CapitalPsi]", "[", "t", "]"}], ",", "t"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"A", "[", 
   RowBox[{"2", 
    SqrtBox["5"]}], "]"}], ".", 
  RowBox[{"\[CapitalPsi]", "[", "t", "]"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["general solution, behavior", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{
  "The", " ", "general", " ", "solution", " ", "is", "      ", "c1", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     SqrtBox["5"], " ", "t"}]], 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      SqrtBox["5"]}], ",", "1"}], "}"}]}], " ", "+", " ", 
  RowBox[{"c2", "  ", "t", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     SqrtBox["5"], " ", "t"}]], 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      SqrtBox["5"]}], ",", "1"}], "}"}]}], " ", "+", 
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", " ", 
      SqrtBox["5"]}], " ", "t"}]], 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "0"}], "}"}], " ", "."}]}]}]], "Text"],

Cell[BoxData[
 RowBox[{"Expand", "[", " ", 
  RowBox[{
   RowBox[{"c1", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      SqrtBox["5"], " ", "t"}]], 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", 
       SqrtBox["5"]}], ",", "1"}], "}"}]}], " ", "+", " ", 
   RowBox[{"c2", " ", 
    RowBox[{"(", " ", 
     RowBox[{
      RowBox[{"t", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         SqrtBox["5"], " ", "t"}]], 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          SqrtBox["5"]}], ",", "1"}], "}"}]}], " ", "+", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         SqrtBox["5"], " ", "t"}]], 
       RowBox[{"{", 
        RowBox[{"1", ",", "0"}], "}"}]}]}], ")"}]}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Limit", "[", 
  RowBox[{"%", ",", 
   RowBox[{"t", "\[Rule]", " ", "\[Infinity]"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Factor", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       SqrtBox["5"]}], " ", "c1", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        SqrtBox["5"], " ", "t"}]]}], "+", 
     RowBox[{"c2", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        SqrtBox["5"], " ", "t"}]]}], "-", 
     RowBox[{
      SqrtBox["5"], " ", "c2", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        SqrtBox["5"], " ", "t"}]], " ", "t"}]}], ",", 
    RowBox[{
     RowBox[{"c1", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        SqrtBox["5"], " ", "t"}]]}], "+", 
     RowBox[{"c2", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        SqrtBox["5"], " ", "t"}]], " ", "t"}]}]}], "}"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Limit", "[", 
  RowBox[{"%", ",", 
   RowBox[{"t", "\[Rule]", " ", "\[Infinity]"}]}], "]"}]], "Input"],

Cell["components of x[t] and y[t]", "Text"],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", " ", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       SqrtBox["5"], " ", "t"}]], ",", " ", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        SqrtBox["5"], " ", "t"}]], " ", "t"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "4"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<t\>\"", ",", "\"\<components\>\""}], "}"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{3.4352037531875*^9}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
   "Note", " ", "that", " ", "for", " ", "both", " ", "of", " ", "these", " ",
     "solutions"}], ",", " ", 
   RowBox[{"for", " ", "any", " ", "c1", " ", "and", " ", "c2"}], ",", "  ", 
   RowBox[{
   "both", " ", "components", " ", "tend", " ", "to", " ", "plus", " ", "or", 
    " ", "minus", " ", "infinity", " ", "as", " ", "t", " ", 
    RowBox[{"increases", ".", "  ", "Thus"}]}], ",", 
   RowBox[{
   "the", " ", "origin", " ", "is", " ", "an", " ", "unstable", " ", "node", 
    " ", "for", " ", "this", " ", "value", " ", "of", " ", 
    RowBox[{"\[Alpha]", "."}]}]}]}]], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       SqrtBox["5"]}], " ", "c1", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        SqrtBox["5"], " ", "t"}]]}], "+", 
     RowBox[{"c2", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        SqrtBox["5"], " ", "t"}]]}], "-", 
     RowBox[{
      SqrtBox["5"], " ", "c2", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        SqrtBox["5"], " ", "t"}]], " ", "t"}]}], ",", 
    RowBox[{
     RowBox[{"c1", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        SqrtBox["5"], " ", "t"}]]}], "+", 
     RowBox[{"c2", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        SqrtBox["5"], " ", "t"}]], " ", "t"}]}]}], "}"}], "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"c1", "\[Rule]", "1"}], ",", 
    RowBox[{"c2", "\[Rule]", "1"}]}], "}"}]}]], "Input"],

Cell["phase plane for one trajectory", "Text"],

Cell[BoxData[
 RowBox[{"ParametricPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        SqrtBox["5"], " ", "t"}]], "-", 
      RowBox[{
       SqrtBox["5"], " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         SqrtBox["5"], " ", "t"}]]}], "-", 
      RowBox[{
       SqrtBox["5"], " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         SqrtBox["5"], " ", "t"}]], " ", "t"}]}], ",", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        SqrtBox["5"], " ", "t"}]], "+", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         SqrtBox["5"], " ", "t"}]], " ", "t"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "10"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<x[t]\>\"", ",", "\"\<y[t]\>\""}], "}"}]}]}], "]"}]], "Input",\

 CellChangeTimes->{3.4352037605*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"fcnlist", "=", 
   RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{"AppendTo", "[", 
    RowBox[{"fcnlist", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SqrtBox["5"]}], " ", "c1", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           SqrtBox["5"], " ", "t"}]]}], "+", 
        RowBox[{"c2", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           SqrtBox["5"], " ", "t"}]]}], "-", 
        RowBox[{
         SqrtBox["5"], " ", "c2", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           SqrtBox["5"], " ", "t"}]], " ", "t"}]}], ",", 
       RowBox[{
        RowBox[{"c1", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           SqrtBox["5"], " ", "t"}]]}], "+", 
        RowBox[{"c2", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           SqrtBox["5"], " ", "t"}]], " ", "t"}]}]}], "}"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"c1", ",", 
     RowBox[{"-", "2"}], ",", "2", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"c2", ",", 
     RowBox[{"-", "2"}], ",", "2", ",", "2"}], "}"}]}], 
  "]"}], "\[IndentingNewLine]", "fcnlist"}], "Input"],

Cell["Here are the initial values for these solutions.", "Text"],

Cell[BoxData[
 RowBox[{"%", "/.", 
  RowBox[{"t", "\[Rule]", "0"}]}]], "Input"],

Cell["phase plane for several trajectories", "Text"],

Cell[BoxData[{
 RowBox[{"Clear", "[", "p5", "]"}], "\[IndentingNewLine]", 
 RowBox[{"p5", "=", 
  RowBox[{"ParametricPlot", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", "fcnlist", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "10"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "[", "t", "]"}], ",", 
       RowBox[{"y", "[", "t", "]"}]}], "}"}]}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1000"}], ",", "1000"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1000"}], ",", "1000"}], "}"}]}], "}"}]}]}], 
   "]"}]}]}], "Input",
 CellChangeTimes->{3.435203772296875*^9}],

Cell["\<\
These aren't very different, especially on this scale.  Also note that we \
only have initial conditions in two of the quadrants.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["direction field", "Subsubsection"],

Cell[TextData[{
 "Load the Graphics`PlotField` package BEFORE trying to generate the \
direction field.\nLoad the package once per ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " session.  If you change anything, generate the direction field again."
}], "Text"],

Cell["<<Graphics`PlotField`", "Input",
 ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Remember that we obtain the coordinates of the direction field from \
{x'[t],y'[t]}, which is given by the matrix product A.{x[t],y[t]}.  To avoid \
confusing the {x,y} used here with ones plotted elsewhere, we'll call these \
{x1,y1}. \
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"A", "[", "\[Alpha]", "]"}], ".", 
  RowBox[{"{", 
   RowBox[{"x1", ",", "y1"}], "}"}]}]], "Input"],

Cell["\<\
Clear[p4]
p4 = PlotVectorField[
{-5 y1,x1 + 2 Sqrt[5] y1},
{x1,-1000,1000}, {y1, -1000,1000}]\
\>", "Input",
 CellChangeTimes->{3.435203785015625*^9},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell["Superimpose the solutions on the direction field.", "Text"],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"p5", ",", "p4"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"Axes", "\[Rule]", "Automatic"}], ",", "\[IndentingNewLine]", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "1000"}], ",", "1000"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "1000"}], ",", "1000"}], "}"}]}], "}"}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<x[t]\>\"", ",", "\"\<y[t]\>\""}], "}"}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"AspectRatio", "\[Rule]", "Automatic"}]}], "]"}]], "Input",
 CellChangeTimes->{3.435203791796875*^9}],

Cell["\<\
These trajectories aren't as straight as the scale makes them seem.  On this \
scale, it is more clear that we have included initial conditions in each \
quadrant.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"p5", ",", "\[IndentingNewLine]", 
   RowBox[{"Axes", "\[Rule]", "Automatic"}], ",", "\[IndentingNewLine]", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "20"}], ",", "20"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "20"}], ",", "20"}], "}"}]}], "}"}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<x[t]\>\"", ",", "\"\<y[t]\>\""}], "}"}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"AspectRatio", "\[Rule]", "Automatic"}]}], "]"}]], "Input",
 CellChangeTimes->{3.435203797015625*^9}],

Cell["\<\
We can also generate functions with specific initial conditions.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        SqrtBox["5"], " ", "t"}]]}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SqrtBox["5"], " ", "c1"}], "-", "c2", "+", 
       RowBox[{
        SqrtBox["5"], " ", "c2", " ", "t"}]}], ")"}]}], ",", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       SqrtBox["5"], " ", "t"}]], " ", 
     RowBox[{"(", 
      RowBox[{"c1", "+", 
       RowBox[{"c2", " ", "t"}]}], ")"}]}]}], "}"}], "/.", 
  RowBox[{"t", "\[Rule]", "0"}]}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"fcnlist2", "=", 
   RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Do", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Clear", "[", 
      RowBox[{"ThisRule", ",", "ThisFcn"}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"ThisRule", "=", 
      RowBox[{"Flatten", "[", 
       RowBox[{"Solve", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"-", 
               SqrtBox["5"]}], " ", "c1"}], "+", "c2"}], ",", "c1"}], "}"}], 
          "\[Equal]", 
          RowBox[{"{", 
           RowBox[{"a", ",", "b"}], "}"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"c1", ",", "c2"}], "}"}]}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"ThisFcn", "=", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             SqrtBox["5"], " ", "t"}]]}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SqrtBox["5"], " ", "c1"}], "-", "c2", "+", 
            RowBox[{
             SqrtBox["5"], " ", "c2", " ", "t"}]}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            SqrtBox["5"], " ", "t"}]], " ", 
          RowBox[{"(", 
           RowBox[{"c1", "+", 
            RowBox[{"c2", " ", "t"}]}], ")"}]}]}], "}"}], "/.", 
       "ThisRule"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"AppendTo", "[", 
      RowBox[{"fcnlist2", ",", "ThisFcn"}], "]"}]}], ",", 
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"a", ",", 
      RowBox[{"-", "4"}], ",", "4", ",", "4"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"b", ",", 
      RowBox[{"-", "4"}], ",", "4", ",", "4"}], "}"}]}], "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Clear", "[", "p6", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"p6", "=", 
   RowBox[{"ParametricPlot", "[", 
    RowBox[{
     RowBox[{"Evaluate", "[", "fcnlist2", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "10"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x[t]\>\"", ",", "\"\<y[t]\>\""}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "50"}], ",", "50"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "50"}], ",", "50"}], "}"}]}], "}"}]}]}], "]"}]}], 
  ";"}]}], "Input"],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"p6", ",", "p4"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"Axes", "\[Rule]", "Automatic"}], ",", "\[IndentingNewLine]", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "100000"}], ",", "100000"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "100000"}], ",", "100000"}], "}"}]}], "}"}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<x[t]\>\"", ",", "\"\<y[t]\>\""}], "}"}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"AspectRatio", "\[Rule]", "Automatic"}]}], "]"}]], "Input",
 CellChangeTimes->{3.43520380771875*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["describe the system,using appropriate vocabulary.", "Subsubsection"],

Cell[TextData[{
 "Consider the system z'=",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"0", ",", 
      RowBox[{"-", "5"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"1", ",", 
      RowBox[{"2", " ", 
       SqrtBox["5"]}]}], "}"}]}], "}"}]]],
 "z.\nThe origin is an unstable improper node.\n\nFrom the eigenvalue alone:  \
Since the eigenvalue is real and repeated and did not yield a full set of \
linearly independent eigenvectors, the origin is an improper node.  Since the \
eigenvalue is positive, the node is unstable.\n\nFurthermore, the {t,x[t]} \
and {t,y[t]} graphs tend to (plus or minus) infinity, indicating that as time \
progresses, the x and y components of the x-y graph increase without bound \
away from the origin, yielding instability.  In addition, the direction field \
indicates that the trajectories rotate clockwise away form the origin, again \
yielding instability."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["THE fundamental matrix", "Subsubsection"],

Cell["\<\
Take any fundamental matrix \[CapitalPsi][t] and compute \
\[CapitalPsi][t].Inverse[\[CapitalPsi][0]]:\
\>", "Text",
 FontFamily->"Courier"],

Cell[BoxData[
 RowBox[{"\[CapitalPsi]", "[", "0", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Inverse", "[", "  ", 
  RowBox[{"\[CapitalPsi]", "[", "0", "]"}], "  ", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[CapitalPsi]", "[", "t", "]"}], " ", ".", " ", 
  RowBox[{"Inverse", "[", "  ", 
   RowBox[{"\[CapitalPsi]", "[", "0", "]"}], "  ", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"Expand", "[", "%", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"MatrixForm", "[", "%", "]"}]], "Input"],

Cell[BoxData[{
 RowBox[{"Clear", "[", "\[CapitalPhi]", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[CapitalPhi]", "[", "t_", "]"}], ":=", 
  TagBox[
   RowBox[{"(", "\[NoBreak]", GridBox[{
      {
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          SqrtBox["5"], " ", "t"}]], "-", 
        RowBox[{
         SqrtBox["5"], " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           SqrtBox["5"], " ", "t"}]], " ", "t"}]}], 
       RowBox[{
        RowBox[{"-", "5"}], " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          SqrtBox["5"], " ", "t"}]], " ", "t"}]},
      {
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          SqrtBox["5"], " ", "t"}]], " ", "t"}], 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          SqrtBox["5"], " ", "t"}]], "+", 
        RowBox[{
         SqrtBox["5"], " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           SqrtBox["5"], " ", "t"}]], " ", "t"}]}]}
     }], "\[NoBreak]", ")"}],
   MatrixForm[#]& ]}]}], "Input"],

Cell["Check the properties of THE fundamental matrix:", "Text",
 FontFamily->"Courier"],

Cell["Its columns are linearly independent:", "Text",
 FontFamily->"Courier"],

Cell[BoxData[
 RowBox[{"Det", "[", 
  RowBox[{"\[CapitalPhi]", "[", "t", "]"}], "]"}]], "Input"],

Cell["THE fundamental matrix also solves the DE:", "Text",
 FontFamily->"Courier"],

Cell[BoxData[
 RowBox[{"D", "[", 
  RowBox[{
   RowBox[{"\[CapitalPhi]", "[", "t", "]"}], ",", "t"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"A", "[", 
   RowBox[{
    RowBox[{"-", "2"}], 
    SqrtBox["5"]}], "]"}], ".", 
  RowBox[{"\[CapitalPhi]", "[", "t", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"Expand", "[", "%", "]"}]], "Input"],

Cell["At t0=0, it is the identity matrix:", "Text",
 FontFamily->"Courier"],

Cell[BoxData[
 RowBox[{"\[CapitalPhi]", "[", "0", "]"}]], "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["2 real roots", "Section",
 CellFrame->{{0, 0}, {0, 2}}],

Cell[TextData[{
 "\n case (2) ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"-", "20"}], "+", 
    SuperscriptBox["\[Alpha]", "2"]}], ">", "0"}]]],
 " really has two cases.\n case (2n)   ",
 Cell[BoxData[
  RowBox[{"\[Alpha]", "<", 
   RowBox[{
    RowBox[{"-", "2"}], 
    SqrtBox["5"], " "}]}]]],
 ".\n  case (2p)   ",
 Cell[BoxData[
  RowBox[{"\[Alpha]", " ", ">", 
   RowBox[{"2", 
    SqrtBox["5"], " "}]}]]],
 "."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  RowBox[{"\[Alpha]", "<", 
   RowBox[{
    RowBox[{"-", "2"}], 
    SqrtBox["5"]}]}]],
  TextAlignment->Left],
 ",   in general"
}], "Subsection",
 CellFrame->{{0, 0}, {0, 0.5}}],

Cell[BoxData[
 RowBox[{"\t", 
  RowBox[{
   RowBox[{"r1", " ", "=", " ", 
    RowBox[{
     FractionBox[
      RowBox[{"\[Alpha]", "+", 
       SqrtBox[
        RowBox[{
         RowBox[{"-", "20"}], "+", 
         SuperscriptBox["\[Alpha]", "2"]}]]}], "2"], " ", "<", " ", "0"}]}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"r1", "<", 
     RowBox[{"0", " ", "since", " ", "0"}], " ", "<", " ", 
     RowBox[{
      SuperscriptBox["\[Alpha]", "2"], " ", "-", " ", "20"}], " ", "<", 
     SuperscriptBox["\[Alpha]", "2"]}], " ", ",", " ", "\[IndentingNewLine]", 
    
    RowBox[{
     RowBox[{
      RowBox[{"so", " ", "that", "              ", "0"}], " ", "<", " ", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["\[Alpha]", "2"], " ", "-", " ", "20", " "}]], " ", 
      "<", " ", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["\[Alpha]", "2"], " "}]]}], "=", " ", 
     RowBox[{"|", "\[Alpha]", "|"}]}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"so", " ", "that", "   ", "\[Alpha]"}], " ", "+", "  ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["\[Alpha]", "2"], " ", "-", " ", "20", " "}]]}], " ", 
      "<", " ", 
      RowBox[{"\[Alpha]", " ", "+", "  ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["\[Alpha]", "2"], " "}]]}]}], "=", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Alpha]", " ", "+"}], "  ", "|", "\[Alpha]", "|"}], " ", "=",
       " ", 
      RowBox[{
       RowBox[{
       "0", " ", ".", "\[IndentingNewLine]", "\[IndentingNewLine]", "r2"}], 
       " ", "=", " ", 
       RowBox[{
        FractionBox[
         RowBox[{"\[Alpha]", "-", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", "20"}], "+", 
            SuperscriptBox["\[Alpha]", "2"]}]]}], "2"], " ", "<", " ", 
        "0"}]}]}]}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"since", " ", 
     RowBox[{"we", "'"}], "re", " ", "adding", " ", "two", " ", 
     RowBox[{
     "negatives", ".", "\[IndentingNewLine]", "\[IndentingNewLine]", "Both"}],
      " ", "eigenvalues", " ", "have", " ", "the", " ", "same", " ", "sign", 
     " ", "and", " ", "are", " ", "unequal"}], ",", " ", 
    RowBox[{"so", " ", "the", " ", "origin", " ", "is", " ", "a", " ", 
     RowBox[{"node", ".", "  ", "Both"}], " ", "eigenvalues", " ", "are", " ",
      "negative"}], ",", " ", 
    RowBox[{
    "so", " ", "our", " ", "solutions", " ", "will", " ", "have", " ", "an", 
     " ", "exponential", " ", "decay"}], ",", " ", 
    RowBox[{"making", " ", "the", " ", "node", " ", 
     RowBox[{"stable", ".", "  ", "That"}], " ", "is"}], ",", " ", 
    RowBox[{
     RowBox[{"trajectories", " ", "in", " ", "the", " ", "x"}], "-", 
     RowBox[{
     "y", " ", "plane", " ", "tend", " ", "toward", " ", "the", " ", "origin",
       " ", "for", " ", "any", " ", "initial", " ", 
      RowBox[{"conditions", "."}]}]}]}]}]}]], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Example:  ",
 Cell[BoxData[
  RowBox[{"\[Alpha]", "=", 
   RowBox[{
    RowBox[{"-", "10"}], "<", 
    RowBox[{
     RowBox[{"-", "2"}], 
     SqrtBox["5"]}]}]}]],
  TextAlignment->Left],
 " gory detail"
}], "Subsection",
 CellFrame->{{0, 0}, {0, 0.5}}],

Cell[CellGroupData[{

Cell["solution from the eigenmethod", "Subsubsection"],

Cell[BoxData[{
 RowBox[{"Clear", "[", "\[Alpha]", "]"}], "\n", 
 RowBox[{"\[Alpha]", "=", 
  RowBox[{"-", "10"}]}], "\n", 
 RowBox[{"A", "[", "\[Alpha]", "]"}]}], "Input"],

Cell[BoxData[
 RowBox[{"Eigensystem", "[", 
  RowBox[{"A", "[", "\[Alpha]", "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"N", "[", "%", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"There", " ", "are", " ", "two", " ", "linearly", " ", "independent",
   " ", "solutions", " ", "to", " ", "the", " ", "DE", " ", "from", " ", 
  "this", " ", 
  RowBox[{"method", ":", " ", "\[IndentingNewLine]", " ", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "5"}], "-", 
        RowBox[{"2", " ", 
         SqrtBox["5"]}]}], ")"}], " ", "t"}]], 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"5", "-", 
       RowBox[{"2", " ", 
        SqrtBox["5"]}]}], ",", "1"}], "}"}], " ", "and", "  ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "5"}], "+", 
        RowBox[{"2", " ", 
         SqrtBox["5"]}]}], ")"}], " ", "t"}]], 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"5", "+", 
        RowBox[{"2", " ", 
         SqrtBox["5"]}]}], ",", "1"}], "}"}], " ", "."}]}]}]}]], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
  "Because", " ", "the", " ", "eigenvalues", " ", "are", " ", "real", " ", 
   "and", " ", "different"}], ",", " ", 
  RowBox[{
   RowBox[{
   "we", " ", "may", " ", "obtain", " ", "an", " ", "idea", " ", "of", " ", 
    "the", " ", "trajectories", " ", "by", " ", "plotting", " ", "the", " ", 
    "eigenvectors", " ", "and", " ", "the", " ", "lines", " ", "they", " ", 
    "individually", " ", 
    RowBox[{"generate", ".", "  ", "\[IndentingNewLine]", "The"}], " ", 
    "first", " ", "eigenvector", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "5"}], "-", 
       RowBox[{"2", " ", 
        SqrtBox["5"]}]}], ",", "1"}], "}"}], " ", "lies", " ", "on", " ", 
    "the", " ", "line", " ", "y"}], " ", "=", "  ", 
   RowBox[{
    RowBox[{
     RowBox[{"1", "/", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "5"}], "-", 
        RowBox[{"2", " ", 
         SqrtBox["5"]}]}], " ", ")"}]}], " ", 
     RowBox[{"x", ".", " ", "\[IndentingNewLine]", " ", "The"}], "  ", 
     "second", " ", "eigenvector", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "5"}], "+", 
        RowBox[{"2", " ", 
         SqrtBox["5"]}]}], ",", "1"}], "}"}], " ", "lies", " ", "on", " ", 
     "the", " ", "line", " ", "y"}], " ", "=", "  ", 
    RowBox[{
     RowBox[{"1", "/", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "5"}], "+", 
        RowBox[{"2", " ", 
         SqrtBox["5"]}]}], " ", ")"}]}], " ", 
     RowBox[{"x", "."}]}]}]}]}]], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["a fundamental matrix", "Subsubsection"],

Cell[BoxData[
 RowBox[{"MatrixForm", "[", 
  RowBox[{"Transpose", "[", 
   RowBox[{"{", " ", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "-", 
          RowBox[{"2", " ", 
           SqrtBox["5"]}]}], ")"}], " ", "t"}]], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"5", "-", 
         RowBox[{"2", " ", 
          SqrtBox["5"]}]}], ",", "1"}], "}"}]}], ",", " ", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          RowBox[{"2", " ", 
           SqrtBox["5"]}]}], ")"}], " ", "t"}]], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"5", "+", 
         RowBox[{"2", " ", 
          SqrtBox["5"]}]}], ",", "1"}], "}"}]}]}], "}"}], "]"}], 
  "]"}]], "Input"],

Cell[BoxData[{
 RowBox[{"Clear", "[", "\[CapitalPsi]", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[CapitalPsi]", "[", "t_", "]"}], ":=", 
  TagBox[
   RowBox[{"(", "\[NoBreak]", GridBox[{
      {
       RowBox[{
        RowBox[{"(", 
         RowBox[{"5", "-", 
          RowBox[{"2", " ", 
           SqrtBox["5"]}]}], ")"}], " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "5"}], "-", 
            RowBox[{"2", " ", 
             SqrtBox["5"]}]}], ")"}], " ", "t"}]]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"5", "+", 
          RowBox[{"2", " ", 
           SqrtBox["5"]}]}], ")"}], " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "5"}], "+", 
            RowBox[{"2", " ", 
             SqrtBox["5"]}]}], ")"}], " ", "t"}]]}]},
      {
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "5"}], "-", 
           RowBox[{"2", " ", 
            SqrtBox["5"]}]}], ")"}], " ", "t"}]], 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "5"}], "+", 
           RowBox[{"2", " ", 
            SqrtBox["5"]}]}], ")"}], " ", "t"}]]}
     }], "\[NoBreak]", ")"}],
   MatrixForm[#]& ]}]}], "Input"],

Cell[BoxData[
 RowBox[{"Det", "[", 
  RowBox[{"\[CapitalPsi]", "[", "t", "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Simplify", "[", "%", "]"}]], "Input"],

Cell["Note that a fundamental matrix also solves the DE.", "Text",
 FontFamily->"Courier"],

Cell[BoxData[
 RowBox[{"D", "[", 
  RowBox[{
   RowBox[{"\[CapitalPsi]", "[", "t", "]"}], ",", "t"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Expand", "[", "%", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"A", "[", "\[Alpha]", "]"}], ".", 
  RowBox[{"\[CapitalPsi]", "[", "t", "]"}]}]], "Input"],

Cell["hard to tell like this, but the difference should be zero.", "Text"],

Cell[BoxData[
 RowBox[{"Expand", "[", "  ", 
  RowBox[{
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{"\[CapitalPsi]", "[", "t", "]"}], ",", "t"}], "]"}], " ", "-", 
   " ", 
   RowBox[{
    RowBox[{"A", "[", "\[Alpha]", "]"}], ".", 
    RowBox[{"\[CapitalPsi]", "[", "t", "]"}]}]}], " ", "]"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["general solution, behavior", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{
  "The", " ", "general", " ", "solution", " ", "is", "      ", "c1", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "5"}], "-", 
       RowBox[{"2", " ", 
        SqrtBox["5"]}]}], ")"}], " ", "t"}]], 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"5", "-", 
      RowBox[{"2", " ", 
       SqrtBox["5"]}]}], ",", "1"}], "}"}]}], " ", "+", " ", 
  RowBox[{"c2", "  ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "5"}], "+", 
       RowBox[{"2", " ", 
        SqrtBox["5"]}]}], ")"}], " ", "t"}]], 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"5", "+", 
       RowBox[{"2", " ", 
        SqrtBox["5"]}]}], ",", "1"}], "}"}], " ", "."}]}]}]], "Text"],

Cell[BoxData[
 RowBox[{"Expand", "[", " ", 
  RowBox[{
   RowBox[{"c1", "  ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "5"}], "-", 
        RowBox[{"2", " ", 
         SqrtBox["5"]}]}], ")"}], " ", "t"}]], 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"5", "-", 
       RowBox[{"2", " ", 
        SqrtBox["5"]}]}], ",", "1"}], "}"}]}], "+", " ", 
   RowBox[{"c2", "  ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "5"}], "+", 
        RowBox[{"2", " ", 
         SqrtBox["5"]}]}], ")"}], " ", "t"}]], 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"5", "+", 
       RowBox[{"2", " ", 
        SqrtBox["5"]}]}], ",", "1"}], "}"}]}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Collect", "[", 
  RowBox[{"%", ",", 
   RowBox[{"{", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "5"}], "-", 
         RowBox[{"2", " ", 
          SqrtBox["5"]}]}], ")"}], " ", "t"}]], ",", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "5"}], "+", 
         RowBox[{"2", " ", 
          SqrtBox["5"]}]}], ")"}], " ", "t"}]]}], " ", "}"}]}], 
  "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Note", " ", "that", " ", "for", " ", "these", " ", "solutions"}], 
   ",", " ", 
   RowBox[{"for", " ", "any", " ", "c1", " ", "and", " ", "c2"}], ",", "  ", 
   RowBox[{
   "since", " ", "\[ExponentialE]", " ", "is", " ", "raised", " ", "to", " ", 
    "a", " ", "negative", " ", "value"}], ",", " ", 
   RowBox[{
   "both", " ", "components", " ", "tend", " ", "to", " ", "zero", " ", "as", 
    " ", "t", " ", 
    RowBox[{"increases", ".", "  ", "Thus"}]}], ",", 
   RowBox[{
   "the", " ", "origin", " ", "is", " ", "a", " ", "stable", " ", "node", " ",
     "for", " ", "this", " ", "value", " ", "of", " ", 
    RowBox[{"\[Alpha]", ".", "\[IndentingNewLine]"}]}]}]}]], "Text"],

Cell["components of x[t] and y[t]", "Text"],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", " ", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "5"}], "-", 
         RowBox[{"2", " ", 
          SqrtBox["5"]}]}], ")"}], " ", "t"}]], ",", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "5"}], "+", 
         RowBox[{"2", " ", 
          SqrtBox["5"]}]}], ")"}], " ", "t"}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "4"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<t\>\"", ",", "\"\<components\>\""}], "}"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{3.435203863890625*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"5", " ", "c1"}], "-", 
        RowBox[{"2", " ", 
         SqrtBox["5"], " ", "c1"}]}], ")"}], " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "-", 
          RowBox[{"2", " ", 
           SqrtBox["5"]}]}], ")"}], " ", "t"}]]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"5", " ", "c2"}], "+", 
        RowBox[{"2", " ", 
         SqrtBox["5"], " ", "c2"}]}], ")"}], " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          RowBox[{"2", " ", 
           SqrtBox["5"]}]}], ")"}], " ", "t"}]]}]}], ",", 
    RowBox[{
     RowBox[{"c1", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "-", 
          RowBox[{"2", " ", 
           SqrtBox["5"]}]}], ")"}], " ", "t"}]]}], "+", 
     RowBox[{"c2", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          RowBox[{"2", " ", 
           SqrtBox["5"]}]}], ")"}], " ", "t"}]]}]}]}], "}"}], "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"c1", "\[Rule]", "1"}], ",", 
    RowBox[{"c2", "\[Rule]", "1"}]}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"5", "-", 
        RowBox[{"2", " ", 
         SqrtBox["5"]}]}], ")"}], " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "-", 
          RowBox[{"2", " ", 
           SqrtBox["5"]}]}], ")"}], " ", "t"}]]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"5", "+", 
        RowBox[{"2", " ", 
         SqrtBox["5"]}]}], ")"}], " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          RowBox[{"2", " ", 
           SqrtBox["5"]}]}], ")"}], " ", "t"}]]}]}], ",", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "5"}], "-", 
         RowBox[{"2", " ", 
          SqrtBox["5"]}]}], ")"}], " ", "t"}]], "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "5"}], "+", 
         RowBox[{"2", " ", 
          SqrtBox["5"]}]}], ")"}], " ", "t"}]]}]}], "}"}], "/.", 
  RowBox[{"t", "\[Rule]", "0"}]}]], "Input"],

Cell["The trajectory begins at (10,2) in this phase plane.", "Text"],

Cell[BoxData[
 RowBox[{"ParametricPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"5", "-", 
         RowBox[{"2", " ", 
          SqrtBox["5"]}]}], ")"}], " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "5"}], "-", 
           RowBox[{"2", " ", 
            SqrtBox["5"]}]}], ")"}], " ", "t"}]]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"5", "+", 
         RowBox[{"2", " ", 
          SqrtBox["5"]}]}], ")"}], " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "5"}], "+", 
           RowBox[{"2", " ", 
            SqrtBox["5"]}]}], ")"}], " ", "t"}]]}]}], ",", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "-", 
          RowBox[{"2", " ", 
           SqrtBox["5"]}]}], ")"}], " ", "t"}]], "+", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          RowBox[{"2", " ", 
           SqrtBox["5"]}]}], ")"}], " ", "t"}]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "10"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<x[t]\>\"", ",", "\"\<y[t]\>\""}], "}"}]}]}], "]"}]], "Input",\

 CellChangeTimes->{3.435203871421875*^9}],

Cell["This trajectory tends toward the origin.", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"fcnlist", "=", 
   RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{"AppendTo", "[", 
    RowBox[{"fcnlist", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"5", " ", "c1"}], "-", 
           RowBox[{"2", " ", 
            SqrtBox["5"], " ", "c1"}]}], ")"}], " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "5"}], "-", 
             RowBox[{"2", " ", 
              SqrtBox["5"]}]}], ")"}], " ", "t"}]]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"5", " ", "c2"}], "+", 
           RowBox[{"2", " ", 
            SqrtBox["5"], " ", "c2"}]}], ")"}], " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "5"}], "+", 
             RowBox[{"2", " ", 
              SqrtBox["5"]}]}], ")"}], " ", "t"}]]}]}], ",", 
       RowBox[{
        RowBox[{"c1", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "5"}], "-", 
             RowBox[{"2", " ", 
              SqrtBox["5"]}]}], ")"}], " ", "t"}]]}], "+", 
        RowBox[{"c2", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "5"}], "+", 
             RowBox[{"2", " ", 
              SqrtBox["5"]}]}], ")"}], " ", "t"}]]}]}]}], "}"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"c1", ",", 
     RowBox[{"-", "2"}], ",", "2", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"c2", ",", 
     RowBox[{"-", "3"}], ",", "3", ",", "3"}], "}"}]}], 
  "]"}], "\[IndentingNewLine]", "fcnlist"}], "Input"],

Cell["\<\
phase plane for several trajectories.  Look for the lines generated by the \
eigenvectors.\
\>", "Text"],

Cell[BoxData[{
 RowBox[{"Clear", "[", "p5", "]"}], "\[IndentingNewLine]", 
 RowBox[{"p5", "=", 
  RowBox[{"ParametricPlot", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", "fcnlist", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "10"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<x[t]\>\"", ",", "\"\<y[t]\>\""}], "}"}]}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "4"}], ",", "4"}], "}"}]}], "}"}]}]}], 
   "]"}]}]}], "Input",
 CellChangeTimes->{3.4352038788125*^9}],

Cell["\<\
We can also generate functions with specific initial conditions.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"5", " ", "c1"}], "-", 
        RowBox[{"2", " ", 
         SqrtBox["5"], " ", "c1"}]}], ")"}], " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "-", 
          RowBox[{"2", " ", 
           SqrtBox["5"]}]}], ")"}], " ", "t"}]]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"5", " ", "c2"}], "+", 
        RowBox[{"2", " ", 
         SqrtBox["5"], " ", "c2"}]}], ")"}], " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          RowBox[{"2", " ", 
           SqrtBox["5"]}]}], ")"}], " ", "t"}]]}]}], ",", 
    RowBox[{
     RowBox[{"c1", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "-", 
          RowBox[{"2", " ", 
           SqrtBox["5"]}]}], ")"}], " ", "t"}]]}], "+", 
     RowBox[{"c2", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          RowBox[{"2", " ", 
           SqrtBox["5"]}]}], ")"}], " ", "t"}]]}]}]}], "}"}], "/.", 
  RowBox[{"t", "\[Rule]", "0"}]}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"fcnlist2", "=", 
   RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Do", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Clear", "[", 
      RowBox[{"ThisRule", ",", "ThisFcn"}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"ThisRule", "=", 
      RowBox[{"Flatten", "[", 
       RowBox[{"Solve", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"5", " ", "c1"}], "-", 
             RowBox[{"2", " ", 
              SqrtBox["5"], " ", "c1"}], "+", 
             RowBox[{"5", " ", "c2"}], "+", 
             RowBox[{"2", " ", 
              SqrtBox["5"], " ", "c2"}]}], ",", 
            RowBox[{"c1", "+", "c2"}]}], "}"}], "\[Equal]", 
          RowBox[{"{", 
           RowBox[{"a", ",", "b"}], "}"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"c1", ",", "c2"}], "}"}]}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"ThisFcn", "=", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"5", " ", "c1"}], "-", 
             RowBox[{"2", " ", 
              SqrtBox["5"], " ", "c1"}]}], ")"}], " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "5"}], "-", 
               RowBox[{"2", " ", 
                SqrtBox["5"]}]}], ")"}], " ", "t"}]]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"5", " ", "c2"}], "+", 
             RowBox[{"2", " ", 
              SqrtBox["5"], " ", "c2"}]}], ")"}], " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "5"}], "+", 
               RowBox[{"2", " ", 
                SqrtBox["5"]}]}], ")"}], " ", "t"}]]}]}], ",", 
         RowBox[{
          RowBox[{"c1", " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "5"}], "-", 
               RowBox[{"2", " ", 
                SqrtBox["5"]}]}], ")"}], " ", "t"}]]}], "+", 
          RowBox[{"c2", " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "5"}], "+", 
               RowBox[{"2", " ", 
                SqrtBox["5"]}]}], ")"}], " ", "t"}]]}]}]}], "}"}], "/.", 
       "ThisRule"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"AppendTo", "[", 
      RowBox[{"fcnlist2", ",", "ThisFcn"}], "]"}]}], ",", 
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"a", ",", 
      RowBox[{"-", "4"}], ",", "4", ",", "4"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"b", ",", 
      RowBox[{"-", "4"}], ",", "4", ",", "4"}], "}"}]}], "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Clear", "[", "p6", "]"}], "\[IndentingNewLine]", 
 RowBox[{"p6", "=", 
  RowBox[{"ParametricPlot", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", "fcnlist2", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "10"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<x[t]\>\"", ",", "\"\<y[t]\>\""}], "}"}]}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "6"}], ",", "6"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "6"}], ",", "6"}], "}"}]}], "}"}]}]}], 
   "]"}]}]}], "Input",
 CellChangeTimes->{3.435203895625*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["direction field", "Subsubsection"],

Cell[TextData[{
 "Load the Graphics`PlotField` package BEFORE trying to generate the \
direction field.Load the package once per ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " session.If you change anything,generate the direction field again."
}], "Text"],

Cell[BoxData[
 RowBox[{"<<", "Graphics`PlotField`"}]], "Input",
 ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Remember that we obtain the coordinates of the direction field from \
{x'[t],y'[t]},which is given by the matrix product A.{x[t],y[t]}.To avoid \
confusing the {x,y} used here with ones plotted elsewhere,we'll call these \
{x1,y1}.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"A", "[", "\[Alpha]", "]"}], ".", 
  RowBox[{"{", 
   RowBox[{"x1", ",", "y1"}], "}"}]}]], "Input"],

Cell[BoxData[{
 RowBox[{"Clear", "[", "p4", "]"}], "\[IndentingNewLine]", 
 RowBox[{"p4", "=", 
  RowBox[{"PlotVectorField", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "5"}], " ", "y1"}], ",", 
      RowBox[{"x1", "-", 
       RowBox[{"10", " ", "y1"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"x1", ",", 
      RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"y1", ",", 
      RowBox[{"-", "5"}], ",", "5"}], "}"}]}], "]"}]}]}], "Input",
 CellChangeTimes->{3.435203904703125*^9},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"p5", ",", "p4"}], "}"}], ",", 
   RowBox[{"Axes", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "5"}], ",", "5"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<x[t]\>\"", ",", "\"\<y[t]\>\""}], "}"}]}], ",", 
   RowBox[{"AspectRatio", "\[Rule]", "Automatic"}]}], "]"}]], "Input",
 CellChangeTimes->{3.43520391034375*^9}],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"p6", ",", "p4"}], "}"}], ",", 
   RowBox[{"Axes", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "6"}], ",", "6"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "6"}], ",", "6"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<x[t]\>\"", ",", "\"\<y[t]\>\""}], "}"}]}], ",", 
   RowBox[{"AspectRatio", "\[Rule]", "Automatic"}]}], "]"}]], "Input",
 CellChangeTimes->{3.43520391303125*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["describe the system,using appropriate vocabulary.", "Subsubsection"],

Cell[TextData[{
 "Consider the system z'=",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"0", ",", 
      RowBox[{"-", "5"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"1", ",", 
      RowBox[{"-", "10"}]}], "}"}]}], "}"}]]],
 "z.\nThe origin is a stable node.\n\nFrom the eigenvalue alone:  Since the \
eigenvalues are real and different, the origin is a node.  Since the \
eigenvalues are negative, the node is stable.\n\nFurthermore, the {t,x[t]} \
and {t,y[t]} graphs tend to zero, indicating that as time progresses, the x \
and y components of the x-y graph approach the origin, yielding stability.  \
In addition, the direction field indicates that the trajectories tend toward \
the origin, again yielding stability."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["THE fundamental matrix", "Subsubsection"],

Cell["\<\
Take any fundamental matrix \[CapitalPsi][t] and compute \
\[CapitalPsi][t].Inverse[\[CapitalPsi][0]]:\
\>", "Text",
 FontFamily->"Courier"],

Cell[BoxData[
 RowBox[{"\[CapitalPsi]", "[", "0", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Inverse", "[", "  ", 
  RowBox[{"\[CapitalPsi]", "[", "0", "]"}], "  ", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[CapitalPsi]", "[", "t", "]"}], " ", ".", " ", 
  RowBox[{"Inverse", "[", "  ", 
   RowBox[{"\[CapitalPsi]", "[", "0", "]"}], "  ", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"MatrixForm", "[", "%", "]"}]], "Input"],

Cell[BoxData[{
 RowBox[{"Clear", "[", "\[CapitalPhi]", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[CapitalPhi]", "[", "t_", "]"}], ":=", 
  TagBox[
   RowBox[{"(", "\[NoBreak]", GridBox[{
      {
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{"5", "-", 
             RowBox[{"2", " ", 
              SqrtBox["5"]}]}], ")"}], " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "5"}], "-", 
               RowBox[{"2", " ", 
                SqrtBox["5"]}]}], ")"}], " ", "t"}]]}], 
          RowBox[{"4", " ", 
           SqrtBox["5"]}]]}], "+", 
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{"5", "+", 
            RowBox[{"2", " ", 
             SqrtBox["5"]}]}], ")"}], " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "5"}], "+", 
              RowBox[{"2", " ", 
               SqrtBox["5"]}]}], ")"}], " ", "t"}]]}], 
         RowBox[{"4", " ", 
          SqrtBox["5"]}]]}], 
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "5"}], "-", 
             RowBox[{"2", " ", 
              SqrtBox["5"]}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"5", "-", 
             RowBox[{"2", " ", 
              SqrtBox["5"]}]}], ")"}], " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "5"}], "-", 
               RowBox[{"2", " ", 
                SqrtBox["5"]}]}], ")"}], " ", "t"}]]}], 
          RowBox[{"4", " ", 
           SqrtBox["5"]}]]}], "-", 
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{"5", "-", 
            RowBox[{"2", " ", 
             SqrtBox["5"]}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"5", "+", 
            RowBox[{"2", " ", 
             SqrtBox["5"]}]}], ")"}], " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "5"}], "+", 
              RowBox[{"2", " ", 
               SqrtBox["5"]}]}], ")"}], " ", "t"}]]}], 
         RowBox[{"4", " ", 
          SqrtBox["5"]}]]}]},
      {
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "5"}], "-", 
              RowBox[{"2", " ", 
               SqrtBox["5"]}]}], ")"}], " ", "t"}]], 
          RowBox[{"4", " ", 
           SqrtBox["5"]}]]}], "+", 
        FractionBox[
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "5"}], "+", 
             RowBox[{"2", " ", 
              SqrtBox["5"]}]}], ")"}], " ", "t"}]], 
         RowBox[{"4", " ", 
          SqrtBox["5"]}]]}], 
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "5"}], "-", 
             RowBox[{"2", " ", 
              SqrtBox["5"]}]}], ")"}], " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "5"}], "-", 
               RowBox[{"2", " ", 
                SqrtBox["5"]}]}], ")"}], " ", "t"}]]}], 
          RowBox[{"4", " ", 
           SqrtBox["5"]}]]}], "-", 
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{"5", "-", 
            RowBox[{"2", " ", 
             SqrtBox["5"]}]}], ")"}], " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "5"}], "+", 
              RowBox[{"2", " ", 
               SqrtBox["5"]}]}], ")"}], " ", "t"}]]}], 
         RowBox[{"4", " ", 
          SqrtBox["5"]}]]}]}
     }], "\[NoBreak]", ")"}],
   MatrixForm[#]& ]}]}], "Input"],

Cell["Check the properties of THE fundamental matrix:", "Text",
 FontFamily->"Courier"],

Cell["Its columns are linearly independent:", "Text",
 FontFamily->"Courier"],

Cell[BoxData[
 RowBox[{"Det", "[", 
  RowBox[{"\[CapitalPhi]", "[", "t", "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Simplify", "[", "%", "]"}]], "Input"],

Cell["THE fundamental matrix also solves the DE:", "Text",
 FontFamily->"Courier"],

Cell[BoxData[
 RowBox[{"D", "[", 
  RowBox[{
   RowBox[{"\[CapitalPhi]", "[", "t", "]"}], ",", "t"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Expand", "[", "%", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"A", "[", "\[Alpha]", "]"}], ".", 
  RowBox[{"\[CapitalPhi]", "[", "t", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"Expand", "[", "%", "]"}]], "Input"],

Cell["too hard on my eyes!", "Text"],

Cell[BoxData[
 RowBox[{"Expand", "[", "  ", 
  RowBox[{
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{"\[CapitalPhi]", "[", "t", "]"}], ",", "t"}], "]"}], " ", "-", 
   " ", 
   RowBox[{
    RowBox[{"A", "[", "\[Alpha]", "]"}], ".", 
    RowBox[{"\[CapitalPhi]", "[", "t", "]"}]}]}], "  ", "]"}]], "Input"],

Cell["At t0=0, it is the identity matrix:", "Text",
 FontFamily->"Courier"],

Cell[BoxData[
 RowBox[{"\[CapitalPhi]", "[", "0", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Expand", "[", "%", "]"}]], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  RowBox[{"\[Alpha]", " ", ">", " ", 
   RowBox[{"2", 
    SqrtBox["5"]}]}]],
  TextAlignment->Left],
 ",   in general"
}], "Subsection",
 CellFrame->{{0, 0}, {0, 0.5}}],

Cell[BoxData[
 RowBox[{"\t", 
  RowBox[{
   RowBox[{"r1", " ", "=", " ", 
    RowBox[{
     FractionBox[
      RowBox[{"\[Alpha]", "+", 
       SqrtBox[
        RowBox[{
         RowBox[{"-", "20"}], "+", 
         SuperscriptBox["\[Alpha]", "2"]}]]}], "2"], " ", ">", " ", "0"}]}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"since", " ", 
     RowBox[{"we", "'"}], "re", " ", "adding", " ", "two", " ", "positive", 
     " ", 
     RowBox[{
     "values", ".", "\[IndentingNewLine]", "\[IndentingNewLine]", "r2"}]}], 
    " ", "=", " ", 
    RowBox[{
     FractionBox[
      RowBox[{"\[Alpha]", "-", 
       SqrtBox[
        RowBox[{
         RowBox[{"-", "20"}], "+", 
         SuperscriptBox["\[Alpha]", "2"]}]]}], "2"], " ", "<", " ", "0"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"r2", ">", 
     RowBox[{"0", " ", "since", " ", "0"}], " ", "<", " ", 
     RowBox[{
      SuperscriptBox["\[Alpha]", "2"], " ", "-", " ", "20"}], " ", "<", 
     SuperscriptBox["\[Alpha]", "2"]}], " ", ",", " ", "\[IndentingNewLine]", 
    
    RowBox[{
     RowBox[{
      RowBox[{"so", " ", "that", "              ", "0"}], " ", "<", " ", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["\[Alpha]", "2"], " ", "-", " ", "20", " "}]], " ", 
      "<", " ", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["\[Alpha]", "2"], " "}]]}], "=", " ", 
     RowBox[{"|", "\[Alpha]", "|"}]}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"so", " ", "that", "              ", "0"}], " ", ">", " ", 
      RowBox[{"-", " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["\[Alpha]", "2"], " ", "-", " ", "20", " "}]]}], " ", 
      ">", " ", 
      RowBox[{"-", " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["\[Alpha]", "2"], " "}]]}]}], "=", " ", 
     RowBox[{"-", 
      RowBox[{"|", "\[Alpha]", "|"}]}]}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"so", " ", "that", "   ", "\[Alpha]"}], " ", "-", "  ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["\[Alpha]", "2"], " ", "-", " ", "20", " "}]]}], " ", 
      ">", " ", 
      RowBox[{"\[Alpha]", " ", "-", "  ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["\[Alpha]", "2"], " "}]]}]}], "=", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Alpha]", " ", "-"}], "  ", "|", "\[Alpha]", "|"}], " ", "=",
       " ", 
      RowBox[{
       RowBox[{
       "0", " ", ".", "\[IndentingNewLine]", "\[IndentingNewLine]", "Both"}], 
       " ", "eigenvalues", " ", "have", " ", "the", " ", "same", " ", "sign", 
       " ", "and", " ", "are", " ", "unequal"}]}]}], ",", " ", 
    RowBox[{"so", " ", "the", " ", "origin", " ", "is", " ", "a", " ", 
     RowBox[{"node", ".", "  ", "Both"}], " ", "eigenvalues", " ", "are", " ",
      "positive"}], ",", " ", 
    RowBox[{
    "so", " ", "our", " ", "solutions", " ", "will", " ", "have", " ", "an", 
     " ", "exponential", " ", "growth"}], ",", " ", 
    RowBox[{"making", " ", "the", " ", "node", " ", 
     RowBox[{"unstable", ".", "  ", "That"}], " ", "is"}], ",", " ", 
    RowBox[{
     RowBox[{"trajectories", " ", "in", " ", "the", " ", "x"}], "-", 
     RowBox[{
     "y", " ", "plane", " ", "tend", " ", "away", " ", "from", " ", "the", 
      " ", "origin", " ", "for", " ", "any", " ", "initial", " ", 
      RowBox[{"conditions", "."}]}]}]}]}]}]], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  RowBox[{
   RowBox[{"Example", ":", "\[Alpha]"}], "=", 
   RowBox[{"10", ">", " ", 
    RowBox[{"2", 
     SqrtBox["5"]}]}]}]],
  TextAlignment->Left],
 " gory detail"
}], "Subsection",
 CellFrame->{{0, 0}, {0, 0.5}}],

Cell[CellGroupData[{

Cell["solution from the eigenmethod", "Subsubsection"],

Cell[BoxData[{
 RowBox[{"Clear", "[", "\[Alpha]", "]"}], "\n", 
 RowBox[{"\[Alpha]", "=", "10"}], "\n", 
 RowBox[{"A", "[", "\[Alpha]", "]"}]}], "Input"],

Cell[BoxData[
 RowBox[{"Eigensystem", "[", 
  RowBox[{"A", "[", "\[Alpha]", "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"N", "[", "%", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"There", " ", "are", " ", "two", " ", "linearly", " ", "independent",
   " ", "solutions", " ", "to", " ", "the", " ", "DE", " ", "from", " ", 
  "this", " ", 
  RowBox[{"method", ":", " ", "\[IndentingNewLine]", " ", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"5", "-", 
        RowBox[{"2", " ", 
         SqrtBox["5"]}]}], ")"}], " ", "t"}]], 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "5"}], "-", 
       RowBox[{"2", " ", 
        SqrtBox["5"]}]}], ",", "1"}], "}"}], " ", "and", "  ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"5", "+", 
        RowBox[{"2", " ", 
         SqrtBox["5"]}]}], ")"}], " ", "t"}]], 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "5"}], "+", 
        RowBox[{"2", " ", 
         SqrtBox["5"]}]}], ",", "1"}], "}"}], " ", "."}]}]}]}]], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
  "Because", " ", "the", " ", "eigenvalues", " ", "are", " ", "real", " ", 
   "and", " ", "different"}], ",", " ", 
  RowBox[{
   RowBox[{
   "we", " ", "may", " ", "obtain", " ", "an", " ", "idea", " ", "of", " ", 
    "the", " ", "trajectories", " ", "by", " ", "plotting", " ", "the", " ", 
    "eigenvectors", " ", "and", " ", "the", " ", "lines", " ", "they", " ", 
    "individually", " ", 
    RowBox[{"generate", ".", "  ", "\[IndentingNewLine]", "The"}], " ", 
    "first", " ", "eigenvector", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"5", "-", 
       RowBox[{"2", " ", 
        SqrtBox["5"]}]}], ",", "1"}], "}"}], " ", "lies", " ", "on", " ", 
    "the", " ", "line", " ", "y"}], " ", "=", "  ", 
   RowBox[{
    RowBox[{
     RowBox[{"1", "/", 
      RowBox[{"(", 
       RowBox[{"5", "-", 
        RowBox[{"2", " ", 
         SqrtBox["5"]}]}], " ", ")"}]}], " ", 
     RowBox[{"x", ".", " ", "\[IndentingNewLine]", " ", "The"}], "  ", 
     "second", " ", "eigenvector", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"5", "+", 
        RowBox[{"2", " ", 
         SqrtBox["5"]}]}], ",", "1"}], "}"}], " ", "lies", " ", "on", " ", 
     "the", " ", "line", " ", "y"}], " ", "=", "  ", 
    RowBox[{
     RowBox[{"1", "/", 
      RowBox[{"(", 
       RowBox[{"5", "+", 
        RowBox[{"2", " ", 
         SqrtBox["5"]}]}], " ", ")"}]}], " ", 
     RowBox[{"x", "."}]}]}]}]}]], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["a fundamental matrix", "Subsubsection"],

Cell[BoxData[
 RowBox[{"MatrixForm", "[", 
  RowBox[{"Transpose", "[", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"5", "-", 
          RowBox[{"2", " ", 
           SqrtBox["5"]}]}], ")"}], " ", "t"}]], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "5"}], "-", 
         RowBox[{"2", " ", 
          SqrtBox["5"]}]}], ",", "1"}], "}"}]}], ",", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"5", "+", 
          RowBox[{"2", " ", 
           SqrtBox["5"]}]}], ")"}], " ", "t"}]], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "5"}], "+", 
         RowBox[{"2", " ", 
          SqrtBox["5"]}]}], ",", "1"}], "}"}]}]}], "}"}], "]"}], 
  "]"}]], "Input"],

Cell[BoxData[{
 RowBox[{"Clear", "[", "\[CapitalPsi]", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[CapitalPsi]", "[", "t_", "]"}], ":=", 
  TagBox[
   RowBox[{"(", "\[NoBreak]", GridBox[{
      {
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "-", 
          RowBox[{"2", " ", 
           SqrtBox["5"]}]}], ")"}], " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"5", "-", 
            RowBox[{"2", " ", 
             SqrtBox["5"]}]}], ")"}], " ", "t"}]]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          RowBox[{"2", " ", 
           SqrtBox["5"]}]}], ")"}], " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"5", "+", 
            RowBox[{"2", " ", 
             SqrtBox["5"]}]}], ")"}], " ", "t"}]]}]},
      {
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"5", "-", 
           RowBox[{"2", " ", 
            SqrtBox["5"]}]}], ")"}], " ", "t"}]], 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"5", "+", 
           RowBox[{"2", " ", 
            SqrtBox["5"]}]}], ")"}], " ", "t"}]]}
     }], "\[NoBreak]", ")"}],
   MatrixForm[#]& ]}]}], "Input"],

Cell[BoxData[
 RowBox[{"Det", "[", 
  RowBox[{"\[CapitalPsi]", "[", "t", "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Simplify", "[", "%", "]"}]], "Input"],

Cell["Note that a fundamental matrix also solves the DE.", "Text",
 FontFamily->"Courier"],

Cell[BoxData[
 RowBox[{"D", "[", 
  RowBox[{
   RowBox[{"\[CapitalPsi]", "[", "t", "]"}], ",", "t"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Expand", "[", "%", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"A", "[", "\[Alpha]", "]"}], ".", 
  RowBox[{"\[CapitalPsi]", "[", "t", "]"}]}]], "Input"],

Cell["hard to tell like this, but the difference should be zero.", "Text"],

Cell[BoxData[
 RowBox[{"Expand", "[", "  ", 
  RowBox[{
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{"\[CapitalPsi]", "[", "t", "]"}], ",", "t"}], "]"}], " ", "-", 
   " ", 
   RowBox[{
    RowBox[{"A", "[", "\[Alpha]", "]"}], ".", 
    RowBox[{"\[CapitalPsi]", "[", "t", "]"}]}]}], " ", "]"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["general solution, behavior", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{
  "The", " ", "general", " ", "solution", " ", "is", "      ", "c1", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "5"}], "-", 
       RowBox[{"2", " ", 
        SqrtBox["5"]}]}], ")"}], " ", "t"}]], 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"5", "-", 
      RowBox[{"2", " ", 
       SqrtBox["5"]}]}], ",", "1"}], "}"}]}], " ", "+", " ", 
  RowBox[{"c2", "  ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "5"}], "+", 
       RowBox[{"2", " ", 
        SqrtBox["5"]}]}], ")"}], " ", "t"}]], 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"5", "+", 
       RowBox[{"2", " ", 
        SqrtBox["5"]}]}], ",", "1"}], "}"}], " ", "."}]}]}]], "Text"],

Cell[BoxData[
 RowBox[{"Expand", "[", " ", 
  RowBox[{
   RowBox[{"c1", "  ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"5", "-", 
        RowBox[{"2", " ", 
         SqrtBox["5"]}]}], ")"}], " ", "t"}]], 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "5"}], "-", 
       RowBox[{"2", " ", 
        SqrtBox["5"]}]}], ",", "1"}], "}"}]}], "+", " ", 
   RowBox[{"c2", "  ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"5", "+", 
        RowBox[{"2", " ", 
         SqrtBox["5"]}]}], ")"}], " ", "t"}]], 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "5"}], "+", 
       RowBox[{"2", " ", 
        SqrtBox["5"]}]}], ",", "1"}], "}"}]}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Collect", "[", 
  RowBox[{"%", ",", 
   RowBox[{"{", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"5", "-", 
         RowBox[{"2", " ", 
          SqrtBox["5"]}]}], ")"}], " ", "t"}]], ",", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"5", "+", 
         RowBox[{"2", " ", 
          SqrtBox["5"]}]}], ")"}], " ", "t"}]]}], " ", "}"}]}], 
  "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Note", " ", "that", " ", "for", " ", "these", " ", "solutions"}], 
   ",", " ", 
   RowBox[{"for", " ", "any", " ", "c1", " ", "and", " ", "c2"}], ",", "  ", 
   RowBox[{
   "since", " ", "\[ExponentialE]", " ", "is", " ", "raised", " ", "to", " ", 
    "a", " ", "positive", " ", "value"}], ",", " ", 
   RowBox[{
   "both", " ", "components", " ", "tend", " ", "to", " ", "infinity", " ", 
    "as", " ", "t", " ", 
    RowBox[{"increases", ".", "  ", "Thus"}]}], ",", 
   RowBox[{
   "the", " ", "origin", " ", "is", " ", "an", " ", "unstable", " ", "node", 
    " ", "for", " ", "this", " ", "value", " ", "of", " ", 
    RowBox[{"\[Alpha]", ".", "\[IndentingNewLine]"}]}]}]}]], "Text"],

Cell["components of x[t] and y[t]", "Text"],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", " ", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "5"}], "-", 
         RowBox[{"2", " ", 
          SqrtBox["5"]}]}], ")"}], " ", "t"}]], ",", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "5"}], "+", 
         RowBox[{"2", " ", 
          SqrtBox["5"]}]}], ")"}], " ", "t"}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "4"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<t\>\"", ",", "\"\<components\>\""}], "}"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{3.43520395828125*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"5", " ", "c1"}], "-", 
        RowBox[{"2", " ", 
         SqrtBox["5"], " ", "c1"}]}], ")"}], " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "-", 
          RowBox[{"2", " ", 
           SqrtBox["5"]}]}], ")"}], " ", "t"}]]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"5", " ", "c2"}], "+", 
        RowBox[{"2", " ", 
         SqrtBox["5"], " ", "c2"}]}], ")"}], " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          RowBox[{"2", " ", 
           SqrtBox["5"]}]}], ")"}], " ", "t"}]]}]}], ",", 
    RowBox[{
     RowBox[{"c1", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "-", 
          RowBox[{"2", " ", 
           SqrtBox["5"]}]}], ")"}], " ", "t"}]]}], "+", 
     RowBox[{"c2", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          RowBox[{"2", " ", 
           SqrtBox["5"]}]}], ")"}], " ", "t"}]]}]}]}], "}"}], "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"c1", "\[Rule]", "1"}], ",", 
    RowBox[{"c2", "\[Rule]", "1"}]}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"5", "-", 
        RowBox[{"2", " ", 
         SqrtBox["5"]}]}], ")"}], " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "-", 
          RowBox[{"2", " ", 
           SqrtBox["5"]}]}], ")"}], " ", "t"}]]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"5", "+", 
        RowBox[{"2", " ", 
         SqrtBox["5"]}]}], ")"}], " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          RowBox[{"2", " ", 
           SqrtBox["5"]}]}], ")"}], " ", "t"}]]}]}], ",", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "5"}], "-", 
         RowBox[{"2", " ", 
          SqrtBox["5"]}]}], ")"}], " ", "t"}]], "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "5"}], "+", 
         RowBox[{"2", " ", 
          SqrtBox["5"]}]}], ")"}], " ", "t"}]]}]}], "}"}], "/.", 
  RowBox[{"t", "\[Rule]", "0"}]}]], "Input"],

Cell["The trajectory begins at (10,2) in the phase plane.", "Text"],

Cell[BoxData[
 RowBox[{"ParametricPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"5", "-", 
         RowBox[{"2", " ", 
          SqrtBox["5"]}]}], ")"}], " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "5"}], "-", 
           RowBox[{"2", " ", 
            SqrtBox["5"]}]}], ")"}], " ", "t"}]]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"5", "+", 
         RowBox[{"2", " ", 
          SqrtBox["5"]}]}], ")"}], " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "5"}], "+", 
           RowBox[{"2", " ", 
            SqrtBox["5"]}]}], ")"}], " ", "t"}]]}]}], ",", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "-", 
          RowBox[{"2", " ", 
           SqrtBox["5"]}]}], ")"}], " ", "t"}]], "+", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          RowBox[{"2", " ", 
           SqrtBox["5"]}]}], ")"}], " ", "t"}]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "10"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<x[t]\>\"", ",", "\"\<y[t]\>\""}], "}"}]}]}], "]"}]], "Input",\

 CellChangeTimes->{3.435203964421875*^9}],

Cell["This trajectory tends toward the origin.", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"fcnlist", "=", 
   RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{"AppendTo", "[", 
    RowBox[{"fcnlist", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"5", " ", "c1"}], "-", 
           RowBox[{"2", " ", 
            SqrtBox["5"], " ", "c1"}]}], ")"}], " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "5"}], "-", 
             RowBox[{"2", " ", 
              SqrtBox["5"]}]}], ")"}], " ", "t"}]]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"5", " ", "c2"}], "+", 
           RowBox[{"2", " ", 
            SqrtBox["5"], " ", "c2"}]}], ")"}], " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "5"}], "+", 
             RowBox[{"2", " ", 
              SqrtBox["5"]}]}], ")"}], " ", "t"}]]}]}], ",", 
       RowBox[{
        RowBox[{"c1", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "5"}], "-", 
             RowBox[{"2", " ", 
              SqrtBox["5"]}]}], ")"}], " ", "t"}]]}], "+", 
        RowBox[{"c2", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "5"}], "+", 
             RowBox[{"2", " ", 
              SqrtBox["5"]}]}], ")"}], " ", "t"}]]}]}]}], "}"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"c1", ",", 
     RowBox[{"-", "2"}], ",", "2", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"c2", ",", 
     RowBox[{"-", "3"}], ",", "3", ",", "3"}], "}"}]}], 
  "]"}], "\[IndentingNewLine]", "fcnlist"}], "Input"],

Cell["\<\
phase plane for several trajectories.  Look for the lines generated by the \
eigenvectors.\
\>", "Text"],

Cell[BoxData[{
 RowBox[{"Clear", "[", "p5", "]"}], "\[IndentingNewLine]", 
 RowBox[{"p5", "=", 
  RowBox[{"ParametricPlot", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", "fcnlist", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "10"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<x[t]\>\"", ",", "\"\<y[t]\>\""}], "}"}]}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "4"}], ",", "4"}], "}"}]}], "}"}]}]}], 
   "]"}]}]}], "Input",
 CellChangeTimes->{3.435203971296875*^9}],

Cell["\<\
We can also generate functions with specific initial conditions.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"5", " ", "c1"}], "-", 
        RowBox[{"2", " ", 
         SqrtBox["5"], " ", "c1"}]}], ")"}], " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "-", 
          RowBox[{"2", " ", 
           SqrtBox["5"]}]}], ")"}], " ", "t"}]]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"5", " ", "c2"}], "+", 
        RowBox[{"2", " ", 
         SqrtBox["5"], " ", "c2"}]}], ")"}], " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          RowBox[{"2", " ", 
           SqrtBox["5"]}]}], ")"}], " ", "t"}]]}]}], ",", 
    RowBox[{
     RowBox[{"c1", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "-", 
          RowBox[{"2", " ", 
           SqrtBox["5"]}]}], ")"}], " ", "t"}]]}], "+", 
     RowBox[{"c2", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          RowBox[{"2", " ", 
           SqrtBox["5"]}]}], ")"}], " ", "t"}]]}]}]}], "}"}], "/.", 
  RowBox[{"t", "\[Rule]", "0"}]}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"fcnlist2", "=", 
   RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Do", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Clear", "[", 
      RowBox[{"ThisRule", ",", "ThisFcn"}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"ThisRule", "=", 
      RowBox[{"Flatten", "[", 
       RowBox[{"Solve", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"5", " ", "c1"}], "-", 
             RowBox[{"2", " ", 
              SqrtBox["5"], " ", "c1"}], "+", 
             RowBox[{"5", " ", "c2"}], "+", 
             RowBox[{"2", " ", 
              SqrtBox["5"], " ", "c2"}]}], ",", 
            RowBox[{"c1", "+", "c2"}]}], "}"}], "\[Equal]", 
          RowBox[{"{", 
           RowBox[{"a", ",", "b"}], "}"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"c1", ",", "c2"}], "}"}]}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"ThisFcn", "=", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"5", " ", "c1"}], "-", 
             RowBox[{"2", " ", 
              SqrtBox["5"], " ", "c1"}]}], ")"}], " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "5"}], "-", 
               RowBox[{"2", " ", 
                SqrtBox["5"]}]}], ")"}], " ", "t"}]]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"5", " ", "c2"}], "+", 
             RowBox[{"2", " ", 
              SqrtBox["5"], " ", "c2"}]}], ")"}], " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "5"}], "+", 
               RowBox[{"2", " ", 
                SqrtBox["5"]}]}], ")"}], " ", "t"}]]}]}], ",", 
         RowBox[{
          RowBox[{"c1", " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "5"}], "-", 
               RowBox[{"2", " ", 
                SqrtBox["5"]}]}], ")"}], " ", "t"}]]}], "+", 
          RowBox[{"c2", " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "5"}], "+", 
               RowBox[{"2", " ", 
                SqrtBox["5"]}]}], ")"}], " ", "t"}]]}]}]}], "}"}], "/.", 
       "ThisRule"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"AppendTo", "[", 
      RowBox[{"fcnlist2", ",", "ThisFcn"}], "]"}]}], ",", 
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"a", ",", 
      RowBox[{"-", "4"}], ",", "4", ",", "4"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"b", ",", 
      RowBox[{"-", "4"}], ",", "4", ",", "4"}], "}"}]}], "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Clear", "[", "p6", "]"}], "\[IndentingNewLine]", 
 RowBox[{"p6", "=", 
  RowBox[{"ParametricPlot", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", "fcnlist2", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "10"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<x[t]\>\"", ",", "\"\<y[t]\>\""}], "}"}]}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "6"}], ",", "6"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "6"}], ",", "6"}], "}"}]}], "}"}]}]}], 
   "]"}]}]}], "Input",
 CellChangeTimes->{3.435203981046875*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["direction field", "Subsubsection"],

Cell["\<\
Load the Graphics`PlotField` package BEFORE trying to generate the direction \
field.Load the package once perMathematicasession.If you change \
anything,generate the direction field again.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"<<", "Graphics`PlotField`"}]], "Input",
 ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Remember that we obtain the coordinates of the direction field from \
{x'[t],y'[t]},which is given by the matrix product A.{x[t],y[t]}.To avoid \
confusing the {x,y} used here with ones plotted elsewhere,we'll call these \
{x1,y1}.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"A", "[", "\[Alpha]", "]"}], ".", 
  RowBox[{"{", 
   RowBox[{"x1", ",", "y1"}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "5"}], " ", "y1"}], ",", 
   RowBox[{"x1", "-", 
    RowBox[{"2", " ", 
     SqrtBox["5"], " ", "y1"}]}]}], "}"}]], "Input"],

Cell[BoxData[{
 RowBox[{"Clear", "[", "p4", "]"}], "\[IndentingNewLine]", 
 RowBox[{"p4", "=", 
  RowBox[{"PlotVectorField", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "5"}], " ", "y1"}], ",", 
      RowBox[{"x1", "-", 
       RowBox[{"2", " ", 
        SqrtBox["5"], " ", "y1"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"x1", ",", 
      RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"y1", ",", 
      RowBox[{"-", "4"}], ",", "4"}], "}"}]}], "]"}]}]}], "Input",
 CellChangeTimes->{3.435203992765625*^9},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"p5", ",", "p4"}], "}"}], ",", 
   RowBox[{"Axes", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "4"}], ",", "4"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<x[t]\>\"", ",", "\"\<y[t]\>\""}], "}"}]}], ",", 
   RowBox[{"AspectRatio", "\[Rule]", "Automatic"}]}], "]"}]], "Input",
 CellChangeTimes->{3.43520399859375*^9}],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"p6", ",", "p4"}], "}"}], ",", 
   RowBox[{"Axes", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "4"}], ",", "4"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<x[t]\>\"", ",", "\"\<y[t]\>\""}], "}"}]}], ",", 
   RowBox[{"AspectRatio", "\[Rule]", "Automatic"}]}], "]"}]], "Input",
 CellChangeTimes->{3.4352040024375*^9}],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"p6", ",", "p5", ",", "p4"}], "}"}], ",", 
   RowBox[{"Axes", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "4"}], ",", "4"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<x[t]\>\"", ",", "\"\<y[t]\>\""}], "}"}]}], ",", 
   RowBox[{"AspectRatio", "\[Rule]", "Automatic"}]}], "]"}]], "Input",
 CellChangeTimes->{3.4352040045625*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["describe the system,using appropriate vocabulary.", "Subsubsection"],

Cell[TextData[{
 "Consider the system z'=",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"0", ",", 
      RowBox[{"-", "5"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"1", ",", 
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       SqrtBox["5"]}]}], "}"}]}], "}"}]]],
 "z.\nThe origin is a stable improper node.\n\nFrom the eigenvalue alone:  \
Since the eigenvalue is real and repeated and did not yield a full set of \
linearly independent eigenvectors, the origin is an improper node.  Since the \
eigenvalue is negative, the node is stable.\n\nFurthermore, the {t,x[t]} and \
{t,y[t]} graphs tend to zero, indicating that as time progresses, the x and y \
components of the x-y graph approach the origin, yielding stability.  In \
addition, the direction field indicates that the trajectories rotate \
counterclockwise toward the origin, again yielding stability."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["THE fundamental matrix", "Subsubsection"],

Cell["\<\
Take any fundamental matrix \[CapitalPsi][t] and compute \
\[CapitalPsi][t].Inverse[\[CapitalPsi][0]]:\
\>", "Text",
 FontFamily->"Courier"],

Cell[BoxData[
 RowBox[{"\[CapitalPsi]", "[", "0", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Inverse", "[", "  ", 
  RowBox[{"\[CapitalPsi]", "[", "0", "]"}], "  ", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[CapitalPsi]", "[", "t", "]"}], " ", ".", " ", 
  RowBox[{"Inverse", "[", "  ", 
   RowBox[{"\[CapitalPsi]", "[", "0", "]"}], "  ", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"MatrixForm", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.435204009046875*^9, 3.43520401203125*^9}}],

Cell[BoxData[{
 RowBox[{"Clear", "[", "\[CapitalPhi]", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[CapitalPhi]", "[", "t_", "]"}], ":=", 
  TagBox[
   RowBox[{"(", "\[NoBreak]", GridBox[{
      {
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "5"}], "-", 
             RowBox[{"2", " ", 
              SqrtBox["5"]}]}], ")"}], " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"5", "-", 
               RowBox[{"2", " ", 
                SqrtBox["5"]}]}], ")"}], " ", "t"}]]}], 
          RowBox[{"4", " ", 
           SqrtBox["5"]}]]}], "+", 
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "5"}], "+", 
            RowBox[{"2", " ", 
             SqrtBox["5"]}]}], ")"}], " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"5", "+", 
              RowBox[{"2", " ", 
               SqrtBox["5"]}]}], ")"}], " ", "t"}]]}], 
         RowBox[{"4", " ", 
          SqrtBox["5"]}]]}], 
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "5"}], "-", 
             RowBox[{"2", " ", 
              SqrtBox["5"]}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"5", "-", 
             RowBox[{"2", " ", 
              SqrtBox["5"]}]}], ")"}], " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"5", "-", 
               RowBox[{"2", " ", 
                SqrtBox["5"]}]}], ")"}], " ", "t"}]]}], 
          RowBox[{"4", " ", 
           SqrtBox["5"]}]]}], "-", 
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "5"}], "-", 
            RowBox[{"2", " ", 
             SqrtBox["5"]}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "5"}], "+", 
            RowBox[{"2", " ", 
             SqrtBox["5"]}]}], ")"}], " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"5", "+", 
              RowBox[{"2", " ", 
               SqrtBox["5"]}]}], ")"}], " ", "t"}]]}], 
         RowBox[{"4", " ", 
          SqrtBox["5"]}]]}]},
      {
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"5", "-", 
              RowBox[{"2", " ", 
               SqrtBox["5"]}]}], ")"}], " ", "t"}]], 
          RowBox[{"4", " ", 
           SqrtBox["5"]}]]}], "+", 
        FractionBox[
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"5", "+", 
             RowBox[{"2", " ", 
              SqrtBox["5"]}]}], ")"}], " ", "t"}]], 
         RowBox[{"4", " ", 
          SqrtBox["5"]}]]}], 
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{"5", "-", 
             RowBox[{"2", " ", 
              SqrtBox["5"]}]}], ")"}], " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"5", "-", 
               RowBox[{"2", " ", 
                SqrtBox["5"]}]}], ")"}], " ", "t"}]]}], 
          RowBox[{"4", " ", 
           SqrtBox["5"]}]]}], "-", 
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "5"}], "-", 
            RowBox[{"2", " ", 
             SqrtBox["5"]}]}], ")"}], " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"5", "+", 
              RowBox[{"2", " ", 
               SqrtBox["5"]}]}], ")"}], " ", "t"}]]}], 
         RowBox[{"4", " ", 
          SqrtBox["5"]}]]}]}
     }], "\[NoBreak]", ")"}],
   MatrixForm[#]& ]}]}], "Input"],

Cell["Check the properties of THE fundamental matrix:", "Text",
 FontFamily->"Courier"],

Cell["Its columns are linearly independent:", "Text",
 FontFamily->"Courier"],

Cell[BoxData[
 RowBox[{"Det", "[", 
  RowBox[{"\[CapitalPhi]", "[", "t", "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Simplify", "[", "%", "]"}]], "Input"],

Cell["THE fundamental matrix also solves the DE:", "Text",
 FontFamily->"Courier"],

Cell[BoxData[
 RowBox[{"D", "[", 
  RowBox[{
   RowBox[{"\[CapitalPhi]", "[", "t", "]"}], ",", "t"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Expand", "[", "%", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"A", "[", "\[Alpha]", "]"}], ".", 
  RowBox[{"\[CapitalPhi]", "[", "t", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"Expand", "[", "%", "]"}]], "Input"],

Cell["too hard on my eyes!", "Text"],

Cell[BoxData[
 RowBox[{"Expand", "[", "  ", 
  RowBox[{
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{"\[CapitalPhi]", "[", "t", "]"}], ",", "t"}], "]"}], " ", "-", 
   " ", 
   RowBox[{
    RowBox[{"A", "[", "\[Alpha]", "]"}], ".", 
    RowBox[{"\[CapitalPhi]", "[", "t", "]"}]}]}], "  ", "]"}]], "Input"],

Cell["At t0=0, it is the identity matrix:", "Text",
 FontFamily->"Courier"],

Cell[BoxData[
 RowBox[{"\[CapitalPhi]", "[", "0", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Expand", "[", "%", "]"}]], "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["complex roots", "Section",
 CellFrame->{{0, 0}, {0, 2}}],

Cell[TextData[{
 "\n",
 StyleBox["case (3) ",
  FontFamily->"Courier"],
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"-", "20"}], "+", 
    SuperscriptBox["\[Alpha]", "2"]}], "<", "0"}]]],
 StyleBox[".\n  ",
  FontFamily->"Courier"],
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"-", "2"}], 
    SqrtBox["5"]}], " ", "<", " ", "\[Alpha]", " ", "<", " ", 
   RowBox[{"2", " ", 
    SqrtBox["5"]}]}]]],
 StyleBox[".\n  Note that the eigenvalues are r1 = \[Lambda] + \[ImaginaryI] \
\[Mu] and  r2 = \[Lambda] - \[ImaginaryI] \[Mu] where \[Lambda]=",
  FontFamily->"Courier"],
 Cell[BoxData[
  FractionBox["\[Alpha]", "2"]]],
 " and \[Mu]=",
 Cell[BoxData[
  FractionBox[
   SqrtBox[
    RowBox[{"20", "-", 
     SuperscriptBox["\[Alpha]", "2"]}]], "2"]]],
 StyleBox["\n  \n  Really 3 cases.\ncase (3n) ",
  FontFamily->"Courier"],
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"-", "2"}], 
    SqrtBox["5"]}], " ", "<", " ", "\[Alpha]", " ", "<", " ", "0"}]]],
 StyleBox[" \ncase (3z)  \[Alpha] = 0\ncase (3p)  ",
  FontFamily->"Courier"],
 Cell[BoxData[
  RowBox[{"0", " ", "<", " ", "\[Alpha]", " ", "<", " ", 
   RowBox[{"2", " ", 
    SqrtBox["5"]}]}]]]
}], "Text"],

Cell[TextData[{
 StyleBox["case (3n) ",
  FontFamily->"Courier"],
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"-", "2"}], 
    SqrtBox["5"]}], " ", "<", " ", "\[Alpha]", " ", "<", " ", "0"}]]],
 StyleBox[" \n  Complex solutions with a real part result in spirals.  Since \
the real part of the eigenvalues are negative, the origin is a stable spiral.\
\n",
  FontFamily->"Courier"]
}], "Text"],

Cell[TextData[StyleBox["case (3z)  \[Alpha] = 0\n  Since the eigenvalues are \
purely imaginary, there is no exponential damping or growth in the solutions, \
so the solutions oscillate with constant amplitute.  This makes the origin a \
center in the x-y plane.\n",
 FontFamily->"Courier"]], "Text"],

Cell[TextData[{
 StyleBox["case (3p)  ",
  FontFamily->"Courier"],
 Cell[BoxData[
  RowBox[{"0", " ", "<", " ", "\[Alpha]", " ", "<", " ", 
   RowBox[{"2", " ", 
    SqrtBox["5"]}]}]]],
 "\n",
 "  ",
 StyleBox["Complex solutions with a real part result in spirals.  Since the \
real part of the eigenvalues are positive, the origin is an unstable spiral.",
  
  FontFamily->"Courier"]
}], "Text"]
}, Open  ]]
}, Open  ]]
},
WindowSize->{773, 667},
WindowMargins->{{20, Automatic}, {Automatic, 25}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
Magnification->1,
FrontEndVersion->"8.0 for Microsoft Windows (64-bit) (November 7, 2010)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 561, 16, 68, "Subsubtitle"],
Cell[CellGroupData[{
Cell[1153, 42, 63, 1, 72, "Section"],
Cell[1219, 45, 184, 7, 42, "Input"],
Cell[1406, 54, 99, 2, 31, "Input"],
Cell[1508, 58, 203, 7, 33, "Input"],
Cell[1714, 67, 54, 1, 31, "Input"],
Cell[1771, 70, 289, 9, 33, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2097, 84, 62, 1, 72, "Section"],
Cell[2162, 87, 1667, 38, 145, "Text"],
Cell[CellGroupData[{
Cell[3854, 129, 208, 9, 48, "Subsection"],
Cell[CellGroupData[{
Cell[4087, 142, 54, 0, 27, "Subsubsection"],
Cell[4144, 144, 174, 5, 54, "Input"],
Cell[4321, 151, 61, 1, 31, "Input"],
Cell[4385, 154, 99, 2, 31, "Input"],
Cell[4487, 158, 675, 18, 80, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5199, 181, 66, 0, 27, "Subsubsection"],
Cell[5268, 183, 511, 17, 40, "Input"],
Cell[5782, 202, 1883, 52, 163, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7702, 259, 45, 0, 27, "Subsubsection"],
Cell[7750, 261, 830, 29, 41, "Input"],
Cell[8583, 292, 1061, 35, 80, "Input"],
Cell[9647, 329, 96, 2, 31, "Input"],
Cell[9746, 333, 90, 1, 29, "Text"],
Cell[9839, 336, 118, 3, 31, "Input"],
Cell[9960, 341, 124, 3, 31, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[10121, 349, 51, 0, 28, "Subsubsection"],
Cell[10175, 351, 857, 29, 45, "Text"],
Cell[11035, 382, 821, 28, 43, "Input"],
Cell[11859, 412, 126, 3, 31, "Input"],
Cell[11988, 417, 43, 0, 29, "Text"],
Cell[12034, 419, 633, 20, 68, "Input"],
Cell[12670, 441, 1436, 30, 182, "Text"],
Cell[14109, 473, 1040, 36, 41, "Input"],
Cell[15152, 511, 863, 31, 41, "Input"],
Cell[16018, 544, 54, 1, 31, "Input"],
Cell[16075, 547, 181, 8, 36, "Text"],
Cell[16259, 557, 1281, 42, 68, "Input"],
Cell[17543, 601, 56, 0, 29, "Text"],
Cell[17602, 603, 46, 0, 29, "Text"],
Cell[17651, 605, 1151, 38, 68, "Input"],
Cell[18805, 645, 1445, 46, 109, "Input"],
Cell[20253, 693, 52, 0, 29, "Text"],
Cell[20308, 695, 471, 12, 72, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[20816, 712, 40, 0, 28, "Subsubsection"],
Cell[20859, 714, 213, 4, 47, "Text"],
Cell[21075, 720, 95, 2, 31, "Input"],
Cell[21173, 724, 255, 5, 47, "Text"],
Cell[21431, 731, 133, 4, 31, "Input"],
Cell[21567, 737, 193, 7, 39, "Input"],
Cell[21763, 746, 616, 19, 59, "Input"],
Cell[22382, 767, 649, 19, 52, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23068, 791, 74, 0, 28, "Subsubsection"],
Cell[23145, 793, 915, 21, 180, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[24097, 819, 47, 0, 28, "Subsubsection"],
Cell[24147, 821, 150, 4, 29, "Text"],
Cell[24300, 827, 66, 1, 31, "Input"],
Cell[24369, 830, 100, 2, 31, "Input"],
Cell[24472, 834, 164, 4, 31, "Input"],
Cell[24639, 840, 59, 1, 31, "Input"],
Cell[24701, 843, 63, 1, 31, "Input"],
Cell[24767, 846, 1128, 36, 81, "Input"],
Cell[25898, 884, 87, 1, 29, "Text"],
Cell[25988, 887, 77, 1, 29, "Text"],
Cell[26068, 890, 96, 2, 31, "Input"],
Cell[26167, 894, 82, 1, 29, "Text"],
Cell[26252, 897, 118, 3, 31, "Input"],
Cell[26373, 902, 170, 6, 39, "Input"],
Cell[26546, 910, 59, 1, 31, "Input"],
Cell[26608, 913, 74, 1, 29, "Text"],
Cell[26685, 916, 66, 1, 31, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[26800, 923, 188, 8, 48, "Subsection"],
Cell[CellGroupData[{
Cell[27013, 935, 54, 0, 28, "Subsubsection"],
Cell[27070, 937, 155, 4, 54, "Input"],
Cell[27228, 943, 61, 1, 31, "Input"],
Cell[27292, 946, 99, 2, 31, "Input"],
Cell[27394, 950, 693, 19, 80, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[28124, 974, 66, 0, 28, "Subsubsection"],
Cell[28193, 976, 503, 17, 39, "Input"],
Cell[28699, 995, 1875, 52, 163, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[30611, 1052, 45, 0, 28, "Subsubsection"],
Cell[30659, 1054, 789, 28, 41, "Input"],
Cell[31451, 1084, 951, 31, 80, "Input"],
Cell[32405, 1117, 96, 2, 31, "Input"],
Cell[32504, 1121, 90, 1, 29, "Text"],
Cell[32597, 1124, 118, 3, 31, "Input"],
Cell[32718, 1129, 150, 5, 39, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[32905, 1139, 51, 0, 28, "Subsubsection"],
Cell[32959, 1141, 735, 26, 41, "Text"],
Cell[33697, 1169, 780, 27, 43, "Input"],
Cell[34480, 1198, 126, 3, 31, "Input"],
Cell[34609, 1203, 836, 28, 41, "Input"],
Cell[35448, 1233, 126, 3, 31, "Input"],
Cell[35577, 1238, 43, 0, 29, "Text"],
Cell[35623, 1240, 587, 18, 68, "Input"],
Cell[36213, 1260, 660, 14, 87, "Text"],
Cell[36876, 1276, 938, 32, 41, "Input"],
Cell[37817, 1310, 46, 0, 29, "Text"],
Cell[37866, 1312, 1018, 33, 68, "Input"],
Cell[38887, 1347, 1327, 41, 109, "Input"],
Cell[40217, 1390, 64, 0, 29, "Text"],
Cell[40284, 1392, 79, 2, 31, "Input"],
Cell[40366, 1396, 52, 0, 29, "Text"],
Cell[40421, 1398, 797, 23, 72, "Input"],
Cell[41221, 1423, 153, 3, 29, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[41411, 1431, 40, 0, 28, "Subsubsection"],
Cell[41454, 1433, 268, 6, 47, "Text"],
Cell[41725, 1441, 70, 1, 31, "Input"],
Cell[41798, 1444, 260, 5, 47, "Text"],
Cell[42061, 1451, 133, 4, 31, "Input"],
Cell[42197, 1457, 192, 7, 82, "Input"],
Cell[42392, 1466, 65, 0, 29, "Text"],
Cell[42460, 1468, 762, 21, 112, "Input"],
Cell[43225, 1491, 187, 4, 47, "Text"],
Cell[43415, 1497, 704, 19, 112, "Input"],
Cell[44122, 1518, 88, 2, 29, "Text"],
Cell[44213, 1522, 621, 22, 41, "Input"],
Cell[44837, 1546, 2710, 80, 283, "Input"],
Cell[47550, 1628, 769, 21, 112, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[48356, 1654, 74, 0, 28, "Subsubsection"],
Cell[48433, 1656, 943, 21, 180, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[49413, 1682, 47, 0, 28, "Subsubsection"],
Cell[49463, 1684, 150, 4, 29, "Text"],
Cell[49616, 1690, 66, 1, 31, "Input"],
Cell[49685, 1693, 112, 2, 31, "Input"],
Cell[49800, 1697, 186, 4, 31, "Input"],
Cell[49989, 1703, 59, 1, 31, "Input"],
Cell[50051, 1706, 63, 1, 31, "Input"],
Cell[50117, 1709, 1128, 36, 81, "Input"],
Cell[51248, 1747, 87, 1, 29, "Text"],
Cell[51338, 1750, 77, 1, 29, "Text"],
Cell[51418, 1753, 96, 2, 31, "Input"],
Cell[51517, 1757, 82, 1, 29, "Text"],
Cell[51602, 1760, 118, 3, 31, "Input"],
Cell[51723, 1765, 170, 6, 39, "Input"],
Cell[51896, 1773, 59, 1, 31, "Input"],
Cell[51958, 1776, 75, 1, 29, "Text"],
Cell[52036, 1779, 66, 1, 31, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[52163, 1787, 61, 1, 72, "Section"],
Cell[52227, 1790, 438, 19, 87, "Text"],
Cell[CellGroupData[{
Cell[52690, 1813, 210, 9, 48, "Subsection"],
Cell[52903, 1824, 2935, 78, 311, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[55875, 1907, 271, 12, 48, "Subsection"],
Cell[CellGroupData[{
Cell[56171, 1923, 54, 0, 28, "Subsubsection"],
Cell[56228, 1925, 171, 4, 72, "Input"],
Cell[56402, 1931, 99, 2, 31, "Input"],
Cell[56504, 1935, 54, 1, 31, "Input"],
Cell[56561, 1938, 969, 30, 65, "Text"],
Cell[57533, 1970, 1538, 44, 118, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[59108, 2019, 45, 0, 28, "Subsubsection"],
Cell[59156, 2021, 885, 31, 43, "Input"],
Cell[60044, 2054, 1444, 47, 92, "Input"],
Cell[61491, 2103, 96, 2, 31, "Input"],
Cell[61590, 2107, 61, 1, 31, "Input"],
Cell[61654, 2110, 90, 1, 29, "Text"],
Cell[61747, 2113, 118, 3, 31, "Input"],
Cell[61868, 2118, 59, 1, 31, "Input"],
Cell[61930, 2121, 124, 3, 31, "Input"],
Cell[62057, 2126, 74, 0, 29, "Text"],
Cell[62134, 2128, 307, 9, 31, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[62478, 2142, 51, 0, 28, "Subsubsection"],
Cell[62532, 2144, 820, 29, 45, "Text"],
Cell[63355, 2175, 788, 28, 43, "Input"],
Cell[64146, 2205, 540, 19, 43, "Input"],
Cell[64689, 2226, 753, 16, 87, "Text"],
Cell[65445, 2244, 43, 0, 29, "Text"],
Cell[65491, 2246, 790, 25, 70, "Input"],
Cell[66284, 2273, 1480, 51, 65, "Input"],
Cell[67767, 2326, 1248, 44, 43, "Input"],
Cell[69018, 2372, 68, 0, 29, "Text"],
Cell[69089, 2374, 1549, 51, 91, "Input"],
Cell[70641, 2427, 56, 0, 29, "Text"],
Cell[70700, 2429, 1926, 60, 117, "Input"],
Cell[72629, 2491, 114, 3, 29, "Text"],
Cell[72746, 2496, 739, 21, 72, "Input"],
Cell[73488, 2519, 88, 2, 29, "Text"],
Cell[73579, 2523, 1398, 48, 65, "Input"],
Cell[74980, 2573, 3778, 109, 319, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[78795, 2687, 40, 0, 28, "Subsubsection"],
Cell[78838, 2689, 263, 6, 47, "Text"],
Cell[79104, 2697, 95, 2, 31, "Input"],
Cell[79202, 2701, 255, 5, 47, "Text"],
Cell[79460, 2708, 133, 4, 31, "Input"],
Cell[79596, 2714, 590, 18, 52, "Input"],
Cell[80189, 2734, 649, 19, 52, "Input"],
Cell[80841, 2755, 649, 19, 52, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[81527, 2779, 74, 0, 28, "Subsubsection"],
Cell[81604, 2781, 770, 18, 173, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[82411, 2804, 47, 0, 28, "Subsubsection"],
Cell[82461, 2806, 150, 4, 29, "Text"],
Cell[82614, 2812, 66, 1, 31, "Input"],
Cell[82683, 2815, 112, 2, 31, "Input"],
Cell[82798, 2819, 186, 4, 31, "Input"],
Cell[82987, 2825, 63, 1, 31, "Input"],
Cell[83053, 2828, 4255, 137, 123, "Input"],
Cell[87311, 2967, 87, 1, 29, "Text"],
Cell[87401, 2970, 77, 1, 29, "Text"],
Cell[87481, 2973, 96, 2, 31, "Input"],
Cell[87580, 2977, 61, 1, 31, "Input"],
Cell[87644, 2980, 82, 1, 29, "Text"],
Cell[87729, 2983, 118, 3, 31, "Input"],
Cell[87850, 2988, 59, 1, 31, "Input"],
Cell[87912, 2991, 124, 3, 31, "Input"],
Cell[88039, 2996, 59, 1, 31, "Input"],
Cell[88101, 2999, 36, 0, 29, "Text"],
Cell[88140, 3001, 308, 9, 31, "Input"],
Cell[88451, 3012, 75, 1, 29, "Text"],
Cell[88529, 3015, 66, 1, 31, "Input"],
Cell[88598, 3018, 59, 1, 31, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[88706, 3025, 200, 8, 48, "Subsection"],
Cell[88909, 3035, 3412, 93, 338, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[92358, 3133, 250, 10, 48, "Subsection"],
Cell[CellGroupData[{
Cell[92633, 3147, 54, 0, 28, "Subsubsection"],
Cell[92690, 3149, 153, 3, 72, "Input"],
Cell[92846, 3154, 99, 2, 31, "Input"],
Cell[92948, 3158, 54, 1, 31, "Input"],
Cell[93005, 3161, 968, 30, 65, "Text"],
Cell[93976, 3193, 1443, 40, 118, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[95456, 3238, 45, 0, 28, "Subsubsection"],
Cell[95504, 3240, 878, 31, 43, "Input"],
Cell[96385, 3273, 1386, 45, 92, "Input"],
Cell[97774, 3320, 96, 2, 31, "Input"],
Cell[97873, 3324, 61, 1, 31, "Input"],
Cell[97937, 3327, 90, 1, 29, "Text"],
Cell[98030, 3330, 118, 3, 31, "Input"],
Cell[98151, 3335, 59, 1, 31, "Input"],
Cell[98213, 3338, 124, 3, 31, "Input"],
Cell[98340, 3343, 74, 0, 29, "Text"],
Cell[98417, 3345, 307, 9, 31, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[98761, 3359, 51, 0, 28, "Subsubsection"],
Cell[98815, 3361, 820, 29, 45, "Text"],
Cell[99638, 3392, 786, 28, 43, "Input"],
Cell[100427, 3422, 490, 17, 43, "Input"],
Cell[100920, 3441, 760, 16, 106, "Text"],
Cell[101683, 3459, 43, 0, 29, "Text"],
Cell[101729, 3461, 789, 25, 70, "Input"],
Cell[102521, 3488, 1480, 51, 65, "Input"],
Cell[104004, 3541, 1248, 44, 43, "Input"],
Cell[105255, 3587, 67, 0, 29, "Text"],
Cell[105325, 3589, 1549, 51, 91, "Input"],
Cell[106877, 3642, 56, 0, 29, "Text"],
Cell[106936, 3644, 1926, 60, 117, "Input"],
Cell[108865, 3706, 114, 3, 29, "Text"],
Cell[108982, 3711, 741, 21, 72, "Input"],
Cell[109726, 3734, 88, 2, 29, "Text"],
Cell[109817, 3738, 1398, 48, 65, "Input"],
Cell[111218, 3788, 3781, 109, 319, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[115036, 3902, 40, 0, 28, "Subsubsection"],
Cell[115079, 3904, 213, 4, 47, "Text"],
Cell[115295, 3910, 95, 2, 31, "Input"],
Cell[115393, 3914, 255, 5, 47, "Text"],
Cell[115651, 3921, 133, 4, 31, "Input"],
Cell[115787, 3927, 193, 7, 39, "Input"],
Cell[115983, 3936, 617, 19, 59, "Input"],
Cell[116603, 3957, 649, 19, 52, "Input"],
Cell[117255, 3978, 648, 19, 52, "Input"],
Cell[117906, 3999, 659, 19, 52, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[118602, 4023, 74, 0, 28, "Subsubsection"],
Cell[118679, 4025, 915, 21, 180, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[119631, 4051, 47, 0, 28, "Subsubsection"],
Cell[119681, 4053, 150, 4, 29, "Text"],
Cell[119834, 4059, 66, 1, 31, "Input"],
Cell[119903, 4062, 112, 2, 31, "Input"],
Cell[120018, 4066, 186, 4, 31, "Input"],
Cell[120207, 4072, 128, 2, 31, "Input"],
Cell[120338, 4076, 4125, 133, 123, "Input"],
Cell[124466, 4211, 87, 1, 29, "Text"],
Cell[124556, 4214, 77, 1, 29, "Text"],
Cell[124636, 4217, 96, 2, 31, "Input"],
Cell[124735, 4221, 61, 1, 31, "Input"],
Cell[124799, 4224, 82, 1, 29, "Text"],
Cell[124884, 4227, 118, 3, 31, "Input"],
Cell[125005, 4232, 59, 1, 31, "Input"],
Cell[125067, 4235, 124, 3, 31, "Input"],
Cell[125194, 4240, 59, 1, 31, "Input"],
Cell[125256, 4243, 36, 0, 29, "Text"],
Cell[125295, 4245, 308, 9, 31, "Input"],
Cell[125606, 4256, 75, 1, 29, "Text"],
Cell[125684, 4259, 66, 1, 31, "Input"],
Cell[125753, 4262, 59, 1, 31, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[125873, 4270, 62, 1, 72, "Section"],
Cell[125938, 4273, 1180, 42, 194, "Text"],
Cell[127121, 4317, 399, 12, 85, "Text"],
Cell[127523, 4331, 300, 4, 101, "Text"],
Cell[127826, 4337, 396, 13, 67, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
