(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[    356728,      13913]
NotebookOptionsPosition[    333795,      13287]
NotebookOutlinePosition[    334409,      13310]
CellTagsIndexPosition[    334366,      13307]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Consider", " ", "the", " ", "one"}], "-", 
   RowBox[{
   "parameter", " ", "family", " ", "of", " ", "DE", " ", "systems", " ", 
    RowBox[{"x", "'"}]}]}], "=", 
  RowBox[{"A", " ", "x", " ", "where", " ", "A", " ", "is", " ", 
   RowBox[{
    RowBox[{"(", GridBox[{
       {"0", 
        RowBox[{"-", "5"}]},
       {"1", "\[Alpha]"}
      }], ")"}], ".", "  ", "Find"}], " ", "critical", " ", 
   RowBox[{"values", ".", "  ", "Describe"}], " ", 
   RowBox[{"behaviors", "."}]}]}]], "Subsubtitle"],

Cell["\<\
This problem allows us to examine all the possible behaviors of a linear \
system.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Initial set up", "Section",
 CellFrame->{{0, 0}, {0, 2}}],

Cell[BoxData[{
 RowBox[{"Clear", "[", 
  RowBox[{"A", ",", "\[Alpha]"}], "]"}], "\n", 
 RowBox[{
  RowBox[{"A", "[", "\[Alpha]_", "]"}], ":=", 
  RowBox[{"(", GridBox[{
     {"0", 
      RowBox[{"-", "5"}]},
     {"1", "\[Alpha]"}
    }], ")"}]}], "\n", 
 RowBox[{
  RowBox[{"Eigensystem", "[", 
   RowBox[{"A", "[", "\[Alpha]", "]"}], "]"}], "//", "MatrixForm"}]}], "Input"],

Cell[TextData[{
 "The eigenvalue ",
 Cell[BoxData[
  RowBox[{
   FractionBox["1", "2"], " ", 
   RowBox[{"(", 
    RowBox[{"\[Alpha]", "-", 
     SqrtBox[
      RowBox[{
       RowBox[{"-", "20"}], "+", 
       SuperscriptBox["\[Alpha]", "2"]}]]}], ")"}]}]]],
 "has eigenvector ",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "\[Alpha]"}], "-", 
       SqrtBox[
        RowBox[{
         RowBox[{"-", "20"}], "+", 
         SuperscriptBox["\[Alpha]", "2"]}]]}], ")"}]}], ",", "1"}], "}"}]]],
 ".\nThe eigenvalue ",
 Cell[BoxData[
  RowBox[{
   FractionBox["1", "2"], " ", 
   RowBox[{"(", 
    RowBox[{"\[Alpha]", "+", 
     SqrtBox[
      RowBox[{
       RowBox[{"-", "20"}], "+", 
       SuperscriptBox["\[Alpha]", "2"]}]]}], ")"}]}]]],
 "has eigenvector ",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "\[Alpha]"}], "+", 
       SqrtBox[
        RowBox[{
         RowBox[{"-", "20"}], "+", 
         SuperscriptBox["\[Alpha]", "2"]}]]}], ")"}]}], ",", "1"}], "}"}]]],
 ".\nThe system will have drammatically different behaviors based on the \
algebraic sign of the discriminant  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"-", "20"}], "+", 
   SuperscriptBox["\[Alpha]", "2"]}]]],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{"Solve", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"-", "20"}], "+", 
     SuperscriptBox["\[Alpha]", "2"]}], "\[Equal]", "0"}], ",", "\[Alpha]"}], 
  "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"N", "[", "%", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "20"}], "+", 
     SuperscriptBox["\[Alpha]", "2"]}], ",", 
    RowBox[{"{", 
     RowBox[{"\[Alpha]", ",", 
      RowBox[{"-", "10"}], ",", "10"}], "}"}]}], "]"}], ";"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["one real root", "Section",
 CellFrame->{{0, 0}, {0, 2}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"case", 
    RowBox[{"(", "1", ")"}]}], ":", 
   RowBox[{
    RowBox[{"-", "20"}], "+", 
    SuperscriptBox["\[Alpha]", "2"]}]}], "=", "0."}], "\n", 
 RowBox[{
  RowBox[{"\[Alpha]", "=", 
   RowBox[{
    RowBox[{"-", "2"}], 
    SqrtBox["5"]}]}], ",", 
  RowBox[{"2", " ", 
   RowBox[{
    SqrtBox["5"], ".", "For"}], " ", "each", " ", "of", " ", "these", " ", 
   "values", " ", "of", " ", "\[Alpha]"}], ",", 
  RowBox[{
  "the", " ", "resulting", " ", "system", " ", "of", " ", "DEs", " ", "has", 
   " ", "one", " ", "eigenvalue", " ", "that", " ", "is", " ", 
   RowBox[{"repeated", ".", "Since"}], " ", "A", " ", "is", " ", "not", " ", 
   "Hermitian", " ", "for", " ", "any", " ", "\[Alpha]"}], ",", 
  RowBox[{
  "we", " ", "are", " ", "not", " ", "guaranteed", " ", "a", " ", "full", " ",
    "set", " ", "of", " ", "linearly", " ", "independent", " ", 
   RowBox[{"eigenvectors", ".", "This"}], " ", "case", " ", "occurs", " ", 
   "at", " ", "isolated", " ", 
   RowBox[{"points", ".", "Therefore"}]}], ",", 
  RowBox[{
  "behavior", " ", "on", " ", "either", " ", "side", " ", "of", " ", "these", 
   " ", "points", " ", "will", " ", "determine", " ", "whether", " ", "or", 
   " ", "not", " ", "these", " ", "are", " ", "critical", " ", 
   RowBox[{"points", ".", "The"}], " ", "analysis", " ", "of", " ", 
   "behavior", " ", "is", " ", "given"}], ",", " ", 
  RowBox[{
  "but", " ", "we", " ", "would", " ", "skip", " ", "it", " ", "if", " ", 
   "we", " ", "were", " ", "only", " ", "interested", " ", "in", " ", "the", 
   " ", "critical", " ", 
   RowBox[{"values", "."}]}]}]}], "Text",
 TextAlignment->Left],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  RowBox[{"\[Alpha]", "=", 
   RowBox[{
    RowBox[{"-", "2"}], 
    SqrtBox["5"]}]}]],
  TextAlignment->Left],
 " gory detail"
}], "Subsection",
 CellFrame->{{0, 0}, {0, 0.5}}],

Cell[CellGroupData[{

Cell["solution from the eigenmethod", "Subsubsection"],

Cell[BoxData[{
 RowBox[{"Clear", "[", "\[Alpha]", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Alpha]", "=", 
   RowBox[{
    RowBox[{"-", "2"}], 
    SqrtBox["5"]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"MatrixForm", "[", 
  RowBox[{"A", "[", "\[Alpha]", "]"}], "]"}]}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Eigensystem", "[", 
   RowBox[{"A", "[", "\[Alpha]", "]"}], "]"}], "//", "MatrixForm"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
  "The", " ", "only", " ", "solution", " ", "to", " ", "the", " ", "DE", " ", 
   "from", " ", "this", " ", "method", " ", "is", "   ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", " ", 
      SqrtBox["5"]}], " ", "t"}]], 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      SqrtBox["5"], ",", "1"}], "}"}], ".", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", "To"}], " ", "find", " ", "a", " ", "second"}], 
  ",", 
  RowBox[{"linearly", " ", "independent", " ", "solution"}], ",", 
  RowBox[{
  "we", " ", "use", " ", "the", " ", "generalized", " ", "eigenvector", " ", 
   RowBox[{"method", "."}]}]}]], "Text",
 FontFamily->"Times"]
}, Open  ]],

Cell[CellGroupData[{

Cell["solution from the generalized eigenmethod", "Subsubsection"],

Cell[BoxData[
 RowBox[{"Solve", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"A", "[", "\[Alpha]", "]"}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"-", 
          SqrtBox["5"]}], ")"}], " ", 
        RowBox[{"IdentityMatrix", "[", "2", "]"}]}]}], ")"}], ".", 
     RowBox[{"{", 
      RowBox[{"\[Eta]1", ",", "\[Eta]2"}], "}"}]}], "==", 
    RowBox[{"{", 
     RowBox[{
      SqrtBox["5"], ",", "1"}], "}"}]}], ",", "\[Eta]1"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1", "+", 
      RowBox[{
       SqrtBox["5"], " ", "\[Eta]2"}]}], ",", "\[Eta]2"}], "}"}], " ", "=", 
   " ", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "0"}], "}"}], " ", "+", " ", 
    RowBox[{"\[Eta]2", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        SqrtBox["5"], ",", "1"}], "}"}], ".", "\[IndentingNewLine]", 
      "WLOG"}]}]}]}], ",", " ", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"without", " ", "loss", " ", "of", " ", "generality"}], ")"}], "  ",
    "let", " ", "the", " ", "generalized", " ", "eigenvector", " ", "be", " ", 
   RowBox[{"{", 
    RowBox[{"1", ",", "0"}], "}"}]}], ",", " ", 
  RowBox[{
   RowBox[{
   "which", " ", "is", " ", "the", " ", "part", " ", "of", " ", "the", " ", 
    "above", " ", "which", " ", "is", " ", "linearly", " ", "independent", 
    " ", "from", " ", "the", " ", 
    RowBox[{"eigenvector", ".", "\[IndentingNewLine]", "The"}], " ", "second",
     " ", "solution", " ", "is", "       ", "t", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", " ", 
       SqrtBox["5"]}], " ", "t"}]], 
    RowBox[{"{", 
     RowBox[{
      SqrtBox["5"], ",", "1"}], "}"}]}], " ", "+", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", " ", 
       SqrtBox["5"]}], " ", "t"}]], 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "0"}], "}"}], " ", ".", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", "One"}], " ", "may", " ", "check", " ", "linear", 
    " ", "independence", " ", "of", " ", "these", " ", 
    RowBox[{"solutions", ".", "  ", "Write"}], " ", "the", " ", "solutions", "  ",
     "as", " ", "columns", " ", "of", " ", "a", " ", 
    RowBox[{"matrix", ".", " ", "The"}], " ", "determinant", " ", "is", " ", 
    "not", " ", 
    RowBox[{"zero", ".", "  ", "This"}], " ", "is", " ", "a", " ", 
    "fundamental", " ", 
    RowBox[{"matrix", "."}]}]}]}]], "Text",
 FontFamily->"Times"]
}, Open  ]],

Cell[CellGroupData[{

Cell["a fundamental matrix", "Subsubsection"],

Cell[BoxData[
 RowBox[{"MatrixForm", "[", 
  RowBox[{"Transpose", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", " ", 
         SqrtBox["5"]}], " ", "t"}]], 
      RowBox[{"{", 
       RowBox[{
        SqrtBox["5"], ",", "1"}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"t", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", " ", 
          SqrtBox["5"]}], " ", "t"}]], 
       RowBox[{"{", 
        RowBox[{
         SqrtBox["5"], ",", "1"}], "}"}]}], " ", "+", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", " ", 
          SqrtBox["5"]}], " ", "t"}]], 
       RowBox[{"{", 
        RowBox[{"1", ",", "0"}], "}"}]}]}]}], " ", "}"}], "]"}], 
  "]"}]], "Input"],

Cell[BoxData[{
 RowBox[{"Clear", "[", "\[CapitalPsi]", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[CapitalPsi]", "[", "t_", "]"}], ":=", 
  TagBox[
   RowBox[{"(", "\[NoBreak]", GridBox[{
      {
       RowBox[{
        SqrtBox["5"], " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", 
           SqrtBox["5"]}], " ", "t"}]]}], 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", 
           SqrtBox["5"]}], " ", "t"}]], "+", 
        RowBox[{
         SqrtBox["5"], " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", 
            SqrtBox["5"]}], " ", "t"}]], " ", "t"}]}]},
      {
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", 
          SqrtBox["5"]}], " ", "t"}]], 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", 
           SqrtBox["5"]}], " ", "t"}]], " ", "t"}]}
     }], "\[NoBreak]", ")"}],
   MatrixForm[#]& ]}]}], "Input"],

Cell[BoxData[
 RowBox[{"Det", "[", 
  RowBox[{"\[CapitalPsi]", "[", "t", "]"}], "]"}]], "Input"],

Cell["Note that a fundamental matrix also solves the DE. ", "Text"],

Cell[BoxData[
 RowBox[{"D", "[", 
  RowBox[{
   RowBox[{"\[CapitalPsi]", "[", "t", "]"}], ",", "t"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"A", "[", "\[Alpha]", "]"}], ".", 
  RowBox[{"\[CapitalPsi]", "[", "t", "]"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["general solution, behavior", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{
  "The", " ", "general", " ", "solution", " ", "is", "      ", "c1", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", " ", 
      SqrtBox["5"]}], " ", "t"}]], 
   RowBox[{"{", 
    RowBox[{
     SqrtBox["5"], ",", "1"}], "}"}]}], " ", "+", " ", 
  RowBox[{"c2", 
   RowBox[{
    RowBox[{"(", "  ", 
     RowBox[{
      RowBox[{"t", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", " ", 
          SqrtBox["5"]}], " ", "t"}]], 
       RowBox[{"{", 
        RowBox[{
         SqrtBox["5"], ",", "1"}], "}"}]}], " ", "+", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", " ", 
          SqrtBox["5"]}], " ", "t"}]], 
       RowBox[{"{", 
        RowBox[{"1", ",", "0"}], "}"}]}]}], ")"}], " ", "."}]}]}]], "Text",
 FontFamily->"Times"],

Cell[BoxData[
 RowBox[{"Expand", "[", " ", 
  RowBox[{
   RowBox[{"c1", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", " ", 
       SqrtBox["5"]}], " ", "t"}]], 
    RowBox[{"{", 
     RowBox[{
      SqrtBox["5"], ",", "1"}], "}"}]}], " ", "+", " ", 
   RowBox[{"c2", " ", 
    RowBox[{"(", " ", 
     RowBox[{
      RowBox[{"t", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", " ", 
          SqrtBox["5"]}], " ", "t"}]], 
       RowBox[{"{", 
        RowBox[{
         SqrtBox["5"], ",", "1"}], "}"}]}], " ", "+", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", " ", 
          SqrtBox["5"]}], " ", "t"}]], 
       RowBox[{"{", 
        RowBox[{"1", ",", "0"}], "}"}]}]}], ")"}]}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Limit", "[", 
  RowBox[{"%", ",", 
   RowBox[{"t", "\[Rule]", " ", "\[Infinity]"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", 
         SqrtBox["5"]}], " ", "t"}]], ",", " ", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", 
          SqrtBox["5"]}], " ", "t"}]], " ", "t"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "4"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<t\>\"", ",", "\"\<components\>\""}], "}"}]}]}], "]"}], 
  ";"}]], "Input"],

Cell["\<\

Note that for both of these solutions, for any c1 and c2,  all functions that \
make up both x[t] and y[t] tend to zero as t increases.  Thus,in the x-y \
plane, all trajectories tend to the origin, regardless of initial conditions. \
 The origin is a stable node for this value of \[Alpha].  
    
    The node is improper since the single eigenvalue did not yield a full set \
of linearly independent eigenvectors.
    \
\>", "Text"],

Cell["\<\
Consider a single trajectory, that is, the path taken for one of the \
solutions.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{
      SqrtBox["5"], " ", "c1", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", 
         SqrtBox["5"]}], " ", "t"}]]}], "+", 
     RowBox[{"c2", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", 
         SqrtBox["5"]}], " ", "t"}]]}], "+", 
     RowBox[{
      SqrtBox["5"], " ", "c2", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", 
         SqrtBox["5"]}], " ", "t"}]], " ", "t"}]}], ",", 
    RowBox[{
     RowBox[{"c1", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", 
         SqrtBox["5"]}], " ", "t"}]]}], "+", 
     RowBox[{"c2", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", 
         SqrtBox["5"]}], " ", "t"}]], " ", "t"}]}]}], "}"}], "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"c1", "\[Rule]", "1"}], ",", 
    RowBox[{"c2", "\[Rule]", "1"}]}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", 
        SqrtBox["5"]}], " ", "t"}]], "+", 
     RowBox[{
      SqrtBox["5"], " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", 
         SqrtBox["5"]}], " ", "t"}]]}], "+", 
     RowBox[{
      SqrtBox["5"], " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", 
         SqrtBox["5"]}], " ", "t"}]], " ", "t"}]}], ",", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", 
        SqrtBox["5"]}], " ", "t"}]], "+", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", 
         SqrtBox["5"]}], " ", "t"}]], " ", "t"}]}]}], "}"}], "/.", 
  RowBox[{"t", "\[Rule]", "0"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"N", "[", "%", "]"}]], "Input"],

Cell["\<\
Note that this trajectory begins near (3,1) and tends toward the origin in \
the phase plane below.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ParametricPlot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", 
          SqrtBox["5"]}], " ", "t"}]], "+", 
       RowBox[{
        SqrtBox["5"], " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", 
           SqrtBox["5"]}], " ", "t"}]]}], "+", 
       RowBox[{
        SqrtBox["5"], " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", 
           SqrtBox["5"]}], " ", "t"}]], " ", "t"}]}], ",", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", 
          SqrtBox["5"]}], " ", "t"}]], "+", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", 
           SqrtBox["5"]}], " ", "t"}]], " ", "t"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "10"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<x[t]\>\"", ",", "\"\<y[t]\>\""}], "}"}]}]}], "]"}], 
  ";"}]], "Input"],

Cell["Now consider several trajectories.", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"fcnlist", "=", 
   RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{"AppendTo", "[", 
    RowBox[{"fcnlist", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         SqrtBox["5"], " ", "c1", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", 
            SqrtBox["5"]}], " ", "t"}]]}], "+", 
        RowBox[{"c2", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", 
            SqrtBox["5"]}], " ", "t"}]]}], "+", 
        RowBox[{
         SqrtBox["5"], " ", "c2", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", 
            SqrtBox["5"]}], " ", "t"}]], " ", "t"}]}], ",", 
       RowBox[{
        RowBox[{"c1", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", 
            SqrtBox["5"]}], " ", "t"}]]}], "+", 
        RowBox[{"c2", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", 
            SqrtBox["5"]}], " ", "t"}]], " ", "t"}]}]}], "}"}]}], "]"}], ",", 
   
   RowBox[{"{", 
    RowBox[{"c1", ",", 
     RowBox[{"-", "2"}], ",", "2", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"c2", ",", 
     RowBox[{"-", "2"}], ",", "2", ",", "2"}], "}"}]}], 
  "]"}], "\[IndentingNewLine]", "fcnlist"}], "Input"],

Cell["phase plane for several trajectories", "Text"],

Cell[BoxData[{
 RowBox[{"Clear", "[", "p1", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"p1", "=", 
   RowBox[{"ParametricPlot", "[", 
    RowBox[{
     RowBox[{"Evaluate", "[", "fcnlist", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "10"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x[t]\>\"", ",", "\"\<y[t]\>\""}], "}"}]}]}], "]"}]}], 
  ";"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["direction field", "Subsubsection"],

Cell["\<\
Load the Graphics`PlotField` package BEFORE trying to generate the direction \
field.Load the package once perMathematicasession.If you change \
anything,generate the direction field again.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"<<", "Graphics`PlotField`"}]], "Input",
 ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Remember that we obtain the coordinates of the direction field from \
{x'[t],y'[t]},which is given by the matrix product A.{x[t],y[t]}.To avoid \
confusing the {x,y} used here with ones plotted elsewhere,we'll call these \
{x1,y1}.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"A", "[", "\[Alpha]", "]"}], ".", 
  RowBox[{"{", 
   RowBox[{"x1", ",", "y1"}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "5"}], " ", "y1"}], ",", 
   RowBox[{"x1", "-", 
    RowBox[{"2", " ", 
     SqrtBox["5"], " ", "y1"}]}]}], "}"}]], "Input"],

Cell[BoxData[{
 RowBox[{"Clear", "[", "p2", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"p2", "=", 
   RowBox[{"PlotVectorField", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "5"}], " ", "y1"}], ",", 
       RowBox[{"x1", "-", 
        RowBox[{"2", " ", 
         SqrtBox["5"], " ", "y1"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"x1", ",", 
       RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y1", ",", 
       RowBox[{"-", "4"}], ",", "4"}], "}"}]}], "]"}]}], ";"}]}], "Input",
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .91211 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.108584 0.456053 0.108584 [
[ 0 0 0 0 ]
[ 1 .91211 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto fill
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto
-0.02 0.005 lineto stroke
} ifelse
grestore
} def
/MAarrowzero1 {
gsave
mathtops translate
0 0 Mdot
grestore
} def
% End of user PostScript
0 g
.0001 w
[ ] 0 setdash
.06566 .02172 m
.10752 .05078 L
s
% Start of user PostScript
-4. -4. -3.61455 -3.73233 MAarrowhead1
% End of user PostScript
.06566 .08376 m
.10154 .10748 L
s
% Start of user PostScript
-4. -3.42857 -3.66961 -3.21015 MAarrowhead1
% End of user PostScript
.06566 .14581 m
.09556 .16418 L
s
% Start of user PostScript
-4. -2.85714 -3.72468 -2.68798 MAarrowhead1
% End of user PostScript
.06566 .20786 m
.08958 .22088 L
s
% Start of user PostScript
-4. -2.28571 -3.77974 -2.1658 MAarrowhead1
% End of user PostScript
.06566 .26991 m
.0836 .27758 L
s
% Start of user PostScript
-4. -1.71429 -3.83481 -1.64362 MAarrowhead1
% End of user PostScript
.06566 .33196 m
.07762 .33428 L
s
% Start of user PostScript
-4. -1.14286 -3.88987 -1.12145 MAarrowhead1
% End of user PostScript
.06566 .39401 m
.07164 .39098 L
s
% Start of user PostScript
-4. -0.571429 -3.94494 -0.599268 MAarrowhead1
% End of user PostScript
.06566 .45605 m
.06566 .44768 L
s
% Start of user PostScript
-4. 0 -4. -0.0770905 MAarrowhead1
% End of user PostScript
.06566 .5181 m
.05968 .50438 L
s
% Start of user PostScript
-4. 0.571429 -4.05506 0.445087 MAarrowhead1
% End of user PostScript
.06566 .58015 m
.05371 .56108 L
s
% Start of user PostScript
-4. 1.14286 -4.11013 0.967264 MAarrowhead1
% End of user PostScript
.06566 .6422 m
.04773 .61778 L
s
% Start of user PostScript
-4. 1.71429 -4.16519 1.48944 MAarrowhead1
% End of user PostScript
.06566 .70425 m
.04175 .67448 L
s
% Start of user PostScript
-4. 2.28571 -4.22026 2.01162 MAarrowhead1
% End of user PostScript
.06566 .76629 m
.03577 .73118 L
s
% Start of user PostScript
-4. 2.85714 -4.27532 2.5338 MAarrowhead1
% End of user PostScript
.06566 .82834 m
.02979 .78788 L
s
% Start of user PostScript
-4. 3.42857 -4.33039 3.05597 MAarrowhead1
% End of user PostScript
.06566 .89039 m
.02381 .84458 L
s
% Start of user PostScript
-4. 4. -4.38545 3.57815 MAarrowhead1
% End of user PostScript
.12771 .02172 m
.16957 .05198 L
s
% Start of user PostScript
-3.42857 -4. -3.04312 -3.72132 MAarrowhead1
% End of user PostScript
.12771 .08376 m
.16359 .10868 L
s
% Start of user PostScript
-3.42857 -3.42857 -3.09818 -3.19914 MAarrowhead1
% End of user PostScript
.12771 .14581 m
.15761 .16538 L
s
% Start of user PostScript
-3.42857 -2.85714 -3.15325 -2.67696 MAarrowhead1
% End of user PostScript
.12771 .20786 m
.15163 .22208 L
s
% Start of user PostScript
-3.42857 -2.28571 -3.20831 -2.15479 MAarrowhead1
% End of user PostScript
.12771 .26991 m
.14565 .27878 L
s
% Start of user PostScript
-3.42857 -1.71429 -3.26338 -1.63261 MAarrowhead1
% End of user PostScript
.12771 .33196 m
.13967 .33548 L
s
% Start of user PostScript
-3.42857 -1.14286 -3.31844 -1.11043 MAarrowhead1
% End of user PostScript
.12771 .39401 m
.13369 .39218 L
s
% Start of user PostScript
-3.42857 -0.571429 -3.37351 -0.588255 MAarrowhead1
% End of user PostScript
.12771 .45605 m
.12771 .44888 L
s
% Start of user PostScript
-3.42857 0 -3.42857 -0.0660776 MAarrowhead1
% End of user PostScript
.12771 .5181 m
.12173 .50558 L
s
% Start of user PostScript
-3.42857 0.571429 -3.48364 0.4561 MAarrowhead1
% End of user PostScript
.12771 .58015 m
.11575 .56228 L
s
% Start of user PostScript
-3.42857 1.14286 -3.5387 0.978277 MAarrowhead1
% End of user PostScript
.12771 .6422 m
.10977 .61898 L
s
% Start of user PostScript
-3.42857 1.71429 -3.59377 1.50045 MAarrowhead1
% End of user PostScript
.12771 .70425 m
.1038 .67568 L
s
% Start of user PostScript
-3.42857 2.28571 -3.64883 2.02263 MAarrowhead1
% End of user PostScript
.12771 .76629 m
.09782 .73238 L
s
% Start of user PostScript
-3.42857 2.85714 -3.70389 2.54481 MAarrowhead1
% End of user PostScript
.12771 .82834 m
.09184 .78908 L
s
% Start of user PostScript
-3.42857 3.42857 -3.75896 3.06699 MAarrowhead1
% End of user PostScript
.12771 .89039 m
.08586 .84578 L
s
% Start of user PostScript
-3.42857 4. -3.81402 3.58916 MAarrowhead1
% End of user PostScript
.18976 .02172 m
.23161 .05317 L
s
% Start of user PostScript
-2.85714 -4. -2.47169 -3.71031 MAarrowhead1
% End of user PostScript
.18976 .08376 m
.22563 .10987 L
s
% Start of user PostScript
-2.85714 -3.42857 -2.52676 -3.18813 MAarrowhead1
% End of user PostScript
.18976 .14581 m
.21966 .16657 L
s
% Start of user PostScript
-2.85714 -2.85714 -2.58182 -2.66595 MAarrowhead1
% End of user PostScript
.18976 .20786 m
.21368 .22327 L
s
% Start of user PostScript
-2.85714 -2.28571 -2.63688 -2.14377 MAarrowhead1
% End of user PostScript
.18976 .26991 m
.2077 .27997 L
s
% Start of user PostScript
-2.85714 -1.71429 -2.69195 -1.6216 MAarrowhead1
% End of user PostScript
.18976 .33196 m
.20172 .33667 L
s
% Start of user PostScript
-2.85714 -1.14286 -2.74701 -1.09942 MAarrowhead1
% End of user PostScript
.18976 .39401 m
.19574 .39337 L
s
% Start of user PostScript
-2.85714 -0.571429 -2.80208 -0.577242 MAarrowhead1
% End of user PostScript
.18976 .45605 m
.18976 .45007 L
s
% Start of user PostScript
-2.85714 0 -2.85714 -0.0550646 MAarrowhead1
% End of user PostScript
.18976 .5181 m
.18378 .50677 L
s
% Start of user PostScript
-2.85714 0.571429 -2.91221 0.467113 MAarrowhead1
% End of user PostScript
.18976 .58015 m
.1778 .56347 L
s
% Start of user PostScript
-2.85714 1.14286 -2.96727 0.98929 MAarrowhead1
% End of user PostScript
.18976 .6422 m
.17182 .62017 L
s
% Start of user PostScript
-2.85714 1.71429 -3.02234 1.51147 MAarrowhead1
% End of user PostScript
.18976 .70425 m
.16584 .67687 L
s
% Start of user PostScript
-2.85714 2.28571 -3.0774 2.03364 MAarrowhead1
% End of user PostScript
.18976 .76629 m
.15986 .73357 L
s
% Start of user PostScript
-2.85714 2.85714 -3.13247 2.55582 MAarrowhead1
% End of user PostScript
.18976 .82834 m
.15388 .79028 L
s
% Start of user PostScript
-2.85714 3.42857 -3.18753 3.078 MAarrowhead1
% End of user PostScript
.18976 .89039 m
.14791 .84698 L
s
% Start of user PostScript
-2.85714 4. -3.2426 3.60018 MAarrowhead1
% End of user PostScript
.25181 .02172 m
.29366 .05437 L
s
% Start of user PostScript
-2.28571 -4. -1.90026 -3.69929 MAarrowhead1
% End of user PostScript
.25181 .08376 m
.28768 .11107 L
s
% Start of user PostScript
-2.28571 -3.42857 -1.95533 -3.17712 MAarrowhead1
% End of user PostScript
.25181 .14581 m
.2817 .16777 L
s
% Start of user PostScript
-2.28571 -2.85714 -2.01039 -2.65494 MAarrowhead1
% End of user PostScript
.25181 .20786 m
.27572 .22447 L
s
% Start of user PostScript
-2.28571 -2.28571 -2.06546 -2.13276 MAarrowhead1
% End of user PostScript
.25181 .26991 m
.26975 .28117 L
s
% Start of user PostScript
-2.28571 -1.71429 -2.12052 -1.61058 MAarrowhead1
% End of user PostScript
.25181 .33196 m
.26377 .33787 L
s
% Start of user PostScript
-2.28571 -1.14286 -2.17559 -1.08841 MAarrowhead1
% End of user PostScript
.25181 .39401 m
.25779 .39457 L
s
% Start of user PostScript
-2.28571 -0.571429 -2.23065 -0.566229 MAarrowhead1
% End of user PostScript
.25181 .45605 m
.25181 .45127 L
s
% Start of user PostScript
-2.28571 0 -2.28571 -0.0440517 MAarrowhead1
% End of user PostScript
.25181 .5181 m
.24583 .50797 L
s
% Start of user PostScript
-2.28571 0.571429 -2.34078 0.478126 MAarrowhead1
% End of user PostScript
.25181 .58015 m
.23985 .56467 L
s
% Start of user PostScript
-2.28571 1.14286 -2.39584 1.0003 MAarrowhead1
% End of user PostScript
.25181 .6422 m
.23387 .62137 L
s
% Start of user PostScript
-2.28571 1.71429 -2.45091 1.52248 MAarrowhead1
% End of user PostScript
.25181 .70425 m
.22789 .67807 L
s
% Start of user PostScript
-2.28571 2.28571 -2.50597 2.04466 MAarrowhead1
% End of user PostScript
.25181 .76629 m
.22191 .73477 L
s
% Start of user PostScript
-2.28571 2.85714 -2.56104 2.56683 MAarrowhead1
% End of user PostScript
.25181 .82834 m
.21593 .79147 L
s
% Start of user PostScript
-2.28571 3.42857 -2.6161 3.08901 MAarrowhead1
% End of user PostScript
.25181 .89039 m
.20995 .84817 L
s
% Start of user PostScript
-2.28571 4. -2.67117 3.61119 MAarrowhead1
% End of user PostScript
.31386 .02172 m
.35571 .05556 L
s
% Start of user PostScript
-1.71429 -4. -1.32883 -3.68828 MAarrowhead1
% End of user PostScript
.31386 .08376 m
.34973 .11226 L
s
% Start of user PostScript
-1.71429 -3.42857 -1.3839 -3.1661 MAarrowhead1
% End of user PostScript
.31386 .14581 m
.34375 .16897 L
s
% Start of user PostScript
-1.71429 -2.85714 -1.43896 -2.64393 MAarrowhead1
% End of user PostScript
.31386 .20786 m
.33777 .22567 L
s
% Start of user PostScript
-1.71429 -2.28571 -1.49403 -2.12175 MAarrowhead1
% End of user PostScript
.31386 .26991 m
.33179 .28237 L
s
% Start of user PostScript
-1.71429 -1.71429 -1.54909 -1.59957 MAarrowhead1
% End of user PostScript
.31386 .33196 m
.32581 .33907 L
s
% Start of user PostScript
-1.71429 -1.14286 -1.60416 -1.07739 MAarrowhead1
% End of user PostScript
.31386 .39401 m
.31983 .39577 L
s
% Start of user PostScript
-1.71429 -0.571429 -1.65922 -0.555216 MAarrowhead1
% End of user PostScript
.31386 .45605 m
.31386 .45247 L
s
% Start of user PostScript
-1.71429 0 -1.71429 -0.0330388 MAarrowhead1
% End of user PostScript
.31386 .5181 m
.30788 .50917 L
s
% Start of user PostScript
-1.71429 0.571429 -1.76935 0.489138 MAarrowhead1
% End of user PostScript
.31386 .58015 m
.3019 .56587 L
s
% Start of user PostScript
-1.71429 1.14286 -1.82441 1.01132 MAarrowhead1
% End of user PostScript
.31386 .6422 m
.29592 .62257 L
s
% Start of user PostScript
-1.71429 1.71429 -1.87948 1.53349 MAarrowhead1
% End of user PostScript
.31386 .70425 m
.28994 .67927 L
s
% Start of user PostScript
-1.71429 2.28571 -1.93454 2.05567 MAarrowhead1
% End of user PostScript
.31386 .76629 m
.28396 .73597 L
s
% Start of user PostScript
-1.71429 2.85714 -1.98961 2.57785 MAarrowhead1
% End of user PostScript
.31386 .82834 m
.27798 .79267 L
s
% Start of user PostScript
-1.71429 3.42857 -2.04467 3.10002 MAarrowhead1
% End of user PostScript
.31386 .89039 m
.272 .84937 L
s
% Start of user PostScript
-1.71429 4. -2.09974 3.6222 MAarrowhead1
% End of user PostScript
.3759 .02172 m
.41776 .05676 L
s
% Start of user PostScript
-1.14286 -4. -0.757405 -3.67727 MAarrowhead1
% End of user PostScript
.3759 .08376 m
.41178 .11346 L
s
% Start of user PostScript
-1.14286 -3.42857 -0.812469 -3.15509 MAarrowhead1
% End of user PostScript
.3759 .14581 m
.4058 .17016 L
s
% Start of user PostScript
-1.14286 -2.85714 -0.867534 -2.63291 MAarrowhead1
% End of user PostScript
.3759 .20786 m
.39982 .22686 L
s
% Start of user PostScript
-1.14286 -2.28571 -0.922599 -2.11073 MAarrowhead1
% End of user PostScript
.3759 .26991 m
.39384 .28356 L
s
% Start of user PostScript
-1.14286 -1.71429 -0.977663 -1.58856 MAarrowhead1
% End of user PostScript
.3759 .33196 m
.38786 .34026 L
s
% Start of user PostScript
-1.14286 -1.14286 -1.03273 -1.06638 MAarrowhead1
% End of user PostScript
.3759 .39401 m
.38188 .39696 L
s
% Start of user PostScript
-1.14286 -0.571429 -1.08779 -0.544203 MAarrowhead1
% End of user PostScript
.3759 .45605 m
.3759 .45366 L
s
% Start of user PostScript
-1.14286 0 -1.14286 -0.0220259 MAarrowhead1
% End of user PostScript
.3759 .5181 m
.36992 .51036 L
s
% Start of user PostScript
-1.14286 0.571429 -1.19792 0.500151 MAarrowhead1
% End of user PostScript
.3759 .58015 m
.36395 .56706 L
s
% Start of user PostScript
-1.14286 1.14286 -1.25299 1.02233 MAarrowhead1
% End of user PostScript
.3759 .6422 m
.35797 .62376 L
s
% Start of user PostScript
-1.14286 1.71429 -1.30805 1.54451 MAarrowhead1
% End of user PostScript
.3759 .70425 m
.35199 .68046 L
s
% Start of user PostScript
-1.14286 2.28571 -1.36312 2.06668 MAarrowhead1
% End of user PostScript
.3759 .76629 m
.34601 .73716 L
s
% Start of user PostScript
-1.14286 2.85714 -1.41818 2.58886 MAarrowhead1
% End of user PostScript
.3759 .82834 m
.34003 .79386 L
s
% Start of user PostScript
-1.14286 3.42857 -1.47324 3.11104 MAarrowhead1
% End of user PostScript
.3759 .89039 m
.33405 .85056 L
s
% Start of user PostScript
-1.14286 4. -1.52831 3.63322 MAarrowhead1
% End of user PostScript
.43795 .02172 m
.47981 .05796 L
s
% Start of user PostScript
-0.571429 -4. -0.185976 -3.66625 MAarrowhead1
% End of user PostScript
.43795 .08376 m
.47383 .11466 L
s
% Start of user PostScript
-0.571429 -3.42857 -0.241041 -3.14408 MAarrowhead1
% End of user PostScript
.43795 .14581 m
.46785 .17136 L
s
% Start of user PostScript
-0.571429 -2.85714 -0.296105 -2.6219 MAarrowhead1
% End of user PostScript
.43795 .20786 m
.46187 .22806 L
s
% Start of user PostScript
-0.571429 -2.28571 -0.35117 -2.09972 MAarrowhead1
% End of user PostScript
.43795 .26991 m
.45589 .28476 L
s
% Start of user PostScript
-0.571429 -1.71429 -0.406235 -1.57754 MAarrowhead1
% End of user PostScript
.43795 .33196 m
.44991 .34146 L
s
% Start of user PostScript
-0.571429 -1.14286 -0.461299 -1.05537 MAarrowhead1
% End of user PostScript
.43795 .39401 m
.44393 .39816 L
s
% Start of user PostScript
-0.571429 -0.571429 -0.516364 -0.53319 MAarrowhead1
% End of user PostScript
.43795 .45605 m
.43795 .45486 L
s
% Start of user PostScript
-0.571429 0 -0.571429 -0.0110129 MAarrowhead1
% End of user PostScript
.43795 .5181 m
.43197 .51156 L
s
% Start of user PostScript
-0.571429 0.571429 -0.626493 0.511164 MAarrowhead1
% End of user PostScript
.43795 .58015 m
.42599 .56826 L
s
% Start of user PostScript
-0.571429 1.14286 -0.681558 1.03334 MAarrowhead1
% End of user PostScript
.43795 .6422 m
.42001 .62496 L
s
% Start of user PostScript
-0.571429 1.71429 -0.736622 1.55552 MAarrowhead1
% End of user PostScript
.43795 .70425 m
.41404 .68166 L
s
% Start of user PostScript
-0.571429 2.28571 -0.791687 2.0777 MAarrowhead1
% End of user PostScript
.43795 .76629 m
.40806 .73836 L
s
% Start of user PostScript
-0.571429 2.85714 -0.846752 2.59987 MAarrowhead1
% End of user PostScript
.43795 .82834 m
.40208 .79506 L
s
% Start of user PostScript
-0.571429 3.42857 -0.901816 3.12205 MAarrowhead1
% End of user PostScript
.43795 .89039 m
.3961 .85176 L
s
% Start of user PostScript
-0.571429 4. -0.956881 3.64423 MAarrowhead1
% End of user PostScript
.5 .02172 m
.54185 .05915 L
s
% Start of user PostScript
0 -4. 0.385452 -3.65524 MAarrowhead1
% End of user PostScript
.5 .08376 m
.53587 .11585 L
s
% Start of user PostScript
0 -3.42857 0.330388 -3.13306 MAarrowhead1
% End of user PostScript
.5 .14581 m
.5299 .17255 L
s
% Start of user PostScript
0 -2.85714 0.275323 -2.61089 MAarrowhead1
% End of user PostScript
.5 .20786 m
.52392 .22925 L
s
% Start of user PostScript
0 -2.28571 0.220259 -2.08871 MAarrowhead1
% End of user PostScript
.5 .26991 m
.51794 .28595 L
s
% Start of user PostScript
0 -1.71429 0.165194 -1.56653 MAarrowhead1
% End of user PostScript
.5 .33196 m
.51196 .34265 L
s
% Start of user PostScript
0 -1.14286 0.110129 -1.04435 MAarrowhead1
% End of user PostScript
.5 .39401 m
.50598 .39935 L
s
% Start of user PostScript
0 -0.571429 0.0550646 -0.522177 MAarrowhead1
% End of user PostScript
.5 .45605 m
.5 .45605 L
s
% Start of user PostScript
0 0 MAarrowzero1
% End of user PostScript
.5 .5181 m
.49402 .51275 L
s
% Start of user PostScript
0 0.571429 -0.0550646 0.522177 MAarrowhead1
% End of user PostScript
.5 .58015 m
.48804 .56945 L
s
% Start of user PostScript
0 1.14286 -0.110129 1.04435 MAarrowhead1
% End of user PostScript
.5 .6422 m
.48206 .62615 L
s
% Start of user PostScript
0 1.71429 -0.165194 1.56653 MAarrowhead1
% End of user PostScript
.5 .70425 m
.47608 .68285 L
s
% Start of user PostScript
0 2.28571 -0.220259 2.08871 MAarrowhead1
% End of user PostScript
.5 .76629 m
.4701 .73955 L
s
% Start of user PostScript
0 2.85714 -0.275323 2.61089 MAarrowhead1
% End of user PostScript
.5 .82834 m
.46413 .79625 L
s
% Start of user PostScript
0 3.42857 -0.330388 3.13306 MAarrowhead1
% End of user PostScript
.5 .89039 m
.45815 .85295 L
s
% Start of user PostScript
0 4. -0.385452 3.65524 MAarrowhead1
% End of user PostScript
.56205 .02172 m
.6039 .06035 L
s
% Start of user PostScript
0.571429 -4. 0.956881 -3.64423 MAarrowhead1
% End of user PostScript
.56205 .08376 m
.59792 .11705 L
s
% Start of user PostScript
0.571429 -3.42857 0.901816 -3.12205 MAarrowhead1
% End of user PostScript
.56205 .14581 m
.59194 .17375 L
s
% Start of user PostScript
0.571429 -2.85714 0.846752 -2.59987 MAarrowhead1
% End of user PostScript
.56205 .20786 m
.58596 .23045 L
s
% Start of user PostScript
0.571429 -2.28571 0.791687 -2.0777 MAarrowhead1
% End of user PostScript
.56205 .26991 m
.57999 .28715 L
s
% Start of user PostScript
0.571429 -1.71429 0.736622 -1.55552 MAarrowhead1
% End of user PostScript
.56205 .33196 m
.57401 .34385 L
s
% Start of user PostScript
0.571429 -1.14286 0.681558 -1.03334 MAarrowhead1
% End of user PostScript
.56205 .39401 m
.56803 .40055 L
s
% Start of user PostScript
0.571429 -0.571429 0.626493 -0.511164 MAarrowhead1
% End of user PostScript
.56205 .45605 m
.56205 .45725 L
s
% Start of user PostScript
0.571429 0 0.571429 0.0110129 MAarrowhead1
% End of user PostScript
.56205 .5181 m
.55607 .51395 L
s
% Start of user PostScript
0.571429 0.571429 0.516364 0.53319 MAarrowhead1
% End of user PostScript
.56205 .58015 m
.55009 .57065 L
s
% Start of user PostScript
0.571429 1.14286 0.461299 1.05537 MAarrowhead1
% End of user PostScript
.56205 .6422 m
.54411 .62735 L
s
% Start of user PostScript
0.571429 1.71429 0.406235 1.57754 MAarrowhead1
% End of user PostScript
.56205 .70425 m
.53813 .68405 L
s
% Start of user PostScript
0.571429 2.28571 0.35117 2.09972 MAarrowhead1
% End of user PostScript
.56205 .76629 m
.53215 .74075 L
s
% Start of user PostScript
0.571429 2.85714 0.296105 2.6219 MAarrowhead1
% End of user PostScript
.56205 .82834 m
.52617 .79745 L
s
% Start of user PostScript
0.571429 3.42857 0.241041 3.14408 MAarrowhead1
% End of user PostScript
.56205 .89039 m
.52019 .85415 L
s
% Start of user PostScript
0.571429 4. 0.185976 3.66625 MAarrowhead1
% End of user PostScript
.6241 .02172 m
.66595 .06154 L
s
% Start of user PostScript
1.14286 -4. 1.52831 -3.63322 MAarrowhead1
% End of user PostScript
.6241 .08376 m
.65997 .11824 L
s
% Start of user PostScript
1.14286 -3.42857 1.47324 -3.11104 MAarrowhead1
% End of user PostScript
.6241 .14581 m
.65399 .17494 L
s
% Start of user PostScript
1.14286 -2.85714 1.41818 -2.58886 MAarrowhead1
% End of user PostScript
.6241 .20786 m
.64801 .23164 L
s
% Start of user PostScript
1.14286 -2.28571 1.36312 -2.06668 MAarrowhead1
% End of user PostScript
.6241 .26991 m
.64203 .28834 L
s
% Start of user PostScript
1.14286 -1.71429 1.30805 -1.54451 MAarrowhead1
% End of user PostScript
.6241 .33196 m
.63605 .34504 L
s
% Start of user PostScript
1.14286 -1.14286 1.25299 -1.02233 MAarrowhead1
% End of user PostScript
.6241 .39401 m
.63008 .40174 L
s
% Start of user PostScript
1.14286 -0.571429 1.19792 -0.500151 MAarrowhead1
% End of user PostScript
.6241 .45605 m
.6241 .45844 L
s
% Start of user PostScript
1.14286 0 1.14286 0.0220259 MAarrowhead1
% End of user PostScript
.6241 .5181 m
.61812 .51515 L
s
% Start of user PostScript
1.14286 0.571429 1.08779 0.544203 MAarrowhead1
% End of user PostScript
.6241 .58015 m
.61214 .57185 L
s
% Start of user PostScript
1.14286 1.14286 1.03273 1.06638 MAarrowhead1
% End of user PostScript
.6241 .6422 m
.60616 .62855 L
s
% Start of user PostScript
1.14286 1.71429 0.977663 1.58856 MAarrowhead1
% End of user PostScript
.6241 .70425 m
.60018 .68525 L
s
% Start of user PostScript
1.14286 2.28571 0.922599 2.11073 MAarrowhead1
% End of user PostScript
.6241 .76629 m
.5942 .74195 L
s
% Start of user PostScript
1.14286 2.85714 0.867534 2.63291 MAarrowhead1
% End of user PostScript
.6241 .82834 m
.58822 .79865 L
s
% Start of user PostScript
1.14286 3.42857 0.812469 3.15509 MAarrowhead1
% End of user PostScript
.6241 .89039 m
.58224 .85535 L
s
% Start of user PostScript
1.14286 4. 0.757405 3.67727 MAarrowhead1
% End of user PostScript
.68614 .02172 m
.728 .06274 L
s
% Start of user PostScript
1.71429 -4. 2.09974 -3.6222 MAarrowhead1
% End of user PostScript
.68614 .08376 m
.72202 .11944 L
s
% Start of user PostScript
1.71429 -3.42857 2.04467 -3.10002 MAarrowhead1
% End of user PostScript
.68614 .14581 m
.71604 .17614 L
s
% Start of user PostScript
1.71429 -2.85714 1.98961 -2.57785 MAarrowhead1
% End of user PostScript
.68614 .20786 m
.71006 .23284 L
s
% Start of user PostScript
1.71429 -2.28571 1.93454 -2.05567 MAarrowhead1
% End of user PostScript
.68614 .26991 m
.70408 .28954 L
s
% Start of user PostScript
1.71429 -1.71429 1.87948 -1.53349 MAarrowhead1
% End of user PostScript
.68614 .33196 m
.6981 .34624 L
s
% Start of user PostScript
1.71429 -1.14286 1.82441 -1.01132 MAarrowhead1
% End of user PostScript
.68614 .39401 m
.69212 .40294 L
s
% Start of user PostScript
1.71429 -0.571429 1.76935 -0.489138 MAarrowhead1
% End of user PostScript
.68614 .45605 m
.68614 .45964 L
s
% Start of user PostScript
1.71429 0 1.71429 0.0330388 MAarrowhead1
% End of user PostScript
.68614 .5181 m
.68017 .51634 L
s
% Start of user PostScript
1.71429 0.571429 1.65922 0.555216 MAarrowhead1
% End of user PostScript
.68614 .58015 m
.67419 .57304 L
s
% Start of user PostScript
1.71429 1.14286 1.60416 1.07739 MAarrowhead1
% End of user PostScript
.68614 .6422 m
.66821 .62974 L
s
% Start of user PostScript
1.71429 1.71429 1.54909 1.59957 MAarrowhead1
% End of user PostScript
.68614 .70425 m
.66223 .68644 L
s
% Start of user PostScript
1.71429 2.28571 1.49403 2.12175 MAarrowhead1
% End of user PostScript
.68614 .76629 m
.65625 .74314 L
s
% Start of user PostScript
1.71429 2.85714 1.43896 2.64393 MAarrowhead1
% End of user PostScript
.68614 .82834 m
.65027 .79984 L
s
% Start of user PostScript
1.71429 3.42857 1.3839 3.1661 MAarrowhead1
% End of user PostScript
.68614 .89039 m
.64429 .85654 L
s
% Start of user PostScript
1.71429 4. 1.32883 3.68828 MAarrowhead1
% End of user PostScript
.74819 .02172 m
.79005 .06394 L
s
% Start of user PostScript
2.28571 -4. 2.67117 -3.61119 MAarrowhead1
% End of user PostScript
.74819 .08376 m
.78407 .12064 L
s
% Start of user PostScript
2.28571 -3.42857 2.6161 -3.08901 MAarrowhead1
% End of user PostScript
.74819 .14581 m
.77809 .17734 L
s
% Start of user PostScript
2.28571 -2.85714 2.56104 -2.56683 MAarrowhead1
% End of user PostScript
.74819 .20786 m
.77211 .23404 L
s
% Start of user PostScript
2.28571 -2.28571 2.50597 -2.04466 MAarrowhead1
% End of user PostScript
.74819 .26991 m
.76613 .29074 L
s
% Start of user PostScript
2.28571 -1.71429 2.45091 -1.52248 MAarrowhead1
% End of user PostScript
.74819 .33196 m
.76015 .34744 L
s
% Start of user PostScript
2.28571 -1.14286 2.39584 -1.0003 MAarrowhead1
% End of user PostScript
.74819 .39401 m
.75417 .40414 L
s
% Start of user PostScript
2.28571 -0.571429 2.34078 -0.478126 MAarrowhead1
% End of user PostScript
.74819 .45605 m
.74819 .46084 L
s
% Start of user PostScript
2.28571 0 2.28571 0.0440517 MAarrowhead1
% End of user PostScript
.74819 .5181 m
.74221 .51754 L
s
% Start of user PostScript
2.28571 0.571429 2.23065 0.566229 MAarrowhead1
% End of user PostScript
.74819 .58015 m
.73623 .57424 L
s
% Start of user PostScript
2.28571 1.14286 2.17559 1.08841 MAarrowhead1
% End of user PostScript
.74819 .6422 m
.73025 .63094 L
s
% Start of user PostScript
2.28571 1.71429 2.12052 1.61058 MAarrowhead1
% End of user PostScript
.74819 .70425 m
.72428 .68764 L
s
% Start of user PostScript
2.28571 2.28571 2.06546 2.13276 MAarrowhead1
% End of user PostScript
.74819 .76629 m
.7183 .74434 L
s
% Start of user PostScript
2.28571 2.85714 2.01039 2.65494 MAarrowhead1
% End of user PostScript
.74819 .82834 m
.71232 .80104 L
s
% Start of user PostScript
2.28571 3.42857 1.95533 3.17712 MAarrowhead1
% End of user PostScript
.74819 .89039 m
.70634 .85774 L
s
% Start of user PostScript
2.28571 4. 1.90026 3.69929 MAarrowhead1
% End of user PostScript
.81024 .02172 m
.85209 .06513 L
s
% Start of user PostScript
2.85714 -4. 3.2426 -3.60018 MAarrowhead1
% End of user PostScript
.81024 .08376 m
.84612 .12183 L
s
% Start of user PostScript
2.85714 -3.42857 3.18753 -3.078 MAarrowhead1
% End of user PostScript
.81024 .14581 m
.84014 .17853 L
s
% Start of user PostScript
2.85714 -2.85714 3.13247 -2.55582 MAarrowhead1
% End of user PostScript
.81024 .20786 m
.83416 .23523 L
s
% Start of user PostScript
2.85714 -2.28571 3.0774 -2.03364 MAarrowhead1
% End of user PostScript
.81024 .26991 m
.82818 .29193 L
s
% Start of user PostScript
2.85714 -1.71429 3.02234 -1.51147 MAarrowhead1
% End of user PostScript
.81024 .33196 m
.8222 .34863 L
s
% Start of user PostScript
2.85714 -1.14286 2.96727 -0.98929 MAarrowhead1
% End of user PostScript
.81024 .39401 m
.81622 .40533 L
s
% Start of user PostScript
2.85714 -0.571429 2.91221 -0.467113 MAarrowhead1
% End of user PostScript
.81024 .45605 m
.81024 .46203 L
s
% Start of user PostScript
2.85714 0 2.85714 0.0550646 MAarrowhead1
% End of user PostScript
.81024 .5181 m
.80426 .51873 L
s
% Start of user PostScript
2.85714 0.571429 2.80208 0.577242 MAarrowhead1
% End of user PostScript
.81024 .58015 m
.79828 .57543 L
s
% Start of user PostScript
2.85714 1.14286 2.74701 1.09942 MAarrowhead1
% End of user PostScript
.81024 .6422 m
.7923 .63213 L
s
% Start of user PostScript
2.85714 1.71429 2.69195 1.6216 MAarrowhead1
% End of user PostScript
.81024 .70425 m
.78632 .68883 L
s
% Start of user PostScript
2.85714 2.28571 2.63688 2.14377 MAarrowhead1
% End of user PostScript
.81024 .76629 m
.78034 .74553 L
s
% Start of user PostScript
2.85714 2.85714 2.58182 2.66595 MAarrowhead1
% End of user PostScript
.81024 .82834 m
.77437 .80223 L
s
% Start of user PostScript
2.85714 3.42857 2.52676 3.18813 MAarrowhead1
% End of user PostScript
.81024 .89039 m
.76839 .85893 L
s
% Start of user PostScript
2.85714 4. 2.47169 3.71031 MAarrowhead1
% End of user PostScript
.87229 .02172 m
.91414 .06633 L
s
% Start of user PostScript
3.42857 -4. 3.81402 -3.58916 MAarrowhead1
% End of user PostScript
.87229 .08376 m
.90816 .12303 L
s
% Start of user PostScript
3.42857 -3.42857 3.75896 -3.06699 MAarrowhead1
% End of user PostScript
.87229 .14581 m
.90218 .17973 L
s
% Start of user PostScript
3.42857 -2.85714 3.70389 -2.54481 MAarrowhead1
% End of user PostScript
.87229 .20786 m
.8962 .23643 L
s
% Start of user PostScript
3.42857 -2.28571 3.64883 -2.02263 MAarrowhead1
% End of user PostScript
.87229 .26991 m
.89023 .29313 L
s
% Start of user PostScript
3.42857 -1.71429 3.59377 -1.50045 MAarrowhead1
% End of user PostScript
.87229 .33196 m
.88425 .34983 L
s
% Start of user PostScript
3.42857 -1.14286 3.5387 -0.978277 MAarrowhead1
% End of user PostScript
.87229 .39401 m
.87827 .40653 L
s
% Start of user PostScript
3.42857 -0.571429 3.48364 -0.4561 MAarrowhead1
% End of user PostScript
.87229 .45605 m
.87229 .46323 L
s
% Start of user PostScript
3.42857 0 3.42857 0.0660776 MAarrowhead1
% End of user PostScript
.87229 .5181 m
.86631 .51993 L
s
% Start of user PostScript
3.42857 0.571429 3.37351 0.588255 MAarrowhead1
% End of user PostScript
.87229 .58015 m
.86033 .57663 L
s
% Start of user PostScript
3.42857 1.14286 3.31844 1.11043 MAarrowhead1
% End of user PostScript
.87229 .6422 m
.85435 .63333 L
s
% Start of user PostScript
3.42857 1.71429 3.26338 1.63261 MAarrowhead1
% End of user PostScript
.87229 .70425 m
.84837 .69003 L
s
% Start of user PostScript
3.42857 2.28571 3.20831 2.15479 MAarrowhead1
% End of user PostScript
.87229 .76629 m
.84239 .74673 L
s
% Start of user PostScript
3.42857 2.85714 3.15325 2.67696 MAarrowhead1
% End of user PostScript
.87229 .82834 m
.83641 .80343 L
s
% Start of user PostScript
3.42857 3.42857 3.09818 3.19914 MAarrowhead1
% End of user PostScript
.87229 .89039 m
.83043 .86013 L
s
% Start of user PostScript
3.42857 4. 3.04312 3.72132 MAarrowhead1
% End of user PostScript
.93434 .02172 m
.97619 .06752 L
s
% Start of user PostScript
4. -4. 4.38545 -3.57815 MAarrowhead1
% End of user PostScript
.93434 .08376 m
.97021 .12422 L
s
% Start of user PostScript
4. -3.42857 4.33039 -3.05597 MAarrowhead1
% End of user PostScript
.93434 .14581 m
.96423 .18092 L
s
% Start of user PostScript
4. -2.85714 4.27532 -2.5338 MAarrowhead1
% End of user PostScript
.93434 .20786 m
.95825 .23762 L
s
% Start of user PostScript
4. -2.28571 4.22026 -2.01162 MAarrowhead1
% End of user PostScript
.93434 .26991 m
.95227 .29432 L
s
% Start of user PostScript
4. -1.71429 4.16519 -1.48944 MAarrowhead1
% End of user PostScript
.93434 .33196 m
.94629 .35102 L
s
% Start of user PostScript
4. -1.14286 4.11013 -0.967264 MAarrowhead1
% End of user PostScript
.93434 .39401 m
.94032 .40772 L
s
% Start of user PostScript
4. -0.571429 4.05506 -0.445087 MAarrowhead1
% End of user PostScript
.93434 .45605 m
.93434 .46442 L
s
% Start of user PostScript
4. 0 4. 0.0770905 MAarrowhead1
% End of user PostScript
.93434 .5181 m
.92836 .52112 L
s
% Start of user PostScript
4. 0.571429 3.94494 0.599268 MAarrowhead1
% End of user PostScript
.93434 .58015 m
.92238 .57782 L
s
% Start of user PostScript
4. 1.14286 3.88987 1.12145 MAarrowhead1
% End of user PostScript
.93434 .6422 m
.9164 .63452 L
s
% Start of user PostScript
4. 1.71429 3.83481 1.64362 MAarrowhead1
% End of user PostScript
.93434 .70425 m
.91042 .69122 L
s
% Start of user PostScript
4. 2.28571 3.77974 2.1658 MAarrowhead1
% End of user PostScript
.93434 .76629 m
.90444 .74792 L
s
% Start of user PostScript
4. 2.85714 3.72468 2.68798 MAarrowhead1
% End of user PostScript
.93434 .82834 m
.89846 .80463 L
s
% Start of user PostScript
4. 3.42857 3.66961 3.21015 MAarrowhead1
% End of user PostScript
.93434 .89039 m
.89248 .86133 L
s
% Start of user PostScript
4. 4. 3.61455 3.73233 MAarrowhead1
% End of user PostScript
0 0 m
1 0 L
1 .91211 L
0 .91211 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Input",
 ImageSize->{288, 262.688},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
 ImageRangeCache->{{{99.875, 386.875}, {285.562, 23.875}} -> {-7.8123, \
-3.43366, 0.0320998, 0.0320998}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Show", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"p1", ",", "p2"}], "}"}], ",", 
    RowBox[{"Axes", "\[Rule]", "Automatic"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "4"}], ",", "4"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<x[t]\>\"", ",", "\"\<y[t]\>\""}], "}"}]}], ",", 
    RowBox[{"AspectRatio", "\[Rule]", "Automatic"}]}], "]"}], ";"}]], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.5 0.125 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -6 -9 ]
[.125 .4875 6 0 ]
[.25 .4875 -6 -9 ]
[.25 .4875 6 0 ]
[.375 .4875 -6 -9 ]
[.375 .4875 6 0 ]
[.625 .4875 -3 -9 ]
[.625 .4875 3 0 ]
[.75 .4875 -3 -9 ]
[.75 .4875 3 0 ]
[.875 .4875 -3 -9 ]
[.875 .4875 3 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 28 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -12 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -12 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -12 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -6 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -6 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -6 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -14 0 ]
[.5 1.025 14 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-4)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-3)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-2)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-1)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(1)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(2)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(3)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(4)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 13.000 moveto
(D) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-3)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-2)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-1)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(1)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(2)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(3)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(4)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 13.000 moveto
(D) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto fill
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto
-0.02 0.005 lineto stroke
} ifelse
grestore
} def
/MAarrowzero1 {
gsave
mathtops translate
0 0 Mdot
grestore
} def
% End of user PostScript
.5 Mabswid
0 .33549 m
.08186 .35814 L
.30739 .43065 L
.41017 .46645 L
.45782 .48385 L
.48148 .49276 L
.49173 .49672 L
.49653 .49861 L
.49851 .4994 L
.49934 .49973 L
.49973 .49989 L
.49988 .49995 L
.49995 .49998 L
.49998 .49999 L
.49999 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
s
0 .27639 m
.27433 .39908 L
.41609 .46247 L
.46686 .48518 L
.48644 .49394 L
.49476 .49766 L
.4979 .49906 L
.49921 .49965 L
.49969 .49986 L
.49987 .49994 L
.49995 .49998 L
.49998 .49999 L
.49999 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
s
.19098 .25 m
.4668 .44002 L
.50901 .47588 L
.51927 .48669 L
.52267 .49103 L
.52478 .4943 L
.52598 .49674 L
.5262 .49733 L
.52638 .49791 L
.52651 .49838 L
.52661 .49885 L
.52667 .49926 L
.52671 .49961 L
.52672 .49995 L
.52671 .50025 L
.52669 .50058 L
.52664 .50087 L
.52657 .50117 L
.52648 .50147 L
.52637 .50173 L
.52625 .50195 L
.52595 .50241 L
.52562 .50276 L
.52524 .50309 L
.52449 .50354 L
.52402 .50375 L
.52356 .50391 L
.52301 .50406 L
.52249 .50417 L
.52191 .50426 L
.52161 .5043 L
.52127 .50433 L
.521 .50435 L
.52071 .50437 L
.52056 .50438 L
.5204 .50438 L
.5201 .50439 L
.51983 .5044 L
.51953 .5044 L
.51925 .50439 L
.519 .50439 L
.51873 .50438 L
.51845 .50437 L
.51795 .50434 L
.51741 .5043 L
.51683 .50424 L
.51488 .504 L
.51284 .50365 L
.51114 .5033 L
.50795 .50253 L
Mistroke
.50397 .50137 L
.50195 .50071 L
.50089 .50033 L
.50041 .50016 L
.50017 .50007 L
.50008 .50003 L
.50003 .50001 L
.50001 .50001 L
.50001 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
.25 .5 m
.25009 .497 L
.25034 .49441 L
.25079 .49158 L
.25138 .48906 L
.25207 .48686 L
.25281 .48493 L
.25483 .48092 L
.25732 .47733 L
.26053 .47387 L
.26434 .47075 L
.26826 .46825 L
.27267 .46604 L
.27712 .46427 L
.28135 .46293 L
.28601 .46175 L
.29119 .46073 L
.29612 .46001 L
.29917 .45966 L
.30207 .4594 L
.30469 .45921 L
.30617 .45913 L
.30753 .45906 L
.31026 .45896 L
.31177 .45892 L
.3132 .45889 L
.31574 .45887 L
.3185 .45888 L
.31994 .45891 L
.32154 .45894 L
.3232 .45899 L
.32475 .45904 L
.3305 .45933 L
.33344 .45952 L
.33652 .45976 L
.34197 .46025 L
.35396 .46165 L
.37267 .46455 L
.39131 .46817 L
.44427 .48155 L
.47241 .49025 L
.48746 .49537 L
.49429 .49783 L
.49737 .49898 L
.49887 .49955 L
.4995 .4998 L
.49978 .49991 L
.49991 .49996 L
.49996 .49998 L
.49998 .49999 L
Mistroke
.49999 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
.5 .5 m
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
s
.75 .5 m
.74991 .503 L
.74966 .50559 L
.74921 .50842 L
.74862 .51094 L
.74793 .51314 L
.74719 .51507 L
.74517 .51908 L
.74268 .52267 L
.73947 .52613 L
.73566 .52925 L
.73174 .53175 L
.72733 .53396 L
.72288 .53573 L
.71865 .53707 L
.71399 .53825 L
.70881 .53927 L
.70388 .53999 L
.70083 .54034 L
.69793 .5406 L
.69531 .54079 L
.69383 .54087 L
.69247 .54094 L
.68974 .54104 L
.68823 .54108 L
.6868 .54111 L
.68426 .54113 L
.6815 .54112 L
.68006 .54109 L
.67846 .54106 L
.6768 .54101 L
.67525 .54096 L
.6695 .54067 L
.66656 .54048 L
.66348 .54024 L
.65803 .53975 L
.64604 .53835 L
.62733 .53545 L
.60869 .53183 L
.55573 .51845 L
.52759 .50975 L
.51254 .50463 L
.50571 .50217 L
.50263 .50102 L
.50113 .50045 L
.5005 .5002 L
.50022 .50009 L
.50009 .50004 L
.50004 .50002 L
.50002 .50001 L
Mistroke
.50001 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
.80902 .75 m
.5332 .55998 L
.49099 .52412 L
.48073 .51331 L
.47733 .50897 L
.47522 .5057 L
.47402 .50326 L
.4738 .50267 L
.47362 .50209 L
.47349 .50162 L
.47339 .50115 L
.47333 .50074 L
.47329 .50039 L
.47328 .50005 L
.47329 .49975 L
.47331 .49942 L
.47336 .49913 L
.47343 .49883 L
.47352 .49853 L
.47363 .49827 L
.47375 .49805 L
.47405 .49759 L
.47438 .49724 L
.47476 .49691 L
.47551 .49646 L
.47598 .49625 L
.47644 .49609 L
.47699 .49594 L
.47751 .49583 L
.47809 .49574 L
.47839 .4957 L
.47873 .49567 L
.479 .49565 L
.47929 .49563 L
.47944 .49562 L
.4796 .49562 L
.4799 .49561 L
.48017 .4956 L
.48047 .4956 L
.48075 .49561 L
.481 .49561 L
.48127 .49562 L
.48155 .49563 L
.48205 .49566 L
.48259 .4957 L
.48317 .49576 L
.48512 .496 L
.48716 .49635 L
.48886 .4967 L
.49205 .49747 L
Mistroke
.49603 .49863 L
.49805 .49929 L
.49911 .49967 L
.49959 .49984 L
.49983 .49993 L
.49992 .49997 L
.49997 .49999 L
.49999 .49999 L
.49999 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 .72361 m
.72567 .60092 L
.58391 .53753 L
.53314 .51482 L
.51356 .50606 L
.50524 .50234 L
.5021 .50094 L
.50079 .50035 L
.50031 .50014 L
.50013 .50006 L
.50005 .50002 L
.50002 .50001 L
.50001 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
s
1 .66451 m
.91814 .64186 L
.69261 .56935 L
.58983 .53355 L
.54218 .51615 L
.51852 .50724 L
.50827 .50328 L
.50347 .50139 L
.50149 .5006 L
.50066 .50027 L
.50027 .50011 L
.50012 .50005 L
.50005 .50002 L
.50002 .50001 L
.50001 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
s
.0001 w
0 0 m
.04818 .03346 L
s
% Start of user PostScript
-4. -4. -3.61455 -3.73233 MAarrowhead1
% End of user PostScript
0 .07143 m
.0413 .09873 L
s
% Start of user PostScript
-4. -3.42857 -3.66961 -3.21015 MAarrowhead1
% End of user PostScript
0 .14286 m
.03442 .164 L
s
% Start of user PostScript
-4. -2.85714 -3.72468 -2.68798 MAarrowhead1
% End of user PostScript
0 .21429 m
.02753 .22928 L
s
% Start of user PostScript
-4. -2.28571 -3.77974 -2.1658 MAarrowhead1
% End of user PostScript
0 .28571 m
.02065 .29455 L
s
% Start of user PostScript
-4. -1.71429 -3.83481 -1.64362 MAarrowhead1
% End of user PostScript
0 .35714 m
.01377 .35982 L
s
% Start of user PostScript
-4. -1.14286 -3.88987 -1.12145 MAarrowhead1
% End of user PostScript
0 .42857 m
.00688 .42509 L
s
% Start of user PostScript
-4. -0.571429 -3.94494 -0.599268 MAarrowhead1
% End of user PostScript
0 .5 m
0 .49036 L
s
% Start of user PostScript
-4. 0 -4. -0.0770905 MAarrowhead1
% End of user PostScript
0 .57143 m
0 0 rlineto s
% Start of user PostScript
-4. 0.571429 -4.05506 0.445087 MAarrowhead1
% End of user PostScript
0 .64286 m
0 0 rlineto s
% Start of user PostScript
-4. 1.14286 -4.11013 0.967264 MAarrowhead1
% End of user PostScript
0 .71429 m
0 0 rlineto s
% Start of user PostScript
-4. 1.71429 -4.16519 1.48944 MAarrowhead1
% End of user PostScript
0 .78571 m
0 0 rlineto s
% Start of user PostScript
-4. 2.28571 -4.22026 2.01162 MAarrowhead1
% End of user PostScript
0 .85714 m
0 0 rlineto s
% Start of user PostScript
-4. 2.85714 -4.27532 2.5338 MAarrowhead1
% End of user PostScript
0 .92857 m
0 0 rlineto s
% Start of user PostScript
-4. 3.42857 -4.33039 3.05597 MAarrowhead1
% End of user PostScript
0 1 m
0 0 rlineto s
% Start of user PostScript
-4. 4. -4.38545 3.57815 MAarrowhead1
% End of user PostScript
.07143 0 m
.11961 .03484 L
s
% Start of user PostScript
-3.42857 -4. -3.04312 -3.72132 MAarrowhead1
% End of user PostScript
.07143 .07143 m
.11273 .10011 L
s
% Start of user PostScript
-3.42857 -3.42857 -3.09818 -3.19914 MAarrowhead1
% End of user PostScript
.07143 .14286 m
.10584 .16538 L
s
% Start of user PostScript
-3.42857 -2.85714 -3.15325 -2.67696 MAarrowhead1
% End of user PostScript
.07143 .21429 m
.09896 .23065 L
s
% Start of user PostScript
-3.42857 -2.28571 -3.20831 -2.15479 MAarrowhead1
% End of user PostScript
.07143 .28571 m
.09208 .29592 L
s
% Start of user PostScript
-3.42857 -1.71429 -3.26338 -1.63261 MAarrowhead1
% End of user PostScript
.07143 .35714 m
.08519 .3612 L
s
% Start of user PostScript
-3.42857 -1.14286 -3.31844 -1.11043 MAarrowhead1
% End of user PostScript
.07143 .42857 m
.07831 .42647 L
s
% Start of user PostScript
-3.42857 -0.571429 -3.37351 -0.588255 MAarrowhead1
% End of user PostScript
.07143 .5 m
.07143 .49174 L
s
% Start of user PostScript
-3.42857 0 -3.42857 -0.0660776 MAarrowhead1
% End of user PostScript
.07143 .57143 m
.06455 .55701 L
s
% Start of user PostScript
-3.42857 0.571429 -3.48364 0.4561 MAarrowhead1
% End of user PostScript
.07143 .64286 m
.05766 .62228 L
s
% Start of user PostScript
-3.42857 1.14286 -3.5387 0.978277 MAarrowhead1
% End of user PostScript
.07143 .71429 m
.05078 .68756 L
s
% Start of user PostScript
-3.42857 1.71429 -3.59377 1.50045 MAarrowhead1
% End of user PostScript
.07143 .78571 m
.0439 .75283 L
s
% Start of user PostScript
-3.42857 2.28571 -3.64883 2.02263 MAarrowhead1
% End of user PostScript
.07143 .85714 m
.03701 .8181 L
s
% Start of user PostScript
-3.42857 2.85714 -3.70389 2.54481 MAarrowhead1
% End of user PostScript
.07143 .92857 m
.03013 .88337 L
s
% Start of user PostScript
-3.42857 3.42857 -3.75896 3.06699 MAarrowhead1
% End of user PostScript
.07143 1 m
.02325 .94865 L
s
% Start of user PostScript
-3.42857 4. -3.81402 3.58916 MAarrowhead1
% End of user PostScript
.14286 0 m
.19104 .03621 L
s
% Start of user PostScript
-2.85714 -4. -2.47169 -3.71031 MAarrowhead1
% End of user PostScript
.14286 .07143 m
.18416 .10148 L
s
% Start of user PostScript
-2.85714 -3.42857 -2.52676 -3.18813 MAarrowhead1
% End of user PostScript
.14286 .14286 m
.17727 .16676 L
s
% Start of user PostScript
-2.85714 -2.85714 -2.58182 -2.66595 MAarrowhead1
% End of user PostScript
.14286 .21429 m
.17039 .23203 L
s
% Start of user PostScript
-2.85714 -2.28571 -2.63688 -2.14377 MAarrowhead1
% End of user PostScript
.14286 .28571 m
.16351 .2973 L
s
% Start of user PostScript
-2.85714 -1.71429 -2.69195 -1.6216 MAarrowhead1
% End of user PostScript
.14286 .35714 m
.15662 .36257 L
s
% Start of user PostScript
-2.85714 -1.14286 -2.74701 -1.09942 MAarrowhead1
% End of user PostScript
.14286 .42857 m
.14974 .42784 L
s
% Start of user PostScript
-2.85714 -0.571429 -2.80208 -0.577242 MAarrowhead1
% End of user PostScript
.14286 .5 m
.14286 .49312 L
s
% Start of user PostScript
-2.85714 0 -2.85714 -0.0550646 MAarrowhead1
% End of user PostScript
.14286 .57143 m
.13597 .55839 L
s
% Start of user PostScript
-2.85714 0.571429 -2.91221 0.467113 MAarrowhead1
% End of user PostScript
.14286 .64286 m
.12909 .62366 L
s
% Start of user PostScript
-2.85714 1.14286 -2.96727 0.98929 MAarrowhead1
% End of user PostScript
.14286 .71429 m
.12221 .68893 L
s
% Start of user PostScript
-2.85714 1.71429 -3.02234 1.51147 MAarrowhead1
% End of user PostScript
.14286 .78571 m
.11532 .75421 L
s
% Start of user PostScript
-2.85714 2.28571 -3.0774 2.03364 MAarrowhead1
% End of user PostScript
.14286 .85714 m
.10844 .81948 L
s
% Start of user PostScript
-2.85714 2.85714 -3.13247 2.55582 MAarrowhead1
% End of user PostScript
.14286 .92857 m
.10156 .88475 L
s
% Start of user PostScript
-2.85714 3.42857 -3.18753 3.078 MAarrowhead1
% End of user PostScript
.14286 1 m
.09468 .95002 L
s
% Start of user PostScript
-2.85714 4. -3.2426 3.60018 MAarrowhead1
% End of user PostScript
.21429 0 m
.26247 .03759 L
s
% Start of user PostScript
-2.28571 -4. -1.90026 -3.69929 MAarrowhead1
% End of user PostScript
.21429 .07143 m
.25558 .10286 L
s
% Start of user PostScript
-2.28571 -3.42857 -1.95533 -3.17712 MAarrowhead1
% End of user PostScript
.21429 .14286 m
.2487 .16813 L
s
% Start of user PostScript
-2.28571 -2.85714 -2.01039 -2.65494 MAarrowhead1
% End of user PostScript
.21429 .21429 m
.24182 .2334 L
s
% Start of user PostScript
-2.28571 -2.28571 -2.06546 -2.13276 MAarrowhead1
% End of user PostScript
.21429 .28571 m
.23493 .29868 L
s
% Start of user PostScript
-2.28571 -1.71429 -2.12052 -1.61058 MAarrowhead1
% End of user PostScript
.21429 .35714 m
.22805 .36395 L
s
% Start of user PostScript
-2.28571 -1.14286 -2.17559 -1.08841 MAarrowhead1
% End of user PostScript
.21429 .42857 m
.22117 .42922 L
s
% Start of user PostScript
-2.28571 -0.571429 -2.23065 -0.566229 MAarrowhead1
% End of user PostScript
.21429 .5 m
.21429 .49449 L
s
% Start of user PostScript
-2.28571 0 -2.28571 -0.0440517 MAarrowhead1
% End of user PostScript
.21429 .57143 m
.2074 .55977 L
s
% Start of user PostScript
-2.28571 0.571429 -2.34078 0.478126 MAarrowhead1
% End of user PostScript
.21429 .64286 m
.20052 .62504 L
s
% Start of user PostScript
-2.28571 1.14286 -2.39584 1.0003 MAarrowhead1
% End of user PostScript
.21429 .71429 m
.19364 .69031 L
s
% Start of user PostScript
-2.28571 1.71429 -2.45091 1.52248 MAarrowhead1
% End of user PostScript
.21429 .78571 m
.18675 .75558 L
s
% Start of user PostScript
-2.28571 2.28571 -2.50597 2.04466 MAarrowhead1
% End of user PostScript
.21429 .85714 m
.17987 .82085 L
s
% Start of user PostScript
-2.28571 2.85714 -2.56104 2.56683 MAarrowhead1
% End of user PostScript
.21429 .92857 m
.17299 .88613 L
s
% Start of user PostScript
-2.28571 3.42857 -2.6161 3.08901 MAarrowhead1
% End of user PostScript
.21429 1 m
.1661 .9514 L
s
% Start of user PostScript
-2.28571 4. -2.67117 3.61119 MAarrowhead1
% End of user PostScript
.28571 0 m
.3339 .03897 L
s
% Start of user PostScript
-1.71429 -4. -1.32883 -3.68828 MAarrowhead1
% End of user PostScript
.28571 .07143 m
.32701 .10424 L
s
% Start of user PostScript
-1.71429 -3.42857 -1.3839 -3.1661 MAarrowhead1
% End of user PostScript
.28571 .14286 m
.32013 .16951 L
s
% Start of user PostScript
-1.71429 -2.85714 -1.43896 -2.64393 MAarrowhead1
% End of user PostScript
.28571 .21429 m
.31325 .23478 L
s
% Start of user PostScript
-1.71429 -2.28571 -1.49403 -2.12175 MAarrowhead1
% End of user PostScript
.28571 .28571 m
.30636 .30005 L
s
% Start of user PostScript
-1.71429 -1.71429 -1.54909 -1.59957 MAarrowhead1
% End of user PostScript
.28571 .35714 m
.29948 .36533 L
s
% Start of user PostScript
-1.71429 -1.14286 -1.60416 -1.07739 MAarrowhead1
% End of user PostScript
.28571 .42857 m
.2926 .4306 L
s
% Start of user PostScript
-1.71429 -0.571429 -1.65922 -0.555216 MAarrowhead1
% End of user PostScript
.28571 .5 m
.28571 .49587 L
s
% Start of user PostScript
-1.71429 0 -1.71429 -0.0330388 MAarrowhead1
% End of user PostScript
.28571 .57143 m
.27883 .56114 L
s
% Start of user PostScript
-1.71429 0.571429 -1.76935 0.489138 MAarrowhead1
% End of user PostScript
.28571 .64286 m
.27195 .62641 L
s
% Start of user PostScript
-1.71429 1.14286 -1.82441 1.01132 MAarrowhead1
% End of user PostScript
.28571 .71429 m
.26507 .69169 L
s
% Start of user PostScript
-1.71429 1.71429 -1.87948 1.53349 MAarrowhead1
% End of user PostScript
.28571 .78571 m
.25818 .75696 L
s
% Start of user PostScript
-1.71429 2.28571 -1.93454 2.05567 MAarrowhead1
% End of user PostScript
.28571 .85714 m
.2513 .82223 L
s
% Start of user PostScript
-1.71429 2.85714 -1.98961 2.57785 MAarrowhead1
% End of user PostScript
.28571 .92857 m
.24442 .8875 L
s
% Start of user PostScript
-1.71429 3.42857 -2.04467 3.10002 MAarrowhead1
% End of user PostScript
.28571 1 m
.23753 .95278 L
s
% Start of user PostScript
-1.71429 4. -2.09974 3.6222 MAarrowhead1
% End of user PostScript
.35714 0 m
.40532 .04034 L
s
% Start of user PostScript
-1.14286 -4. -0.757405 -3.67727 MAarrowhead1
% End of user PostScript
.35714 .07143 m
.39844 .10561 L
s
% Start of user PostScript
-1.14286 -3.42857 -0.812469 -3.15509 MAarrowhead1
% End of user PostScript
.35714 .14286 m
.39156 .17089 L
s
% Start of user PostScript
-1.14286 -2.85714 -0.867534 -2.63291 MAarrowhead1
% End of user PostScript
.35714 .21429 m
.38468 .23616 L
s
% Start of user PostScript
-1.14286 -2.28571 -0.922599 -2.11073 MAarrowhead1
% End of user PostScript
.35714 .28571 m
.37779 .30143 L
s
% Start of user PostScript
-1.14286 -1.71429 -0.977663 -1.58856 MAarrowhead1
% End of user PostScript
.35714 .35714 m
.37091 .3667 L
s
% Start of user PostScript
-1.14286 -1.14286 -1.03273 -1.06638 MAarrowhead1
% End of user PostScript
.35714 .42857 m
.36403 .43197 L
s
% Start of user PostScript
-1.14286 -0.571429 -1.08779 -0.544203 MAarrowhead1
% End of user PostScript
.35714 .5 m
.35714 .49725 L
s
% Start of user PostScript
-1.14286 0 -1.14286 -0.0220259 MAarrowhead1
% End of user PostScript
.35714 .57143 m
.35026 .56252 L
s
% Start of user PostScript
-1.14286 0.571429 -1.19792 0.500151 MAarrowhead1
% End of user PostScript
.35714 .64286 m
.34338 .62779 L
s
% Start of user PostScript
-1.14286 1.14286 -1.25299 1.02233 MAarrowhead1
% End of user PostScript
.35714 .71429 m
.33649 .69306 L
s
% Start of user PostScript
-1.14286 1.71429 -1.30805 1.54451 MAarrowhead1
% End of user PostScript
.35714 .78571 m
.32961 .75834 L
s
% Start of user PostScript
-1.14286 2.28571 -1.36312 2.06668 MAarrowhead1
% End of user PostScript
.35714 .85714 m
.32273 .82361 L
s
% Start of user PostScript
-1.14286 2.85714 -1.41818 2.58886 MAarrowhead1
% End of user PostScript
.35714 .92857 m
.31584 .88888 L
s
% Start of user PostScript
-1.14286 3.42857 -1.47324 3.11104 MAarrowhead1
% End of user PostScript
.35714 1 m
.30896 .95415 L
s
% Start of user PostScript
-1.14286 4. -1.52831 3.63322 MAarrowhead1
% End of user PostScript
.42857 0 m
.47675 .04172 L
s
% Start of user PostScript
-0.571429 -4. -0.185976 -3.66625 MAarrowhead1
% End of user PostScript
.42857 .07143 m
.46987 .10699 L
s
% Start of user PostScript
-0.571429 -3.42857 -0.241041 -3.14408 MAarrowhead1
% End of user PostScript
.42857 .14286 m
.46299 .17226 L
s
% Start of user PostScript
-0.571429 -2.85714 -0.296105 -2.6219 MAarrowhead1
% End of user PostScript
.42857 .21429 m
.4561 .23753 L
s
% Start of user PostScript
-0.571429 -2.28571 -0.35117 -2.09972 MAarrowhead1
% End of user PostScript
.42857 .28571 m
.44922 .30281 L
s
% Start of user PostScript
-0.571429 -1.71429 -0.406235 -1.57754 MAarrowhead1
% End of user PostScript
.42857 .35714 m
.44234 .36808 L
s
% Start of user PostScript
-0.571429 -1.14286 -0.461299 -1.05537 MAarrowhead1
% End of user PostScript
.42857 .42857 m
.43545 .43335 L
s
% Start of user PostScript
-0.571429 -0.571429 -0.516364 -0.53319 MAarrowhead1
% End of user PostScript
.42857 .5 m
.42857 .49862 L
s
% Start of user PostScript
-0.571429 0 -0.571429 -0.0110129 MAarrowhead1
% End of user PostScript
.42857 .57143 m
.42169 .5639 L
s
% Start of user PostScript
-0.571429 0.571429 -0.626493 0.511164 MAarrowhead1
% End of user PostScript
.42857 .64286 m
.41481 .62917 L
s
% Start of user PostScript
-0.571429 1.14286 -0.681558 1.03334 MAarrowhead1
% End of user PostScript
.42857 .71429 m
.40792 .69444 L
s
% Start of user PostScript
-0.571429 1.71429 -0.736622 1.55552 MAarrowhead1
% End of user PostScript
.42857 .78571 m
.40104 .75971 L
s
% Start of user PostScript
-0.571429 2.28571 -0.791687 2.0777 MAarrowhead1
% End of user PostScript
.42857 .85714 m
.39416 .82498 L
s
% Start of user PostScript
-0.571429 2.85714 -0.846752 2.59987 MAarrowhead1
% End of user PostScript
.42857 .92857 m
.38727 .89026 L
s
% Start of user PostScript
-0.571429 3.42857 -0.901816 3.12205 MAarrowhead1
% End of user PostScript
.42857 1 m
.38039 .95553 L
s
% Start of user PostScript
-0.571429 4. -0.956881 3.64423 MAarrowhead1
% End of user PostScript
.5 0 m
.54818 .04309 L
s
% Start of user PostScript
0 -4. 0.385452 -3.65524 MAarrowhead1
% End of user PostScript
.5 .07143 m
.5413 .10837 L
s
% Start of user PostScript
0 -3.42857 0.330388 -3.13306 MAarrowhead1
% End of user PostScript
.5 .14286 m
.53442 .17364 L
s
% Start of user PostScript
0 -2.85714 0.275323 -2.61089 MAarrowhead1
% End of user PostScript
.5 .21429 m
.52753 .23891 L
s
% Start of user PostScript
0 -2.28571 0.220259 -2.08871 MAarrowhead1
% End of user PostScript
.5 .28571 m
.52065 .30418 L
s
% Start of user PostScript
0 -1.71429 0.165194 -1.56653 MAarrowhead1
% End of user PostScript
.5 .35714 m
.51377 .36946 L
s
% Start of user PostScript
0 -1.14286 0.110129 -1.04435 MAarrowhead1
% End of user PostScript
.5 .42857 m
.50688 .43473 L
s
% Start of user PostScript
0 -0.571429 0.0550646 -0.522177 MAarrowhead1
% End of user PostScript
.5 .5 m
.5 .5 L
s
% Start of user PostScript
0 0 MAarrowzero1
% End of user PostScript
.5 .57143 m
.49312 .56527 L
s
% Start of user PostScript
0 0.571429 -0.0550646 0.522177 MAarrowhead1
% End of user PostScript
.5 .64286 m
.48623 .63054 L
s
% Start of user PostScript
0 1.14286 -0.110129 1.04435 MAarrowhead1
% End of user PostScript
.5 .71429 m
.47935 .69582 L
s
% Start of user PostScript
0 1.71429 -0.165194 1.56653 MAarrowhead1
% End of user PostScript
.5 .78571 m
.47247 .76109 L
s
% Start of user PostScript
0 2.28571 -0.220259 2.08871 MAarrowhead1
% End of user PostScript
.5 .85714 m
.46558 .82636 L
s
% Start of user PostScript
0 2.85714 -0.275323 2.61089 MAarrowhead1
% End of user PostScript
.5 .92857 m
.4587 .89163 L
s
% Start of user PostScript
0 3.42857 -0.330388 3.13306 MAarrowhead1
% End of user PostScript
.5 1 m
.45182 .95691 L
s
% Start of user PostScript
0 4. -0.385452 3.65524 MAarrowhead1
% End of user PostScript
.57143 0 m
.61961 .04447 L
s
% Start of user PostScript
0.571429 -4. 0.956881 -3.64423 MAarrowhead1
% End of user PostScript
.57143 .07143 m
.61273 .10974 L
s
% Start of user PostScript
0.571429 -3.42857 0.901816 -3.12205 MAarrowhead1
% End of user PostScript
.57143 .14286 m
.60584 .17502 L
s
% Start of user PostScript
0.571429 -2.85714 0.846752 -2.59987 MAarrowhead1
% End of user PostScript
.57143 .21429 m
.59896 .24029 L
s
% Start of user PostScript
0.571429 -2.28571 0.791687 -2.0777 MAarrowhead1
% End of user PostScript
.57143 .28571 m
.59208 .30556 L
s
% Start of user PostScript
0.571429 -1.71429 0.736622 -1.55552 MAarrowhead1
% End of user PostScript
.57143 .35714 m
.58519 .37083 L
s
% Start of user PostScript
0.571429 -1.14286 0.681558 -1.03334 MAarrowhead1
% End of user PostScript
.57143 .42857 m
.57831 .4361 L
s
% Start of user PostScript
0.571429 -0.571429 0.626493 -0.511164 MAarrowhead1
% End of user PostScript
.57143 .5 m
.57143 .50138 L
s
% Start of user PostScript
0.571429 0 0.571429 0.0110129 MAarrowhead1
% End of user PostScript
.57143 .57143 m
.56455 .56665 L
s
% Start of user PostScript
0.571429 0.571429 0.516364 0.53319 MAarrowhead1
% End of user PostScript
.57143 .64286 m
.55766 .63192 L
s
% Start of user PostScript
0.571429 1.14286 0.461299 1.05537 MAarrowhead1
% End of user PostScript
.57143 .71429 m
.55078 .69719 L
s
% Start of user PostScript
0.571429 1.71429 0.406235 1.57754 MAarrowhead1
% End of user PostScript
.57143 .78571 m
.5439 .76247 L
s
% Start of user PostScript
0.571429 2.28571 0.35117 2.09972 MAarrowhead1
% End of user PostScript
.57143 .85714 m
.53701 .82774 L
s
% Start of user PostScript
0.571429 2.85714 0.296105 2.6219 MAarrowhead1
% End of user PostScript
.57143 .92857 m
.53013 .89301 L
s
% Start of user PostScript
0.571429 3.42857 0.241041 3.14408 MAarrowhead1
% End of user PostScript
.57143 1 m
.52325 .95828 L
s
% Start of user PostScript
0.571429 4. 0.185976 3.66625 MAarrowhead1
% End of user PostScript
.64286 0 m
.69104 .04585 L
s
% Start of user PostScript
1.14286 -4. 1.52831 -3.63322 MAarrowhead1
% End of user PostScript
.64286 .07143 m
.68416 .11112 L
s
% Start of user PostScript
1.14286 -3.42857 1.47324 -3.11104 MAarrowhead1
% End of user PostScript
.64286 .14286 m
.67727 .17639 L
s
% Start of user PostScript
1.14286 -2.85714 1.41818 -2.58886 MAarrowhead1
% End of user PostScript
.64286 .21429 m
.67039 .24166 L
s
% Start of user PostScript
1.14286 -2.28571 1.36312 -2.06668 MAarrowhead1
% End of user PostScript
.64286 .28571 m
.66351 .30694 L
s
% Start of user PostScript
1.14286 -1.71429 1.30805 -1.54451 MAarrowhead1
% End of user PostScript
.64286 .35714 m
.65662 .37221 L
s
% Start of user PostScript
1.14286 -1.14286 1.25299 -1.02233 MAarrowhead1
% End of user PostScript
.64286 .42857 m
.64974 .43748 L
s
% Start of user PostScript
1.14286 -0.571429 1.19792 -0.500151 MAarrowhead1
% End of user PostScript
.64286 .5 m
.64286 .50275 L
s
% Start of user PostScript
1.14286 0 1.14286 0.0220259 MAarrowhead1
% End of user PostScript
.64286 .57143 m
.63597 .56803 L
s
% Start of user PostScript
1.14286 0.571429 1.08779 0.544203 MAarrowhead1
% End of user PostScript
.64286 .64286 m
.62909 .6333 L
s
% Start of user PostScript
1.14286 1.14286 1.03273 1.06638 MAarrowhead1
% End of user PostScript
.64286 .71429 m
.62221 .69857 L
s
% Start of user PostScript
1.14286 1.71429 0.977663 1.58856 MAarrowhead1
% End of user PostScript
.64286 .78571 m
.61532 .76384 L
s
% Start of user PostScript
1.14286 2.28571 0.922599 2.11073 MAarrowhead1
% End of user PostScript
.64286 .85714 m
.60844 .82911 L
s
% Start of user PostScript
1.14286 2.85714 0.867534 2.63291 MAarrowhead1
% End of user PostScript
.64286 .92857 m
.60156 .89439 L
s
% Start of user PostScript
1.14286 3.42857 0.812469 3.15509 MAarrowhead1
% End of user PostScript
.64286 1 m
.59468 .95966 L
s
% Start of user PostScript
1.14286 4. 0.757405 3.67727 MAarrowhead1
% End of user PostScript
.71429 0 m
.76247 .04722 L
s
% Start of user PostScript
1.71429 -4. 2.09974 -3.6222 MAarrowhead1
% End of user PostScript
.71429 .07143 m
.75558 .1125 L
s
% Start of user PostScript
1.71429 -3.42857 2.04467 -3.10002 MAarrowhead1
% End of user PostScript
.71429 .14286 m
.7487 .17777 L
s
% Start of user PostScript
1.71429 -2.85714 1.98961 -2.57785 MAarrowhead1
% End of user PostScript
.71429 .21429 m
.74182 .24304 L
s
% Start of user PostScript
1.71429 -2.28571 1.93454 -2.05567 MAarrowhead1
% End of user PostScript
.71429 .28571 m
.73493 .30831 L
s
% Start of user PostScript
1.71429 -1.71429 1.87948 -1.53349 MAarrowhead1
% End of user PostScript
.71429 .35714 m
.72805 .37359 L
s
% Start of user PostScript
1.71429 -1.14286 1.82441 -1.01132 MAarrowhead1
% End of user PostScript
.71429 .42857 m
.72117 .43886 L
s
% Start of user PostScript
1.71429 -0.571429 1.76935 -0.489138 MAarrowhead1
% End of user PostScript
.71429 .5 m
.71429 .50413 L
s
% Start of user PostScript
1.71429 0 1.71429 0.0330388 MAarrowhead1
% End of user PostScript
.71429 .57143 m
.7074 .5694 L
s
% Start of user PostScript
1.71429 0.571429 1.65922 0.555216 MAarrowhead1
% End of user PostScript
.71429 .64286 m
.70052 .63467 L
s
% Start of user PostScript
1.71429 1.14286 1.60416 1.07739 MAarrowhead1
% End of user PostScript
.71429 .71429 m
.69364 .69995 L
s
% Start of user PostScript
1.71429 1.71429 1.54909 1.59957 MAarrowhead1
% End of user PostScript
.71429 .78571 m
.68675 .76522 L
s
% Start of user PostScript
1.71429 2.28571 1.49403 2.12175 MAarrowhead1
% End of user PostScript
.71429 .85714 m
.67987 .83049 L
s
% Start of user PostScript
1.71429 2.85714 1.43896 2.64393 MAarrowhead1
% End of user PostScript
.71429 .92857 m
.67299 .89576 L
s
% Start of user PostScript
1.71429 3.42857 1.3839 3.1661 MAarrowhead1
% End of user PostScript
.71429 1 m
.6661 .96103 L
s
% Start of user PostScript
1.71429 4. 1.32883 3.68828 MAarrowhead1
% End of user PostScript
.78571 0 m
.8339 .0486 L
s
% Start of user PostScript
2.28571 -4. 2.67117 -3.61119 MAarrowhead1
% End of user PostScript
.78571 .07143 m
.82701 .11387 L
s
% Start of user PostScript
2.28571 -3.42857 2.6161 -3.08901 MAarrowhead1
% End of user PostScript
.78571 .14286 m
.82013 .17915 L
s
% Start of user PostScript
2.28571 -2.85714 2.56104 -2.56683 MAarrowhead1
% End of user PostScript
.78571 .21429 m
.81325 .24442 L
s
% Start of user PostScript
2.28571 -2.28571 2.50597 -2.04466 MAarrowhead1
% End of user PostScript
.78571 .28571 m
.80636 .30969 L
s
% Start of user PostScript
2.28571 -1.71429 2.45091 -1.52248 MAarrowhead1
% End of user PostScript
.78571 .35714 m
.79948 .37496 L
s
% Start of user PostScript
2.28571 -1.14286 2.39584 -1.0003 MAarrowhead1
% End of user PostScript
.78571 .42857 m
.7926 .44023 L
s
% Start of user PostScript
2.28571 -0.571429 2.34078 -0.478126 MAarrowhead1
% End of user PostScript
.78571 .5 m
.78571 .50551 L
s
% Start of user PostScript
2.28571 0 2.28571 0.0440517 MAarrowhead1
% End of user PostScript
.78571 .57143 m
.77883 .57078 L
s
% Start of user PostScript
2.28571 0.571429 2.23065 0.566229 MAarrowhead1
% End of user PostScript
.78571 .64286 m
.77195 .63605 L
s
% Start of user PostScript
2.28571 1.14286 2.17559 1.08841 MAarrowhead1
% End of user PostScript
.78571 .71429 m
.76507 .70132 L
s
% Start of user PostScript
2.28571 1.71429 2.12052 1.61058 MAarrowhead1
% End of user PostScript
.78571 .78571 m
.75818 .7666 L
s
% Start of user PostScript
2.28571 2.28571 2.06546 2.13276 MAarrowhead1
% End of user PostScript
.78571 .85714 m
.7513 .83187 L
s
% Start of user PostScript
2.28571 2.85714 2.01039 2.65494 MAarrowhead1
% End of user PostScript
.78571 .92857 m
.74442 .89714 L
s
% Start of user PostScript
2.28571 3.42857 1.95533 3.17712 MAarrowhead1
% End of user PostScript
.78571 1 m
.73753 .96241 L
s
% Start of user PostScript
2.28571 4. 1.90026 3.69929 MAarrowhead1
% End of user PostScript
.85714 0 m
.90532 .04998 L
s
% Start of user PostScript
2.85714 -4. 3.2426 -3.60018 MAarrowhead1
% End of user PostScript
.85714 .07143 m
.89844 .11525 L
s
% Start of user PostScript
2.85714 -3.42857 3.18753 -3.078 MAarrowhead1
% End of user PostScript
.85714 .14286 m
.89156 .18052 L
s
% Start of user PostScript
2.85714 -2.85714 3.13247 -2.55582 MAarrowhead1
% End of user PostScript
.85714 .21429 m
.88468 .24579 L
s
% Start of user PostScript
2.85714 -2.28571 3.0774 -2.03364 MAarrowhead1
% End of user PostScript
.85714 .28571 m
.87779 .31107 L
s
% Start of user PostScript
2.85714 -1.71429 3.02234 -1.51147 MAarrowhead1
% End of user PostScript
.85714 .35714 m
.87091 .37634 L
s
% Start of user PostScript
2.85714 -1.14286 2.96727 -0.98929 MAarrowhead1
% End of user PostScript
.85714 .42857 m
.86403 .44161 L
s
% Start of user PostScript
2.85714 -0.571429 2.91221 -0.467113 MAarrowhead1
% End of user PostScript
.85714 .5 m
.85714 .50688 L
s
% Start of user PostScript
2.85714 0 2.85714 0.0550646 MAarrowhead1
% End of user PostScript
.85714 .57143 m
.85026 .57216 L
s
% Start of user PostScript
2.85714 0.571429 2.80208 0.577242 MAarrowhead1
% End of user PostScript
.85714 .64286 m
.84338 .63743 L
s
% Start of user PostScript
2.85714 1.14286 2.74701 1.09942 MAarrowhead1
% End of user PostScript
.85714 .71429 m
.83649 .7027 L
s
% Start of user PostScript
2.85714 1.71429 2.69195 1.6216 MAarrowhead1
% End of user PostScript
.85714 .78571 m
.82961 .76797 L
s
% Start of user PostScript
2.85714 2.28571 2.63688 2.14377 MAarrowhead1
% End of user PostScript
.85714 .85714 m
.82273 .83324 L
s
% Start of user PostScript
2.85714 2.85714 2.58182 2.66595 MAarrowhead1
% End of user PostScript
.85714 .92857 m
.81584 .89852 L
s
% Start of user PostScript
2.85714 3.42857 2.52676 3.18813 MAarrowhead1
% End of user PostScript
.85714 1 m
.80896 .96379 L
s
% Start of user PostScript
2.85714 4. 2.47169 3.71031 MAarrowhead1
% End of user PostScript
.92857 0 m
.97675 .05135 L
s
% Start of user PostScript
3.42857 -4. 3.81402 -3.58916 MAarrowhead1
% End of user PostScript
.92857 .07143 m
.96987 .11663 L
s
% Start of user PostScript
3.42857 -3.42857 3.75896 -3.06699 MAarrowhead1
% End of user PostScript
.92857 .14286 m
.96299 .1819 L
s
% Start of user PostScript
3.42857 -2.85714 3.70389 -2.54481 MAarrowhead1
% End of user PostScript
.92857 .21429 m
.9561 .24717 L
s
% Start of user PostScript
3.42857 -2.28571 3.64883 -2.02263 MAarrowhead1
% End of user PostScript
.92857 .28571 m
.94922 .31244 L
s
% Start of user PostScript
3.42857 -1.71429 3.59377 -1.50045 MAarrowhead1
% End of user PostScript
.92857 .35714 m
.94234 .37772 L
s
% Start of user PostScript
3.42857 -1.14286 3.5387 -0.978277 MAarrowhead1
% End of user PostScript
.92857 .42857 m
.93545 .44299 L
s
% Start of user PostScript
3.42857 -0.571429 3.48364 -0.4561 MAarrowhead1
% End of user PostScript
.92857 .5 m
.92857 .50826 L
s
% Start of user PostScript
3.42857 0 3.42857 0.0660776 MAarrowhead1
% End of user PostScript
.92857 .57143 m
.92169 .57353 L
s
% Start of user PostScript
3.42857 0.571429 3.37351 0.588255 MAarrowhead1
% End of user PostScript
.92857 .64286 m
.91481 .6388 L
s
% Start of user PostScript
3.42857 1.14286 3.31844 1.11043 MAarrowhead1
% End of user PostScript
.92857 .71429 m
.90792 .70408 L
s
% Start of user PostScript
3.42857 1.71429 3.26338 1.63261 MAarrowhead1
% End of user PostScript
.92857 .78571 m
.90104 .76935 L
s
% Start of user PostScript
3.42857 2.28571 3.20831 2.15479 MAarrowhead1
% End of user PostScript
.92857 .85714 m
.89416 .83462 L
s
% Start of user PostScript
3.42857 2.85714 3.15325 2.67696 MAarrowhead1
% End of user PostScript
.92857 .92857 m
.88727 .89989 L
s
% Start of user PostScript
3.42857 3.42857 3.09818 3.19914 MAarrowhead1
% End of user PostScript
.92857 1 m
.88039 .96516 L
s
% Start of user PostScript
3.42857 4. 3.04312 3.72132 MAarrowhead1
% End of user PostScript
1 0 m
0 0 rlineto s
% Start of user PostScript
4. -4. 4.38545 -3.57815 MAarrowhead1
% End of user PostScript
1 .07143 m
0 0 rlineto s
1 .07143 m
1 .07143 L
s
% Start of user PostScript
4. -3.42857 4.33039 -3.05597 MAarrowhead1
% End of user PostScript
1 .14286 m
0 0 rlineto s
1 .14286 m
1 .14286 L
s
% Start of user PostScript
4. -2.85714 4.27532 -2.5338 MAarrowhead1
% End of user PostScript
1 .21429 m
0 0 rlineto s
1 .21429 m
1 .21429 L
s
% Start of user PostScript
4. -2.28571 4.22026 -2.01162 MAarrowhead1
% End of user PostScript
1 .28571 m
0 0 rlineto s
1 .28571 m
1 .28571 L
s
% Start of user PostScript
4. -1.71429 4.16519 -1.48944 MAarrowhead1
% End of user PostScript
1 .35714 m
0 0 rlineto s
1 .35714 m
1 .35714 L
s
% Start of user PostScript
4. -1.14286 4.11013 -0.967264 MAarrowhead1
% End of user PostScript
1 .42857 m
0 0 rlineto s
1 .42857 m
1 .42857 L
s
% Start of user PostScript
4. -0.571429 4.05506 -0.445087 MAarrowhead1
% End of user PostScript
1 .5 m
1 .50964 L
s
% Start of user PostScript
4. 0 4. 0.0770905 MAarrowhead1
% End of user PostScript
1 .57143 m
.99312 .57491 L
s
% Start of user PostScript
4. 0.571429 3.94494 0.599268 MAarrowhead1
% End of user PostScript
1 .64286 m
.98623 .64018 L
s
% Start of user PostScript
4. 1.14286 3.88987 1.12145 MAarrowhead1
% End of user PostScript
1 .71429 m
.97935 .70545 L
s
% Start of user PostScript
4. 1.71429 3.83481 1.64362 MAarrowhead1
% End of user PostScript
1 .78571 m
.97247 .77072 L
s
% Start of user PostScript
4. 2.28571 3.77974 2.1658 MAarrowhead1
% End of user PostScript
1 .85714 m
.96558 .836 L
s
% Start of user PostScript
4. 2.85714 3.72468 2.68798 MAarrowhead1
% End of user PostScript
1 .92857 m
.9587 .90127 L
s
% Start of user PostScript
4. 3.42857 3.66961 3.21015 MAarrowhead1
% End of user PostScript
1 1 m
.95182 .96654 L
s
% Start of user PostScript
4. 4. 3.61455 3.73233 MAarrowhead1
% End of user PostScript
% End of Graphics
MathPictureEnd
\
\>"], "Input",
 ImageSize->{288, 288},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
 ImageRangeCache->{{{99.875, 386.875}, {615.812, 328.812}} -> {-7.4316, \
6.22778, 0.0324114, 0.0324114}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["describe the system,using appropriate vocabulary.", "Subsubsection"],

Cell[TextData[{
 "Consider the system z'=",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"0", ",", 
      RowBox[{"-", "5"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"1", ",", 
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       SqrtBox["5"]}]}], "}"}]}], "}"}]]],
 "z.\nThe origin is a stable improper node.\n\nFrom the eigenvalue alone:  \
Since the eigenvalue is real and repeated and did not yield a full set of \
linearly independent eigenvectors, the origin is an improper node.  Since the \
eigenvalue is negative, the node is stable.\n\nFurthermore, the {t,x[t]} and \
{t,y[t]} graphs tend to zero, indicating that as time progresses, the x and y \
components of the x-y graph approach the origin, yielding stability.  In \
addition, the direction field indicates that the trajectories rotate \
counterclockwise toward the origin, again yielding stability."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["THE fundamental matrix", "Subsubsection"],

Cell["\<\
Take any fundamental matrix \[CapitalPsi][t] and compute \
\[CapitalPsi][t].Inverse[\[CapitalPsi][0]]:\
\>", "Text"],

Cell[BoxData[
 RowBox[{"\[CapitalPsi]", "[", "0", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      SqrtBox["5"]}], ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "0"}], "}"}]}], "}"}]], "Input"],

Cell[BoxData[
 RowBox[{"Inverse", "[", 
  RowBox[{"\[CapitalPsi]", "[", "0", "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", 
     SqrtBox["5"]}], "}"}]}], "}"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[CapitalPsi]", "[", "t", "]"}], ".", 
  RowBox[{"Inverse", "[", 
   RowBox[{"\[CapitalPsi]", "[", "0", "]"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        SqrtBox["5"], " ", "t"}]], "-", 
      RowBox[{
       SqrtBox["5"], " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         SqrtBox["5"], " ", "t"}]], " ", "t"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        SqrtBox["5"]}], " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         SqrtBox["5"], " ", "t"}]]}], "+", 
      RowBox[{
       SqrtBox["5"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           SqrtBox["5"], " ", "t"}]], "-", 
         RowBox[{
          SqrtBox["5"], " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            SqrtBox["5"], " ", "t"}]], " ", "t"}]}], ")"}]}]}]}], "}"}], ",", 
   
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        SqrtBox["5"], " ", "t"}]], " ", "t"}], ",", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        SqrtBox["5"], " ", "t"}]], "+", 
      RowBox[{
       SqrtBox["5"], " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         SqrtBox["5"], " ", "t"}]], " ", "t"}]}]}], "}"}]}], "}"}]], "Input"],

Cell[BoxData[
 RowBox[{"Expand", "[", "%", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        SqrtBox["5"], " ", "t"}]], "-", 
      RowBox[{
       SqrtBox["5"], " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         SqrtBox["5"], " ", "t"}]], " ", "t"}]}], ",", 
     RowBox[{
      RowBox[{"-", "5"}], " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        SqrtBox["5"], " ", "t"}]], " ", "t"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        SqrtBox["5"], " ", "t"}]], " ", "t"}], ",", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        SqrtBox["5"], " ", "t"}]], "+", 
      RowBox[{
       SqrtBox["5"], " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         SqrtBox["5"], " ", "t"}]], " ", "t"}]}]}], "}"}]}], "}"}]], "Input"],

Cell[BoxData[
 RowBox[{"MatrixForm", "[", "%", "]"}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         SqrtBox["5"], " ", "t"}]], "-", 
       RowBox[{
        SqrtBox["5"], " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          SqrtBox["5"], " ", "t"}]], " ", "t"}]}], 
      RowBox[{
       RowBox[{"-", "5"}], " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         SqrtBox["5"], " ", "t"}]], " ", "t"}]},
     {
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         SqrtBox["5"], " ", "t"}]], " ", "t"}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         SqrtBox["5"], " ", "t"}]], "+", 
       RowBox[{
        SqrtBox["5"], " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          SqrtBox["5"], " ", "t"}]], " ", "t"}]}]}
    }], "\[NoBreak]", ")"}],
  MatrixForm[#]& ]], "Input"],

Cell[BoxData[{
 RowBox[{"Clear", "[", "\[CapitalPhi]", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[CapitalPhi]", "[", "t_", "]"}], ":=", 
  TagBox[
   RowBox[{"(", "\[NoBreak]", GridBox[{
      {
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          SqrtBox["5"], " ", "t"}]], "-", 
        RowBox[{
         SqrtBox["5"], " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           SqrtBox["5"], " ", "t"}]], " ", "t"}]}], 
       RowBox[{
        RowBox[{"-", "5"}], " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          SqrtBox["5"], " ", "t"}]], " ", "t"}]},
      {
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          SqrtBox["5"], " ", "t"}]], " ", "t"}], 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          SqrtBox["5"], " ", "t"}]], "+", 
        RowBox[{
         SqrtBox["5"], " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           SqrtBox["5"], " ", "t"}]], " ", "t"}]}]}
     }], "\[NoBreak]", ")"}],
   MatrixForm[#]& ]}]}], "Input"],

Cell["Check the properties of THE fundamental matrix:", "Text"],

Cell["\<\
Its columns are linearly independent since its determinant is nonzero.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"Det", "[", 
  RowBox[{"\[CapitalPhi]", "[", "t", "]"}], "]"}]], "Input"],

Cell[BoxData[
 SuperscriptBox["\[ExponentialE]", 
  RowBox[{"2", " ", 
   SqrtBox["5"], " ", "t"}]]], "Input"],

Cell["THE fundamental matrix also solves the DE:", "Text"],

Cell[BoxData[
 RowBox[{"D", "[", 
  RowBox[{
   RowBox[{"\[CapitalPhi]", "[", "t", "]"}], ",", "t"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "5"}], " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        SqrtBox["5"], " ", "t"}]], " ", "t"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "5"}], " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         SqrtBox["5"], " ", "t"}]]}], "-", 
      RowBox[{"5", " ", 
       SqrtBox["5"], " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         SqrtBox["5"], " ", "t"}]], " ", "t"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        SqrtBox["5"], " ", "t"}]], "+", 
      RowBox[{
       SqrtBox["5"], " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         SqrtBox["5"], " ", "t"}]], " ", "t"}]}], ",", 
     RowBox[{
      RowBox[{"2", " ", 
       SqrtBox["5"], " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         SqrtBox["5"], " ", "t"}]]}], "+", 
      RowBox[{"5", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         SqrtBox["5"], " ", "t"}]], " ", "t"}]}]}], "}"}]}], "}"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"A", "[", "\[Alpha]", "]"}], ".", 
  RowBox[{"\[CapitalPhi]", "[", "t", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "5"}], " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        SqrtBox["5"], " ", "t"}]], " ", "t"}], ",", 
     RowBox[{
      RowBox[{"-", "5"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          SqrtBox["5"], " ", "t"}]], "+", 
        RowBox[{
         SqrtBox["5"], " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           SqrtBox["5"], " ", "t"}]], " ", "t"}]}], ")"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        SqrtBox["5"], " ", "t"}]], "-", 
      RowBox[{"3", " ", 
       SqrtBox["5"], " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         SqrtBox["5"], " ", "t"}]], " ", "t"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "5"}], " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         SqrtBox["5"], " ", "t"}]], " ", "t"}], "-", 
      RowBox[{"2", " ", 
       SqrtBox["5"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           SqrtBox["5"], " ", "t"}]], "+", 
         RowBox[{
          SqrtBox["5"], " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            SqrtBox["5"], " ", "t"}]], " ", "t"}]}], ")"}]}]}]}], "}"}]}], 
  "}"}]], "Input"],

Cell[BoxData[
 RowBox[{"Expand", "[", "%", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "5"}], " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        SqrtBox["5"], " ", "t"}]], " ", "t"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "5"}], " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         SqrtBox["5"], " ", "t"}]]}], "-", 
      RowBox[{"5", " ", 
       SqrtBox["5"], " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         SqrtBox["5"], " ", "t"}]], " ", "t"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        SqrtBox["5"], " ", "t"}]], "-", 
      RowBox[{"3", " ", 
       SqrtBox["5"], " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         SqrtBox["5"], " ", "t"}]], " ", "t"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       SqrtBox["5"], " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         SqrtBox["5"], " ", "t"}]]}], "-", 
      RowBox[{"15", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         SqrtBox["5"], " ", "t"}]], " ", "t"}]}]}], "}"}]}], "}"}]], "Input"],

Cell["At t=0, it is the identity matrix.", "Text"],

Cell[BoxData[
 RowBox[{"\[CapitalPhi]", "[", "0", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "1"}], "}"}]}], "}"}]], "Input"],

Cell["\<\
A fundamental matrix is useful for solving nonhomogeneous problems.\
\>", "Text"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  RowBox[{"\[Alpha]", "=", 
   RowBox[{"2", 
    SqrtBox["5"]}]}]],
  TextAlignment->Left],
 " gory detail"
}], "Subsection",
 CellFrame->{{0, 0}, {0, 0.5}}],

Cell[CellGroupData[{

Cell["solution from the eigenmethod", "Subsubsection"],

Cell[BoxData[{
 RowBox[{"Clear", "[", "\[Alpha]", "]"}], "\n", 
 RowBox[{
  RowBox[{"\[Alpha]", "=", 
   RowBox[{"2", 
    SqrtBox["5"]}]}], ";"}], "\n", 
 RowBox[{"MatrixForm", "[", 
  RowBox[{"A", "[", "\[Alpha]", "]"}], "]"}]}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Eigensystem", "[", 
   RowBox[{"A", "[", "\[Alpha]", "]"}], "]"}], "//", "MatrixForm"}]], "Input"],

Cell[TextData[{
 "There is only one eigenvector from this method; (eigenvectors cannot be \
zero).  So far, one solution is ",
 Cell[BoxData[
  RowBox[{" ", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", 
       SqrtBox["5"]}], " ", "t"}]], 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", 
       SqrtBox["5"]}], ",", "1"}], "}"}]}]}]]],
 ".  To find a second, linearly independent solution, we use the generalized \
eigenvector method."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["solution from the generalized eigenmethod", "Subsubsection"],

Cell[BoxData[
 RowBox[{"Solve", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"A", "[", "\[Alpha]", "]"}], "-", 
       RowBox[{
        RowBox[{"(", 
         SqrtBox["5"], ")"}], 
        RowBox[{"IdentityMatrix", "[", "2", "]"}]}]}], ")"}], ".", 
     RowBox[{"{", 
      RowBox[{"\[Eta]1", ",", "\[Eta]2"}], "}"}]}], "==", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", 
       SqrtBox["5"]}], ",", "1"}], "}"}]}], ",", "\[Eta]1"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1", "-", 
      RowBox[{
       SqrtBox["5"], " ", "\[Eta]2"}]}], ",", "\[Eta]2"}], "}"}], " ", "=", 
   " ", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "0"}], "}"}], " ", "+", " ", 
    RowBox[{"\[Eta]2", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         SqrtBox["5"]}], ",", "1"}], "}"}], ".", "\[IndentingNewLine]", 
      "WLOG"}]}]}]}], ",", " ", 
  RowBox[{
  "let", " ", "the", " ", "generalized", " ", "eigenvector", " ", "be", " ", 
   RowBox[{"{", 
    RowBox[{"1", ",", "0"}], "}"}]}], ",", " ", 
  RowBox[{
   RowBox[{
   "which", " ", "is", " ", "the", " ", "part", " ", "of", " ", "the", " ", 
    "above", " ", "which", " ", "is", " ", "linearly", " ", "independent", 
    " ", "from", " ", "the", " ", 
    RowBox[{"eigenvector", ".", "\[IndentingNewLine]", "The"}], " ", "second",
     " ", "solution", " ", "is", "       ", "t", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      SqrtBox["5"], " ", "t"}]], 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", 
       SqrtBox["5"]}], ",", "1"}], "}"}]}], " ", "+", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      SqrtBox["5"], " ", "t"}]], 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "0"}], "}"}], " ", ".", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", "One"}], " ", "may", " ", "check", " ", "linear", 
    " ", "independence", " ", "of", " ", "these", " ", 
    RowBox[{"solutions", ".", "  ", "Write"}], " ", "the", " ", "solutions", "  ",
     "as", " ", "columns", " ", "of", " ", "a", " ", 
    RowBox[{"matrix", ".", " ", "The"}], " ", "determinant", " ", "is", " ", 
    "not", " ", 
    RowBox[{"zero", ".", "  ", "This"}], " ", "is", " ", "a", " ", 
    "fundamental", " ", 
    RowBox[{"matrix", "."}]}]}]}]], "Text",
 FontFamily->"Times"]
}, Open  ]],

Cell[CellGroupData[{

Cell["a fundamental matrix", "Subsubsection"],

Cell[BoxData[
 RowBox[{"MatrixForm", "[", 
  RowBox[{"Transpose", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        SqrtBox["5"], " ", "t"}]], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         SqrtBox["5"]}], ",", "1"}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"t", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         SqrtBox["5"], " ", "t"}]], 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          SqrtBox["5"]}], ",", "1"}], "}"}]}], " ", "+", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         SqrtBox["5"], " ", "t"}]], 
       RowBox[{"{", 
        RowBox[{"1", ",", "0"}], "}"}]}]}]}], " ", "}"}], "]"}], 
  "]"}]], "Input"],

Cell[BoxData[{
 RowBox[{"Clear", "[", "\[CapitalPsi]", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[CapitalPsi]", "[", "t_", "]"}], ":=", 
  TagBox[
   RowBox[{"(", "\[NoBreak]", GridBox[{
      {
       RowBox[{
        RowBox[{"-", 
         SqrtBox["5"]}], " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          SqrtBox["5"], " ", "t"}]]}], 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          SqrtBox["5"], " ", "t"}]], "-", 
        RowBox[{
         SqrtBox["5"], " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           SqrtBox["5"], " ", "t"}]], " ", "t"}]}]},
      {
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         SqrtBox["5"], " ", "t"}]], 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          SqrtBox["5"], " ", "t"}]], " ", "t"}]}
     }], "\[NoBreak]", ")"}],
   MatrixForm[#]& ]}]}], "Input"],

Cell[BoxData[
 RowBox[{"Det", "[", 
  RowBox[{"\[CapitalPsi]", "[", "t", "]"}], "]"}]], "Input"],

Cell["Note that a fundamental matrix also solves the DE.", "Text"],

Cell[BoxData[
 RowBox[{"D", "[", 
  RowBox[{
   RowBox[{"\[CapitalPsi]", "[", "t", "]"}], ",", "t"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"A", "[", "\[Alpha]", "]"}], ".", 
  RowBox[{"\[CapitalPsi]", "[", "t", "]"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["general solution, behavior", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{
  "The", " ", "general", " ", "solution", " ", "is", "      ", "c1", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     SqrtBox["5"], " ", "t"}]], 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      SqrtBox["5"]}], ",", "1"}], "}"}]}], " ", "+", " ", 
  RowBox[{"c2", "  ", "t", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     SqrtBox["5"], " ", "t"}]], 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      SqrtBox["5"]}], ",", "1"}], "}"}]}], " ", "+", 
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", " ", 
      SqrtBox["5"]}], " ", "t"}]], 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "0"}], "}"}], " ", "."}]}]}]], "Text",
 FontFamily->"Times"],

Cell[BoxData[
 RowBox[{"Expand", "[", " ", 
  RowBox[{
   RowBox[{"c1", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      SqrtBox["5"], " ", "t"}]], 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", 
       SqrtBox["5"]}], ",", "1"}], "}"}]}], " ", "+", " ", 
   RowBox[{"c2", " ", 
    RowBox[{"(", " ", 
     RowBox[{
      RowBox[{"t", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         SqrtBox["5"], " ", "t"}]], 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          SqrtBox["5"]}], ",", "1"}], "}"}]}], " ", "+", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         SqrtBox["5"], " ", "t"}]], 
       RowBox[{"{", 
        RowBox[{"1", ",", "0"}], "}"}]}]}], ")"}]}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Limit", "[", 
  RowBox[{"%", ",", 
   RowBox[{"t", "\[Rule]", " ", "\[Infinity]"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Factor", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       SqrtBox["5"]}], " ", "c1", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        SqrtBox["5"], " ", "t"}]]}], "+", 
     RowBox[{"c2", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        SqrtBox["5"], " ", "t"}]]}], "-", 
     RowBox[{
      SqrtBox["5"], " ", "c2", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        SqrtBox["5"], " ", "t"}]], " ", "t"}]}], ",", 
    RowBox[{
     RowBox[{"c1", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        SqrtBox["5"], " ", "t"}]]}], "+", 
     RowBox[{"c2", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        SqrtBox["5"], " ", "t"}]], " ", "t"}]}]}], "}"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Limit", "[", 
  RowBox[{"%", ",", 
   RowBox[{"t", "\[Rule]", " ", "\[Infinity]"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        SqrtBox["5"]}], "  ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         SqrtBox["5"], " ", "t"}]]}], ",", 
      RowBox[{
       SqrtBox["5"], "  ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         SqrtBox["5"], " ", "t"}]], " ", "t"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "4"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<t\>\"", ",", "\"\<components\>\""}], "}"}]}]}], "]"}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
   "Note", " ", "that", " ", "for", " ", "both", " ", "of", " ", "these", " ",
     "solutions"}], ",", " ", 
   RowBox[{"for", " ", "any", " ", "c1", " ", "and", " ", "c2"}], ",", "  ", 
   RowBox[{
    RowBox[{
    "both", " ", "components", " ", "tend", " ", "to", " ", "plus", " ", "or",
      " ", "minus", " ", "infinity", " ", "as", " ", "t", " ", 
     RowBox[{"increases", ".", " ", "\[IndentingNewLine]", "Even"}], "  ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       SqrtBox["5"], " ", "t"}]], " ", "t"}], " ", "-", "  ", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       SqrtBox["5"], " ", "t"}]], " ", "will", " ", "have", " ", "the", " ", 
     "same", " ", 
     RowBox[{"behavior", ".", "   ", "\[IndentingNewLine]", "Thus"}]}]}], ",", 
   RowBox[{
   "the", " ", "origin", " ", "is", " ", "an", " ", "unstable", " ", "node", 
    " ", "for", " ", "this", " ", "value", " ", "of", " ", 
    RowBox[{"\[Alpha]", "."}]}]}]}]], "Text",
 FontFamily->"Times"],

Cell["\<\
Consider a single trajectory, that is, the path taken for one of the \
solutions.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       SqrtBox["5"]}], " ", "c1", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        SqrtBox["5"], " ", "t"}]]}], "+", 
     RowBox[{"c2", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        SqrtBox["5"], " ", "t"}]]}], "-", 
     RowBox[{
      SqrtBox["5"], " ", "c2", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        SqrtBox["5"], " ", "t"}]], " ", "t"}]}], ",", 
    RowBox[{
     RowBox[{"c1", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        SqrtBox["5"], " ", "t"}]]}], "+", 
     RowBox[{"c2", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        SqrtBox["5"], " ", "t"}]], " ", "t"}]}]}], "}"}], "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"c1", "\[Rule]", "1"}], ",", 
    RowBox[{"c2", "\[Rule]", "1"}]}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"%", "/.", 
  RowBox[{"t", "\[Rule]", "0"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"N", "[", "%", "]"}]], "Input"],

Cell["\<\
Note that this trajectory begins near (-1,1) and moves away from the origin.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ParametricPlot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         SqrtBox["5"], " ", "t"}]], "-", 
       RowBox[{
        SqrtBox["5"], " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          SqrtBox["5"], " ", "t"}]]}], "-", 
       RowBox[{
        SqrtBox["5"], " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          SqrtBox["5"], " ", "t"}]], " ", "t"}]}], ",", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         SqrtBox["5"], " ", "t"}]], "+", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          SqrtBox["5"], " ", "t"}]], " ", "t"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "4"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<x[t]\>\"", ",", "\"\<y[t]\>\""}], "}"}]}]}], "]"}], 
  ";"}]], "Input"],

Cell["Now consider multiple trajectories.", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"fcnlist", "=", 
   RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{"AppendTo", "[", 
    RowBox[{"fcnlist", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SqrtBox["5"]}], " ", "c1", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           SqrtBox["5"], " ", "t"}]]}], "+", 
        RowBox[{"c2", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           SqrtBox["5"], " ", "t"}]]}], "-", 
        RowBox[{
         SqrtBox["5"], " ", "c2", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           SqrtBox["5"], " ", "t"}]], " ", "t"}]}], ",", 
       RowBox[{
        RowBox[{"c1", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           SqrtBox["5"], " ", "t"}]]}], "+", 
        RowBox[{"c2", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           SqrtBox["5"], " ", "t"}]], " ", "t"}]}]}], "}"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"c1", ",", 
     RowBox[{"-", "2"}], ",", "2", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"c2", ",", 
     RowBox[{"-", "2"}], ",", "2", ",", "2"}], "}"}]}], 
  "]"}], "\[IndentingNewLine]", "fcnlist"}], "Input"],

Cell["Here are the initial values for these solutions.", "Text"],

Cell[BoxData[
 RowBox[{"%", "/.", 
  RowBox[{"t", "\[Rule]", "0"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"N", "[", "%", "]"}]], "Input"],

Cell["phase plane for several trajectories", "Text"],

Cell[BoxData[{
 RowBox[{"Clear", "[", "p1", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"p1", "=", 
   RowBox[{"ParametricPlot", "[", 
    RowBox[{
     RowBox[{"Evaluate", "[", "fcnlist", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "10"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x[t]\>\"", ",", "\"\<y[t]\>\""}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1000"}], ",", "1000"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1000"}], ",", "1000"}], "}"}]}], "}"}]}]}], "]"}]}], 
  ";"}]}], "Input"],

Cell["\<\
These aren't very different, especially on this scale.  They also appear to \
only begin in two quadrants, which is not true.  Consider the decimal initial \
values above or the plot below.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ParametricPlot", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", "fcnlist", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "10"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<x[t]\>\"", ",", "\"\<y[t]\>\""}], "}"}]}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "10"}], ",", "10"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "10"}], ",", "10"}], "}"}]}], "}"}]}]}], "]"}], 
  ";"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["direction field", "Subsubsection"],

Cell[TextData[{
 "Load the Graphics`PlotField` package BEFORE trying to generate the \
direction field.\nLoad the package once per ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " session.  If you change anything, generate the direction field again."
}], "Text"],

Cell["<<Graphics`PlotField`", "Input",
 ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Remember that we obtain the coordinates of the direction field from \
{x'[t],y'[t]}, which is given by the matrix product A.{x[t],y[t]}.  To avoid \
confusing the {x,y} used here with ones plotted elsewhere, we'll call these \
{x1,y1}. \
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"A", "[", "\[Alpha]", "]"}], ".", 
  RowBox[{"{", 
   RowBox[{"x1", ",", "y1"}], "}"}]}]], "Input"],

Cell["\<\
Clear[p2]
p2 = PlotVectorField[
{-5 y1,x1 + 2 Sqrt[5] y1},
{x1,-1000,1000}, {y1, -1000,1000}];\
\>", "Input",
 ImageRegion->{{0, 1}, {0, 1}}],

Cell["Superimpose the solutions on the direction field.", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Show", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"p1", ",", "p2"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"Axes", "\[Rule]", "Automatic"}], ",", "\[IndentingNewLine]", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1000"}], ",", "1000"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1000"}], ",", "1000"}], "}"}]}], "}"}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<x[t]\>\"", ",", "\"\<y[t]\>\""}], "}"}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"AspectRatio", "\[Rule]", "Automatic"}]}], "]"}], ";"}]], "Input"],

Cell["\<\
These trajectories aren't as straight as the scale makes them seem.  On this \
scale, it is more clear that we have included initial conditions in each \
quadrant.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Show", "[", 
   RowBox[{"p1", ",", "\[IndentingNewLine]", 
    RowBox[{"Axes", "\[Rule]", "Automatic"}], ",", "\[IndentingNewLine]", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "20"}], ",", "20"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "20"}], ",", "20"}], "}"}]}], "}"}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<x[t]\>\"", ",", "\"\<y[t]\>\""}], "}"}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"AspectRatio", "\[Rule]", "Automatic"}]}], "]"}], ";"}]], "Input"],

Cell["\<\
We can also generate functions with specific initial conditions.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        SqrtBox["5"], " ", "t"}]]}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SqrtBox["5"], " ", "c1"}], "-", "c2", "+", 
       RowBox[{
        SqrtBox["5"], " ", "c2", " ", "t"}]}], ")"}]}], ",", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       SqrtBox["5"], " ", "t"}]], " ", 
     RowBox[{"(", 
      RowBox[{"c1", "+", 
       RowBox[{"c2", " ", "t"}]}], ")"}]}]}], "}"}], "/.", 
  RowBox[{"t", "\[Rule]", "0"}]}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"fcnlist2", "=", 
   RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Do", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Clear", "[", 
      RowBox[{"ThisRule", ",", "ThisFcn"}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"ThisRule", "=", 
      RowBox[{"Flatten", "[", 
       RowBox[{"Solve", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"-", 
               SqrtBox["5"]}], " ", "c1"}], "+", "c2"}], ",", "c1"}], "}"}], 
          "\[Equal]", 
          RowBox[{"{", 
           RowBox[{"a", ",", "b"}], "}"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"c1", ",", "c2"}], "}"}]}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"ThisFcn", "=", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             SqrtBox["5"], " ", "t"}]]}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SqrtBox["5"], " ", "c1"}], "-", "c2", "+", 
            RowBox[{
             SqrtBox["5"], " ", "c2", " ", "t"}]}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            SqrtBox["5"], " ", "t"}]], " ", 
          RowBox[{"(", 
           RowBox[{"c1", "+", 
            RowBox[{"c2", " ", "t"}]}], ")"}]}]}], "}"}], "/.", 
       "ThisRule"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"AppendTo", "[", 
      RowBox[{"fcnlist2", ",", "ThisFcn"}], "]"}]}], ",", 
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"a", ",", 
      RowBox[{"-", "4"}], ",", "4", ",", "4"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"b", ",", 
      RowBox[{"-", "4"}], ",", "4", ",", "4"}], "}"}]}], "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Clear", "[", "p3", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"p3", "=", 
   RowBox[{"ParametricPlot", "[", 
    RowBox[{
     RowBox[{"Evaluate", "[", "fcnlist2", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "10"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"x", "[", "t", "]"}], ",", 
        RowBox[{"y", "[", "t", "]"}]}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "50"}], ",", "50"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "50"}], ",", "50"}], "}"}]}], "}"}]}]}], "]"}]}], 
  ";"}]}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Show", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"p3", ",", "p2"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"Axes", "\[Rule]", "Automatic"}], ",", "\[IndentingNewLine]", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "100000"}], ",", "100000"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "100000"}], ",", "100000"}], "}"}]}], "}"}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<x[t]\>\"", ",", "\"\<y[t]\>\""}], "}"}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"AspectRatio", "\[Rule]", "Automatic"}]}], "]"}], ";"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["describe the system,using appropriate vocabulary.", "Subsubsection"],

Cell[TextData[{
 "Consider the system z'=",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"0", ",", 
      RowBox[{"-", "5"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"1", ",", 
      RowBox[{"2", " ", 
       SqrtBox["5"]}]}], "}"}]}], "}"}]]],
 "z.\nThe origin is an unstable improper node.\n\nFrom the eigenvalue alone:  \
Since the eigenvalue is real and repeated and did not yield a full set of \
linearly independent eigenvectors, the origin is an improper node.  Since the \
eigenvalue is positive, the node is unstable.\n\nFurthermore, the {t,x[t]} \
and {t,y[t]} graphs tend to (plus or minus) infinity, indicating that as time \
progresses, the x and y components of the x-y graph increase without bound \
away from the origin, yielding instability.  In addition, the direction field \
indicates that the trajectories rotate clockwise away form the origin, again \
yielding instability."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["THE fundamental matrix", "Subsubsection"],

Cell["\<\
Take any fundamental matrix \[CapitalPsi][t] and compute \
\[CapitalPsi][t].Inverse[\[CapitalPsi][0]]:\
\>", "Text"],

Cell[BoxData[
 RowBox[{"\[CapitalPsi]", "[", "0", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Inverse", "[", "  ", 
  RowBox[{"\[CapitalPsi]", "[", "0", "]"}], "  ", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[CapitalPsi]", "[", "t", "]"}], " ", ".", " ", 
  RowBox[{"Inverse", "[", "  ", 
   RowBox[{"\[CapitalPsi]", "[", "0", "]"}], "  ", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"Expand", "[", "%", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"MatrixForm", "[", "%", "]"}]], "Input"],

Cell[BoxData[{
 RowBox[{"Clear", "[", "\[CapitalPhi]", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[CapitalPhi]", "[", "t_", "]"}], ":=", 
  TagBox[
   RowBox[{"(", "\[NoBreak]", GridBox[{
      {
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          SqrtBox["5"], " ", "t"}]], "-", 
        RowBox[{
         SqrtBox["5"], " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           SqrtBox["5"], " ", "t"}]], " ", "t"}]}], 
       RowBox[{
        RowBox[{"-", "5"}], " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          SqrtBox["5"], " ", "t"}]], " ", "t"}]},
      {
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          SqrtBox["5"], " ", "t"}]], " ", "t"}], 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          SqrtBox["5"], " ", "t"}]], "+", 
        RowBox[{
         SqrtBox["5"], " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           SqrtBox["5"], " ", "t"}]], " ", "t"}]}]}
     }], "\[NoBreak]", ")"}],
   MatrixForm[#]& ]}]}], "Input"],

Cell["\<\
Check the properties of THE fundamental matrix:  it has linearly independent \
columns, so its determinant is nonzero, and it solves the DE.  Further, at \
t=0, it is the identity matrix.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"Det", "[", 
  RowBox[{"\[CapitalPhi]", "[", "t", "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"D", "[", 
  RowBox[{
   RowBox[{"\[CapitalPhi]", "[", "t", "]"}], ",", "t"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"A", "[", 
   RowBox[{
    RowBox[{"-", "2"}], 
    SqrtBox["5"]}], "]"}], ".", 
  RowBox[{"\[CapitalPhi]", "[", "t", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"Expand", "[", "%", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"\[CapitalPhi]", "[", "0", "]"}]], "Input"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["2 real roots", "Section",
 CellFrame->{{0, 0}, {0, 2}}],

Cell[TextData[{
 "\n case (2) ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"-", "20"}], "+", 
    SuperscriptBox["\[Alpha]", "2"]}], ">", "0"}]]],
 " really has two cases.\n case (2n)   ",
 Cell[BoxData[
  RowBox[{"\[Alpha]", "<", 
   RowBox[{
    RowBox[{"-", "2"}], 
    SqrtBox["5"], " "}]}]]],
 ".\n  case (2p)   ",
 Cell[BoxData[
  RowBox[{"\[Alpha]", " ", ">", 
   RowBox[{"2", 
    SqrtBox["5"], " "}]}]]],
 "."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  RowBox[{"\[Alpha]", "<", 
   RowBox[{
    RowBox[{"-", "2"}], 
    SqrtBox["5"]}]}]],
  TextAlignment->Left],
 ",   in general"
}], "Subsection",
 CellFrame->{{0, 0}, {0, 0.5}}],

Cell[BoxData[
 RowBox[{"\t", 
  RowBox[{
   RowBox[{"r1", " ", "=", " ", 
    RowBox[{
     FractionBox[
      RowBox[{"\[Alpha]", "+", 
       SqrtBox[
        RowBox[{
         RowBox[{"-", "20"}], "+", 
         SuperscriptBox["\[Alpha]", "2"]}]]}], "2"], " ", "<", " ", "0", 
     " "}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"r1", "<", 
     RowBox[{"0", " ", "since", " ", "0"}], " ", "<", " ", 
     RowBox[{
      SuperscriptBox["\[Alpha]", "2"], " ", "-", " ", "20"}], " ", "<", 
     SuperscriptBox["\[Alpha]", "2"]}], " ", ",", " ", "\[IndentingNewLine]", 
    
    RowBox[{
     RowBox[{
      RowBox[{"so", " ", "that", "              ", "0"}], " ", "<", " ", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["\[Alpha]", "2"], " ", "-", " ", "20", " "}]], " ", 
      "<", " ", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["\[Alpha]", "2"], " "}]]}], "=", " ", 
     RowBox[{"|", "\[Alpha]", "|"}]}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"so", " ", "that", "   ", "\[Alpha]"}], " ", "+", "  ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["\[Alpha]", "2"], " ", "-", " ", "20", " "}]]}], " ", 
      "<", " ", 
      RowBox[{"\[Alpha]", " ", "+", "  ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["\[Alpha]", "2"], " "}]]}]}], "=", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Alpha]", " ", "+"}], "  ", "|", "\[Alpha]", "|"}], " ", "=",
       " ", 
      RowBox[{
       RowBox[{
       "0", " ", ".", "\[IndentingNewLine]", "\[IndentingNewLine]", "r2"}], 
       " ", "=", " ", 
       RowBox[{
        FractionBox[
         RowBox[{"\[Alpha]", "-", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", "20"}], "+", 
            SuperscriptBox["\[Alpha]", "2"]}]]}], "2"], " ", "<", " ", 
        "0"}]}]}]}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"since", " ", 
     RowBox[{"we", "'"}], "re", " ", "adding", " ", "two", " ", 
     RowBox[{
     "negatives", ".", "\[IndentingNewLine]", "\[IndentingNewLine]", "Both"}],
      " ", "eigenvalues", " ", "have", " ", "the", " ", "same", " ", "sign", 
     " ", "and", " ", "are", " ", "unequal"}], ",", " ", 
    RowBox[{"so", " ", "the", " ", "origin", " ", "is", " ", "a", " ", 
     RowBox[{"node", ".", "  ", "Both"}], " ", "eigenvalues", " ", "are", " ",
      "negative"}], ",", " ", 
    RowBox[{
    "so", " ", "our", " ", "solutions", " ", "will", " ", "have", " ", "an", 
     " ", "exponential", " ", "decay"}], ",", " ", 
    RowBox[{"making", " ", "the", " ", "node", " ", 
     RowBox[{"stable", ".", "  ", "That"}], " ", "is"}], ",", " ", 
    RowBox[{
     RowBox[{"trajectories", " ", "in", " ", "the", " ", "x"}], "-", 
     RowBox[{
     "y", " ", "plane", " ", "tend", " ", "toward", " ", "the", " ", "origin",
       " ", "for", " ", "any", " ", "initial", " ", 
      RowBox[{"condition", "."}]}]}]}]}]}]], "Text",
 FontFamily->"Times"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Example:  ",
 Cell[BoxData[
  RowBox[{"\[Alpha]", "=", 
   RowBox[{
    RowBox[{"-", "20"}], "<", 
    RowBox[{
     RowBox[{"-", "2"}], 
     SqrtBox["5"]}]}]}]],
  TextAlignment->Left],
 " gory detail"
}], "Subsection",
 CellFrame->{{0, 0}, {0, 0.5}}],

Cell[CellGroupData[{

Cell["solution from the eigenmethod", "Subsubsection"],

Cell[BoxData[{
 RowBox[{"Clear", "[", "\[Alpha]", "]"}], "\n", 
 RowBox[{
  RowBox[{"\[Alpha]", "=", 
   RowBox[{"-", "10"}]}], ";"}], "\n", 
 RowBox[{"MatrixForm", "[", 
  RowBox[{"A", "[", "\[Alpha]", "]"}], "]"}]}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Eigensystem", "[", 
   RowBox[{"A", "[", "\[Alpha]", "]"}], "]"}], "//", "MatrixForm"}]], "Input"],

Cell[BoxData[
 RowBox[{"N", "[", "%", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"There", " ", "are", " ", "two", " ", "linearly", " ", "independent",
   " ", "solutions", " ", "to", " ", "the", " ", "DE", " ", "from", " ", 
  "this", " ", 
  RowBox[{"method", ":", " ", "\[IndentingNewLine]", " ", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "5"}], "-", 
        RowBox[{"2", " ", 
         SqrtBox["5"]}]}], ")"}], " ", "t"}]], 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"5", "-", 
       RowBox[{"2", " ", 
        SqrtBox["5"]}]}], ",", "1"}], "}"}], " ", "and", "  ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "5"}], "+", 
        RowBox[{"2", " ", 
         SqrtBox["5"]}]}], ")"}], " ", "t"}]], 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"5", "+", 
        RowBox[{"2", " ", 
         SqrtBox["5"]}]}], ",", "1"}], "}"}], " ", "."}]}]}]}]], "Text",
 FontFamily->"Times"],

Cell[BoxData[
 RowBox[{
  RowBox[{
  "Because", " ", "the", " ", "eigenvalues", " ", "are", " ", "real", " ", 
   "and", " ", "different"}], ",", " ", 
  RowBox[{
   RowBox[{
   "we", " ", "may", " ", "obtain", " ", "an", " ", "idea", " ", "of", " ", 
    "the", " ", "trajectories", " ", "by", " ", "plotting", " ", "the", " ", 
    "eigenvectors", " ", "and", " ", "the", " ", "lines", " ", "they", " ", 
    "individually", " ", 
    RowBox[{"generate", ".", "  ", "\[IndentingNewLine]", "The"}], " ", 
    "first", " ", "eigenvector", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "5"}], "-", 
       RowBox[{"2", " ", 
        SqrtBox["5"]}]}], ",", "1"}], "}"}], " ", "lies", " ", "on", " ", 
    "the", " ", "line", " ", "y"}], " ", "=", "  ", 
   RowBox[{
    RowBox[{
     RowBox[{"1", "/", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "5"}], "-", 
        RowBox[{"2", " ", 
         SqrtBox["5"]}]}], " ", ")"}]}], " ", 
     RowBox[{"x", ".", " ", "\[IndentingNewLine]", " ", "The"}], "  ", 
     "second", " ", "eigenvector", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "5"}], "+", 
        RowBox[{"2", " ", 
         SqrtBox["5"]}]}], ",", "1"}], "}"}], " ", "lies", " ", "on", " ", 
     "the", " ", "line", " ", "y"}], " ", "=", "  ", 
    RowBox[{
     RowBox[{"1", "/", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "5"}], "+", 
        RowBox[{"2", " ", 
         SqrtBox["5"]}]}], " ", ")"}]}], " ", 
     RowBox[{"x", "."}]}]}]}]}]], "Text",
 FontFamily->"Times"]
}, Open  ]],

Cell[CellGroupData[{

Cell["a fundamental matrix", "Subsubsection"],

Cell[BoxData[
 RowBox[{"MatrixForm", "[", 
  RowBox[{"Transpose", "[", 
   RowBox[{"{", " ", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "-", 
          RowBox[{"2", " ", 
           SqrtBox["5"]}]}], ")"}], " ", "t"}]], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"5", "-", 
         RowBox[{"2", " ", 
          SqrtBox["5"]}]}], ",", "1"}], "}"}]}], ",", " ", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          RowBox[{"2", " ", 
           SqrtBox["5"]}]}], ")"}], " ", "t"}]], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"5", "+", 
         RowBox[{"2", " ", 
          SqrtBox["5"]}]}], ",", "1"}], "}"}]}]}], "}"}], "]"}], 
  "]"}]], "Input"],

Cell[BoxData[{
 RowBox[{"Clear", "[", "\[CapitalPsi]", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[CapitalPsi]", "[", "t_", "]"}], ":=", 
  TagBox[
   RowBox[{"(", "\[NoBreak]", GridBox[{
      {
       RowBox[{
        RowBox[{"(", 
         RowBox[{"5", "-", 
          RowBox[{"2", " ", 
           SqrtBox["5"]}]}], ")"}], " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "5"}], "-", 
            RowBox[{"2", " ", 
             SqrtBox["5"]}]}], ")"}], " ", "t"}]]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"5", "+", 
          RowBox[{"2", " ", 
           SqrtBox["5"]}]}], ")"}], " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "5"}], "+", 
            RowBox[{"2", " ", 
             SqrtBox["5"]}]}], ")"}], " ", "t"}]]}]},
      {
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "5"}], "-", 
           RowBox[{"2", " ", 
            SqrtBox["5"]}]}], ")"}], " ", "t"}]], 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "5"}], "+", 
           RowBox[{"2", " ", 
            SqrtBox["5"]}]}], ")"}], " ", "t"}]]}
     }], "\[NoBreak]", ")"}],
   MatrixForm[#]& ]}]}], "Input"],

Cell[BoxData[
 RowBox[{"Det", "[", 
  RowBox[{"\[CapitalPsi]", "[", "t", "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Simplify", "[", "%", "]"}]], "Input"],

Cell["Note that a fundamental matrix also solves the DE.", "Text"],

Cell[BoxData[
 RowBox[{"D", "[", 
  RowBox[{
   RowBox[{"\[CapitalPsi]", "[", "t", "]"}], ",", "t"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Expand", "[", "%", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"A", "[", "\[Alpha]", "]"}], ".", 
  RowBox[{"\[CapitalPsi]", "[", "t", "]"}]}]], "Input"],

Cell["hard to tell like this, but the difference should be zero.", "Text"],

Cell[BoxData[
 RowBox[{"Expand", "[", "  ", 
  RowBox[{
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{"\[CapitalPsi]", "[", "t", "]"}], ",", "t"}], "]"}], " ", "-", 
   " ", 
   RowBox[{
    RowBox[{"A", "[", "\[Alpha]", "]"}], ".", 
    RowBox[{"\[CapitalPsi]", "[", "t", "]"}]}]}], " ", "]"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["general solution, behavior", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{
  "The", " ", "general", " ", "solution", " ", "is", "      ", "c1", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "5"}], "-", 
       RowBox[{"2", " ", 
        SqrtBox["5"]}]}], ")"}], " ", "t"}]], 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"5", "-", 
      RowBox[{"2", " ", 
       SqrtBox["5"]}]}], ",", "1"}], "}"}]}], " ", "+", " ", 
  RowBox[{"c2", "  ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "5"}], "+", 
       RowBox[{"2", " ", 
        SqrtBox["5"]}]}], ")"}], " ", "t"}]], 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"5", "+", 
       RowBox[{"2", " ", 
        SqrtBox["5"]}]}], ",", "1"}], "}"}], " ", "."}]}]}]], "Text",
 FontFamily->"Times"],

Cell[BoxData[
 RowBox[{"Expand", "[", " ", 
  RowBox[{
   RowBox[{"c1", "  ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "5"}], "-", 
        RowBox[{"2", " ", 
         SqrtBox["5"]}]}], ")"}], " ", "t"}]], 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"5", "-", 
       RowBox[{"2", " ", 
        SqrtBox["5"]}]}], ",", "1"}], "}"}]}], "+", " ", 
   RowBox[{"c2", "  ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "5"}], "+", 
        RowBox[{"2", " ", 
         SqrtBox["5"]}]}], ")"}], " ", "t"}]], 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"5", "+", 
       RowBox[{"2", " ", 
        SqrtBox["5"]}]}], ",", "1"}], "}"}]}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Collect", "[", 
  RowBox[{"%", ",", 
   RowBox[{"{", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "5"}], "-", 
         RowBox[{"2", " ", 
          SqrtBox["5"]}]}], ")"}], " ", "t"}]], ",", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "5"}], "+", 
         RowBox[{"2", " ", 
          SqrtBox["5"]}]}], ")"}], " ", "t"}]]}], " ", "}"}]}], 
  "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Note", " ", "that", " ", "for", " ", "these", " ", "solutions"}], 
   ",", " ", 
   RowBox[{"for", " ", "any", " ", "c1", " ", "and", " ", "c2"}], ",", "  ", 
   RowBox[{
   "since", " ", "\[ExponentialE]", " ", "is", " ", "raised", " ", "to", " ", 
    "a", " ", "negative", " ", "value"}], ",", " ", 
   RowBox[{
   "both", " ", "components", " ", "tend", " ", "to", " ", "zero", " ", "as", 
    " ", "t", " ", 
    RowBox[{"increases", ".", "  ", "Thus"}]}], ",", 
   RowBox[{
   "the", " ", "origin", " ", "is", " ", "a", " ", "stable", " ", "node", " ",
     "for", " ", "this", " ", "value", " ", "of", " ", 
    RowBox[{"\[Alpha]", "."}]}]}]}]], "Text",
 FontFamily->"Times"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"{", " ", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "-", 
          RowBox[{"2", " ", 
           SqrtBox["5"]}]}], ")"}], " ", "t"}]], ",", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          RowBox[{"2", " ", 
           SqrtBox["5"]}]}], ")"}], " ", "t"}]]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "4"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<t\>\"", ",", "\"\<components\>\""}], "}"}]}]}], "]"}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"5", " ", "c1"}], "-", 
        RowBox[{"2", " ", 
         SqrtBox["5"], " ", "c1"}]}], ")"}], " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "-", 
          RowBox[{"2", " ", 
           SqrtBox["5"]}]}], ")"}], " ", "t"}]]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"5", " ", "c2"}], "+", 
        RowBox[{"2", " ", 
         SqrtBox["5"], " ", "c2"}]}], ")"}], " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          RowBox[{"2", " ", 
           SqrtBox["5"]}]}], ")"}], " ", "t"}]]}]}], ",", 
    RowBox[{
     RowBox[{"c1", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "-", 
          RowBox[{"2", " ", 
           SqrtBox["5"]}]}], ")"}], " ", "t"}]]}], "+", 
     RowBox[{"c2", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          RowBox[{"2", " ", 
           SqrtBox["5"]}]}], ")"}], " ", "t"}]]}]}]}], "}"}], "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"c1", "\[Rule]", "1"}], ",", 
    RowBox[{"c2", "\[Rule]", "1"}]}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"5", "-", 
        RowBox[{"2", " ", 
         SqrtBox["5"]}]}], ")"}], " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "-", 
          RowBox[{"2", " ", 
           SqrtBox["5"]}]}], ")"}], " ", "t"}]]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"5", "+", 
        RowBox[{"2", " ", 
         SqrtBox["5"]}]}], ")"}], " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          RowBox[{"2", " ", 
           SqrtBox["5"]}]}], ")"}], " ", "t"}]]}]}], ",", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "5"}], "-", 
         RowBox[{"2", " ", 
          SqrtBox["5"]}]}], ")"}], " ", "t"}]], "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "5"}], "+", 
         RowBox[{"2", " ", 
          SqrtBox["5"]}]}], ")"}], " ", "t"}]]}]}], "}"}], "/.", 
  RowBox[{"t", "\[Rule]", "0"}]}]], "Input"],

Cell["\<\
The trajectory begins at (10,2) and travels toward the origin.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ParametricPlot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"5", "-", 
          RowBox[{"2", " ", 
           SqrtBox["5"]}]}], ")"}], " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "5"}], "-", 
            RowBox[{"2", " ", 
             SqrtBox["5"]}]}], ")"}], " ", "t"}]]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"5", "+", 
          RowBox[{"2", " ", 
           SqrtBox["5"]}]}], ")"}], " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "5"}], "+", 
            RowBox[{"2", " ", 
             SqrtBox["5"]}]}], ")"}], " ", "t"}]]}]}], ",", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "5"}], "-", 
           RowBox[{"2", " ", 
            SqrtBox["5"]}]}], ")"}], " ", "t"}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "5"}], "+", 
           RowBox[{"2", " ", 
            SqrtBox["5"]}]}], ")"}], " ", "t"}]]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "10"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<x[t]\>\"", ",", "\"\<y[t]\>\""}], "}"}]}]}], "]"}], 
  ";"}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"fcnlist", "=", 
   RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{"AppendTo", "[", 
    RowBox[{"fcnlist", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"5", " ", "c1"}], "-", 
           RowBox[{"2", " ", 
            SqrtBox["5"], " ", "c1"}]}], ")"}], " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "5"}], "-", 
             RowBox[{"2", " ", 
              SqrtBox["5"]}]}], ")"}], " ", "t"}]]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"5", " ", "c2"}], "+", 
           RowBox[{"2", " ", 
            SqrtBox["5"], " ", "c2"}]}], ")"}], " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "5"}], "+", 
             RowBox[{"2", " ", 
              SqrtBox["5"]}]}], ")"}], " ", "t"}]]}]}], ",", 
       RowBox[{
        RowBox[{"c1", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "5"}], "-", 
             RowBox[{"2", " ", 
              SqrtBox["5"]}]}], ")"}], " ", "t"}]]}], "+", 
        RowBox[{"c2", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "5"}], "+", 
             RowBox[{"2", " ", 
              SqrtBox["5"]}]}], ")"}], " ", "t"}]]}]}]}], "}"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"c1", ",", 
     RowBox[{"-", "2"}], ",", "2", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"c2", ",", 
     RowBox[{"-", "3"}], ",", "3", ",", "3"}], "}"}]}], 
  "]"}], "\[IndentingNewLine]", "fcnlist"}], "Input"],

Cell["\<\
phase plane for several trajectories.  Look for the lines generated by the \
eigenvectors.\
\>", "Text"],

Cell[BoxData[{
 RowBox[{"Clear", "[", "p1", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"p1", "=", 
   RowBox[{"ParametricPlot", "[", 
    RowBox[{
     RowBox[{"Evaluate", "[", "fcnlist", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "10"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"x", "[", "t", "]"}], ",", 
        RowBox[{"y", "[", "t", "]"}]}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "4"}], ",", "4"}], "}"}]}], "}"}]}]}], "]"}]}], 
  ";"}]}], "Input"],

Cell["\<\
We can also generate functions with specific initial conditions.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"5", " ", "c1"}], "-", 
        RowBox[{"2", " ", 
         SqrtBox["5"], " ", "c1"}]}], ")"}], " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "-", 
          RowBox[{"2", " ", 
           SqrtBox["5"]}]}], ")"}], " ", "t"}]]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"5", " ", "c2"}], "+", 
        RowBox[{"2", " ", 
         SqrtBox["5"], " ", "c2"}]}], ")"}], " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          RowBox[{"2", " ", 
           SqrtBox["5"]}]}], ")"}], " ", "t"}]]}]}], ",", 
    RowBox[{
     RowBox[{"c1", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "-", 
          RowBox[{"2", " ", 
           SqrtBox["5"]}]}], ")"}], " ", "t"}]]}], "+", 
     RowBox[{"c2", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          RowBox[{"2", " ", 
           SqrtBox["5"]}]}], ")"}], " ", "t"}]]}]}]}], "}"}], "/.", 
  RowBox[{"t", "\[Rule]", "0"}]}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"fcnlist2", "=", 
   RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Do", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Clear", "[", 
      RowBox[{"ThisRule", ",", "ThisFcn"}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"ThisRule", "=", 
      RowBox[{"Flatten", "[", 
       RowBox[{"Solve", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"5", " ", "c1"}], "-", 
             RowBox[{"2", " ", 
              SqrtBox["5"], " ", "c1"}], "+", 
             RowBox[{"5", " ", "c2"}], "+", 
             RowBox[{"2", " ", 
              SqrtBox["5"], " ", "c2"}]}], ",", 
            RowBox[{"c1", "+", "c2"}]}], "}"}], "\[Equal]", 
          RowBox[{"{", 
           RowBox[{"a", ",", "b"}], "}"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"c1", ",", "c2"}], "}"}]}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"ThisFcn", "=", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"5", " ", "c1"}], "-", 
             RowBox[{"2", " ", 
              SqrtBox["5"], " ", "c1"}]}], ")"}], " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "5"}], "-", 
               RowBox[{"2", " ", 
                SqrtBox["5"]}]}], ")"}], " ", "t"}]]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"5", " ", "c2"}], "+", 
             RowBox[{"2", " ", 
              SqrtBox["5"], " ", "c2"}]}], ")"}], " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "5"}], "+", 
               RowBox[{"2", " ", 
                SqrtBox["5"]}]}], ")"}], " ", "t"}]]}]}], ",", 
         RowBox[{
          RowBox[{"c1", " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "5"}], "-", 
               RowBox[{"2", " ", 
                SqrtBox["5"]}]}], ")"}], " ", "t"}]]}], "+", 
          RowBox[{"c2", " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "5"}], "+", 
               RowBox[{"2", " ", 
                SqrtBox["5"]}]}], ")"}], " ", "t"}]]}]}]}], "}"}], "/.", 
       "ThisRule"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"AppendTo", "[", 
      RowBox[{"fcnlist2", ",", "ThisFcn"}], "]"}]}], ",", 
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"a", ",", 
      RowBox[{"-", "4"}], ",", "4", ",", "4"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"b", ",", 
      RowBox[{"-", "4"}], ",", "4", ",", "4"}], "}"}]}], "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Clear", "[", "p3", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"p3", "=", 
   RowBox[{"ParametricPlot", "[", 
    RowBox[{
     RowBox[{"Evaluate", "[", "fcnlist2", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "10"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"x", "[", "t", "]"}], ",", 
        RowBox[{"y", "[", "t", "]"}]}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "6"}], ",", "6"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "6"}], ",", "6"}], "}"}]}], "}"}]}]}], "]"}]}], 
  ";"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["direction field", "Subsubsection"],

Cell[TextData[{
 "Load the Graphics`PlotField` package BEFORE trying to generate the \
direction field.Load the package once per ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " session.If you change anything,generate the direction field again."
}], "Text"],

Cell[BoxData[
 RowBox[{"<<", "Graphics`PlotField`"}]], "Input",
 ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Remember that we obtain the coordinates of the direction field from \
{x'[t],y'[t]},which is given by the matrix product A.{x[t],y[t]}.To avoid \
confusing the {x,y} used here with ones plotted elsewhere,we'll call these \
{x1,y1}.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"A", "[", "\[Alpha]", "]"}], ".", 
  RowBox[{"{", 
   RowBox[{"x1", ",", "y1"}], "}"}]}]], "Input"],

Cell[BoxData[{
 RowBox[{"Clear", "[", "p2", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"p2", "=", 
   RowBox[{"PlotVectorField", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "5"}], " ", "y1"}], ",", 
       RowBox[{"x1", "-", 
        RowBox[{"10", " ", "y1"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"x1", ",", 
       RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y1", ",", 
       RowBox[{"-", "5"}], ",", "5"}], "}"}]}], "]"}]}], ";"}]}], "Input",
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Show", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"p1", ",", "p2"}], "}"}], ",", 
    RowBox[{"Axes", "\[Rule]", "Automatic"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "5"}], ",", "5"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<x[t]\>\"", ",", "\"\<y[t]\>\""}], "}"}]}], ",", 
    RowBox[{"AspectRatio", "\[Rule]", "Automatic"}]}], "]"}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Show", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"p2", ",", "p3"}], "}"}], ",", 
    RowBox[{"Axes", "\[Rule]", "Automatic"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "6"}], ",", "6"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "6"}], ",", "6"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<x[t]\>\"", ",", "\"\<y[t]\>\""}], "}"}]}], ",", 
    RowBox[{"AspectRatio", "\[Rule]", "Automatic"}]}], "]"}], ";"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["describe the system,using appropriate vocabulary.", "Subsubsection"],

Cell[TextData[{
 "Consider the system z'=",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"0", ",", 
      RowBox[{"-", "5"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"1", ",", 
      RowBox[{"-", "10"}]}], "}"}]}], "}"}]]],
 "z.\nThe origin is a stable node.\n\nFrom the eigenvalue alone:  Since the \
eigenvalues are real and different, the origin is a node.  Since the \
eigenvalues are negative, the node is stable.\n\nFurthermore, the {t,x[t]} \
and {t,y[t]} graphs tend to zero, indicating that as time progresses, the x \
and y components of the x-y graph approach the origin, yielding stability.  \
In addition, the direction field indicates that the trajectories tend toward \
the origin, again yielding stability."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["THE fundamental matrix", "Subsubsection"],

Cell["\<\
Take any fundamental matrix \[CapitalPsi][t] and compute \
\[CapitalPsi][t].Inverse[\[CapitalPsi][0]]:\
\>", "Text"],

Cell[BoxData[
 RowBox[{"\[CapitalPsi]", "[", "0", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Inverse", "[", "  ", 
  RowBox[{"\[CapitalPsi]", "[", "0", "]"}], "  ", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[CapitalPsi]", "[", "t", "]"}], " ", ".", " ", 
  RowBox[{"Inverse", "[", "  ", 
   RowBox[{"\[CapitalPsi]", "[", "0", "]"}], "  ", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"MatrixForm", "[", "%", "]"}]], "Input"],

Cell[BoxData[{
 RowBox[{"Clear", "[", "\[CapitalPhi]", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[CapitalPhi]", "[", "t_", "]"}], ":=", 
  TagBox[
   RowBox[{"(", "\[NoBreak]", GridBox[{
      {
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{"5", "-", 
             RowBox[{"2", " ", 
              SqrtBox["5"]}]}], ")"}], " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "5"}], "-", 
               RowBox[{"2", " ", 
                SqrtBox["5"]}]}], ")"}], " ", "t"}]]}], 
          RowBox[{"4", " ", 
           SqrtBox["5"]}]]}], "+", 
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{"5", "+", 
            RowBox[{"2", " ", 
             SqrtBox["5"]}]}], ")"}], " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "5"}], "+", 
              RowBox[{"2", " ", 
               SqrtBox["5"]}]}], ")"}], " ", "t"}]]}], 
         RowBox[{"4", " ", 
          SqrtBox["5"]}]]}], 
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "5"}], "-", 
             RowBox[{"2", " ", 
              SqrtBox["5"]}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"5", "-", 
             RowBox[{"2", " ", 
              SqrtBox["5"]}]}], ")"}], " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "5"}], "-", 
               RowBox[{"2", " ", 
                SqrtBox["5"]}]}], ")"}], " ", "t"}]]}], 
          RowBox[{"4", " ", 
           SqrtBox["5"]}]]}], "-", 
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{"5", "-", 
            RowBox[{"2", " ", 
             SqrtBox["5"]}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"5", "+", 
            RowBox[{"2", " ", 
             SqrtBox["5"]}]}], ")"}], " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "5"}], "+", 
              RowBox[{"2", " ", 
               SqrtBox["5"]}]}], ")"}], " ", "t"}]]}], 
         RowBox[{"4", " ", 
          SqrtBox["5"]}]]}]},
      {
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "5"}], "-", 
              RowBox[{"2", " ", 
               SqrtBox["5"]}]}], ")"}], " ", "t"}]], 
          RowBox[{"4", " ", 
           SqrtBox["5"]}]]}], "+", 
        FractionBox[
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "5"}], "+", 
             RowBox[{"2", " ", 
              SqrtBox["5"]}]}], ")"}], " ", "t"}]], 
         RowBox[{"4", " ", 
          SqrtBox["5"]}]]}], 
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "5"}], "-", 
             RowBox[{"2", " ", 
              SqrtBox["5"]}]}], ")"}], " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "5"}], "-", 
               RowBox[{"2", " ", 
                SqrtBox["5"]}]}], ")"}], " ", "t"}]]}], 
          RowBox[{"4", " ", 
           SqrtBox["5"]}]]}], "-", 
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{"5", "-", 
            RowBox[{"2", " ", 
             SqrtBox["5"]}]}], ")"}], " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "5"}], "+", 
              RowBox[{"2", " ", 
               SqrtBox["5"]}]}], ")"}], " ", "t"}]]}], 
         RowBox[{"4", " ", 
          SqrtBox["5"]}]]}]}
     }], "\[NoBreak]", ")"}],
   MatrixForm[#]& ]}]}], "Input"],

Cell["\<\
Check the properties of THE fundamental matrix:  nonzero determinant (meaning \
the solutions to the DE are linearly independent), solves the DE, has the \
identity matrix as its initial value.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"Det", "[", 
  RowBox[{"\[CapitalPhi]", "[", "t", "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Simplify", "[", "%", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"D", "[", 
  RowBox[{
   RowBox[{"\[CapitalPhi]", "[", "t", "]"}], ",", "t"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Expand", "[", "%", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"A", "[", "\[Alpha]", "]"}], ".", 
  RowBox[{"\[CapitalPhi]", "[", "t", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"Expand", "[", "%", "]"}]], "Input"],

Cell["too hard on my eyes!", "Text"],

Cell[BoxData[
 RowBox[{"Expand", "[", "  ", 
  RowBox[{
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{"\[CapitalPhi]", "[", "t", "]"}], ",", "t"}], "]"}], " ", "-", 
   " ", 
   RowBox[{
    RowBox[{"A", "[", "\[Alpha]", "]"}], ".", 
    RowBox[{"\[CapitalPhi]", "[", "t", "]"}]}]}], "  ", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"\[CapitalPhi]", "[", "0", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Expand", "[", "%", "]"}]], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  RowBox[{"\[Alpha]", " ", ">", " ", 
   RowBox[{"2", 
    SqrtBox["5"]}]}]],
  TextAlignment->Left],
 ",   in general"
}], "Subsection",
 CellFrame->{{0, 0}, {0, 0.5}}],

Cell[BoxData[
 RowBox[{"\t", 
  RowBox[{
   RowBox[{"r1", " ", "=", " ", 
    RowBox[{
     FractionBox[
      RowBox[{"\[Alpha]", "+", 
       SqrtBox[
        RowBox[{
         RowBox[{"-", "20"}], "+", 
         SuperscriptBox["\[Alpha]", "2"]}]]}], "2"], " ", ">", " ", "0", 
     " "}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"since", " ", 
     RowBox[{"we", "'"}], "re", " ", "adding", " ", "two", " ", "positive", 
     " ", 
     RowBox[{
     "values", ".", "\[IndentingNewLine]", "\[IndentingNewLine]", "r2"}]}], 
    " ", "=", " ", 
    RowBox[{
     FractionBox[
      RowBox[{"\[Alpha]", "-", 
       SqrtBox[
        RowBox[{
         RowBox[{"-", "20"}], "+", 
         SuperscriptBox["\[Alpha]", "2"]}]]}], "2"], " ", "<", " ", "0"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"r2", ">", 
     RowBox[{"0", " ", "since", " ", "0"}], " ", "<", " ", 
     RowBox[{
      SuperscriptBox["\[Alpha]", "2"], " ", "-", " ", "20"}], " ", "<", 
     SuperscriptBox["\[Alpha]", "2"]}], " ", ",", " ", "\[IndentingNewLine]", 
    
    RowBox[{
     RowBox[{
      RowBox[{"so", " ", "that", "              ", "0"}], " ", "<", " ", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["\[Alpha]", "2"], " ", "-", " ", "20", " "}]], " ", 
      "<", " ", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["\[Alpha]", "2"], " "}]]}], "=", " ", 
     RowBox[{"|", "\[Alpha]", "|"}]}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"so", " ", "that", "              ", "0"}], " ", ">", " ", 
      RowBox[{"-", " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["\[Alpha]", "2"], " ", "-", " ", "20", " "}]]}], " ", 
      ">", " ", 
      RowBox[{"-", " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["\[Alpha]", "2"], " "}]]}]}], "=", " ", 
     RowBox[{"-", 
      RowBox[{"|", "\[Alpha]", "|"}]}]}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"so", " ", "that", "   ", "\[Alpha]"}], " ", "-", "  ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["\[Alpha]", "2"], " ", "-", " ", "20", " "}]]}], " ", 
      ">", " ", 
      RowBox[{"\[Alpha]", " ", "-", "  ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["\[Alpha]", "2"], " "}]]}]}], "=", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Alpha]", " ", "-"}], "  ", "|", "\[Alpha]", "|"}], " ", "=",
       " ", 
      RowBox[{
       RowBox[{
       "0", " ", ".", "\[IndentingNewLine]", "\[IndentingNewLine]", "Both"}], 
       " ", "eigenvalues", " ", "have", " ", "the", " ", "same", " ", "sign", 
       " ", "and", " ", "are", " ", "unequal"}]}]}], ",", " ", 
    RowBox[{"so", " ", "the", " ", "origin", " ", "is", " ", "a", " ", 
     RowBox[{"node", ".", "  ", "Both"}], " ", "eigenvalues", " ", "are", " ",
      "positive"}], ",", " ", 
    RowBox[{
    "so", " ", "our", " ", "solutions", " ", "will", " ", "have", " ", "an", 
     " ", "exponential", " ", "growth"}], ",", " ", 
    RowBox[{"making", " ", "the", " ", "node", " ", 
     RowBox[{"unstable", ".", "  ", "That"}], " ", "is"}], ",", " ", 
    RowBox[{
     RowBox[{"trajectories", " ", "in", " ", "the", " ", "x"}], "-", 
     RowBox[{
     "y", " ", "plane", " ", "tend", " ", "away", " ", "from", " ", "the", 
      " ", "origin", " ", "for", " ", "any", " ", "initial", " ", 
      RowBox[{"condition", "."}]}]}]}]}]}]], "Text",
 FontFamily->"Times"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  RowBox[{
   RowBox[{"Example", ":", "\[Alpha]"}], "=", 
   RowBox[{"10", ">", " ", 
    RowBox[{"2", 
     SqrtBox["5"]}]}]}]],
  TextAlignment->Left],
 " gory detail"
}], "Subsection",
 CellFrame->{{0, 0}, {0, 0.5}}],

Cell[CellGroupData[{

Cell["solution from the eigenmethod", "Subsubsection"],

Cell[BoxData[{
 RowBox[{"Clear", "[", "\[Alpha]", "]"}], "\n", 
 RowBox[{
  RowBox[{"\[Alpha]", "=", "10"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"A", "[", "\[Alpha]", "]"}], "//", "MatrixForm"}]}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Eigensystem", "[", 
   RowBox[{"A", "[", "\[Alpha]", "]"}], "]"}], "//", "MatrixForm"}]], "Input"],

Cell[BoxData[
 RowBox[{"N", "[", "%", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"There", " ", "are", " ", "two", " ", "linearly", " ", "independent",
   " ", "solutions", " ", "to", " ", "the", " ", "DE", " ", "from", " ", 
  "this", " ", 
  RowBox[{"method", ":", " ", "\[IndentingNewLine]", " ", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"5", "-", 
        RowBox[{"2", " ", 
         SqrtBox["5"]}]}], ")"}], " ", "t"}]], 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "5"}], "-", 
       RowBox[{"2", " ", 
        SqrtBox["5"]}]}], ",", "1"}], "}"}], " ", "and", "  ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"5", "+", 
        RowBox[{"2", " ", 
         SqrtBox["5"]}]}], ")"}], " ", "t"}]], 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "5"}], "+", 
        RowBox[{"2", " ", 
         SqrtBox["5"]}]}], ",", "1"}], "}"}], " ", "."}]}]}]}]], "Text",
 FontFamily->"Times"],

Cell[BoxData[
 RowBox[{
  RowBox[{
  "Because", " ", "the", " ", "eigenvalues", " ", "are", " ", "real", " ", 
   "and", " ", "different"}], ",", " ", 
  RowBox[{
   RowBox[{
   "we", " ", "may", " ", "obtain", " ", "an", " ", "idea", " ", "of", " ", 
    "the", " ", "trajectories", " ", "by", " ", "plotting", " ", "the", " ", 
    "eigenvectors", " ", "and", " ", "the", " ", "lines", " ", "they", " ", 
    "individually", " ", 
    RowBox[{"generate", ".", "  ", "\[IndentingNewLine]", "The"}], " ", 
    "first", " ", "eigenvector", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "5"}], "-", 
       RowBox[{"2", " ", 
        SqrtBox["5"]}]}], ",", "1"}], "}"}], " ", "lies", " ", "on", " ", 
    "the", " ", "line", " ", "y"}], " ", "=", "  ", 
   RowBox[{
    RowBox[{
     RowBox[{"1", "/", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "5"}], "-", 
        RowBox[{"2", " ", 
         SqrtBox["5"]}]}], " ", ")"}]}], " ", 
     RowBox[{"x", ".", " ", "\[IndentingNewLine]", " ", "The"}], "  ", 
     "second", " ", "eigenvector", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "5"}], "+", 
        RowBox[{"2", " ", 
         SqrtBox["5"]}]}], ",", "1"}], "}"}], " ", "lies", " ", "on", " ", 
     "the", " ", "line", " ", "y"}], " ", "=", "  ", 
    RowBox[{
     RowBox[{"1", "/", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "5"}], "+", 
        RowBox[{"2", " ", 
         SqrtBox["5"]}]}], " ", ")"}]}], " ", 
     RowBox[{"x", "."}]}]}]}]}]], "Text",
 FontFamily->"Times"]
}, Open  ]],

Cell[CellGroupData[{

Cell["a fundamental matrix", "Subsubsection"],

Cell[BoxData[
 RowBox[{"MatrixForm", "[", 
  RowBox[{"Transpose", "[", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"5", "-", 
          RowBox[{"2", " ", 
           SqrtBox["5"]}]}], ")"}], " ", "t"}]], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "5"}], "-", 
         RowBox[{"2", " ", 
          SqrtBox["5"]}]}], ",", "1"}], "}"}]}], ",", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"5", "+", 
          RowBox[{"2", " ", 
           SqrtBox["5"]}]}], ")"}], " ", "t"}]], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "5"}], "+", 
         RowBox[{"2", " ", 
          SqrtBox["5"]}]}], ",", "1"}], "}"}]}]}], "}"}], "]"}], 
  "]"}]], "Input"],

Cell[BoxData[{
 RowBox[{"Clear", "[", "\[CapitalPsi]", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[CapitalPsi]", "[", "t_", "]"}], ":=", 
  TagBox[
   RowBox[{"(", "\[NoBreak]", GridBox[{
      {
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "-", 
          RowBox[{"2", " ", 
           SqrtBox["5"]}]}], ")"}], " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"5", "-", 
            RowBox[{"2", " ", 
             SqrtBox["5"]}]}], ")"}], " ", "t"}]]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          RowBox[{"2", " ", 
           SqrtBox["5"]}]}], ")"}], " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"5", "+", 
            RowBox[{"2", " ", 
             SqrtBox["5"]}]}], ")"}], " ", "t"}]]}]},
      {
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"5", "-", 
           RowBox[{"2", " ", 
            SqrtBox["5"]}]}], ")"}], " ", "t"}]], 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"5", "+", 
           RowBox[{"2", " ", 
            SqrtBox["5"]}]}], ")"}], " ", "t"}]]}
     }], "\[NoBreak]", ")"}],
   MatrixForm[#]& ]}]}], "Input"],

Cell["columns are linearly independent, matrix solves the DE.", "Text"],

Cell[BoxData[
 RowBox[{"Det", "[", 
  RowBox[{"\[CapitalPsi]", "[", "t", "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Simplify", "[", "%", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"D", "[", 
  RowBox[{
   RowBox[{"\[CapitalPsi]", "[", "t", "]"}], ",", "t"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Expand", "[", "%", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"A", "[", "\[Alpha]", "]"}], ".", 
  RowBox[{"\[CapitalPsi]", "[", "t", "]"}]}]], "Input"],

Cell["hard to tell like this, but the difference should be zero.", "Text"],

Cell[BoxData[
 RowBox[{"Expand", "[", "  ", 
  RowBox[{
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{"\[CapitalPsi]", "[", "t", "]"}], ",", "t"}], "]"}], " ", "-", 
   " ", 
   RowBox[{
    RowBox[{"A", "[", "\[Alpha]", "]"}], ".", 
    RowBox[{"\[CapitalPsi]", "[", "t", "]"}]}]}], " ", "]"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["general solution, behavior", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{
  "The", " ", "general", " ", "solution", " ", "is", "      ", "c1", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"5", "-", 
       RowBox[{"2", " ", 
        SqrtBox["5"]}]}], ")"}], " ", "t"}]], 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "5"}], "-", 
      RowBox[{"2", " ", 
       SqrtBox["5"]}]}], ",", "1"}], "}"}]}], " ", "+", " ", 
  RowBox[{"c2", "  ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"5", "+", 
       RowBox[{"2", " ", 
        SqrtBox["5"]}]}], ")"}], " ", "t"}]], 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "5"}], "+", 
       RowBox[{"2", " ", 
        SqrtBox["5"]}]}], ",", "1"}], "}"}], " ", "."}]}]}]], "Text",
 FontFamily->"Times"],

Cell[BoxData[
 RowBox[{"Expand", "[", " ", 
  RowBox[{
   RowBox[{"c1", "  ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"5", "-", 
        RowBox[{"2", " ", 
         SqrtBox["5"]}]}], ")"}], " ", "t"}]], 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "5"}], "-", 
       RowBox[{"2", " ", 
        SqrtBox["5"]}]}], ",", "1"}], "}"}]}], "+", " ", 
   RowBox[{"c2", "  ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"5", "+", 
        RowBox[{"2", " ", 
         SqrtBox["5"]}]}], ")"}], " ", "t"}]], 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "5"}], "+", 
       RowBox[{"2", " ", 
        SqrtBox["5"]}]}], ",", "1"}], "}"}]}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Collect", "[", 
  RowBox[{"%", ",", 
   RowBox[{"{", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"5", "-", 
         RowBox[{"2", " ", 
          SqrtBox["5"]}]}], ")"}], " ", "t"}]], ",", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"5", "+", 
         RowBox[{"2", " ", 
          SqrtBox["5"]}]}], ")"}], " ", "t"}]]}], " ", "}"}]}], 
  "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Note", " ", "that", " ", "for", " ", "these", " ", "solutions"}], 
   ",", " ", 
   RowBox[{"for", " ", "any", " ", "c1", " ", "and", " ", "c2"}], ",", "  ", 
   RowBox[{
   "since", " ", "\[ExponentialE]", " ", "is", " ", "raised", " ", "to", " ", 
    "a", " ", "positive", " ", "value"}], ",", " ", 
   RowBox[{
   "both", " ", "components", " ", "tend", " ", "to", " ", "infinity", " ", 
    "as", " ", "t", " ", 
    RowBox[{"increases", ".", "  ", "Thus"}]}], ",", 
   RowBox[{
   "the", " ", "origin", " ", "is", " ", "an", " ", "unstable", " ", "node", 
    " ", "for", " ", "this", " ", "value", " ", "of", " ", 
    RowBox[{"\[Alpha]", "."}]}]}]}]], "Text",
 FontFamily->"Times"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"{", " ", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"5", "-", 
          RowBox[{"2", " ", 
           SqrtBox["5"]}]}], ")"}], " ", "t"}]], ",", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"5", "+", 
          RowBox[{"2", " ", 
           SqrtBox["5"]}]}], ")"}], " ", "t"}]]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "4"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<t\>\"", ",", "\"\<components\>\""}], "}"}]}]}], "]"}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "5"}], " ", "c1"}], "-", 
        RowBox[{"2", " ", 
         SqrtBox["5"], " ", "c1"}]}], ")"}], " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"5", "-", 
          RowBox[{"2", " ", 
           SqrtBox["5"]}]}], ")"}], " ", "t"}]]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "5"}], " ", "c2"}], "+", 
        RowBox[{"2", " ", 
         SqrtBox["5"], " ", "c2"}]}], ")"}], " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"5", "+", 
          RowBox[{"2", " ", 
           SqrtBox["5"]}]}], ")"}], " ", "t"}]]}]}], ",", 
    RowBox[{
     RowBox[{"c1", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"5", "-", 
          RowBox[{"2", " ", 
           SqrtBox["5"]}]}], ")"}], " ", "t"}]]}], "+", 
     RowBox[{"c2", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"5", "+", 
          RowBox[{"2", " ", 
           SqrtBox["5"]}]}], ")"}], " ", "t"}]]}]}]}], "}"}], "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"c1", "\[Rule]", "1"}], ",", 
    RowBox[{"c2", "\[Rule]", "1"}]}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"%", "/.", 
  RowBox[{"t", "\[Rule]", "0"}]}]], "Input"],

Cell["\<\
The trajectory in the phase plane below begins at (-10,2) and travels away \
from the origin.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ParametricPlot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "-", 
          RowBox[{"2", " ", 
           SqrtBox["5"]}]}], ")"}], " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"5", "-", 
            RowBox[{"2", " ", 
             SqrtBox["5"]}]}], ")"}], " ", "t"}]]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          RowBox[{"2", " ", 
           SqrtBox["5"]}]}], ")"}], " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"5", "+", 
            RowBox[{"2", " ", 
             SqrtBox["5"]}]}], ")"}], " ", "t"}]]}]}], ",", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"5", "-", 
           RowBox[{"2", " ", 
            SqrtBox["5"]}]}], ")"}], " ", "t"}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"5", "+", 
           RowBox[{"2", " ", 
            SqrtBox["5"]}]}], ")"}], " ", "t"}]]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "10"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<x[t]\>\"", ",", "\"\<y[t]\>\""}], "}"}]}]}], "]"}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{"\n", 
  RowBox[{
   RowBox[{
    RowBox[{"fcnlist", "=", 
     RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"Do", "[", 
    RowBox[{
     RowBox[{"AppendTo", "[", 
      RowBox[{"fcnlist", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "5"}], " ", "c1"}], "-", 
             RowBox[{"2", " ", 
              SqrtBox["5"], " ", "c1"}]}], ")"}], " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"5", "-", 
               RowBox[{"2", " ", 
                SqrtBox["5"]}]}], ")"}], " ", "t"}]]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "5"}], " ", "c2"}], "+", 
             RowBox[{"2", " ", 
              SqrtBox["5"], " ", "c2"}]}], ")"}], " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"5", "+", 
               RowBox[{"2", " ", 
                SqrtBox["5"]}]}], ")"}], " ", "t"}]]}]}], ",", 
         RowBox[{
          RowBox[{"c1", " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"5", "-", 
               RowBox[{"2", " ", 
                SqrtBox["5"]}]}], ")"}], " ", "t"}]]}], "+", 
          RowBox[{"c2", " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"5", "+", 
               RowBox[{"2", " ", 
                SqrtBox["5"]}]}], ")"}], " ", "t"}]]}]}]}], "}"}]}], "]"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"c1", ",", 
       RowBox[{"-", "2"}], ",", "2", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"c2", ",", 
       RowBox[{"-", "3"}], ",", "3", ",", "3"}], "}"}]}], "]"}], 
   "\[IndentingNewLine]", "fcnlist"}]}]], "Input"],

Cell["\<\
phase plane for several trajectories.  Look for the lines generated by the \
eigenvectors.\
\>", "Text"],

Cell[BoxData[{
 RowBox[{"Clear", "[", "p1", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"p1", "=", 
   RowBox[{"ParametricPlot", "[", 
    RowBox[{
     RowBox[{"Evaluate", "[", "fcnlist", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "10"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x[t]\>\"", ",", "\"\<y[t]\>\""}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "4000"}], ",", "4000"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "4000"}], ",", "4000"}], "}"}]}], "}"}]}]}], "]"}]}], 
  ";"}]}], "Input"],

Cell["\<\
We can also generate functions with specific initial conditions.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "5"}], " ", "c1"}], "-", 
        RowBox[{"2", " ", 
         SqrtBox["5"], " ", "c1"}]}], ")"}], " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"5", "-", 
          RowBox[{"2", " ", 
           SqrtBox["5"]}]}], ")"}], " ", "t"}]]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "5"}], " ", "c2"}], "+", 
        RowBox[{"2", " ", 
         SqrtBox["5"], " ", "c2"}]}], ")"}], " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"5", "+", 
          RowBox[{"2", " ", 
           SqrtBox["5"]}]}], ")"}], " ", "t"}]]}]}], ",", 
    RowBox[{
     RowBox[{"c1", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"5", "-", 
          RowBox[{"2", " ", 
           SqrtBox["5"]}]}], ")"}], " ", "t"}]]}], "+", 
     RowBox[{"c2", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"5", "+", 
          RowBox[{"2", " ", 
           SqrtBox["5"]}]}], ")"}], " ", "t"}]]}]}]}], "}"}], "/.", 
  RowBox[{"t", "\[Rule]", "0"}]}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"fcnlist2", "=", 
   RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Do", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Clear", "[", 
      RowBox[{"ThisRule", ",", "ThisFcn"}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"ThisRule", "=", 
      RowBox[{"Flatten", "[", 
       RowBox[{"Solve", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"-", "5"}], " ", "c1"}], "-", 
             RowBox[{"2", " ", 
              SqrtBox["5"], " ", "c1"}], "-", 
             RowBox[{"5", " ", "c2"}], "+", 
             RowBox[{"2", " ", 
              SqrtBox["5"], " ", "c2"}]}], ",", 
            RowBox[{"c1", "+", "c2"}]}], "}"}], "\[Equal]", 
          RowBox[{"{", 
           RowBox[{"a", ",", "b"}], "}"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"c1", ",", "c2"}], "}"}]}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"ThisFcn", "=", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "5"}], " ", "c1"}], "-", 
             RowBox[{"2", " ", 
              SqrtBox["5"], " ", "c1"}]}], ")"}], " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"5", "-", 
               RowBox[{"2", " ", 
                SqrtBox["5"]}]}], ")"}], " ", "t"}]]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "5"}], " ", "c2"}], "+", 
             RowBox[{"2", " ", 
              SqrtBox["5"], " ", "c2"}]}], ")"}], " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"5", "+", 
               RowBox[{"2", " ", 
                SqrtBox["5"]}]}], ")"}], " ", "t"}]]}]}], ",", 
         RowBox[{
          RowBox[{"c1", " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"5", "-", 
               RowBox[{"2", " ", 
                SqrtBox["5"]}]}], ")"}], " ", "t"}]]}], "+", 
          RowBox[{"c2", " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"5", "+", 
               RowBox[{"2", " ", 
                SqrtBox["5"]}]}], ")"}], " ", "t"}]]}]}]}], "}"}], "/.", 
       "ThisRule"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"AppendTo", "[", 
      RowBox[{"fcnlist2", ",", "ThisFcn"}], "]"}]}], ",", 
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"a", ",", 
      RowBox[{"-", "4"}], ",", "4", ",", "4"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"b", ",", 
      RowBox[{"-", "4"}], ",", "4", ",", "4"}], "}"}]}], "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Clear", "[", "p3", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"p3", "=", 
   RowBox[{"ParametricPlot", "[", 
    RowBox[{
     RowBox[{"Evaluate", "[", "fcnlist2", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "10"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x[t]\>\"", ",", "\"\<y[t]\>\""}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "6000"}], ",", "6000"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "6000"}], ",", "6000"}], "}"}]}], "}"}]}]}], "]"}]}], 
  ";"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["direction field", "Subsubsection"],

Cell["\<\
Load the Graphics`PlotField` package BEFORE trying to generate the direction \
field.Load the package once perMathematicasession.If you change \
anything,generate the direction field again.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"<<", "Graphics`PlotField`"}]], "Input",
 ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Remember that we obtain the coordinates of the direction field from \
{x'[t],y'[t]},which is given by the matrix product A.{x[t],y[t]}.To avoid \
confusing the {x,y} used here with ones plotted elsewhere,we'll call these \
{x1,y1}.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"A", "[", "\[Alpha]", "]"}], ".", 
  RowBox[{"{", 
   RowBox[{"x1", ",", "y1"}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "5"}], " ", "y1"}], ",", 
   RowBox[{"x1", "-", 
    RowBox[{"2", " ", 
     SqrtBox["5"], " ", "y1"}]}]}], "}"}]], "Input"],

Cell[BoxData[{
 RowBox[{"Clear", "[", "p4", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"p4", "=", 
   RowBox[{"PlotVectorField", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "5"}], " ", "y1"}], ",", 
       RowBox[{"x1", "-", 
        RowBox[{"2", " ", 
         RowBox[{"Sqrt", "[", "5", "]"}], " ", "y1"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"x1", ",", 
       RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y1", ",", 
       RowBox[{"-", "4"}], ",", "4"}], "}"}]}], "]"}]}], ";"}]}], "Input",
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Show", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"p5", ",", "p4"}], "}"}], ",", 
    RowBox[{"Axes", "\[Rule]", "Automatic"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "4"}], ",", "4"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<x[t]\>\"", ",", "\"\<y[t]\>\""}], "}"}]}], ",", 
    RowBox[{"AspectRatio", "\[Rule]", "Automatic"}]}], "]"}], ";"}]], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.5 0.125 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -6 -9 ]
[.125 .4875 6 0 ]
[.25 .4875 -6 -9 ]
[.25 .4875 6 0 ]
[.375 .4875 -6 -9 ]
[.375 .4875 6 0 ]
[.625 .4875 -3 -9 ]
[.625 .4875 3 0 ]
[.75 .4875 -3 -9 ]
[.75 .4875 3 0 ]
[.875 .4875 -3 -9 ]
[.875 .4875 3 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 28 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -12 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -12 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -12 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -6 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -6 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -6 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -14 0 ]
[.5 1.025 14 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-4)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-3)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-2)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-1)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(1)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(2)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(3)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(4)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 13.000 moveto
(D) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-3)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-2)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-1)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(1)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(2)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(3)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(4)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 13.000 moveto
(D) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto fill
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto
-0.02 0.005 lineto stroke
} ifelse
grestore
} def
/MAarrowzero1 {
gsave
mathtops translate
0 0 Mdot
grestore
} def
% End of user PostScript
.5 Mabswid
0 .33549 m
.08186 .35814 L
.30739 .43065 L
.41017 .46645 L
.45782 .48385 L
.48148 .49276 L
.49173 .49672 L
.49653 .49861 L
.49851 .4994 L
.49934 .49973 L
.49973 .49989 L
.49988 .49995 L
.49995 .49998 L
.49998 .49999 L
.49999 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
s
0 .27639 m
.27433 .39908 L
.41609 .46247 L
.46686 .48518 L
.48644 .49394 L
.49476 .49766 L
.4979 .49906 L
.49921 .49965 L
.49969 .49986 L
.49987 .49994 L
.49995 .49998 L
.49998 .49999 L
.49999 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
s
.19098 .25 m
.4668 .44002 L
.50901 .47588 L
.51927 .48669 L
.52267 .49103 L
.52478 .4943 L
.52598 .49674 L
.5262 .49733 L
.52638 .49791 L
.52651 .49838 L
.52661 .49885 L
.52667 .49926 L
.52671 .49961 L
.52672 .49995 L
.52671 .50025 L
.52669 .50058 L
.52664 .50087 L
.52657 .50117 L
.52648 .50147 L
.52637 .50173 L
.52625 .50195 L
.52595 .50241 L
.52562 .50276 L
.52524 .50309 L
.52449 .50354 L
.52402 .50375 L
.52356 .50391 L
.52301 .50406 L
.52249 .50417 L
.52191 .50426 L
.52161 .5043 L
.52127 .50433 L
.521 .50435 L
.52071 .50437 L
.52056 .50438 L
.5204 .50438 L
.5201 .50439 L
.51983 .5044 L
.51953 .5044 L
.51925 .50439 L
.519 .50439 L
.51873 .50438 L
.51845 .50437 L
.51795 .50434 L
.51741 .5043 L
.51683 .50424 L
.51488 .504 L
.51284 .50365 L
.51114 .5033 L
.50795 .50253 L
Mistroke
.50397 .50137 L
.50195 .50071 L
.50089 .50033 L
.50041 .50016 L
.50017 .50007 L
.50008 .50003 L
.50003 .50001 L
.50001 .50001 L
.50001 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
.25 .5 m
.25009 .497 L
.25034 .49441 L
.25079 .49158 L
.25138 .48906 L
.25207 .48686 L
.25281 .48493 L
.25483 .48092 L
.25732 .47733 L
.26053 .47387 L
.26434 .47075 L
.26826 .46825 L
.27267 .46604 L
.27712 .46427 L
.28135 .46293 L
.28601 .46175 L
.29119 .46073 L
.29612 .46001 L
.29917 .45966 L
.30207 .4594 L
.30469 .45921 L
.30617 .45913 L
.30753 .45906 L
.31026 .45896 L
.31177 .45892 L
.3132 .45889 L
.31574 .45887 L
.3185 .45888 L
.31994 .45891 L
.32154 .45894 L
.3232 .45899 L
.32475 .45904 L
.3305 .45933 L
.33344 .45952 L
.33652 .45976 L
.34197 .46025 L
.35396 .46165 L
.37267 .46455 L
.39131 .46817 L
.44427 .48155 L
.47241 .49025 L
.48746 .49537 L
.49429 .49783 L
.49737 .49898 L
.49887 .49955 L
.4995 .4998 L
.49978 .49991 L
.49991 .49996 L
.49996 .49998 L
.49998 .49999 L
Mistroke
.49999 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
.5 .5 m
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
s
.75 .5 m
.74991 .503 L
.74966 .50559 L
.74921 .50842 L
.74862 .51094 L
.74793 .51314 L
.74719 .51507 L
.74517 .51908 L
.74268 .52267 L
.73947 .52613 L
.73566 .52925 L
.73174 .53175 L
.72733 .53396 L
.72288 .53573 L
.71865 .53707 L
.71399 .53825 L
.70881 .53927 L
.70388 .53999 L
.70083 .54034 L
.69793 .5406 L
.69531 .54079 L
.69383 .54087 L
.69247 .54094 L
.68974 .54104 L
.68823 .54108 L
.6868 .54111 L
.68426 .54113 L
.6815 .54112 L
.68006 .54109 L
.67846 .54106 L
.6768 .54101 L
.67525 .54096 L
.6695 .54067 L
.66656 .54048 L
.66348 .54024 L
.65803 .53975 L
.64604 .53835 L
.62733 .53545 L
.60869 .53183 L
.55573 .51845 L
.52759 .50975 L
.51254 .50463 L
.50571 .50217 L
.50263 .50102 L
.50113 .50045 L
.5005 .5002 L
.50022 .50009 L
.50009 .50004 L
.50004 .50002 L
.50002 .50001 L
Mistroke
.50001 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
.80902 .75 m
.5332 .55998 L
.49099 .52412 L
.48073 .51331 L
.47733 .50897 L
.47522 .5057 L
.47402 .50326 L
.4738 .50267 L
.47362 .50209 L
.47349 .50162 L
.47339 .50115 L
.47333 .50074 L
.47329 .50039 L
.47328 .50005 L
.47329 .49975 L
.47331 .49942 L
.47336 .49913 L
.47343 .49883 L
.47352 .49853 L
.47363 .49827 L
.47375 .49805 L
.47405 .49759 L
.47438 .49724 L
.47476 .49691 L
.47551 .49646 L
.47598 .49625 L
.47644 .49609 L
.47699 .49594 L
.47751 .49583 L
.47809 .49574 L
.47839 .4957 L
.47873 .49567 L
.479 .49565 L
.47929 .49563 L
.47944 .49562 L
.4796 .49562 L
.4799 .49561 L
.48017 .4956 L
.48047 .4956 L
.48075 .49561 L
.481 .49561 L
.48127 .49562 L
.48155 .49563 L
.48205 .49566 L
.48259 .4957 L
.48317 .49576 L
.48512 .496 L
.48716 .49635 L
.48886 .4967 L
.49205 .49747 L
Mistroke
.49603 .49863 L
.49805 .49929 L
.49911 .49967 L
.49959 .49984 L
.49983 .49993 L
.49992 .49997 L
.49997 .49999 L
.49999 .49999 L
.49999 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
Mfstroke
1 .72361 m
.72567 .60092 L
.58391 .53753 L
.53314 .51482 L
.51356 .50606 L
.50524 .50234 L
.5021 .50094 L
.50079 .50035 L
.50031 .50014 L
.50013 .50006 L
.50005 .50002 L
.50002 .50001 L
.50001 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
s
1 .66451 m
.91814 .64186 L
.69261 .56935 L
.58983 .53355 L
.54218 .51615 L
.51852 .50724 L
.50827 .50328 L
.50347 .50139 L
.50149 .5006 L
.50066 .50027 L
.50027 .50011 L
.50012 .50005 L
.50005 .50002 L
.50002 .50001 L
.50001 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
.5 .5 L
s
.0001 w
0 0 m
.04818 .03346 L
s
% Start of user PostScript
-4. -4. -3.61455 -3.73233 MAarrowhead1
% End of user PostScript
0 .07143 m
.0413 .09873 L
s
% Start of user PostScript
-4. -3.42857 -3.66961 -3.21015 MAarrowhead1
% End of user PostScript
0 .14286 m
.03442 .164 L
s
% Start of user PostScript
-4. -2.85714 -3.72468 -2.68798 MAarrowhead1
% End of user PostScript
0 .21429 m
.02753 .22928 L
s
% Start of user PostScript
-4. -2.28571 -3.77974 -2.1658 MAarrowhead1
% End of user PostScript
0 .28571 m
.02065 .29455 L
s
% Start of user PostScript
-4. -1.71429 -3.83481 -1.64362 MAarrowhead1
% End of user PostScript
0 .35714 m
.01377 .35982 L
s
% Start of user PostScript
-4. -1.14286 -3.88987 -1.12145 MAarrowhead1
% End of user PostScript
0 .42857 m
.00688 .42509 L
s
% Start of user PostScript
-4. -0.571429 -3.94494 -0.599268 MAarrowhead1
% End of user PostScript
0 .5 m
0 .49036 L
s
% Start of user PostScript
-4. 0 -4. -0.0770905 MAarrowhead1
% End of user PostScript
0 .57143 m
0 0 rlineto s
% Start of user PostScript
-4. 0.571429 -4.05506 0.445087 MAarrowhead1
% End of user PostScript
0 .64286 m
0 0 rlineto s
% Start of user PostScript
-4. 1.14286 -4.11013 0.967264 MAarrowhead1
% End of user PostScript
0 .71429 m
0 0 rlineto s
% Start of user PostScript
-4. 1.71429 -4.16519 1.48944 MAarrowhead1
% End of user PostScript
0 .78571 m
0 0 rlineto s
% Start of user PostScript
-4. 2.28571 -4.22026 2.01162 MAarrowhead1
% End of user PostScript
0 .85714 m
0 0 rlineto s
% Start of user PostScript
-4. 2.85714 -4.27532 2.5338 MAarrowhead1
% End of user PostScript
0 .92857 m
0 0 rlineto s
% Start of user PostScript
-4. 3.42857 -4.33039 3.05597 MAarrowhead1
% End of user PostScript
0 1 m
0 0 rlineto s
% Start of user PostScript
-4. 4. -4.38545 3.57815 MAarrowhead1
% End of user PostScript
.07143 0 m
.11961 .03484 L
s
% Start of user PostScript
-3.42857 -4. -3.04312 -3.72132 MAarrowhead1
% End of user PostScript
.07143 .07143 m
.11273 .10011 L
s
% Start of user PostScript
-3.42857 -3.42857 -3.09818 -3.19914 MAarrowhead1
% End of user PostScript
.07143 .14286 m
.10584 .16538 L
s
% Start of user PostScript
-3.42857 -2.85714 -3.15325 -2.67696 MAarrowhead1
% End of user PostScript
.07143 .21429 m
.09896 .23065 L
s
% Start of user PostScript
-3.42857 -2.28571 -3.20831 -2.15479 MAarrowhead1
% End of user PostScript
.07143 .28571 m
.09208 .29592 L
s
% Start of user PostScript
-3.42857 -1.71429 -3.26338 -1.63261 MAarrowhead1
% End of user PostScript
.07143 .35714 m
.08519 .3612 L
s
% Start of user PostScript
-3.42857 -1.14286 -3.31844 -1.11043 MAarrowhead1
% End of user PostScript
.07143 .42857 m
.07831 .42647 L
s
% Start of user PostScript
-3.42857 -0.571429 -3.37351 -0.588255 MAarrowhead1
% End of user PostScript
.07143 .5 m
.07143 .49174 L
s
% Start of user PostScript
-3.42857 0 -3.42857 -0.0660776 MAarrowhead1
% End of user PostScript
.07143 .57143 m
.06455 .55701 L
s
% Start of user PostScript
-3.42857 0.571429 -3.48364 0.4561 MAarrowhead1
% End of user PostScript
.07143 .64286 m
.05766 .62228 L
s
% Start of user PostScript
-3.42857 1.14286 -3.5387 0.978277 MAarrowhead1
% End of user PostScript
.07143 .71429 m
.05078 .68756 L
s
% Start of user PostScript
-3.42857 1.71429 -3.59377 1.50045 MAarrowhead1
% End of user PostScript
.07143 .78571 m
.0439 .75283 L
s
% Start of user PostScript
-3.42857 2.28571 -3.64883 2.02263 MAarrowhead1
% End of user PostScript
.07143 .85714 m
.03701 .8181 L
s
% Start of user PostScript
-3.42857 2.85714 -3.70389 2.54481 MAarrowhead1
% End of user PostScript
.07143 .92857 m
.03013 .88337 L
s
% Start of user PostScript
-3.42857 3.42857 -3.75896 3.06699 MAarrowhead1
% End of user PostScript
.07143 1 m
.02325 .94865 L
s
% Start of user PostScript
-3.42857 4. -3.81402 3.58916 MAarrowhead1
% End of user PostScript
.14286 0 m
.19104 .03621 L
s
% Start of user PostScript
-2.85714 -4. -2.47169 -3.71031 MAarrowhead1
% End of user PostScript
.14286 .07143 m
.18416 .10148 L
s
% Start of user PostScript
-2.85714 -3.42857 -2.52676 -3.18813 MAarrowhead1
% End of user PostScript
.14286 .14286 m
.17727 .16676 L
s
% Start of user PostScript
-2.85714 -2.85714 -2.58182 -2.66595 MAarrowhead1
% End of user PostScript
.14286 .21429 m
.17039 .23203 L
s
% Start of user PostScript
-2.85714 -2.28571 -2.63688 -2.14377 MAarrowhead1
% End of user PostScript
.14286 .28571 m
.16351 .2973 L
s
% Start of user PostScript
-2.85714 -1.71429 -2.69195 -1.6216 MAarrowhead1
% End of user PostScript
.14286 .35714 m
.15662 .36257 L
s
% Start of user PostScript
-2.85714 -1.14286 -2.74701 -1.09942 MAarrowhead1
% End of user PostScript
.14286 .42857 m
.14974 .42784 L
s
% Start of user PostScript
-2.85714 -0.571429 -2.80208 -0.577242 MAarrowhead1
% End of user PostScript
.14286 .5 m
.14286 .49312 L
s
% Start of user PostScript
-2.85714 0 -2.85714 -0.0550646 MAarrowhead1
% End of user PostScript
.14286 .57143 m
.13597 .55839 L
s
% Start of user PostScript
-2.85714 0.571429 -2.91221 0.467113 MAarrowhead1
% End of user PostScript
.14286 .64286 m
.12909 .62366 L
s
% Start of user PostScript
-2.85714 1.14286 -2.96727 0.98929 MAarrowhead1
% End of user PostScript
.14286 .71429 m
.12221 .68893 L
s
% Start of user PostScript
-2.85714 1.71429 -3.02234 1.51147 MAarrowhead1
% End of user PostScript
.14286 .78571 m
.11532 .75421 L
s
% Start of user PostScript
-2.85714 2.28571 -3.0774 2.03364 MAarrowhead1
% End of user PostScript
.14286 .85714 m
.10844 .81948 L
s
% Start of user PostScript
-2.85714 2.85714 -3.13247 2.55582 MAarrowhead1
% End of user PostScript
.14286 .92857 m
.10156 .88475 L
s
% Start of user PostScript
-2.85714 3.42857 -3.18753 3.078 MAarrowhead1
% End of user PostScript
.14286 1 m
.09468 .95002 L
s
% Start of user PostScript
-2.85714 4. -3.2426 3.60018 MAarrowhead1
% End of user PostScript
.21429 0 m
.26247 .03759 L
s
% Start of user PostScript
-2.28571 -4. -1.90026 -3.69929 MAarrowhead1
% End of user PostScript
.21429 .07143 m
.25558 .10286 L
s
% Start of user PostScript
-2.28571 -3.42857 -1.95533 -3.17712 MAarrowhead1
% End of user PostScript
.21429 .14286 m
.2487 .16813 L
s
% Start of user PostScript
-2.28571 -2.85714 -2.01039 -2.65494 MAarrowhead1
% End of user PostScript
.21429 .21429 m
.24182 .2334 L
s
% Start of user PostScript
-2.28571 -2.28571 -2.06546 -2.13276 MAarrowhead1
% End of user PostScript
.21429 .28571 m
.23493 .29868 L
s
% Start of user PostScript
-2.28571 -1.71429 -2.12052 -1.61058 MAarrowhead1
% End of user PostScript
.21429 .35714 m
.22805 .36395 L
s
% Start of user PostScript
-2.28571 -1.14286 -2.17559 -1.08841 MAarrowhead1
% End of user PostScript
.21429 .42857 m
.22117 .42922 L
s
% Start of user PostScript
-2.28571 -0.571429 -2.23065 -0.566229 MAarrowhead1
% End of user PostScript
.21429 .5 m
.21429 .49449 L
s
% Start of user PostScript
-2.28571 0 -2.28571 -0.0440517 MAarrowhead1
% End of user PostScript
.21429 .57143 m
.2074 .55977 L
s
% Start of user PostScript
-2.28571 0.571429 -2.34078 0.478126 MAarrowhead1
% End of user PostScript
.21429 .64286 m
.20052 .62504 L
s
% Start of user PostScript
-2.28571 1.14286 -2.39584 1.0003 MAarrowhead1
% End of user PostScript
.21429 .71429 m
.19364 .69031 L
s
% Start of user PostScript
-2.28571 1.71429 -2.45091 1.52248 MAarrowhead1
% End of user PostScript
.21429 .78571 m
.18675 .75558 L
s
% Start of user PostScript
-2.28571 2.28571 -2.50597 2.04466 MAarrowhead1
% End of user PostScript
.21429 .85714 m
.17987 .82085 L
s
% Start of user PostScript
-2.28571 2.85714 -2.56104 2.56683 MAarrowhead1
% End of user PostScript
.21429 .92857 m
.17299 .88613 L
s
% Start of user PostScript
-2.28571 3.42857 -2.6161 3.08901 MAarrowhead1
% End of user PostScript
.21429 1 m
.1661 .9514 L
s
% Start of user PostScript
-2.28571 4. -2.67117 3.61119 MAarrowhead1
% End of user PostScript
.28571 0 m
.3339 .03897 L
s
% Start of user PostScript
-1.71429 -4. -1.32883 -3.68828 MAarrowhead1
% End of user PostScript
.28571 .07143 m
.32701 .10424 L
s
% Start of user PostScript
-1.71429 -3.42857 -1.3839 -3.1661 MAarrowhead1
% End of user PostScript
.28571 .14286 m
.32013 .16951 L
s
% Start of user PostScript
-1.71429 -2.85714 -1.43896 -2.64393 MAarrowhead1
% End of user PostScript
.28571 .21429 m
.31325 .23478 L
s
% Start of user PostScript
-1.71429 -2.28571 -1.49403 -2.12175 MAarrowhead1
% End of user PostScript
.28571 .28571 m
.30636 .30005 L
s
% Start of user PostScript
-1.71429 -1.71429 -1.54909 -1.59957 MAarrowhead1
% End of user PostScript
.28571 .35714 m
.29948 .36533 L
s
% Start of user PostScript
-1.71429 -1.14286 -1.60416 -1.07739 MAarrowhead1
% End of user PostScript
.28571 .42857 m
.2926 .4306 L
s
% Start of user PostScript
-1.71429 -0.571429 -1.65922 -0.555216 MAarrowhead1
% End of user PostScript
.28571 .5 m
.28571 .49587 L
s
% Start of user PostScript
-1.71429 0 -1.71429 -0.0330388 MAarrowhead1
% End of user PostScript
.28571 .57143 m
.27883 .56114 L
s
% Start of user PostScript
-1.71429 0.571429 -1.76935 0.489138 MAarrowhead1
% End of user PostScript
.28571 .64286 m
.27195 .62641 L
s
% Start of user PostScript
-1.71429 1.14286 -1.82441 1.01132 MAarrowhead1
% End of user PostScript
.28571 .71429 m
.26507 .69169 L
s
% Start of user PostScript
-1.71429 1.71429 -1.87948 1.53349 MAarrowhead1
% End of user PostScript
.28571 .78571 m
.25818 .75696 L
s
% Start of user PostScript
-1.71429 2.28571 -1.93454 2.05567 MAarrowhead1
% End of user PostScript
.28571 .85714 m
.2513 .82223 L
s
% Start of user PostScript
-1.71429 2.85714 -1.98961 2.57785 MAarrowhead1
% End of user PostScript
.28571 .92857 m
.24442 .8875 L
s
% Start of user PostScript
-1.71429 3.42857 -2.04467 3.10002 MAarrowhead1
% End of user PostScript
.28571 1 m
.23753 .95278 L
s
% Start of user PostScript
-1.71429 4. -2.09974 3.6222 MAarrowhead1
% End of user PostScript
.35714 0 m
.40532 .04034 L
s
% Start of user PostScript
-1.14286 -4. -0.757405 -3.67727 MAarrowhead1
% End of user PostScript
.35714 .07143 m
.39844 .10561 L
s
% Start of user PostScript
-1.14286 -3.42857 -0.812469 -3.15509 MAarrowhead1
% End of user PostScript
.35714 .14286 m
.39156 .17089 L
s
% Start of user PostScript
-1.14286 -2.85714 -0.867534 -2.63291 MAarrowhead1
% End of user PostScript
.35714 .21429 m
.38468 .23616 L
s
% Start of user PostScript
-1.14286 -2.28571 -0.922599 -2.11073 MAarrowhead1
% End of user PostScript
.35714 .28571 m
.37779 .30143 L
s
% Start of user PostScript
-1.14286 -1.71429 -0.977663 -1.58856 MAarrowhead1
% End of user PostScript
.35714 .35714 m
.37091 .3667 L
s
% Start of user PostScript
-1.14286 -1.14286 -1.03273 -1.06638 MAarrowhead1
% End of user PostScript
.35714 .42857 m
.36403 .43197 L
s
% Start of user PostScript
-1.14286 -0.571429 -1.08779 -0.544203 MAarrowhead1
% End of user PostScript
.35714 .5 m
.35714 .49725 L
s
% Start of user PostScript
-1.14286 0 -1.14286 -0.0220259 MAarrowhead1
% End of user PostScript
.35714 .57143 m
.35026 .56252 L
s
% Start of user PostScript
-1.14286 0.571429 -1.19792 0.500151 MAarrowhead1
% End of user PostScript
.35714 .64286 m
.34338 .62779 L
s
% Start of user PostScript
-1.14286 1.14286 -1.25299 1.02233 MAarrowhead1
% End of user PostScript
.35714 .71429 m
.33649 .69306 L
s
% Start of user PostScript
-1.14286 1.71429 -1.30805 1.54451 MAarrowhead1
% End of user PostScript
.35714 .78571 m
.32961 .75834 L
s
% Start of user PostScript
-1.14286 2.28571 -1.36312 2.06668 MAarrowhead1
% End of user PostScript
.35714 .85714 m
.32273 .82361 L
s
% Start of user PostScript
-1.14286 2.85714 -1.41818 2.58886 MAarrowhead1
% End of user PostScript
.35714 .92857 m
.31584 .88888 L
s
% Start of user PostScript
-1.14286 3.42857 -1.47324 3.11104 MAarrowhead1
% End of user PostScript
.35714 1 m
.30896 .95415 L
s
% Start of user PostScript
-1.14286 4. -1.52831 3.63322 MAarrowhead1
% End of user PostScript
.42857 0 m
.47675 .04172 L
s
% Start of user PostScript
-0.571429 -4. -0.185976 -3.66625 MAarrowhead1
% End of user PostScript
.42857 .07143 m
.46987 .10699 L
s
% Start of user PostScript
-0.571429 -3.42857 -0.241041 -3.14408 MAarrowhead1
% End of user PostScript
.42857 .14286 m
.46299 .17226 L
s
% Start of user PostScript
-0.571429 -2.85714 -0.296105 -2.6219 MAarrowhead1
% End of user PostScript
.42857 .21429 m
.4561 .23753 L
s
% Start of user PostScript
-0.571429 -2.28571 -0.35117 -2.09972 MAarrowhead1
% End of user PostScript
.42857 .28571 m
.44922 .30281 L
s
% Start of user PostScript
-0.571429 -1.71429 -0.406235 -1.57754 MAarrowhead1
% End of user PostScript
.42857 .35714 m
.44234 .36808 L
s
% Start of user PostScript
-0.571429 -1.14286 -0.461299 -1.05537 MAarrowhead1
% End of user PostScript
.42857 .42857 m
.43545 .43335 L
s
% Start of user PostScript
-0.571429 -0.571429 -0.516364 -0.53319 MAarrowhead1
% End of user PostScript
.42857 .5 m
.42857 .49862 L
s
% Start of user PostScript
-0.571429 0 -0.571429 -0.0110129 MAarrowhead1
% End of user PostScript
.42857 .57143 m
.42169 .5639 L
s
% Start of user PostScript
-0.571429 0.571429 -0.626493 0.511164 MAarrowhead1
% End of user PostScript
.42857 .64286 m
.41481 .62917 L
s
% Start of user PostScript
-0.571429 1.14286 -0.681558 1.03334 MAarrowhead1
% End of user PostScript
.42857 .71429 m
.40792 .69444 L
s
% Start of user PostScript
-0.571429 1.71429 -0.736622 1.55552 MAarrowhead1
% End of user PostScript
.42857 .78571 m
.40104 .75971 L
s
% Start of user PostScript
-0.571429 2.28571 -0.791687 2.0777 MAarrowhead1
% End of user PostScript
.42857 .85714 m
.39416 .82498 L
s
% Start of user PostScript
-0.571429 2.85714 -0.846752 2.59987 MAarrowhead1
% End of user PostScript
.42857 .92857 m
.38727 .89026 L
s
% Start of user PostScript
-0.571429 3.42857 -0.901816 3.12205 MAarrowhead1
% End of user PostScript
.42857 1 m
.38039 .95553 L
s
% Start of user PostScript
-0.571429 4. -0.956881 3.64423 MAarrowhead1
% End of user PostScript
.5 0 m
.54818 .04309 L
s
% Start of user PostScript
0 -4. 0.385452 -3.65524 MAarrowhead1
% End of user PostScript
.5 .07143 m
.5413 .10837 L
s
% Start of user PostScript
0 -3.42857 0.330388 -3.13306 MAarrowhead1
% End of user PostScript
.5 .14286 m
.53442 .17364 L
s
% Start of user PostScript
0 -2.85714 0.275323 -2.61089 MAarrowhead1
% End of user PostScript
.5 .21429 m
.52753 .23891 L
s
% Start of user PostScript
0 -2.28571 0.220259 -2.08871 MAarrowhead1
% End of user PostScript
.5 .28571 m
.52065 .30418 L
s
% Start of user PostScript
0 -1.71429 0.165194 -1.56653 MAarrowhead1
% End of user PostScript
.5 .35714 m
.51377 .36946 L
s
% Start of user PostScript
0 -1.14286 0.110129 -1.04435 MAarrowhead1
% End of user PostScript
.5 .42857 m
.50688 .43473 L
s
% Start of user PostScript
0 -0.571429 0.0550646 -0.522177 MAarrowhead1
% End of user PostScript
.5 .5 m
.5 .5 L
s
% Start of user PostScript
0 0 MAarrowzero1
% End of user PostScript
.5 .57143 m
.49312 .56527 L
s
% Start of user PostScript
0 0.571429 -0.0550646 0.522177 MAarrowhead1
% End of user PostScript
.5 .64286 m
.48623 .63054 L
s
% Start of user PostScript
0 1.14286 -0.110129 1.04435 MAarrowhead1
% End of user PostScript
.5 .71429 m
.47935 .69582 L
s
% Start of user PostScript
0 1.71429 -0.165194 1.56653 MAarrowhead1
% End of user PostScript
.5 .78571 m
.47247 .76109 L
s
% Start of user PostScript
0 2.28571 -0.220259 2.08871 MAarrowhead1
% End of user PostScript
.5 .85714 m
.46558 .82636 L
s
% Start of user PostScript
0 2.85714 -0.275323 2.61089 MAarrowhead1
% End of user PostScript
.5 .92857 m
.4587 .89163 L
s
% Start of user PostScript
0 3.42857 -0.330388 3.13306 MAarrowhead1
% End of user PostScript
.5 1 m
.45182 .95691 L
s
% Start of user PostScript
0 4. -0.385452 3.65524 MAarrowhead1
% End of user PostScript
.57143 0 m
.61961 .04447 L
s
% Start of user PostScript
0.571429 -4. 0.956881 -3.64423 MAarrowhead1
% End of user PostScript
.57143 .07143 m
.61273 .10974 L
s
% Start of user PostScript
0.571429 -3.42857 0.901816 -3.12205 MAarrowhead1
% End of user PostScript
.57143 .14286 m
.60584 .17502 L
s
% Start of user PostScript
0.571429 -2.85714 0.846752 -2.59987 MAarrowhead1
% End of user PostScript
.57143 .21429 m
.59896 .24029 L
s
% Start of user PostScript
0.571429 -2.28571 0.791687 -2.0777 MAarrowhead1
% End of user PostScript
.57143 .28571 m
.59208 .30556 L
s
% Start of user PostScript
0.571429 -1.71429 0.736622 -1.55552 MAarrowhead1
% End of user PostScript
.57143 .35714 m
.58519 .37083 L
s
% Start of user PostScript
0.571429 -1.14286 0.681558 -1.03334 MAarrowhead1
% End of user PostScript
.57143 .42857 m
.57831 .4361 L
s
% Start of user PostScript
0.571429 -0.571429 0.626493 -0.511164 MAarrowhead1
% End of user PostScript
.57143 .5 m
.57143 .50138 L
s
% Start of user PostScript
0.571429 0 0.571429 0.0110129 MAarrowhead1
% End of user PostScript
.57143 .57143 m
.56455 .56665 L
s
% Start of user PostScript
0.571429 0.571429 0.516364 0.53319 MAarrowhead1
% End of user PostScript
.57143 .64286 m
.55766 .63192 L
s
% Start of user PostScript
0.571429 1.14286 0.461299 1.05537 MAarrowhead1
% End of user PostScript
.57143 .71429 m
.55078 .69719 L
s
% Start of user PostScript
0.571429 1.71429 0.406235 1.57754 MAarrowhead1
% End of user PostScript
.57143 .78571 m
.5439 .76247 L
s
% Start of user PostScript
0.571429 2.28571 0.35117 2.09972 MAarrowhead1
% End of user PostScript
.57143 .85714 m
.53701 .82774 L
s
% Start of user PostScript
0.571429 2.85714 0.296105 2.6219 MAarrowhead1
% End of user PostScript
.57143 .92857 m
.53013 .89301 L
s
% Start of user PostScript
0.571429 3.42857 0.241041 3.14408 MAarrowhead1
% End of user PostScript
.57143 1 m
.52325 .95828 L
s
% Start of user PostScript
0.571429 4. 0.185976 3.66625 MAarrowhead1
% End of user PostScript
.64286 0 m
.69104 .04585 L
s
% Start of user PostScript
1.14286 -4. 1.52831 -3.63322 MAarrowhead1
% End of user PostScript
.64286 .07143 m
.68416 .11112 L
s
% Start of user PostScript
1.14286 -3.42857 1.47324 -3.11104 MAarrowhead1
% End of user PostScript
.64286 .14286 m
.67727 .17639 L
s
% Start of user PostScript
1.14286 -2.85714 1.41818 -2.58886 MAarrowhead1
% End of user PostScript
.64286 .21429 m
.67039 .24166 L
s
% Start of user PostScript
1.14286 -2.28571 1.36312 -2.06668 MAarrowhead1
% End of user PostScript
.64286 .28571 m
.66351 .30694 L
s
% Start of user PostScript
1.14286 -1.71429 1.30805 -1.54451 MAarrowhead1
% End of user PostScript
.64286 .35714 m
.65662 .37221 L
s
% Start of user PostScript
1.14286 -1.14286 1.25299 -1.02233 MAarrowhead1
% End of user PostScript
.64286 .42857 m
.64974 .43748 L
s
% Start of user PostScript
1.14286 -0.571429 1.19792 -0.500151 MAarrowhead1
% End of user PostScript
.64286 .5 m
.64286 .50275 L
s
% Start of user PostScript
1.14286 0 1.14286 0.0220259 MAarrowhead1
% End of user PostScript
.64286 .57143 m
.63597 .56803 L
s
% Start of user PostScript
1.14286 0.571429 1.08779 0.544203 MAarrowhead1
% End of user PostScript
.64286 .64286 m
.62909 .6333 L
s
% Start of user PostScript
1.14286 1.14286 1.03273 1.06638 MAarrowhead1
% End of user PostScript
.64286 .71429 m
.62221 .69857 L
s
% Start of user PostScript
1.14286 1.71429 0.977663 1.58856 MAarrowhead1
% End of user PostScript
.64286 .78571 m
.61532 .76384 L
s
% Start of user PostScript
1.14286 2.28571 0.922599 2.11073 MAarrowhead1
% End of user PostScript
.64286 .85714 m
.60844 .82911 L
s
% Start of user PostScript
1.14286 2.85714 0.867534 2.63291 MAarrowhead1
% End of user PostScript
.64286 .92857 m
.60156 .89439 L
s
% Start of user PostScript
1.14286 3.42857 0.812469 3.15509 MAarrowhead1
% End of user PostScript
.64286 1 m
.59468 .95966 L
s
% Start of user PostScript
1.14286 4. 0.757405 3.67727 MAarrowhead1
% End of user PostScript
.71429 0 m
.76247 .04722 L
s
% Start of user PostScript
1.71429 -4. 2.09974 -3.6222 MAarrowhead1
% End of user PostScript
.71429 .07143 m
.75558 .1125 L
s
% Start of user PostScript
1.71429 -3.42857 2.04467 -3.10002 MAarrowhead1
% End of user PostScript
.71429 .14286 m
.7487 .17777 L
s
% Start of user PostScript
1.71429 -2.85714 1.98961 -2.57785 MAarrowhead1
% End of user PostScript
.71429 .21429 m
.74182 .24304 L
s
% Start of user PostScript
1.71429 -2.28571 1.93454 -2.05567 MAarrowhead1
% End of user PostScript
.71429 .28571 m
.73493 .30831 L
s
% Start of user PostScript
1.71429 -1.71429 1.87948 -1.53349 MAarrowhead1
% End of user PostScript
.71429 .35714 m
.72805 .37359 L
s
% Start of user PostScript
1.71429 -1.14286 1.82441 -1.01132 MAarrowhead1
% End of user PostScript
.71429 .42857 m
.72117 .43886 L
s
% Start of user PostScript
1.71429 -0.571429 1.76935 -0.489138 MAarrowhead1
% End of user PostScript
.71429 .5 m
.71429 .50413 L
s
% Start of user PostScript
1.71429 0 1.71429 0.0330388 MAarrowhead1
% End of user PostScript
.71429 .57143 m
.7074 .5694 L
s
% Start of user PostScript
1.71429 0.571429 1.65922 0.555216 MAarrowhead1
% End of user PostScript
.71429 .64286 m
.70052 .63467 L
s
% Start of user PostScript
1.71429 1.14286 1.60416 1.07739 MAarrowhead1
% End of user PostScript
.71429 .71429 m
.69364 .69995 L
s
% Start of user PostScript
1.71429 1.71429 1.54909 1.59957 MAarrowhead1
% End of user PostScript
.71429 .78571 m
.68675 .76522 L
s
% Start of user PostScript
1.71429 2.28571 1.49403 2.12175 MAarrowhead1
% End of user PostScript
.71429 .85714 m
.67987 .83049 L
s
% Start of user PostScript
1.71429 2.85714 1.43896 2.64393 MAarrowhead1
% End of user PostScript
.71429 .92857 m
.67299 .89576 L
s
% Start of user PostScript
1.71429 3.42857 1.3839 3.1661 MAarrowhead1
% End of user PostScript
.71429 1 m
.6661 .96103 L
s
% Start of user PostScript
1.71429 4. 1.32883 3.68828 MAarrowhead1
% End of user PostScript
.78571 0 m
.8339 .0486 L
s
% Start of user PostScript
2.28571 -4. 2.67117 -3.61119 MAarrowhead1
% End of user PostScript
.78571 .07143 m
.82701 .11387 L
s
% Start of user PostScript
2.28571 -3.42857 2.6161 -3.08901 MAarrowhead1
% End of user PostScript
.78571 .14286 m
.82013 .17915 L
s
% Start of user PostScript
2.28571 -2.85714 2.56104 -2.56683 MAarrowhead1
% End of user PostScript
.78571 .21429 m
.81325 .24442 L
s
% Start of user PostScript
2.28571 -2.28571 2.50597 -2.04466 MAarrowhead1
% End of user PostScript
.78571 .28571 m
.80636 .30969 L
s
% Start of user PostScript
2.28571 -1.71429 2.45091 -1.52248 MAarrowhead1
% End of user PostScript
.78571 .35714 m
.79948 .37496 L
s
% Start of user PostScript
2.28571 -1.14286 2.39584 -1.0003 MAarrowhead1
% End of user PostScript
.78571 .42857 m
.7926 .44023 L
s
% Start of user PostScript
2.28571 -0.571429 2.34078 -0.478126 MAarrowhead1
% End of user PostScript
.78571 .5 m
.78571 .50551 L
s
% Start of user PostScript
2.28571 0 2.28571 0.0440517 MAarrowhead1
% End of user PostScript
.78571 .57143 m
.77883 .57078 L
s
% Start of user PostScript
2.28571 0.571429 2.23065 0.566229 MAarrowhead1
% End of user PostScript
.78571 .64286 m
.77195 .63605 L
s
% Start of user PostScript
2.28571 1.14286 2.17559 1.08841 MAarrowhead1
% End of user PostScript
.78571 .71429 m
.76507 .70132 L
s
% Start of user PostScript
2.28571 1.71429 2.12052 1.61058 MAarrowhead1
% End of user PostScript
.78571 .78571 m
.75818 .7666 L
s
% Start of user PostScript
2.28571 2.28571 2.06546 2.13276 MAarrowhead1
% End of user PostScript
.78571 .85714 m
.7513 .83187 L
s
% Start of user PostScript
2.28571 2.85714 2.01039 2.65494 MAarrowhead1
% End of user PostScript
.78571 .92857 m
.74442 .89714 L
s
% Start of user PostScript
2.28571 3.42857 1.95533 3.17712 MAarrowhead1
% End of user PostScript
.78571 1 m
.73753 .96241 L
s
% Start of user PostScript
2.28571 4. 1.90026 3.69929 MAarrowhead1
% End of user PostScript
.85714 0 m
.90532 .04998 L
s
% Start of user PostScript
2.85714 -4. 3.2426 -3.60018 MAarrowhead1
% End of user PostScript
.85714 .07143 m
.89844 .11525 L
s
% Start of user PostScript
2.85714 -3.42857 3.18753 -3.078 MAarrowhead1
% End of user PostScript
.85714 .14286 m
.89156 .18052 L
s
% Start of user PostScript
2.85714 -2.85714 3.13247 -2.55582 MAarrowhead1
% End of user PostScript
.85714 .21429 m
.88468 .24579 L
s
% Start of user PostScript
2.85714 -2.28571 3.0774 -2.03364 MAarrowhead1
% End of user PostScript
.85714 .28571 m
.87779 .31107 L
s
% Start of user PostScript
2.85714 -1.71429 3.02234 -1.51147 MAarrowhead1
% End of user PostScript
.85714 .35714 m
.87091 .37634 L
s
% Start of user PostScript
2.85714 -1.14286 2.96727 -0.98929 MAarrowhead1
% End of user PostScript
.85714 .42857 m
.86403 .44161 L
s
% Start of user PostScript
2.85714 -0.571429 2.91221 -0.467113 MAarrowhead1
% End of user PostScript
.85714 .5 m
.85714 .50688 L
s
% Start of user PostScript
2.85714 0 2.85714 0.0550646 MAarrowhead1
% End of user PostScript
.85714 .57143 m
.85026 .57216 L
s
% Start of user PostScript
2.85714 0.571429 2.80208 0.577242 MAarrowhead1
% End of user PostScript
.85714 .64286 m
.84338 .63743 L
s
% Start of user PostScript
2.85714 1.14286 2.74701 1.09942 MAarrowhead1
% End of user PostScript
.85714 .71429 m
.83649 .7027 L
s
% Start of user PostScript
2.85714 1.71429 2.69195 1.6216 MAarrowhead1
% End of user PostScript
.85714 .78571 m
.82961 .76797 L
s
% Start of user PostScript
2.85714 2.28571 2.63688 2.14377 MAarrowhead1
% End of user PostScript
.85714 .85714 m
.82273 .83324 L
s
% Start of user PostScript
2.85714 2.85714 2.58182 2.66595 MAarrowhead1
% End of user PostScript
.85714 .92857 m
.81584 .89852 L
s
% Start of user PostScript
2.85714 3.42857 2.52676 3.18813 MAarrowhead1
% End of user PostScript
.85714 1 m
.80896 .96379 L
s
% Start of user PostScript
2.85714 4. 2.47169 3.71031 MAarrowhead1
% End of user PostScript
.92857 0 m
.97675 .05135 L
s
% Start of user PostScript
3.42857 -4. 3.81402 -3.58916 MAarrowhead1
% End of user PostScript
.92857 .07143 m
.96987 .11663 L
s
% Start of user PostScript
3.42857 -3.42857 3.75896 -3.06699 MAarrowhead1
% End of user PostScript
.92857 .14286 m
.96299 .1819 L
s
% Start of user PostScript
3.42857 -2.85714 3.70389 -2.54481 MAarrowhead1
% End of user PostScript
.92857 .21429 m
.9561 .24717 L
s
% Start of user PostScript
3.42857 -2.28571 3.64883 -2.02263 MAarrowhead1
% End of user PostScript
.92857 .28571 m
.94922 .31244 L
s
% Start of user PostScript
3.42857 -1.71429 3.59377 -1.50045 MAarrowhead1
% End of user PostScript
.92857 .35714 m
.94234 .37772 L
s
% Start of user PostScript
3.42857 -1.14286 3.5387 -0.978277 MAarrowhead1
% End of user PostScript
.92857 .42857 m
.93545 .44299 L
s
% Start of user PostScript
3.42857 -0.571429 3.48364 -0.4561 MAarrowhead1
% End of user PostScript
.92857 .5 m
.92857 .50826 L
s
% Start of user PostScript
3.42857 0 3.42857 0.0660776 MAarrowhead1
% End of user PostScript
.92857 .57143 m
.92169 .57353 L
s
% Start of user PostScript
3.42857 0.571429 3.37351 0.588255 MAarrowhead1
% End of user PostScript
.92857 .64286 m
.91481 .6388 L
s
% Start of user PostScript
3.42857 1.14286 3.31844 1.11043 MAarrowhead1
% End of user PostScript
.92857 .71429 m
.90792 .70408 L
s
% Start of user PostScript
3.42857 1.71429 3.26338 1.63261 MAarrowhead1
% End of user PostScript
.92857 .78571 m
.90104 .76935 L
s
% Start of user PostScript
3.42857 2.28571 3.20831 2.15479 MAarrowhead1
% End of user PostScript
.92857 .85714 m
.89416 .83462 L
s
% Start of user PostScript
3.42857 2.85714 3.15325 2.67696 MAarrowhead1
% End of user PostScript
.92857 .92857 m
.88727 .89989 L
s
% Start of user PostScript
3.42857 3.42857 3.09818 3.19914 MAarrowhead1
% End of user PostScript
.92857 1 m
.88039 .96516 L
s
% Start of user PostScript
3.42857 4. 3.04312 3.72132 MAarrowhead1
% End of user PostScript
1 0 m
0 0 rlineto s
% Start of user PostScript
4. -4. 4.38545 -3.57815 MAarrowhead1
% End of user PostScript
1 .07143 m
0 0 rlineto s
1 .07143 m
1 .07143 L
s
% Start of user PostScript
4. -3.42857 4.33039 -3.05597 MAarrowhead1
% End of user PostScript
1 .14286 m
0 0 rlineto s
1 .14286 m
1 .14286 L
s
% Start of user PostScript
4. -2.85714 4.27532 -2.5338 MAarrowhead1
% End of user PostScript
1 .21429 m
0 0 rlineto s
1 .21429 m
1 .21429 L
s
% Start of user PostScript
4. -2.28571 4.22026 -2.01162 MAarrowhead1
% End of user PostScript
1 .28571 m
0 0 rlineto s
1 .28571 m
1 .28571 L
s
% Start of user PostScript
4. -1.71429 4.16519 -1.48944 MAarrowhead1
% End of user PostScript
1 .35714 m
0 0 rlineto s
1 .35714 m
1 .35714 L
s
% Start of user PostScript
4. -1.14286 4.11013 -0.967264 MAarrowhead1
% End of user PostScript
1 .42857 m
0 0 rlineto s
1 .42857 m
1 .42857 L
s
% Start of user PostScript
4. -0.571429 4.05506 -0.445087 MAarrowhead1
% End of user PostScript
1 .5 m
1 .50964 L
s
% Start of user PostScript
4. 0 4. 0.0770905 MAarrowhead1
% End of user PostScript
1 .57143 m
.99312 .57491 L
s
% Start of user PostScript
4. 0.571429 3.94494 0.599268 MAarrowhead1
% End of user PostScript
1 .64286 m
.98623 .64018 L
s
% Start of user PostScript
4. 1.14286 3.88987 1.12145 MAarrowhead1
% End of user PostScript
1 .71429 m
.97935 .70545 L
s
% Start of user PostScript
4. 1.71429 3.83481 1.64362 MAarrowhead1
% End of user PostScript
1 .78571 m
.97247 .77072 L
s
% Start of user PostScript
4. 2.28571 3.77974 2.1658 MAarrowhead1
% End of user PostScript
1 .85714 m
.96558 .836 L
s
% Start of user PostScript
4. 2.85714 3.72468 2.68798 MAarrowhead1
% End of user PostScript
1 .92857 m
.9587 .90127 L
s
% Start of user PostScript
4. 3.42857 3.66961 3.21015 MAarrowhead1
% End of user PostScript
1 1 m
.95182 .96654 L
s
% Start of user PostScript
4. 4. 3.61455 3.73233 MAarrowhead1
% End of user PostScript
% End of Graphics
MathPictureEnd
\
\>"], "Input",
 ImageSize->{288, 288},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
 ImageRangeCache->{{{99.875, 386.875}, {591.875, 304.875}} -> {-7.4316, \
5.45193, 0.0324114, 0.0324114}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Show", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"p6", ",", "p4"}], "}"}], ",", 
    RowBox[{"Axes", "\[Rule]", "Automatic"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "4"}], ",", "4"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<x[t]\>\"", ",", "\"\<y[t]\>\""}], "}"}]}], ",", 
    RowBox[{"AspectRatio", "\[Rule]", "Automatic"}]}], "]"}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Show", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"p6", ",", "p5", ",", "p4"}], "}"}], ",", 
    RowBox[{"Axes", "\[Rule]", "Automatic"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "4"}], ",", "4"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<x[t]\>\"", ",", "\"\<y[t]\>\""}], "}"}]}], ",", 
    RowBox[{"AspectRatio", "\[Rule]", "Automatic"}]}], "]"}], ";"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["describe the system,using appropriate vocabulary.", "Subsubsection"],

Cell[TextData[{
 "Consider the system z'=",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"0", ",", 
      RowBox[{"-", "5"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"1", ",", 
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       SqrtBox["5"]}]}], "}"}]}], "}"}]]],
 "z.\nThe origin is a stable improper node.\n\nFrom the eigenvalue alone:  \
Since the eigenvalue is real and repeated and did not yield a full set of \
linearly independent eigenvectors, the origin is an improper node.  Since the \
eigenvalue is negative, the node is stable.\n\nFurthermore, the {t,x[t]} and \
{t,y[t]} graphs tend to zero, indicating that as time progresses, the x and y \
components of the x-y graph approach the origin, yielding stability.  In \
addition, the direction field indicates that the trajectories rotate \
counterclockwise toward the origin, again yielding stability."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["THE fundamental matrix", "Subsubsection"],

Cell["\<\
Take any fundamental matrix \[CapitalPsi][t] and compute \
\[CapitalPsi][t].Inverse[\[CapitalPsi][0]]:\
\>", "Text",
 FontFamily->"Courier"],

Cell[BoxData[
 RowBox[{"\[CapitalPsi]", "[", "0", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Inverse", "[", "  ", 
  RowBox[{"\[CapitalPsi]", "[", "0", "]"}], "  ", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[CapitalPsi]", "[", "t", "]"}], " ", ".", " ", 
  RowBox[{"Inverse", "[", "  ", 
   RowBox[{"\[CapitalPsi]", "[", "0", "]"}], "  ", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"MatrixForm", "[", "%", "]"}]], "Input"],

Cell[BoxData[{
 RowBox[{"Clear", "[", "\[CapitalPhi]", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[CapitalPhi]", "[", "t_", "]"}], ":=", 
  TagBox[
   RowBox[{"(", "\[NoBreak]", GridBox[{
      {
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "5"}], "-", 
             RowBox[{"2", " ", 
              SqrtBox["5"]}]}], ")"}], " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"5", "-", 
               RowBox[{"2", " ", 
                SqrtBox["5"]}]}], ")"}], " ", "t"}]]}], 
          RowBox[{"4", " ", 
           SqrtBox["5"]}]]}], "+", 
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "5"}], "+", 
            RowBox[{"2", " ", 
             SqrtBox["5"]}]}], ")"}], " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"5", "+", 
              RowBox[{"2", " ", 
               SqrtBox["5"]}]}], ")"}], " ", "t"}]]}], 
         RowBox[{"4", " ", 
          SqrtBox["5"]}]]}], 
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "5"}], "-", 
             RowBox[{"2", " ", 
              SqrtBox["5"]}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"5", "-", 
             RowBox[{"2", " ", 
              SqrtBox["5"]}]}], ")"}], " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"5", "-", 
               RowBox[{"2", " ", 
                SqrtBox["5"]}]}], ")"}], " ", "t"}]]}], 
          RowBox[{"4", " ", 
           SqrtBox["5"]}]]}], "-", 
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "5"}], "-", 
            RowBox[{"2", " ", 
             SqrtBox["5"]}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "5"}], "+", 
            RowBox[{"2", " ", 
             SqrtBox["5"]}]}], ")"}], " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"5", "+", 
              RowBox[{"2", " ", 
               SqrtBox["5"]}]}], ")"}], " ", "t"}]]}], 
         RowBox[{"4", " ", 
          SqrtBox["5"]}]]}]},
      {
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"5", "-", 
              RowBox[{"2", " ", 
               SqrtBox["5"]}]}], ")"}], " ", "t"}]], 
          RowBox[{"4", " ", 
           SqrtBox["5"]}]]}], "+", 
        FractionBox[
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"5", "+", 
             RowBox[{"2", " ", 
              SqrtBox["5"]}]}], ")"}], " ", "t"}]], 
         RowBox[{"4", " ", 
          SqrtBox["5"]}]]}], 
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{"5", "-", 
             RowBox[{"2", " ", 
              SqrtBox["5"]}]}], ")"}], " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"5", "-", 
               RowBox[{"2", " ", 
                SqrtBox["5"]}]}], ")"}], " ", "t"}]]}], 
          RowBox[{"4", " ", 
           SqrtBox["5"]}]]}], "-", 
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "5"}], "-", 
            RowBox[{"2", " ", 
             SqrtBox["5"]}]}], ")"}], " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"5", "+", 
              RowBox[{"2", " ", 
               SqrtBox["5"]}]}], ")"}], " ", "t"}]]}], 
         RowBox[{"4", " ", 
          SqrtBox["5"]}]]}]}
     }], "\[NoBreak]", ")"}],
   MatrixForm[#]& ]}]}], "Input"],

Cell["Check the properties of THE fundamental matrix:", "Text",
 FontFamily->"Courier"],

Cell["Its columns are linearly independent:", "Text",
 FontFamily->"Courier"],

Cell[BoxData[
 RowBox[{"Det", "[", 
  RowBox[{"\[CapitalPhi]", "[", "t", "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Simplify", "[", "%", "]"}]], "Input"],

Cell["THE fundamental matrix also solves the DE:", "Text",
 FontFamily->"Courier"],

Cell[BoxData[
 RowBox[{"D", "[", 
  RowBox[{
   RowBox[{"\[CapitalPhi]", "[", "t", "]"}], ",", "t"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Expand", "[", "%", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"A", "[", "\[Alpha]", "]"}], ".", 
  RowBox[{"\[CapitalPhi]", "[", "t", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"Expand", "[", "%", "]"}]], "Input"],

Cell["too hard on my eyes!", "Text"],

Cell[BoxData[
 RowBox[{"Expand", "[", "  ", 
  RowBox[{
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{"\[CapitalPhi]", "[", "t", "]"}], ",", "t"}], "]"}], " ", "-", 
   " ", 
   RowBox[{
    RowBox[{"A", "[", "\[Alpha]", "]"}], ".", 
    RowBox[{"\[CapitalPhi]", "[", "t", "]"}]}]}], "  ", "]"}]], "Input"],

Cell["At t0=0, it is the identity matrix:", "Text",
 FontFamily->"Courier"],

Cell[BoxData[
 RowBox[{"\[CapitalPhi]", "[", "0", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Expand", "[", "%", "]"}]], "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["complex roots", "Section",
 CellFrame->{{0, 0}, {0, 2}}],

Cell[TextData[{
 "\n",
 StyleBox["case (3) ",
  FontFamily->"Courier"],
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"-", "20"}], "+", 
    SuperscriptBox["\[Alpha]", "2"]}], "<", "0"}]]],
 StyleBox[".\n  ",
  FontFamily->"Courier"],
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"-", "2"}], 
    SqrtBox["5"]}], " ", "<", " ", "\[Alpha]", " ", "<", " ", 
   RowBox[{"2", " ", 
    SqrtBox["5"]}]}]]],
 StyleBox[".\n  Note that the eigenvalues are r1 = \[Lambda] + \[ImaginaryI] \
\[Mu] and  r2 = \[Lambda] - \[ImaginaryI] \[Mu] where \[Lambda]=",
  FontFamily->"Courier"],
 Cell[BoxData[
  FractionBox["\[Alpha]", "2"]]],
 " and \[Mu]=",
 Cell[BoxData[
  FractionBox[
   SqrtBox[
    RowBox[{"20", "-", 
     SuperscriptBox["\[Alpha]", "2"]}]], "2"]]],
 StyleBox["\n  \n  Really 3 cases.\ncase (3n) ",
  FontFamily->"Courier"],
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"-", "2"}], 
    SqrtBox["5"]}], " ", "<", " ", "\[Alpha]", " ", "<", " ", "0"}]]],
 StyleBox[" \ncase (3z)  \[Alpha] = 0\ncase (3p)  ",
  FontFamily->"Courier"],
 Cell[BoxData[
  RowBox[{"0", " ", "<", " ", "\[Alpha]", " ", "<", " ", 
   RowBox[{"2", " ", 
    SqrtBox["5"]}]}]]]
}], "Text"],

Cell[TextData[{
 StyleBox["case (3n) ",
  FontFamily->"Courier"],
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"-", "2"}], 
    SqrtBox["5"]}], " ", "<", " ", "\[Alpha]", " ", "<", " ", "0"}]]],
 StyleBox[" \n  Complex solutions with a real part result in spirals.  Since \
the real part of the eigenvalues are negative, the origin is a stable spiral.\
\n",
  FontFamily->"Courier"]
}], "Text"],

Cell[TextData[StyleBox["case (3z)  \[Alpha] = 0\n  Since the eigenvalues are \
purely imaginary, there is no exponential damping or growth in the solutions, \
so the solutions oscillate with constant amplitute.  This makes the origin a \
center in the x-y plane.\n",
 FontFamily->"Courier"]], "Text"],

Cell[TextData[{
 StyleBox["case (3p)  ",
  FontFamily->"Courier"],
 Cell[BoxData[
  RowBox[{"0", " ", "<", " ", "\[Alpha]", " ", "<", " ", 
   RowBox[{"2", " ", 
    SqrtBox["5"]}]}]]],
 "\n",
 "  ",
 StyleBox["Complex solutions with a real part result in spirals.  Since the \
real part of the eigenvalues are positive, the origin is an unstable spiral.",
  
  FontFamily->"Courier"]
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
 "Example:  ",
 Cell[BoxData[
  RowBox[{"\[Alpha]", "=", "0"}]],
  TextAlignment->Left],
 " gory detail"
}], "Subsection",
 CellFrame->{{0, 0}, {0, 0.5}}],

Cell[CellGroupData[{

Cell["solution from the eigenmethod", "Subsubsection"],

Cell[BoxData[{
 RowBox[{"Clear", "[", "\[Alpha]", "]"}], "\n", 
 RowBox[{"\[Alpha]", "=", "0"}], "\n", 
 RowBox[{"A", "[", "\[Alpha]", "]"}]}], "Input"],

Cell[BoxData[
 RowBox[{"Eigensystem", "[", 
  RowBox[{"A", "[", "\[Alpha]", "]"}], "]"}]], "Input"],

Cell["\<\
Peel off the real and imaginary parts of the eigenvalues and of the \
eigenvectors.  

(Remember to include the algebraic sign with the real parts but not with the \
imaginary parts.  This is because we have conjugates.)\
\>", "Text"],

Cell[BoxData[
 RowBox[{"Re", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", 
       SqrtBox["5"]}], ",", 
      RowBox[{"\[ImaginaryI]", " ", 
       SqrtBox["5"]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", 
         SqrtBox["5"]}], ",", "1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"\[ImaginaryI]", " ", 
         SqrtBox["5"]}], ",", "1"}], "}"}]}], "}"}]}], "}"}], "]"}]], "Input"],

Cell["\<\
The above format is {{RealPartEval,RealPartEval},{RealPartEvec,RealPartEvec}}\
\
\>", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"RealPartEval", "=", "0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"RealPartEvec", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"0", ",", "1"}], "}"}]}], ";"}]}], "Input"],

Cell[BoxData[
 RowBox[{"Im", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", 
       SqrtBox["5"]}], ",", 
      RowBox[{"\[ImaginaryI]", " ", 
       SqrtBox["5"]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", 
         SqrtBox["5"]}], ",", "1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"\[ImaginaryI]", " ", 
         SqrtBox["5"]}], ",", "1"}], "}"}]}], "}"}]}], "}"}], "]"}]], "Input"],

Cell["\<\
The above format is \
{{-ImagPartEval,ImagPartEval},{-ImagPartEvec,ImagPartEvec}}.\
\>", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"ImagPartEval", " ", "=", 
   SqrtBox["5"]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ImagPartEvec", " ", "=", 
   RowBox[{"{", 
    RowBox[{
     SqrtBox["5"], ",", "0"}], "}"}]}], ";"}]}], "Input"],

Cell["State the real-valued solutions.", "Text"],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{"RealPartEval", " ", "*", " ", "t"}]], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"RealPartEvec", " ", "*", 
     RowBox[{"Cos", "[", 
      RowBox[{"ImagPartEval", " ", "*", " ", "t"}], "]"}]}], " ", "-", 
    "\[IndentingNewLine]", 
    RowBox[{"ImagPartEvec", " ", "*", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"ImagPartEval", " ", "*", " ", "t"}], "]"}]}]}], 
   ")"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{"RealPartEval", " ", "*", " ", "t"}]], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"RealPartEvec", " ", "*", 
     RowBox[{"Sin", "[", 
      RowBox[{"ImagPartEval", " ", "*", " ", "t"}], "]"}]}], " ", "+", 
    "\[IndentingNewLine]", 
    RowBox[{"ImagPartEvec", " ", "*", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"ImagPartEval", " ", "*", " ", "t"}], "]"}]}]}], 
   ")"}]}]], "Input"],

Cell["State the general solution.", "Text"],

Cell[BoxData[
 RowBox[{"Expand", "[", 
  RowBox[{
   RowBox[{"c1", " ", "*", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        SqrtBox["5"]}], " ", 
       RowBox[{"Sin", "[", 
        RowBox[{
         SqrtBox["5"], " ", "t"}], "]"}]}], ",", 
      RowBox[{"Cos", "[", 
       RowBox[{
        SqrtBox["5"], " ", "t"}], "]"}]}], "}"}]}], "\[IndentingNewLine]", 
   "+", " ", 
   RowBox[{"c2", " ", "*", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SqrtBox["5"], " ", 
       RowBox[{"Cos", "[", 
        RowBox[{
         SqrtBox["5"], " ", "t"}], "]"}]}], ",", 
      RowBox[{"Sin", "[", 
       RowBox[{
        SqrtBox["5"], " ", "t"}], "]"}]}], "}"}]}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Above", " ", "are", " ", "two", " ", "linearly", " ", "independent",
   " ", "solutions", " ", "to", " ", "the", " ", "DE", " ", "from", " ", 
  "this", " ", 
  RowBox[{"method", " ", "."}]}]], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["a fundamental matrix", "Subsubsection"],

Cell[BoxData[
 RowBox[{"MatrixForm", "[", 
  RowBox[{"Transpose", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SqrtBox["5"]}], " ", 
        RowBox[{"Sin", "[", 
         RowBox[{
          SqrtBox["5"], " ", "t"}], "]"}]}], ",", 
       RowBox[{"Cos", "[", 
        RowBox[{
         SqrtBox["5"], " ", "t"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SqrtBox["5"], " ", 
        RowBox[{"Cos", "[", 
         RowBox[{
          SqrtBox["5"], " ", "t"}], "]"}]}], ",", 
       RowBox[{"Sin", "[", 
        RowBox[{
         SqrtBox["5"], " ", "t"}], "]"}]}], "}"}]}], "}"}], "]"}], 
  "]"}]], "Input"],

Cell[BoxData[{
 RowBox[{"Clear", "[", "\[CapitalPsi]", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[CapitalPsi]", "[", "t_", "]"}], ":=", 
  TagBox[
   RowBox[{"(", "\[NoBreak]", GridBox[{
      {
       RowBox[{
        RowBox[{"-", 
         SqrtBox["5"]}], " ", 
        RowBox[{"Sin", "[", 
         RowBox[{
          SqrtBox["5"], " ", "t"}], "]"}]}], 
       RowBox[{
        SqrtBox["5"], " ", 
        RowBox[{"Cos", "[", 
         RowBox[{
          SqrtBox["5"], " ", "t"}], "]"}]}]},
      {
       RowBox[{"Cos", "[", 
        RowBox[{
         SqrtBox["5"], " ", "t"}], "]"}], 
       RowBox[{"Sin", "[", 
        RowBox[{
         SqrtBox["5"], " ", "t"}], "]"}]}
     }], "\[NoBreak]", ")"}],
   Function[BoxForm`e$, 
    MatrixForm[BoxForm`e$]]]}]}], "Input"],

Cell[BoxData[
 RowBox[{"Det", "[", 
  RowBox[{"\[CapitalPsi]", "[", "t", "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"TrigExpand", "[", "%", "]"}]], "Input"],

Cell["Note that a fundamental matrix also solves the DE.", "Text",
 FontFamily->"Courier"],

Cell[BoxData[
 RowBox[{"D", "[", 
  RowBox[{
   RowBox[{"\[CapitalPsi]", "[", "t", "]"}], ",", "t"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"A", "[", "\[Alpha]", "]"}], ".", 
  RowBox[{"\[CapitalPsi]", "[", "t", "]"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["general solution, behavior", "Subsubsection"],

Cell[BoxData[
 RowBox[{"The", " ", "general", " ", "solution", " ", "is", "     ", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       SqrtBox["5"], " ", "c2", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{
         SqrtBox["5"], " ", "t"}], "]"}]}], "-", 
      RowBox[{
       SqrtBox["5"], " ", "c1", " ", 
       RowBox[{"Sin", "[", 
        RowBox[{
         SqrtBox["5"], " ", "t"}], "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"c1", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{
         SqrtBox["5"], " ", "t"}], "]"}]}], "+", 
      RowBox[{"c2", " ", 
       RowBox[{"Sin", "[", 
        RowBox[{
         SqrtBox["5"], " ", "t"}], "]"}]}]}]}], "}"}], " ", "."}]}]], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Note", " ", "that", " ", "for", " ", "these", " ", "solutions"}], 
   ",", " ", 
   RowBox[{
   "for", " ", "each", "  ", "pair", "  ", "c1", " ", "and", " ", "c2"}], ",",
    "  ", 
   RowBox[{"oscillate", " ", "with", " ", "constant", " ", 
    RowBox[{"amplitude", ".", "  ", "Thus"}]}], ",", 
   RowBox[{
   "the", " ", "origin", " ", "is", " ", "a", " ", "stable", " ", "center", 
    " ", "for", " ", "this", " ", "value", " ", "of", " ", 
    RowBox[{"\[Alpha]", ".", "\[IndentingNewLine]"}]}]}]}]], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Plot", "[", " ", 
   RowBox[{
    RowBox[{
     SqrtBox["5"], " ", 
     RowBox[{"Cos", "[", 
      RowBox[{
       SqrtBox["5"], " ", "t"}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "20"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"t", ",", "\"\<\>\""}], "}"}]}], ",", 
    RowBox[{"PlotLabel", "\[Rule]", "\"\<component of x[t] or y[t]\>\""}]}], 
   "]"}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Plot", "[", " ", 
   RowBox[{
    RowBox[{"Sin", "[", 
     RowBox[{
      SqrtBox["5"], " ", "t"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "20"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"t", ",", "\"\<\>\""}], "}"}]}], ",", 
    RowBox[{"PlotLabel", "\[Rule]", "\"\<component of x[t] or y[t]\>\""}]}], 
   "]"}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{
      SqrtBox["5"], " ", "c2", " ", 
      RowBox[{"Cos", "[", 
       RowBox[{
        SqrtBox["5"], " ", "t"}], "]"}]}], "-", 
     RowBox[{
      SqrtBox["5"], " ", "c1", " ", 
      RowBox[{"Sin", "[", 
       RowBox[{
        SqrtBox["5"], " ", "t"}], "]"}]}]}], ",", 
    RowBox[{
     RowBox[{"c1", " ", 
      RowBox[{"Cos", "[", 
       RowBox[{
        SqrtBox["5"], " ", "t"}], "]"}]}], "+", 
     RowBox[{"c2", " ", 
      RowBox[{"Sin", "[", 
       RowBox[{
        SqrtBox["5"], " ", "t"}], "]"}]}]}]}], "}"}], "/.", 
  RowBox[{"{", " ", 
   RowBox[{
    RowBox[{"c1", "\[Rule]", "1"}], ",", " ", 
    RowBox[{"c2", "\[Rule]", "1"}]}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"%", "/.", 
  RowBox[{"t", "\[Rule]", "0"}]}]], "Input"],

Cell[TextData[{
 "The trajectory begins at (",
 Cell[BoxData[
  RowBox[{
   SqrtBox["5"], ",", "1"}]]],
 ")."
}], "Text"],

Cell["Here's the phase plane for one trajectory.", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ParametricPlot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{
        SqrtBox["5"], " ", 
        RowBox[{"Cos", "[", 
         RowBox[{
          SqrtBox["5"], " ", "t"}], "]"}]}], "-", 
       RowBox[{
        SqrtBox["5"], " ", 
        RowBox[{"Sin", "[", 
         RowBox[{
          SqrtBox["5"], " ", "t"}], "]"}]}]}], ",", 
      RowBox[{
       RowBox[{"Cos", "[", 
        RowBox[{
         SqrtBox["5"], " ", "t"}], "]"}], "+", 
       RowBox[{"Sin", "[", 
        RowBox[{
         SqrtBox["5"], " ", "t"}], "]"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "10"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<x[t]\>\"", ",", "\"\<y[t]\>\""}], "}"}]}]}], "]"}], 
  ";"}]], "Input"],

Cell["This trajectory orbits the origin in an ellipse.", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"fcnlist", "=", 
   RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{"AppendTo", "[", 
    RowBox[{"fcnlist", ",", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         SqrtBox["5"], " ", "c2", "  ", 
         RowBox[{"Cos", "[", 
          RowBox[{
           SqrtBox["5"], " ", "t"}], "]"}]}], "-", 
        RowBox[{
         SqrtBox["5"], " ", "c1", " ", 
         RowBox[{"Sin", "[", 
          RowBox[{
           SqrtBox["5"], " ", "t"}], "]"}]}]}], ",", 
       RowBox[{
        RowBox[{"c1", "  ", 
         RowBox[{"Cos", "[", 
          RowBox[{
           SqrtBox["5"], " ", "t"}], "]"}]}], "+", 
        RowBox[{"c2", " ", 
         RowBox[{"Sin", "[", 
          RowBox[{
           SqrtBox["5"], " ", "t"}], "]"}]}]}]}], "}"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"c1", ",", 
     RowBox[{"-", "2"}], ",", "2", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"c2", ",", 
     RowBox[{"-", "3"}], ",", "3", ",", "3"}], "}"}]}], 
  "]"}], "\[IndentingNewLine]", "fcnlist"}], "Input"],

Cell["\<\
phase plane for several trajectories.  Look for the lines generated by the \
eigenvectors.\
\>", "Text"],

Cell[BoxData[{
 RowBox[{"Clear", "[", "p5", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"p5", "=", 
   RowBox[{"ParametricPlot", "[", 
    RowBox[{
     RowBox[{"Evaluate", "[", "fcnlist", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "10"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x[t]\>\"", ",", "\"\<y[t]\>\""}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "12"}], ",", "12"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "5"}], ",", "5"}], "}"}]}], "}"}]}]}], "]"}]}], 
  ";"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["direction field", "Subsubsection"],

Cell[TextData[{
 "Load the Graphics`PlotField` package BEFORE trying to generate the \
direction field.Load the package once per ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " session.If you change anything,generate the direction field again."
}], "Text"],

Cell[BoxData[
 RowBox[{"<<", "Graphics`PlotField`"}]], "Input",
 ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Remember that we obtain the coordinates of the direction field from \
{x'[t],y'[t]},which is given by the matrix product A.{x[t],y[t]}.To avoid \
confusing the {x,y} used here with ones plotted elsewhere,we'll call these \
{x1,y1}.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"A", "[", "\[Alpha]", "]"}], ".", 
  RowBox[{"{", 
   RowBox[{"x1", ",", "y1"}], "}"}]}]], "Input"],

Cell[BoxData[{
 RowBox[{"Clear", "[", "p4", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"p4", "=", 
   RowBox[{"PlotVectorField", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "5"}], " ", "y1"}], ",", "x1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"x1", ",", 
       RowBox[{"-", "12"}], ",", "12"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y1", ",", 
       RowBox[{"-", "5"}], ",", "5"}], "}"}]}], "]"}]}], ";"}]}], "Input",
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Show", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"p5", ",", "p4"}], "}"}], ",", 
    RowBox[{"Axes", "\[Rule]", "Automatic"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "12"}], ",", "12"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "5"}], ",", "5"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<x[t]\>\"", ",", "\"\<y[t]\>\""}], "}"}]}], ",", 
    RowBox[{"AspectRatio", "\[Rule]", "Automatic"}]}], "]"}], ";"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["describe the system,using appropriate vocabulary.", "Subsubsection"],

Cell["\<\
The origin is a stable center.

From the eigenvalue alone:  Since the eigenvalues are purely imaginary, the \
origin is a center.

Furthermore, the {t,x[t]} and {t,y[t]} graphs oscillate with constant \
amplitude, indicating that as time progresses, the x and y components of the \
x-y graph move on an ellipse.  \
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["THE fundamental matrix", "Subsubsection"],

Cell["\<\
Take any fundamental matrix \[CapitalPsi][t] and compute \
\[CapitalPsi][t].Inverse[\[CapitalPsi][0]]:\
\>", "Text",
 FontFamily->"Courier"],

Cell[BoxData[
 RowBox[{"\[CapitalPsi]", "[", "0", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Inverse", "[", "  ", 
  RowBox[{"\[CapitalPsi]", "[", "0", "]"}], "  ", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[CapitalPsi]", "[", "t", "]"}], " ", ".", " ", 
  RowBox[{"Inverse", "[", "  ", 
   RowBox[{"\[CapitalPsi]", "[", "0", "]"}], "  ", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"MatrixForm", "[", "%", "]"}]], "Input"],

Cell[BoxData[{
 RowBox[{"Clear", "[", "\[CapitalPhi]", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[CapitalPhi]", "[", "t_", "]"}], ":=", 
  TagBox[
   RowBox[{"(", "\[NoBreak]", GridBox[{
      {
       RowBox[{"Cos", "[", 
        RowBox[{
         SqrtBox["5"], " ", "t"}], "]"}], 
       RowBox[{
        RowBox[{"-", 
         SqrtBox["5"]}], " ", 
        RowBox[{"Sin", "[", 
         RowBox[{
          SqrtBox["5"], " ", "t"}], "]"}]}]},
      {
       FractionBox[
        RowBox[{"Sin", "[", 
         RowBox[{
          SqrtBox["5"], " ", "t"}], "]"}], 
        SqrtBox["5"]], 
       RowBox[{"Cos", "[", 
        RowBox[{
         SqrtBox["5"], " ", "t"}], "]"}]}
     }], "\[NoBreak]", ")"}],
   Function[BoxForm`e$, 
    MatrixForm[BoxForm`e$]]]}]}], "Input"],

Cell["Check the properties of THE fundamental matrix:", "Text",
 FontFamily->"Courier"],

Cell["Its columns are linearly independent:", "Text",
 FontFamily->"Courier"],

Cell[BoxData[
 RowBox[{"Det", "[", 
  RowBox[{"\[CapitalPhi]", "[", "t", "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"TrigExpand", "[", "%", "]"}]], "Input"],

Cell["THE fundamental matrix also solves the DE:", "Text",
 FontFamily->"Courier"],

Cell[BoxData[
 RowBox[{"D", "[", 
  RowBox[{
   RowBox[{"\[CapitalPhi]", "[", "t", "]"}], ",", "t"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"A", "[", "\[Alpha]", "]"}], ".", 
  RowBox[{"\[CapitalPhi]", "[", "t", "]"}]}]], "Input"],

Cell["At t0=0, it is the identity matrix:", "Text",
 FontFamily->"Courier"],

Cell[BoxData[
 RowBox[{"\[CapitalPhi]", "[", "0", "]"}]], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Example:  ",
 Cell[BoxData[
  RowBox[{"\[Alpha]", "=", "1"}]],
  TextAlignment->Left],
 " gory detail"
}], "Subsection",
 CellFrame->{{0, 0}, {0, 0.5}}],

Cell[CellGroupData[{

Cell["solution from the eigenmethod", "Subsubsection"],

Cell[BoxData[{
 RowBox[{"Clear", "[", "\[Alpha]", "]"}], "\n", 
 RowBox[{"\[Alpha]", "=", "1"}], "\n", 
 RowBox[{"A", "[", "\[Alpha]", "]"}]}], "Input"],

Cell[BoxData[
 RowBox[{"Eigensystem", "[", 
  RowBox[{"A", "[", "\[Alpha]", "]"}], "]"}]], "Input"],

Cell["\<\
Peel off the real and imaginary parts of the eigenvalues and of the \
eigenvectors.  

(Remember to include the algebraic sign with the real parts but not with the \
imaginary parts.  This is because we have conjugates.)\
\>", "Text"],

Cell[BoxData[
 RowBox[{"Re", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{"\[ImaginaryI]", " ", 
          SqrtBox["19"]}]}], ")"}]}], ",", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"\[ImaginaryI]", " ", 
          SqrtBox["19"]}]}], ")"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         FractionBox["1", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "-", 
           RowBox[{"\[ImaginaryI]", " ", 
            SqrtBox["19"]}]}], ")"}]}], ",", "1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         FractionBox["1", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           RowBox[{"\[ImaginaryI]", " ", 
            SqrtBox["19"]}]}], ")"}]}], ",", "1"}], "}"}]}], "}"}]}], "}"}], 
  "]"}]], "Input"],

Cell["\<\
The above format is {{RealPartEval,RealPartEval},{RealPartEvec,RealPartEvec}}\
\
\>", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"RealPartEval", "=", 
   FractionBox["1", "2"]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"RealPartEvec", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", "2"]}], ",", "1"}], "}"}]}], ";"}]}], "Input"],

Cell[BoxData[
 RowBox[{"Im", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{"\[ImaginaryI]", " ", 
          SqrtBox["19"]}]}], ")"}]}], ",", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"\[ImaginaryI]", " ", 
          SqrtBox["19"]}]}], ")"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         FractionBox["1", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "-", 
           RowBox[{"\[ImaginaryI]", " ", 
            SqrtBox["19"]}]}], ")"}]}], ",", "1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         FractionBox["1", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           RowBox[{"\[ImaginaryI]", " ", 
            SqrtBox["19"]}]}], ")"}]}], ",", "1"}], "}"}]}], "}"}]}], "}"}], 
  "]"}]], "Input"],

Cell["\<\
The above format is \
{{-ImagPartEval,ImagPartEval},{-ImagPartEvec,ImagPartEvec}}.\
\>", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"ImagPartEval", " ", "=", 
   FractionBox[
    SqrtBox["19"], "2"]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ImagPartEvec", " ", "=", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      SqrtBox["19"], "2"], ",", "0"}], "}"}]}], ";"}]}], "Input"],

Cell["State the real-valued solutions.", "Text"],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{"RealPartEval", " ", "*", " ", "t"}]], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"RealPartEvec", " ", "*", 
     RowBox[{"Cos", "[", 
      RowBox[{"ImagPartEval", " ", "*", " ", "t"}], "]"}]}], " ", "-", 
    "\[IndentingNewLine]", 
    RowBox[{"ImagPartEvec", " ", "*", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"ImagPartEval", " ", "*", " ", "t"}], "]"}]}]}], 
   ")"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{"RealPartEval", " ", "*", " ", "t"}]], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"RealPartEvec", " ", "*", 
     RowBox[{"Sin", "[", 
      RowBox[{"ImagPartEval", " ", "*", " ", "t"}], "]"}]}], " ", "+", 
    "\[IndentingNewLine]", 
    RowBox[{"ImagPartEvec", " ", "*", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"ImagPartEval", " ", "*", " ", "t"}], "]"}]}]}], 
   ")"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"Above", " ", "are", " ", "two", " ", "linearly", " ", "independent",
   " ", "solutions", " ", "to", " ", "the", " ", "DE", " ", "from", " ", 
  "this", " ", 
  RowBox[{"method", " ", "."}]}]], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["a fundamental matrix", "Subsubsection"],

Cell[BoxData[
 RowBox[{"MatrixForm", "[", 
  RowBox[{"Transpose", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"t", "/", "2"}]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            FractionBox["1", "2"]}], " ", 
           RowBox[{"Cos", "[", 
            FractionBox[
             RowBox[{
              SqrtBox["19"], " ", "t"}], "2"], "]"}]}], "-", 
          RowBox[{
           FractionBox["1", "2"], " ", 
           SqrtBox["19"], " ", 
           RowBox[{"Sin", "[", 
            FractionBox[
             RowBox[{
              SqrtBox["19"], " ", "t"}], "2"], "]"}]}]}], ")"}]}], ",", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"t", "/", "2"}]], " ", 
        RowBox[{"Cos", "[", 
         FractionBox[
          RowBox[{
           SqrtBox["19"], " ", "t"}], "2"], "]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"t", "/", "2"}]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox["1", "2"], " ", 
           SqrtBox["19"], " ", 
           RowBox[{"Cos", "[", 
            FractionBox[
             RowBox[{
              SqrtBox["19"], " ", "t"}], "2"], "]"}]}], "-", 
          RowBox[{
           FractionBox["1", "2"], " ", 
           RowBox[{"Sin", "[", 
            FractionBox[
             RowBox[{
              SqrtBox["19"], " ", "t"}], "2"], "]"}]}]}], ")"}]}], ",", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"t", "/", "2"}]], " ", 
        RowBox[{"Sin", "[", 
         FractionBox[
          RowBox[{
           SqrtBox["19"], " ", "t"}], "2"], "]"}]}]}], "}"}]}], "}"}], "]"}], 
  "]"}]], "Input"],

Cell[BoxData[{
 RowBox[{"Clear", "[", "\[CapitalPsi]", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[CapitalPsi]", "[", "t_", "]"}], ":=", 
  TagBox[
   RowBox[{"(", "\[NoBreak]", GridBox[{
      {
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"t", "/", "2"}]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            FractionBox["1", "2"]}], " ", 
           RowBox[{"Cos", "[", 
            FractionBox[
             RowBox[{
              SqrtBox["19"], " ", "t"}], "2"], "]"}]}], "-", 
          RowBox[{
           FractionBox["1", "2"], " ", 
           SqrtBox["19"], " ", 
           RowBox[{"Sin", "[", 
            FractionBox[
             RowBox[{
              SqrtBox["19"], " ", "t"}], "2"], "]"}]}]}], ")"}]}], 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"t", "/", "2"}]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox["1", "2"], " ", 
           SqrtBox["19"], " ", 
           RowBox[{"Cos", "[", 
            FractionBox[
             RowBox[{
              SqrtBox["19"], " ", "t"}], "2"], "]"}]}], "-", 
          RowBox[{
           FractionBox["1", "2"], " ", 
           RowBox[{"Sin", "[", 
            FractionBox[
             RowBox[{
              SqrtBox["19"], " ", "t"}], "2"], "]"}]}]}], ")"}]}]},
      {
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"t", "/", "2"}]], " ", 
        RowBox[{"Cos", "[", 
         FractionBox[
          RowBox[{
           SqrtBox["19"], " ", "t"}], "2"], "]"}]}], 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"t", "/", "2"}]], " ", 
        RowBox[{"Sin", "[", 
         FractionBox[
          RowBox[{
           SqrtBox["19"], " ", "t"}], "2"], "]"}]}]}
     }], "\[NoBreak]", ")"}],
   Function[BoxForm`e$, 
    MatrixForm[BoxForm`e$]]]}]}], "Input"],

Cell[BoxData[
 RowBox[{"Det", "[", 
  RowBox[{"\[CapitalPsi]", "[", "t", "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"TrigExpand", "[", "%", "]"}]], "Input"],

Cell["Note that a fundamental matrix also solves the DE.", "Text",
 FontFamily->"Courier"],

Cell[BoxData[
 RowBox[{"D", "[", 
  RowBox[{
   RowBox[{"\[CapitalPsi]", "[", "t", "]"}], ",", "t"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"A", "[", "\[Alpha]", "]"}], ".", 
  RowBox[{"\[CapitalPsi]", "[", "t", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"Expand", "[", 
  RowBox[{
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{"\[CapitalPsi]", "[", "t", "]"}], ",", "t"}], "]"}], "-", 
   RowBox[{
    RowBox[{"A", "[", "\[Alpha]", "]"}], ".", 
    RowBox[{"\[CapitalPsi]", "[", "t", "]"}]}]}], "]"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["general solution, behavior", "Subsubsection"],

Cell["the general solution", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[CapitalPsi]", "[", "t", "]"}], ".", 
  RowBox[{"{", 
   RowBox[{"c1", ",", "c2"}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"%", "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"c1", "\[Rule]", "1"}], ",", 
    RowBox[{"c2", "\[Rule]", "1"}]}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Note", " ", "that", " ", "for", " ", "these", " ", "solutions"}], 
   ",", " ", 
   RowBox[{
   "for", " ", "each", " ", "pair", " ", "c1", " ", "and", " ", "c2"}], ",", 
   "  ", 
   RowBox[{"oscillate", " ", "with", " ", "increasing", " ", 
    RowBox[{"amplitude", ".", "  ", "Thus"}]}], ",", 
   RowBox[{
   "the", " ", "origin", " ", "is", " ", "an", " ", "unstable", " ", "spiral",
     " ", "for", " ", "this", " ", "value", " ", "of", " ", 
    RowBox[{"\[Alpha]", ".", "\[IndentingNewLine]"}]}]}]}]], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Plot", "[", " ", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"t", "/", "2"}]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        FractionBox["1", "2"], " ", 
        SqrtBox["19"], " ", 
        RowBox[{"Cos", "[", 
         FractionBox[
          RowBox[{
           SqrtBox["19"], " ", "t"}], "2"], "]"}]}], "-", 
       RowBox[{
        FractionBox["1", "2"], " ", 
        RowBox[{"Sin", "[", 
         FractionBox[
          RowBox[{
           SqrtBox["19"], " ", "t"}], "2"], "]"}]}]}], ")"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "8"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"t", ",", "\"\<\>\""}], "}"}]}], ",", 
    RowBox[{"PlotLabel", "\[Rule]", "\"\<component of x[t] or y[t]\>\""}]}], 
   "]"}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Plot", "[", " ", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"t", "/", "2"}]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "2"]}], " ", 
        RowBox[{"Cos", "[", 
         FractionBox[
          RowBox[{
           SqrtBox["19"], " ", "t"}], "2"], "]"}]}], "-", 
       RowBox[{
        FractionBox["1", "2"], " ", 
        SqrtBox["19"], " ", 
        RowBox[{"Sin", "[", 
         FractionBox[
          RowBox[{
           SqrtBox["19"], " ", "t"}], "2"], "]"}]}]}], ")"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "8"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"t", ",", "\"\<\>\""}], "}"}]}], ",", 
    RowBox[{"PlotLabel", "\[Rule]", "\"\<component of x[t] or y[t]\>\""}]}], 
   "]"}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Plot", "[", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"t", "/", "2"}]], " ", 
      RowBox[{"Cos", "[", 
       FractionBox[
        RowBox[{
         SqrtBox["19"], " ", "t"}], "2"], "]"}]}], "+", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"t", "/", "2"}]], " ", 
      RowBox[{"Sin", "[", 
       FractionBox[
        RowBox[{
         SqrtBox["19"], " ", "t"}], "2"], "]"}]}]}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "8"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"t", ",", "\"\<\>\""}], "}"}]}], ",", 
    RowBox[{"PlotLabel", "\[Rule]", "\"\<component of x[t] or y[t]\>\""}]}], 
   "]"}], ";"}]], "Input"],

Cell["the initial point of the trajectory:", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"t", "/", "2"}]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         FractionBox["1", "2"], " ", 
         SqrtBox["19"], " ", 
         RowBox[{"Cos", "[", 
          FractionBox[
           RowBox[{
            SqrtBox["19"], " ", "t"}], "2"], "]"}]}], "-", 
        RowBox[{
         FractionBox["1", "2"], " ", 
         RowBox[{"Sin", "[", 
          FractionBox[
           RowBox[{
            SqrtBox["19"], " ", "t"}], "2"], "]"}]}]}], ")"}]}], "+", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"t", "/", "2"}]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", "2"]}], " ", 
         RowBox[{"Cos", "[", 
          FractionBox[
           RowBox[{
            SqrtBox["19"], " ", "t"}], "2"], "]"}]}], "-", 
        RowBox[{
         FractionBox["1", "2"], " ", 
         SqrtBox["19"], " ", 
         RowBox[{"Sin", "[", 
          FractionBox[
           RowBox[{
            SqrtBox["19"], " ", "t"}], "2"], "]"}]}]}], ")"}]}]}], ",", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"t", "/", "2"}]], " ", 
      RowBox[{"Cos", "[", 
       FractionBox[
        RowBox[{
         SqrtBox["19"], " ", "t"}], "2"], "]"}]}], "+", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"t", "/", "2"}]], " ", 
      RowBox[{"Sin", "[", 
       FractionBox[
        RowBox[{
         SqrtBox["19"], " ", "t"}], "2"], "]"}]}]}]}], "}"}], "/.", 
  RowBox[{"t", "\[Rule]", "0"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"N", "[", "%", "]"}]], "Input"],

Cell["Here's the phase plane for one trajectory.", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ParametricPlot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"t", "/", "2"}]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox["1", "2"], " ", 
           SqrtBox["19"], " ", 
           RowBox[{"Cos", "[", 
            FractionBox[
             RowBox[{
              SqrtBox["19"], " ", "t"}], "2"], "]"}]}], "-", 
          RowBox[{
           FractionBox["1", "2"], " ", 
           RowBox[{"Sin", "[", 
            FractionBox[
             RowBox[{
              SqrtBox["19"], " ", "t"}], "2"], "]"}]}]}], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"t", "/", "2"}]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            FractionBox["1", "2"]}], " ", 
           RowBox[{"Cos", "[", 
            FractionBox[
             RowBox[{
              SqrtBox["19"], " ", "t"}], "2"], "]"}]}], "-", 
          RowBox[{
           FractionBox["1", "2"], " ", 
           SqrtBox["19"], " ", 
           RowBox[{"Sin", "[", 
            FractionBox[
             RowBox[{
              SqrtBox["19"], " ", "t"}], "2"], "]"}]}]}], ")"}]}]}], ",", 
      RowBox[{
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"t", "/", "2"}]], " ", 
        RowBox[{"Cos", "[", 
         FractionBox[
          RowBox[{
           SqrtBox["19"], " ", "t"}], "2"], "]"}]}], "+", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"t", "/", "2"}]], " ", 
        RowBox[{"Sin", "[", 
         FractionBox[
          RowBox[{
           SqrtBox["19"], " ", "t"}], "2"], "]"}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "8"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<x[t]\>\"", ",", "\"\<y[t]\>\""}], "}"}]}]}], "]"}], 
  ";"}]], "Input"],

Cell["This trajectory orbits the origin in an enlarging spiral.", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"fcnlist", "=", 
   RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{"AppendTo", "[", 
    RowBox[{"fcnlist", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"c2", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"t", "/", "2"}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            FractionBox["1", "2"], " ", 
            SqrtBox["19"], " ", 
            RowBox[{"Cos", "[", 
             FractionBox[
              RowBox[{
               SqrtBox["19"], " ", "t"}], "2"], "]"}]}], "-", 
           RowBox[{
            FractionBox["1", "2"], " ", 
            RowBox[{"Sin", "[", 
             FractionBox[
              RowBox[{
               SqrtBox["19"], " ", "t"}], "2"], "]"}]}]}], ")"}]}], "+", 
        RowBox[{"c1", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"t", "/", "2"}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             FractionBox["1", "2"]}], " ", 
            RowBox[{"Cos", "[", 
             FractionBox[
              RowBox[{
               SqrtBox["19"], " ", "t"}], "2"], "]"}]}], "-", 
           RowBox[{
            FractionBox["1", "2"], " ", 
            SqrtBox["19"], " ", 
            RowBox[{"Sin", "[", 
             FractionBox[
              RowBox[{
               SqrtBox["19"], " ", "t"}], "2"], "]"}]}]}], ")"}]}]}], ",", 
       RowBox[{
        RowBox[{"c1", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"t", "/", "2"}]], " ", 
         RowBox[{"Cos", "[", 
          FractionBox[
           RowBox[{
            SqrtBox["19"], " ", "t"}], "2"], "]"}]}], "+", 
        RowBox[{"c2", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"t", "/", "2"}]], " ", 
         RowBox[{"Sin", "[", 
          FractionBox[
           RowBox[{
            SqrtBox["19"], " ", "t"}], "2"], "]"}]}]}]}], "}"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"c1", ",", 
     RowBox[{"-", "2"}], ",", "2", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"c2", ",", 
     RowBox[{"-", "3"}], ",", "3", ",", "3"}], "}"}]}], 
  "]"}], "\[IndentingNewLine]", "fcnlist"}], "Input"],

Cell["\<\
phase plane for several trajectories.  Look for the lines generated by the \
eigenvectors.\
\>", "Text"],

Cell[BoxData[{
 RowBox[{"Clear", "[", "p5", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"p5", "=", 
   RowBox[{"ParametricPlot", "[", 
    RowBox[{
     RowBox[{"Evaluate", "[", "fcnlist", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "4"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x[t]\>\"", ",", "\"\<y[t]\>\""}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "20"}], ",", "20"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "20"}], ",", "20"}], "}"}]}], "}"}]}]}], "]"}]}], 
  ";"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["direction field", "Subsubsection"],

Cell[TextData[{
 "Load the Graphics`PlotField` package BEFORE trying to generate the \
direction field.Load the package once per ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " session.If you change anything,generate the direction field again."
}], "Text"],

Cell[BoxData[
 RowBox[{"<<", "Graphics`PlotField`"}]], "Input",
 ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Remember that we obtain the coordinates of the direction field from \
{x'[t],y'[t]},which is given by the matrix product A.{x[t],y[t]}.To avoid \
confusing the {x,y} used here with ones plotted elsewhere,we'll call these \
{x1,y1}.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"A", "[", "\[Alpha]", "]"}], ".", 
  RowBox[{"{", 
   RowBox[{"x1", ",", "y1"}], "}"}]}]], "Input"],

Cell[BoxData[{
 RowBox[{"Clear", "[", "p4", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"p4", "=", 
   RowBox[{"PlotVectorField", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "5"}], " ", "y1"}], ",", 
       RowBox[{"x1", "+", "y1"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"x1", ",", 
       RowBox[{"-", "20"}], ",", "20"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y1", ",", 
       RowBox[{"-", "20"}], ",", "20"}], "}"}]}], "]"}]}], ";"}]}], "Input",
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Show", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"p5", ",", "p4"}], "}"}], ",", 
    RowBox[{"Axes", "\[Rule]", "Automatic"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "20"}], ",", "20"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "20"}], ",", "20"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<x[t]\>\"", ",", "\"\<y[t]\>\""}], "}"}]}], ",", 
    RowBox[{"AspectRatio", "\[Rule]", "Automatic"}]}], "]"}], ";"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["describe the system,using appropriate vocabulary.", "Subsubsection"],

Cell["\<\
The origin is an unstable spiral.

From the eigenvalue alone:  Since the eigenvalues are complex and have \
negative imaginary parts, the origin is an unstable spiral.

Furthermore, the {t,x[t]} and {t,y[t]} graphs oscillate with increasing \
amplitude, indicating that as time progresses, the x and y components of the \
x-y graph move on a spiral with increasing radius.  \
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["THE fundamental matrix", "Subsubsection"],

Cell["\<\
Take any fundamental matrix \[CapitalPsi][t] and compute \
\[CapitalPsi][t].Inverse[\[CapitalPsi][0]]:\
\>", "Text",
 FontFamily->"Courier"],

Cell[BoxData[
 RowBox[{"\[CapitalPsi]", "[", "0", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Inverse", "[", "  ", 
  RowBox[{"\[CapitalPsi]", "[", "0", "]"}], "  ", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[CapitalPsi]", "[", "t", "]"}], " ", ".", " ", 
  RowBox[{"Inverse", "[", "  ", 
   RowBox[{"\[CapitalPsi]", "[", "0", "]"}], "  ", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"MatrixForm", "[", "%", "]"}]], "Input"],

Cell[BoxData[{
 RowBox[{"Clear", "[", "\[CapitalPhi]", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[CapitalPhi]", "[", "t_", "]"}], ":=", 
  TagBox[
   RowBox[{"(", "\[NoBreak]", GridBox[{
      {
       FractionBox[
        RowBox[{"2", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"t", "/", "2"}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            FractionBox["1", "2"], " ", 
            SqrtBox["19"], " ", 
            RowBox[{"Cos", "[", 
             FractionBox[
              RowBox[{
               SqrtBox["19"], " ", "t"}], "2"], "]"}]}], "-", 
           RowBox[{
            FractionBox["1", "2"], " ", 
            RowBox[{"Sin", "[", 
             FractionBox[
              RowBox[{
               SqrtBox["19"], " ", "t"}], "2"], "]"}]}]}], ")"}]}], 
        SqrtBox["19"]], 
       RowBox[{
        FractionBox[
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"t", "/", "2"}]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             FractionBox["1", "2"], " ", 
             SqrtBox["19"], " ", 
             RowBox[{"Cos", "[", 
              FractionBox[
               RowBox[{
                SqrtBox["19"], " ", "t"}], "2"], "]"}]}], "-", 
            RowBox[{
             FractionBox["1", "2"], " ", 
             RowBox[{"Sin", "[", 
              FractionBox[
               RowBox[{
                SqrtBox["19"], " ", "t"}], "2"], "]"}]}]}], ")"}]}], 
         SqrtBox["19"]], "+", 
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"t", "/", "2"}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             FractionBox["1", "2"]}], " ", 
            RowBox[{"Cos", "[", 
             FractionBox[
              RowBox[{
               SqrtBox["19"], " ", "t"}], "2"], "]"}]}], "-", 
           RowBox[{
            FractionBox["1", "2"], " ", 
            SqrtBox["19"], " ", 
            RowBox[{"Sin", "[", 
             FractionBox[
              RowBox[{
               SqrtBox["19"], " ", "t"}], "2"], "]"}]}]}], ")"}]}]}]},
      {
       FractionBox[
        RowBox[{"2", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"t", "/", "2"}]], " ", 
         RowBox[{"Sin", "[", 
          FractionBox[
           RowBox[{
            SqrtBox["19"], " ", "t"}], "2"], "]"}]}], 
        SqrtBox["19"]], 
       RowBox[{
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"t", "/", "2"}]], " ", 
         RowBox[{"Cos", "[", 
          FractionBox[
           RowBox[{
            SqrtBox["19"], " ", "t"}], "2"], "]"}]}], "+", 
        FractionBox[
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"t", "/", "2"}]], " ", 
          RowBox[{"Sin", "[", 
           FractionBox[
            RowBox[{
             SqrtBox["19"], " ", "t"}], "2"], "]"}]}], 
         SqrtBox["19"]]}]}
     }], "\[NoBreak]", ")"}],
   Function[BoxForm`e$, 
    MatrixForm[BoxForm`e$]]]}]}], "Input"],

Cell["Check the properties of THE fundamental matrix:", "Text",
 FontFamily->"Courier"],

Cell["Its columns are linearly independent:", "Text",
 FontFamily->"Courier"],

Cell[BoxData[
 RowBox[{"Det", "[", 
  RowBox[{"\[CapitalPhi]", "[", "t", "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"TrigExpand", "[", "%", "]"}]], "Input"],

Cell["THE fundamental matrix also solves the DE:", "Text",
 FontFamily->"Courier"],

Cell[BoxData[
 RowBox[{"D", "[", 
  RowBox[{
   RowBox[{"\[CapitalPhi]", "[", "t", "]"}], ",", "t"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"A", "[", "\[Alpha]", "]"}], ".", 
  RowBox[{"\[CapitalPhi]", "[", "t", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"Expand", "[", 
  RowBox[{
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{"\[CapitalPhi]", "[", "t", "]"}], ",", "t"}], "]"}], "-", 
   RowBox[{
    RowBox[{"A", "[", "\[Alpha]", "]"}], ".", 
    RowBox[{"\[CapitalPhi]", "[", "t", "]"}]}]}], "]"}]], "Input"],

Cell["At t0=0, it is the identity matrix:", "Text",
 FontFamily->"Courier"],

Cell[BoxData[
 RowBox[{"\[CapitalPhi]", "[", "0", "]"}]], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Example:  ",
 Cell[BoxData[
  RowBox[{"\[Alpha]", "=", 
   RowBox[{"-", "2"}]}]],
  TextAlignment->Left],
 " gory detail"
}], "Subsection",
 CellFrame->{{0, 0}, {0, 0.5}}],

Cell[CellGroupData[{

Cell["solution from the eigenmethod", "Subsubsection"],

Cell[BoxData[{
 RowBox[{"Clear", "[", "\[Alpha]", "]"}], "\n", 
 RowBox[{"\[Alpha]", "=", 
  RowBox[{"-", "2"}]}], "\n", 
 RowBox[{"A", "[", "\[Alpha]", "]"}]}], "Input"],

Cell[BoxData[
 RowBox[{"Eigensystem", "[", 
  RowBox[{"A", "[", "\[Alpha]", "]"}], "]"}]], "Input"],

Cell["\<\
Peel off the real and imaginary parts of the eigenvalues and of the \
eigenvectors.  

(Remember to include the algebraic sign with the real parts but not with the \
imaginary parts.  This is because we have conjugates.)\
\>", "Text"],

Cell[BoxData[
 RowBox[{"Re", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "1"}], "-", 
       RowBox[{"2", " ", "\[ImaginaryI]"}]}], ",", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"2", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"1", "-", 
         RowBox[{"2", " ", "\[ImaginaryI]"}]}], ",", "1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"1", "+", 
         RowBox[{"2", " ", "\[ImaginaryI]"}]}], ",", "1"}], "}"}]}], "}"}]}], 
   "}"}], "]"}]], "Input"],

Cell["\<\
The above format is {{RealPartEval,RealPartEval},{RealPartEvec,RealPartEvec}}\
\
\>", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"RealPartEval", "=", 
   RowBox[{"-", "1"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"RealPartEvec", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}]}], ";"}]}], "Input"],

Cell[BoxData[
 RowBox[{"Im", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "1"}], "-", 
       RowBox[{"2", " ", "\[ImaginaryI]"}]}], ",", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"2", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"1", "-", 
         RowBox[{"2", " ", "\[ImaginaryI]"}]}], ",", "1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"1", "+", 
         RowBox[{"2", " ", "\[ImaginaryI]"}]}], ",", "1"}], "}"}]}], "}"}]}], 
   "}"}], "]"}]], "Input"],

Cell["\<\
The above format is \
{{-ImagPartEval,ImagPartEval},{-ImagPartEvec,ImagPartEvec}}.\
\>", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"ImagPartEval", " ", "=", "2"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ImagPartEvec", " ", "=", 
   RowBox[{"{", 
    RowBox[{"2", ",", "0"}], "}"}]}], ";"}]}], "Input"],

Cell["State the real-valued solutions.", "Text"],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{"RealPartEval", " ", "*", " ", "t"}]], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"RealPartEvec", " ", "*", 
     RowBox[{"Cos", "[", 
      RowBox[{"ImagPartEval", " ", "*", " ", "t"}], "]"}]}], " ", "-", 
    "\[IndentingNewLine]", 
    RowBox[{"ImagPartEvec", " ", "*", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"ImagPartEval", " ", "*", " ", "t"}], "]"}]}]}], 
   ")"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{"RealPartEval", " ", "*", " ", "t"}]], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"RealPartEvec", " ", "*", 
     RowBox[{"Sin", "[", 
      RowBox[{"ImagPartEval", " ", "*", " ", "t"}], "]"}]}], " ", "+", 
    "\[IndentingNewLine]", 
    RowBox[{"ImagPartEvec", " ", "*", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"ImagPartEval", " ", "*", " ", "t"}], "]"}]}]}], 
   ")"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"Above", " ", "are", " ", "two", " ", "linearly", " ", "independent",
   " ", "solutions", " ", "to", " ", "the", " ", "DE", " ", "from", " ", 
  "this", " ", 
  RowBox[{"method", " ", "."}]}]], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["a fundamental matrix", "Subsubsection"],

Cell[BoxData[
 RowBox[{"MatrixForm", "[", 
  RowBox[{"Transpose", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", "t"}]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Cos", "[", 
           RowBox[{"2", " ", "t"}], "]"}], "-", 
          RowBox[{"2", " ", 
           RowBox[{"Sin", "[", 
            RowBox[{"2", " ", "t"}], "]"}]}]}], ")"}]}], ",", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", "t"}]], " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"2", " ", "t"}], "]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", "t"}]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"2", " ", "t"}], "]"}]}], "+", 
          RowBox[{"Sin", "[", 
           RowBox[{"2", " ", "t"}], "]"}]}], ")"}]}], ",", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", "t"}]], " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"2", " ", "t"}], "]"}]}]}], "}"}]}], "}"}], "]"}], 
  "]"}]], "Input"],

Cell[BoxData[{
 RowBox[{"Clear", "[", "\[CapitalPsi]", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[CapitalPsi]", "[", "t_", "]"}], ":=", 
  TagBox[
   RowBox[{"(", "\[NoBreak]", GridBox[{
      {
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", "t"}]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Cos", "[", 
           RowBox[{"2", " ", "t"}], "]"}], "-", 
          RowBox[{"2", " ", 
           RowBox[{"Sin", "[", 
            RowBox[{"2", " ", "t"}], "]"}]}]}], ")"}]}], 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", "t"}]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"2", " ", "t"}], "]"}]}], "+", 
          RowBox[{"Sin", "[", 
           RowBox[{"2", " ", "t"}], "]"}]}], ")"}]}]},
      {
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", "t"}]], " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"2", " ", "t"}], "]"}]}], 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", "t"}]], " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"2", " ", "t"}], "]"}]}]}
     }], "\[NoBreak]", ")"}],
   Function[BoxForm`e$, 
    MatrixForm[BoxForm`e$]]]}]}], "Input"],

Cell[BoxData[
 RowBox[{"Det", "[", 
  RowBox[{"\[CapitalPsi]", "[", "t", "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"TrigExpand", "[", "%", "]"}]], "Input"],

Cell["Note that a fundamental matrix also solves the DE.", "Text",
 FontFamily->"Courier"],

Cell[BoxData[
 RowBox[{"D", "[", 
  RowBox[{
   RowBox[{"\[CapitalPsi]", "[", "t", "]"}], ",", "t"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"A", "[", "\[Alpha]", "]"}], ".", 
  RowBox[{"\[CapitalPsi]", "[", "t", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"Expand", "[", 
  RowBox[{
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{"\[CapitalPsi]", "[", "t", "]"}], ",", "t"}], "]"}], "-", 
   RowBox[{
    RowBox[{"A", "[", "\[Alpha]", "]"}], ".", 
    RowBox[{"\[CapitalPsi]", "[", "t", "]"}]}]}], "]"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["general solution, behavior", "Subsubsection"],

Cell["the general solution", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[CapitalPsi]", "[", "t", "]"}], ".", 
  RowBox[{"{", 
   RowBox[{"c1", ",", "c2"}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"%", "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"c1", "\[Rule]", "1"}], ",", 
    RowBox[{"c2", "\[Rule]", "1"}]}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Note", " ", "that", " ", "for", " ", "these", " ", "solutions"}], 
   ",", " ", 
   RowBox[{
   "for", " ", "each", " ", "pair", " ", "c1", " ", "and", " ", "c2"}], ",", 
   "  ", 
   RowBox[{"oscillate", " ", "with", " ", "increasing", " ", 
    RowBox[{"amplitude", ".", "  ", "Thus"}]}], ",", 
   RowBox[{
   "the", " ", "origin", " ", "is", " ", "a", " ", "stable", " ", "spiral", 
    " ", "for", " ", "this", " ", "value", " ", "of", " ", 
    RowBox[{"\[Alpha]", ".", "\[IndentingNewLine]"}]}]}]}]], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Plot", "[", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", "t"}]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"2", " ", "t"}], "]"}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"2", " ", "t"}], "]"}]}]}], ")"}]}], "+", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", "t"}]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"2", " ", "t"}], "]"}]}], "+", 
        RowBox[{"Sin", "[", 
         RowBox[{"2", " ", "t"}], "]"}]}], ")"}]}]}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "5"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"t", ",", "\"\<\>\""}], "}"}]}], ",", 
    RowBox[{"PlotLabel", "\[Rule]", "\"\<component of x[t] or y[t]\>\""}]}], 
   "]"}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Plot", "[", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", "t"}]], " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"2", " ", "t"}], "]"}]}], "+", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", "t"}]], " ", 
      RowBox[{"Sin", "[", 
       RowBox[{"2", " ", "t"}], "]"}]}]}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "5"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"t", ",", "\"\<\>\""}], "}"}]}], ",", 
    RowBox[{"PlotLabel", "\[Rule]", "\"\<component of x[t] or y[t]\>\""}]}], 
   "]"}], ";"}]], "Input"],

Cell["the initial point of the trajectory:", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", "t"}]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"2", " ", "t"}], "]"}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"2", " ", "t"}], "]"}]}]}], ")"}]}], "+", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", "t"}]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"2", " ", "t"}], "]"}]}], "+", 
        RowBox[{"Sin", "[", 
         RowBox[{"2", " ", "t"}], "]"}]}], ")"}]}]}], ",", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", "t"}]], " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"2", " ", "t"}], "]"}]}], "+", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", "t"}]], " ", 
      RowBox[{"Sin", "[", 
       RowBox[{"2", " ", "t"}], "]"}]}]}]}], "}"}], "/.", 
  RowBox[{"t", "\[Rule]", "0"}]}]], "Input"],

Cell["Here's the phase plane for one trajectory.", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ParametricPlot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", "t"}]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Cos", "[", 
           RowBox[{"2", " ", "t"}], "]"}], "-", 
          RowBox[{"2", " ", 
           RowBox[{"Sin", "[", 
            RowBox[{"2", " ", "t"}], "]"}]}]}], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", "t"}]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"2", " ", "t"}], "]"}]}], "+", 
          RowBox[{"Sin", "[", 
           RowBox[{"2", " ", "t"}], "]"}]}], ")"}]}]}], ",", 
      RowBox[{
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", "t"}]], " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"2", " ", "t"}], "]"}]}], "+", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", "t"}]], " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"2", " ", "t"}], "]"}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "8"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<x[t]\>\"", ",", "\"\<y[t]\>\""}], "}"}]}]}], "]"}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ParametricPlot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", "t"}]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Cos", "[", 
           RowBox[{"2", " ", "t"}], "]"}], "-", 
          RowBox[{"2", " ", 
           RowBox[{"Sin", "[", 
            RowBox[{"2", " ", "t"}], "]"}]}]}], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", "t"}]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"2", " ", "t"}], "]"}]}], "+", 
          RowBox[{"Sin", "[", 
           RowBox[{"2", " ", "t"}], "]"}]}], ")"}]}]}], ",", 
      RowBox[{
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", "t"}]], " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"2", " ", "t"}], "]"}]}], "+", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", "t"}]], " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"2", " ", "t"}], "]"}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "8"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<x[t]\>\"", ",", "\"\<y[t]\>\""}], "}"}]}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1.25"}], ",", "3.25"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", ".25"}], ",", "1.25"}], "}"}]}], "}"}]}]}], "]"}], 
  ";"}]], "Input"],

Cell["This trajectory orbits the origin in a diminishing spiral.", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"fcnlist", "=", 
   RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{"AppendTo", "[", 
    RowBox[{"fcnlist", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"c1", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"-", "t"}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"2", " ", "t"}], "]"}], "-", 
           RowBox[{"2", " ", 
            RowBox[{"Sin", "[", 
             RowBox[{"2", " ", "t"}], "]"}]}]}], ")"}]}], "+", 
        RowBox[{"c2", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"-", "t"}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            RowBox[{"Cos", "[", 
             RowBox[{"2", " ", "t"}], "]"}]}], "+", 
           RowBox[{"Sin", "[", 
            RowBox[{"2", " ", "t"}], "]"}]}], ")"}]}]}], ",", 
       RowBox[{
        RowBox[{"c1", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"-", "t"}]], " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"2", " ", "t"}], "]"}]}], "+", 
        RowBox[{"c2", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"-", "t"}]], " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"2", " ", "t"}], "]"}]}]}]}], "}"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"c1", ",", 
     RowBox[{"-", "2"}], ",", "2", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"c2", ",", 
     RowBox[{"-", "3"}], ",", "3", ",", "3"}], "}"}]}], 
  "]"}], "\[IndentingNewLine]", "fcnlist"}], "Input"],

Cell["\<\
phase plane for several trajectories.  Look for the lines generated by the \
eigenvectors.\
\>", "Text"],

Cell[BoxData[{
 RowBox[{"Clear", "[", "p5", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"p5", "=", 
   RowBox[{"ParametricPlot", "[", 
    RowBox[{
     RowBox[{"Evaluate", "[", "fcnlist", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "4"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x[t]\>\"", ",", "\"\<y[t]\>\""}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "3"}], ",", "3"}], "}"}]}], "}"}]}]}], "]"}]}], 
  ";"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["direction field", "Subsubsection"],

Cell[TextData[{
 "Load the Graphics`PlotField` package BEFORE trying to generate the \
direction field.Load the package once per ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " session.If you change anything,generate the direction field again."
}], "Text"],

Cell[BoxData[
 RowBox[{"<<", "Graphics`PlotField`"}]], "Input",
 ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Remember that we obtain the coordinates of the direction field from \
{x'[t],y'[t]},which is given by the matrix product A.{x[t],y[t]}.To avoid \
confusing the {x,y} used here with ones plotted elsewhere,we'll call these \
{x1,y1}.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"A", "[", "\[Alpha]", "]"}], ".", 
  RowBox[{"{", 
   RowBox[{"x1", ",", "y1"}], "}"}]}]], "Input"],

Cell[BoxData[{
 RowBox[{"Clear", "[", "p4", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"p4", "=", 
   RowBox[{"PlotVectorField", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "5"}], " ", "y1"}], ",", 
       RowBox[{"x1", "-", 
        RowBox[{"2", "y1"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"x1", ",", 
       RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y1", ",", 
       RowBox[{"-", "3"}], ",", "3"}], "}"}]}], "]"}]}], ";"}]}], "Input",
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Show", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"p5", ",", "p4"}], "}"}], ",", 
    RowBox[{"Axes", "\[Rule]", "Automatic"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "3"}], ",", "3"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<x[t]\>\"", ",", "\"\<y[t]\>\""}], "}"}]}], ",", 
    RowBox[{"AspectRatio", "\[Rule]", "Automatic"}]}], "]"}], ";"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["describe the system,using appropriate vocabulary.", "Subsubsection"],

Cell["\<\
The origin is a stable spiral.

From the eigenvalue alone:  Since the eigenvalues are complex and have \
positive imaginary parts, the origin is a stable spiral.

Furthermore, the {t,x[t]} and {t,y[t]} graphs oscillate with decreasing \
amplitude, indicating that as time progresses, the x and y components of the \
x-y graph move on a spiral with decreasing radius.  \
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["THE fundamental matrix", "Subsubsection"],

Cell["\<\
Take any fundamental matrix \[CapitalPsi][t] and compute \
\[CapitalPsi][t].Inverse[\[CapitalPsi][0]]:\
\>", "Text",
 FontFamily->"Courier"],

Cell[BoxData[
 RowBox[{"\[CapitalPsi]", "[", "0", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Inverse", "[", "  ", 
  RowBox[{"\[CapitalPsi]", "[", "0", "]"}], "  ", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[CapitalPsi]", "[", "t", "]"}], " ", ".", " ", 
  RowBox[{"Inverse", "[", "  ", 
   RowBox[{"\[CapitalPsi]", "[", "0", "]"}], "  ", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"MatrixForm", "[", "%", "]"}]], "Input"],

Cell[BoxData[{
 RowBox[{"Clear", "[", "\[CapitalPhi]", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[CapitalPhi]", "[", "t_", "]"}], ":=", 
  TagBox[
   RowBox[{"(", "\[NoBreak]", GridBox[{
      {
       RowBox[{
        FractionBox["1", "2"], " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", "t"}]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"2", " ", "t"}], "]"}]}], "+", 
          RowBox[{"Sin", "[", 
           RowBox[{"2", " ", "t"}], "]"}]}], ")"}]}], 
       RowBox[{
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"-", "t"}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"2", " ", "t"}], "]"}], "-", 
           RowBox[{"2", " ", 
            RowBox[{"Sin", "[", 
             RowBox[{"2", " ", "t"}], "]"}]}]}], ")"}]}], "-", 
        RowBox[{
         FractionBox["1", "2"], " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"-", "t"}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            RowBox[{"Cos", "[", 
             RowBox[{"2", " ", "t"}], "]"}]}], "+", 
           RowBox[{"Sin", "[", 
            RowBox[{"2", " ", "t"}], "]"}]}], ")"}]}]}]},
      {
       RowBox[{
        FractionBox["1", "2"], " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", "t"}]], " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"2", " ", "t"}], "]"}]}], 
       RowBox[{
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"-", "t"}]], " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"2", " ", "t"}], "]"}]}], "-", 
        RowBox[{
         FractionBox["1", "2"], " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"-", "t"}]], " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"2", " ", "t"}], "]"}]}]}]}
     }], "\[NoBreak]", ")"}],
   Function[BoxForm`e$, 
    MatrixForm[BoxForm`e$]]]}]}], "Input"],

Cell["Check the properties of THE fundamental matrix:", "Text",
 FontFamily->"Courier"],

Cell["Its columns are linearly independent:", "Text",
 FontFamily->"Courier"],

Cell[BoxData[
 RowBox[{"Det", "[", 
  RowBox[{"\[CapitalPhi]", "[", "t", "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"TrigExpand", "[", "%", "]"}]], "Input"],

Cell["THE fundamental matrix also solves the DE:", "Text",
 FontFamily->"Courier"],

Cell[BoxData[
 RowBox[{"D", "[", 
  RowBox[{
   RowBox[{"\[CapitalPhi]", "[", "t", "]"}], ",", "t"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"A", "[", "\[Alpha]", "]"}], ".", 
  RowBox[{"\[CapitalPhi]", "[", "t", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"Expand", "[", 
  RowBox[{
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{"\[CapitalPhi]", "[", "t", "]"}], ",", "t"}], "]"}], "-", 
   RowBox[{
    RowBox[{"A", "[", "\[Alpha]", "]"}], ".", 
    RowBox[{"\[CapitalPhi]", "[", "t", "]"}]}]}], "]"}]], "Input"],

Cell["At t0=0, it is the identity matrix:", "Text",
 FontFamily->"Courier"],

Cell[BoxData[
 RowBox[{"\[CapitalPhi]", "[", "0", "]"}]], "Input"]
}, Open  ]]
}, Open  ]]
}, Closed]]
}, Open  ]]
},
WindowToolbars->{"RulerBar", "EditBar"},
WindowSize->{801, 699},
WindowMargins->{{26, Automatic}, {8, Automatic}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
PrintingOptions->{"PrintCellBrackets"->True,
"PrintMultipleHorizontalPages"->False,
"PrintRegistrationMarks"->True,
"PrintingMargins"->{{36, 36}, {36, 36}}},
Magnification->1,
FrontEndVersion->"8.0 for Microsoft Windows (64-bit) (November 7, 2010)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 547, 15, 68, "Subsubtitle"],
Cell[1129, 39, 106, 3, 29, "Text"],
Cell[CellGroupData[{
Cell[1260, 46, 63, 1, 72, "Section"],
Cell[1326, 49, 375, 12, 85, "Input"],
Cell[1704, 63, 1395, 54, 97, "Text"],
Cell[3102, 119, 203, 7, 33, "Input"],
Cell[3308, 128, 54, 1, 31, "Input"],
Cell[3365, 131, 272, 9, 33, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3674, 145, 62, 1, 72, "Section"],
Cell[3739, 148, 1672, 39, 145, "Text"],
Cell[CellGroupData[{
Cell[5436, 191, 208, 9, 48, "Subsection"],
Cell[CellGroupData[{
Cell[5669, 204, 54, 0, 42, "Subsubsection"],
Cell[5726, 206, 294, 8, 64, "Input"],
Cell[6023, 216, 133, 3, 27, "Input"],
Cell[6159, 221, 697, 19, 72, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6893, 245, 66, 0, 42, "Subsubsection"],
Cell[6962, 247, 511, 17, 33, "Input"],
Cell[7476, 266, 2005, 55, 147, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[9518, 326, 45, 0, 42, "Subsubsection"],
Cell[9566, 328, 830, 29, 35, "Input"],
Cell[10399, 359, 1061, 35, 74, "Input"],
Cell[11463, 396, 96, 2, 27, "Input"],
Cell[11562, 400, 67, 0, 32, "Text"],
Cell[11632, 402, 118, 3, 27, "Input"],
Cell[11753, 407, 124, 3, 27, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[11914, 415, 51, 0, 42, "Subsubsection"],
Cell[11968, 417, 879, 30, 39, "Text"],
Cell[12850, 449, 821, 28, 38, "Input"],
Cell[13674, 479, 126, 3, 27, "Input"],
Cell[13803, 484, 626, 20, 54, "Input"],
Cell[14432, 506, 446, 10, 122, "Text"],
Cell[14881, 518, 105, 3, 32, "Text"],
Cell[14989, 523, 1040, 36, 35, "Input"],
Cell[16032, 561, 863, 31, 35, "Input"],
Cell[16898, 594, 54, 1, 27, "Input"],
Cell[16955, 597, 123, 3, 32, "Text"],
Cell[17081, 602, 1163, 38, 54, "Input"],
Cell[18247, 642, 50, 0, 32, "Text"],
Cell[18300, 644, 1445, 46, 88, "Input"],
Cell[19748, 692, 52, 0, 32, "Text"],
Cell[19803, 694, 458, 12, 59, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[20298, 711, 40, 0, 42, "Subsubsection"],
Cell[20341, 713, 213, 4, 50, "Text"],
Cell[20557, 719, 95, 2, 27, "Input"],
Cell[20655, 723, 255, 5, 50, "Text"],
Cell[20913, 730, 133, 4, 27, "Input"],
Cell[21049, 736, 193, 7, 33, "Input"],
Cell[21245, 745, 608, 19, 49, "Input"],
Cell[21856, 766, 33843, 1493, 275, 30676, 1438, "GraphicsData", "PostScript", \
"Input"],
Cell[55702, 2261, 643, 19, 43, "Input"],
Cell[56348, 2282, 47594, 2369, 300, 41901, 2272, "GraphicsData", \
"PostScript", "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[103979, 4656, 74, 0, 42, "Subsubsection"],
Cell[104056, 4658, 915, 21, 158, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[105008, 4684, 47, 0, 42, "Subsubsection"],
Cell[105058, 4686, 126, 3, 32, "Text"],
Cell[105187, 4691, 66, 1, 27, "Input"],
Cell[105256, 4694, 207, 8, 33, "Input"],
Cell[105466, 4704, 100, 2, 27, "Input"],
Cell[105569, 4708, 185, 7, 33, "Input"],
Cell[105757, 4717, 164, 4, 27, "Input"],
Cell[105924, 4723, 1349, 48, 38, "Input"],
Cell[107276, 4773, 59, 1, 27, "Input"],
Cell[107338, 4776, 948, 33, 35, "Input"],
Cell[108289, 4811, 63, 1, 27, "Input"],
Cell[108355, 4814, 958, 33, 55, "Input"],
Cell[109316, 4849, 1128, 36, 74, "Input"],
Cell[110447, 4887, 63, 0, 32, "Text"],
Cell[110513, 4889, 94, 2, 32, "Text"],
Cell[110610, 4893, 96, 2, 27, "Input"],
Cell[110709, 4897, 110, 3, 33, "Input"],
Cell[110822, 4902, 58, 0, 32, "Text"],
Cell[110883, 4904, 118, 3, 27, "Input"],
Cell[111004, 4909, 1196, 41, 35, "Input"],
Cell[112203, 4952, 124, 3, 27, "Input"],
Cell[112330, 4957, 1485, 51, 38, "Input"],
Cell[113818, 5010, 59, 1, 27, "Input"],
Cell[113880, 5013, 1230, 42, 35, "Input"],
Cell[115113, 5057, 50, 0, 32, "Text"],
Cell[115166, 5059, 66, 1, 27, "Input"],
Cell[115235, 5062, 170, 6, 27, "Input"],
Cell[115408, 5070, 91, 2, 32, "Text"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[115548, 5078, 188, 8, 39, "Subsection"],
Cell[CellGroupData[{
Cell[115761, 5090, 54, 0, 42, "Subsubsection"],
Cell[115818, 5092, 240, 7, 64, "Input"],
Cell[116061, 5101, 133, 3, 27, "Input"],
Cell[116197, 5106, 491, 16, 55, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[116725, 5127, 66, 0, 42, "Subsubsection"],
Cell[116794, 5129, 503, 17, 33, "Input"],
Cell[117300, 5148, 1897, 53, 129, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[119234, 5206, 45, 0, 42, "Subsubsection"],
Cell[119282, 5208, 789, 28, 35, "Input"],
Cell[120074, 5238, 951, 31, 74, "Input"],
Cell[121028, 5271, 96, 2, 27, "Input"],
Cell[121127, 5275, 66, 0, 32, "Text"],
Cell[121196, 5277, 118, 3, 27, "Input"],
Cell[121317, 5282, 124, 3, 27, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[121478, 5290, 51, 0, 42, "Subsubsection"],
Cell[121532, 5292, 757, 27, 36, "Text"],
Cell[122292, 5321, 780, 27, 38, "Input"],
Cell[123075, 5350, 126, 3, 27, "Input"],
Cell[123204, 5355, 836, 28, 35, "Input"],
Cell[124043, 5385, 126, 3, 27, "Input"],
Cell[124172, 5390, 670, 22, 54, "Input"],
Cell[124845, 5414, 1082, 25, 88, "Text"],
Cell[125930, 5441, 105, 3, 32, "Text"],
Cell[126038, 5446, 938, 32, 35, "Input"],
Cell[126979, 5480, 79, 2, 27, "Input"],
Cell[127061, 5484, 54, 1, 27, "Input"],
Cell[127118, 5487, 100, 2, 32, "Text"],
Cell[127221, 5491, 1029, 33, 54, "Input"],
Cell[128253, 5526, 51, 0, 32, "Text"],
Cell[128307, 5528, 1327, 41, 88, "Input"],
Cell[129637, 5571, 64, 0, 32, "Text"],
Cell[129704, 5573, 79, 2, 27, "Input"],
Cell[129786, 5577, 54, 1, 27, "Input"],
Cell[129843, 5580, 52, 0, 32, "Text"],
Cell[129898, 5582, 745, 21, 59, "Input"],
Cell[130646, 5605, 213, 4, 50, "Text"],
Cell[130862, 5611, 634, 19, 43, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[131533, 5635, 40, 0, 42, "Subsubsection"],
Cell[131576, 5637, 268, 6, 50, "Text"],
Cell[131847, 5645, 70, 1, 27, "Input"],
Cell[131920, 5648, 260, 5, 50, "Text"],
Cell[132183, 5655, 133, 4, 27, "Input"],
Cell[132319, 5661, 151, 6, 72, "Input"],
Cell[132473, 5669, 65, 0, 32, "Text"],
Cell[132541, 5671, 757, 21, 91, "Input"],
Cell[133301, 5694, 187, 4, 50, "Text"],
Cell[133491, 5700, 697, 19, 91, "Input"],
Cell[134191, 5721, 88, 2, 32, "Text"],
Cell[134282, 5725, 621, 22, 35, "Input"],
Cell[134906, 5749, 2756, 82, 227, "Input"],
Cell[137665, 5833, 765, 21, 91, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[138467, 5859, 74, 0, 42, "Subsubsection"],
Cell[138544, 5861, 943, 21, 176, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[139524, 5887, 47, 0, 42, "Subsubsection"],
Cell[139574, 5889, 126, 3, 32, "Text"],
Cell[139703, 5894, 66, 1, 27, "Input"],
Cell[139772, 5897, 112, 2, 27, "Input"],
Cell[139887, 5901, 186, 4, 27, "Input"],
Cell[140076, 5907, 59, 1, 27, "Input"],
Cell[140138, 5910, 63, 1, 27, "Input"],
Cell[140204, 5913, 1128, 36, 74, "Input"],
Cell[141335, 5951, 211, 4, 50, "Text"],
Cell[141549, 5957, 96, 2, 27, "Input"],
Cell[141648, 5961, 118, 3, 27, "Input"],
Cell[141769, 5966, 170, 6, 33, "Input"],
Cell[141942, 5974, 59, 1, 27, "Input"],
Cell[142004, 5977, 66, 1, 27, "Input"]
}, Open  ]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[142131, 5985, 61, 1, 66, "Section"],
Cell[142195, 5988, 438, 19, 86, "Text"],
Cell[CellGroupData[{
Cell[142658, 6011, 210, 9, 55, "Subsection"],
Cell[142871, 6022, 2958, 79, 253, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[145866, 6106, 271, 12, 55, "Subsection"],
Cell[CellGroupData[{
Cell[146162, 6122, 54, 0, 42, "Subsubsection"],
Cell[146219, 6124, 227, 6, 59, "Input"],
Cell[146449, 6132, 133, 3, 27, "Input"],
Cell[146585, 6137, 54, 1, 27, "Input"],
Cell[146642, 6140, 991, 31, 54, "Text"],
Cell[147636, 6173, 1560, 45, 72, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[149233, 6223, 45, 0, 42, "Subsubsection"],
Cell[149281, 6225, 885, 31, 35, "Input"],
Cell[150169, 6258, 1444, 47, 79, "Input"],
Cell[151616, 6307, 96, 2, 27, "Input"],
Cell[151715, 6311, 61, 1, 27, "Input"],
Cell[151779, 6314, 66, 0, 32, "Text"],
Cell[151848, 6316, 118, 3, 27, "Input"],
Cell[151969, 6321, 59, 1, 27, "Input"],
Cell[152031, 6324, 124, 3, 27, "Input"],
Cell[152158, 6329, 74, 0, 32, "Text"],
Cell[152235, 6331, 307, 9, 27, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[152579, 6345, 51, 0, 42, "Subsubsection"],
Cell[152633, 6347, 842, 30, 36, "Text"],
Cell[153478, 6379, 788, 28, 35, "Input"],
Cell[154269, 6409, 540, 19, 35, "Input"],
Cell[154812, 6430, 752, 17, 66, "Text"],
Cell[155567, 6449, 788, 25, 54, "Input"],
Cell[156358, 6476, 1480, 51, 52, "Input"],
Cell[157841, 6529, 1248, 44, 35, "Input"],
Cell[159092, 6575, 86, 2, 32, "Text"],
Cell[159181, 6579, 1574, 51, 71, "Input"],
Cell[160758, 6632, 1926, 60, 95, "Input"],
Cell[162687, 6694, 114, 3, 32, "Text"],
Cell[162804, 6699, 779, 23, 59, "Input"],
Cell[163586, 6724, 88, 2, 32, "Text"],
Cell[163677, 6728, 1398, 48, 52, "Input"],
Cell[165078, 6778, 3819, 111, 253, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[168934, 6894, 40, 0, 42, "Subsubsection"],
Cell[168977, 6896, 263, 6, 50, "Text"],
Cell[169243, 6904, 95, 2, 27, "Input"],
Cell[169341, 6908, 255, 5, 50, "Text"],
Cell[169599, 6915, 133, 4, 27, "Input"],
Cell[169735, 6921, 580, 18, 43, "Input"],
Cell[170318, 6941, 643, 19, 43, "Input"],
Cell[170964, 6962, 643, 19, 43, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[171644, 6986, 74, 0, 42, "Subsubsection"],
Cell[171721, 6988, 770, 18, 140, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[172528, 7011, 47, 0, 42, "Subsubsection"],
Cell[172578, 7013, 126, 3, 32, "Text"],
Cell[172707, 7018, 66, 1, 27, "Input"],
Cell[172776, 7021, 112, 2, 27, "Input"],
Cell[172891, 7025, 186, 4, 27, "Input"],
Cell[173080, 7031, 63, 1, 27, "Input"],
Cell[173146, 7034, 4255, 137, 126, "Input"],
Cell[177404, 7173, 217, 4, 50, "Text"],
Cell[177624, 7179, 96, 2, 27, "Input"],
Cell[177723, 7183, 61, 1, 27, "Input"],
Cell[177787, 7186, 118, 3, 27, "Input"],
Cell[177908, 7191, 59, 1, 27, "Input"],
Cell[177970, 7194, 124, 3, 27, "Input"],
Cell[178097, 7199, 59, 1, 27, "Input"],
Cell[178159, 7202, 36, 0, 32, "Text"],
Cell[178198, 7204, 308, 9, 27, "Input"],
Cell[178509, 7215, 66, 1, 27, "Input"],
Cell[178578, 7218, 59, 1, 27, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[178686, 7225, 200, 8, 55, "Subsection"],
Cell[178889, 7235, 3435, 94, 297, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[182361, 7334, 250, 10, 55, "Subsection"],
Cell[CellGroupData[{
Cell[182636, 7348, 54, 0, 42, "Subsubsection"],
Cell[182693, 7350, 204, 5, 59, "Input"],
Cell[182900, 7357, 133, 3, 27, "Input"],
Cell[183036, 7362, 54, 1, 27, "Input"],
Cell[183093, 7365, 990, 31, 54, "Text"],
Cell[184086, 7398, 1560, 45, 72, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[185683, 7448, 45, 0, 42, "Subsubsection"],
Cell[185731, 7450, 878, 31, 35, "Input"],
Cell[186612, 7483, 1386, 45, 79, "Input"],
Cell[188001, 7530, 71, 0, 32, "Text"],
Cell[188075, 7532, 96, 2, 27, "Input"],
Cell[188174, 7536, 61, 1, 27, "Input"],
Cell[188238, 7539, 118, 3, 27, "Input"],
Cell[188359, 7544, 59, 1, 27, "Input"],
Cell[188421, 7547, 124, 3, 27, "Input"],
Cell[188548, 7552, 74, 0, 32, "Text"],
Cell[188625, 7554, 307, 9, 27, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[188969, 7568, 51, 0, 42, "Subsubsection"],
Cell[189023, 7570, 841, 30, 36, "Text"],
Cell[189867, 7602, 786, 28, 35, "Input"],
Cell[190656, 7632, 490, 17, 35, "Input"],
Cell[191149, 7651, 759, 17, 66, "Text"],
Cell[191911, 7670, 736, 23, 54, "Input"],
Cell[192650, 7695, 1426, 49, 52, "Input"],
Cell[194079, 7746, 79, 2, 27, "Input"],
Cell[194161, 7750, 117, 3, 32, "Text"],
Cell[194281, 7755, 1516, 49, 71, "Input"],
Cell[195800, 7806, 2016, 61, 111, "Input"],
Cell[197819, 7869, 114, 3, 32, "Text"],
Cell[197936, 7874, 745, 21, 59, "Input"],
Cell[198684, 7897, 88, 2, 32, "Text"],
Cell[198775, 7901, 1344, 46, 52, "Input"],
Cell[200122, 7949, 3751, 108, 243, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[203910, 8062, 40, 0, 42, "Subsubsection"],
Cell[203953, 8064, 213, 4, 50, "Text"],
Cell[204169, 8070, 95, 2, 27, "Input"],
Cell[204267, 8074, 255, 5, 50, "Text"],
Cell[204525, 8081, 133, 4, 27, "Input"],
Cell[204661, 8087, 193, 7, 33, "Input"],
Cell[204857, 8096, 627, 19, 43, "Input"],
Cell[205487, 8117, 643, 19, 43, "Input"],
Cell[206133, 8138, 47594, 2369, 300, 41901, 2272, "GraphicsData", \
"PostScript", "Input"],
Cell[253730, 10509, 643, 19, 43, "Input"],
Cell[254376, 10530, 654, 19, 43, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[255067, 10554, 74, 0, 42, "Subsubsection"],
Cell[255144, 10556, 915, 21, 158, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[256096, 10582, 47, 0, 42, "Subsubsection"],
Cell[256146, 10584, 150, 4, 31, "Text"],
Cell[256299, 10590, 66, 1, 27, "Input"],
Cell[256368, 10593, 112, 2, 27, "Input"],
Cell[256483, 10597, 186, 4, 27, "Input"],
Cell[256672, 10603, 63, 1, 27, "Input"],
Cell[256738, 10606, 4125, 133, 126, "Input"],
Cell[260866, 10741, 87, 1, 31, "Text"],
Cell[260956, 10744, 77, 1, 31, "Text"],
Cell[261036, 10747, 96, 2, 27, "Input"],
Cell[261135, 10751, 61, 1, 27, "Input"],
Cell[261199, 10754, 82, 1, 31, "Text"],
Cell[261284, 10757, 118, 3, 27, "Input"],
Cell[261405, 10762, 59, 1, 27, "Input"],
Cell[261467, 10765, 124, 3, 27, "Input"],
Cell[261594, 10770, 59, 1, 27, "Input"],
Cell[261656, 10773, 36, 0, 32, "Text"],
Cell[261695, 10775, 308, 9, 27, "Input"],
Cell[262006, 10786, 75, 1, 31, "Text"],
Cell[262084, 10789, 66, 1, 27, "Input"],
Cell[262153, 10792, 59, 1, 27, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[262273, 10800, 62, 1, 66, "Section"],
Cell[262338, 10803, 1180, 42, 182, "Text"],
Cell[263521, 10847, 399, 12, 83, "Text"],
Cell[263923, 10861, 300, 4, 99, "Text"],
Cell[264226, 10867, 396, 13, 67, "Text"],
Cell[CellGroupData[{
Cell[264647, 10884, 170, 7, 54, "Subsection"],
Cell[CellGroupData[{
Cell[264842, 10895, 54, 0, 42, "Subsubsection"],
Cell[264899, 10897, 152, 3, 59, "Input"],
Cell[265054, 10902, 99, 2, 27, "Input"],
Cell[265156, 10906, 244, 6, 68, "Text"],
Cell[265403, 10914, 594, 21, 33, "Input"],
Cell[266000, 10937, 103, 3, 32, "Text"],
Cell[266106, 10942, 218, 6, 43, "Input"],
Cell[266327, 10950, 594, 21, 33, "Input"],
Cell[266924, 10973, 106, 3, 32, "Text"],
Cell[267033, 10978, 246, 8, 54, "Input"],
Cell[267282, 10988, 48, 0, 32, "Text"],
Cell[267333, 10990, 460, 13, 45, "Input"],
Cell[267796, 11005, 460, 13, 45, "Input"],
Cell[268259, 11020, 43, 0, 32, "Text"],
Cell[268305, 11022, 719, 26, 56, "Input"],
Cell[269027, 11050, 225, 4, 29, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[269289, 11059, 45, 0, 42, "Subsubsection"],
Cell[269337, 11061, 712, 26, 33, "Input"],
Cell[270052, 11089, 785, 27, 79, "Input"],
Cell[270840, 11118, 96, 2, 27, "Input"],
Cell[270939, 11122, 63, 1, 27, "Input"],
Cell[271005, 11125, 90, 1, 31, "Text"],
Cell[271098, 11128, 118, 3, 27, "Input"],
Cell[271219, 11133, 124, 3, 27, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[271380, 11141, 51, 0, 42, "Subsubsection"],
Cell[271434, 11143, 720, 24, 34, "Text"],
Cell[272157, 11169, 584, 13, 77, "Text"],
Cell[272744, 11184, 500, 15, 52, "Input"],
Cell[273247, 11201, 457, 13, 52, "Input"],
Cell[273707, 11216, 748, 27, 33, "Input"],
Cell[274458, 11245, 79, 2, 27, "Input"],
Cell[274540, 11249, 121, 6, 32, "Text"],
Cell[274664, 11257, 58, 0, 32, "Text"],
Cell[274725, 11259, 856, 29, 52, "Input"],
Cell[275584, 11290, 64, 0, 32, "Text"],
Cell[275651, 11292, 1119, 36, 85, "Input"],
Cell[276773, 11330, 114, 3, 32, "Text"],
Cell[276890, 11335, 735, 21, 59, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[277662, 11361, 40, 0, 42, "Subsubsection"],
Cell[277705, 11363, 263, 6, 50, "Text"],
Cell[277971, 11371, 95, 2, 27, "Input"],
Cell[278069, 11375, 255, 5, 50, "Text"],
Cell[278327, 11382, 133, 4, 27, "Input"],
Cell[278463, 11388, 523, 16, 43, "Input"],
Cell[278989, 11406, 645, 19, 43, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[279671, 11430, 74, 0, 42, "Subsubsection"],
Cell[279748, 11432, 337, 9, 122, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[280122, 11446, 47, 0, 42, "Subsubsection"],
Cell[280172, 11448, 150, 4, 31, "Text"],
Cell[280325, 11454, 66, 1, 27, "Input"],
Cell[280394, 11457, 112, 2, 27, "Input"],
Cell[280509, 11461, 186, 4, 27, "Input"],
Cell[280698, 11467, 63, 1, 27, "Input"],
Cell[280764, 11470, 783, 27, 88, "Input"],
Cell[281550, 11499, 87, 1, 31, "Text"],
Cell[281640, 11502, 77, 1, 31, "Text"],
Cell[281720, 11505, 96, 2, 27, "Input"],
Cell[281819, 11509, 63, 1, 27, "Input"],
Cell[281885, 11512, 82, 1, 31, "Text"],
Cell[281970, 11515, 118, 3, 27, "Input"],
Cell[282091, 11520, 124, 3, 27, "Input"],
Cell[282218, 11525, 75, 1, 31, "Text"],
Cell[282296, 11528, 66, 1, 27, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[282411, 11535, 170, 7, 38, "Subsection"],
Cell[CellGroupData[{
Cell[282606, 11546, 54, 0, 42, "Subsubsection"],
Cell[282663, 11548, 152, 3, 59, "Input"],
Cell[282818, 11553, 99, 2, 27, "Input"],
Cell[282920, 11557, 244, 6, 68, "Text"],
Cell[283167, 11565, 1087, 38, 42, "Input"],
Cell[284257, 11605, 103, 3, 32, "Text"],
Cell[284363, 11610, 286, 9, 76, "Input"],
Cell[284652, 11621, 1087, 38, 42, "Input"],
Cell[285742, 11661, 106, 3, 32, "Text"],
Cell[285851, 11666, 296, 10, 87, "Input"],
Cell[286150, 11678, 48, 0, 32, "Text"],
Cell[286201, 11680, 460, 13, 45, "Input"],
Cell[286664, 11695, 460, 13, 45, "Input"],
Cell[287127, 11710, 225, 4, 29, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[287389, 11719, 45, 0, 42, "Subsubsection"],
Cell[287437, 11721, 1869, 60, 118, "Input"],
Cell[289309, 11783, 1942, 61, 88, "Input"],
Cell[291254, 11846, 96, 2, 27, "Input"],
Cell[291353, 11850, 63, 1, 27, "Input"],
Cell[291419, 11853, 90, 1, 31, "Text"],
Cell[291512, 11856, 118, 3, 27, "Input"],
Cell[291633, 11861, 124, 3, 27, "Input"],
Cell[291760, 11866, 282, 8, 27, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[292079, 11879, 51, 0, 42, "Subsubsection"],
Cell[292133, 11881, 36, 0, 32, "Text"],
Cell[292172, 11883, 138, 4, 27, "Input"],
Cell[292313, 11889, 161, 5, 27, "Input"],
Cell[292477, 11896, 587, 13, 77, "Text"],
Cell[293067, 11911, 901, 28, 72, "Input"],
Cell[293971, 11941, 926, 29, 72, "Input"],
Cell[294900, 11972, 817, 25, 67, "Input"],
Cell[295720, 11999, 52, 0, 32, "Text"],
Cell[295775, 12001, 1686, 57, 92, "Input"],
Cell[297464, 12060, 54, 1, 27, "Input"],
Cell[297521, 12063, 58, 0, 32, "Text"],
Cell[297582, 12065, 2037, 64, 133, "Input"],
Cell[299622, 12131, 73, 0, 32, "Text"],
Cell[299698, 12133, 2285, 69, 213, "Input"],
Cell[301986, 12204, 114, 3, 32, "Text"],
Cell[302103, 12209, 736, 21, 59, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[302876, 12235, 40, 0, 42, "Subsubsection"],
Cell[302919, 12237, 263, 6, 50, "Text"],
Cell[303185, 12245, 95, 2, 27, "Input"],
Cell[303283, 12249, 255, 5, 50, "Text"],
Cell[303541, 12256, 133, 4, 27, "Input"],
Cell[303677, 12262, 554, 17, 43, "Input"],
Cell[304234, 12281, 647, 19, 43, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[304918, 12305, 74, 0, 42, "Subsubsection"],
Cell[304995, 12307, 398, 9, 122, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[305430, 12321, 47, 0, 42, "Subsubsection"],
Cell[305480, 12323, 150, 4, 31, "Text"],
Cell[305633, 12329, 66, 1, 27, "Input"],
Cell[305702, 12332, 112, 2, 27, "Input"],
Cell[305817, 12336, 186, 4, 27, "Input"],
Cell[306006, 12342, 63, 1, 27, "Input"],
Cell[306072, 12345, 3095, 96, 120, "Input"],
Cell[309170, 12443, 87, 1, 31, "Text"],
Cell[309260, 12446, 77, 1, 31, "Text"],
Cell[309340, 12449, 96, 2, 27, "Input"],
Cell[309439, 12453, 63, 1, 27, "Input"],
Cell[309505, 12456, 82, 1, 31, "Text"],
Cell[309590, 12459, 118, 3, 27, "Input"],
Cell[309711, 12464, 124, 3, 27, "Input"],
Cell[309838, 12469, 282, 8, 27, "Input"],
Cell[310123, 12479, 75, 1, 31, "Text"],
Cell[310201, 12482, 66, 1, 27, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[310316, 12489, 189, 8, 38, "Subsection"],
Cell[CellGroupData[{
Cell[310530, 12501, 54, 0, 42, "Subsubsection"],
Cell[310587, 12503, 170, 4, 59, "Input"],
Cell[310760, 12509, 99, 2, 27, "Input"],
Cell[310862, 12513, 244, 6, 68, "Text"],
Cell[311109, 12521, 640, 22, 27, "Input"],
Cell[311752, 12545, 103, 3, 32, "Text"],
Cell[311858, 12550, 237, 7, 43, "Input"],
Cell[312098, 12559, 640, 22, 27, "Input"],
Cell[312741, 12583, 106, 3, 32, "Text"],
Cell[312850, 12588, 218, 6, 43, "Input"],
Cell[313071, 12596, 48, 0, 32, "Text"],
Cell[313122, 12598, 460, 13, 45, "Input"],
Cell[313585, 12613, 460, 13, 45, "Input"],
Cell[314048, 12628, 225, 4, 29, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[314310, 12637, 45, 0, 42, "Subsubsection"],
Cell[314358, 12639, 1241, 39, 61, "Input"],
Cell[315602, 12680, 1314, 40, 63, "Input"],
Cell[316919, 12722, 96, 2, 27, "Input"],
Cell[317018, 12726, 63, 1, 27, "Input"],
Cell[317084, 12729, 90, 1, 31, "Text"],
Cell[317177, 12732, 118, 3, 27, "Input"],
Cell[317298, 12737, 124, 3, 27, "Input"],
Cell[317425, 12742, 282, 8, 27, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[317744, 12755, 51, 0, 42, "Subsubsection"],
Cell[317798, 12757, 36, 0, 32, "Text"],
Cell[317837, 12759, 138, 4, 27, "Input"],
Cell[317978, 12765, 161, 5, 27, "Input"],
Cell[318142, 12772, 584, 13, 77, "Text"],
Cell[318729, 12787, 1025, 31, 44, "Input"],
Cell[319757, 12820, 713, 21, 44, "Input"],
Cell[320473, 12843, 52, 0, 32, "Text"],
Cell[320528, 12845, 1100, 36, 44, "Input"],
Cell[321631, 12883, 58, 0, 32, "Text"],
Cell[321692, 12885, 1409, 43, 61, "Input"],
Cell[323104, 12930, 1686, 52, 61, "Input"],
Cell[324793, 12984, 74, 0, 32, "Text"],
Cell[324870, 12986, 1636, 48, 77, "Input"],
Cell[326509, 13036, 114, 3, 32, "Text"],
Cell[326626, 13041, 732, 21, 59, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[327395, 13067, 40, 0, 42, "Subsubsection"],
Cell[327438, 13069, 263, 6, 50, "Text"],
Cell[327704, 13077, 95, 2, 27, "Input"],
Cell[327802, 13081, 255, 5, 50, "Text"],
Cell[328060, 13088, 133, 4, 27, "Input"],
Cell[328196, 13094, 574, 18, 43, "Input"],
Cell[328773, 13114, 643, 19, 43, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[329453, 13138, 74, 0, 42, "Subsubsection"],
Cell[329530, 13140, 392, 9, 122, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[329959, 13154, 47, 0, 42, "Subsubsection"],
Cell[330009, 13156, 150, 4, 31, "Text"],
Cell[330162, 13162, 66, 1, 27, "Input"],
Cell[330231, 13165, 112, 2, 27, "Input"],
Cell[330346, 13169, 186, 4, 27, "Input"],
Cell[330535, 13175, 63, 1, 27, "Input"],
Cell[330601, 13178, 2042, 61, 79, "Input"],
Cell[332646, 13241, 87, 1, 31, "Text"],
Cell[332736, 13244, 77, 1, 31, "Text"],
Cell[332816, 13247, 96, 2, 27, "Input"],
Cell[332915, 13251, 63, 1, 27, "Input"],
Cell[332981, 13254, 82, 1, 31, "Text"],
Cell[333066, 13257, 118, 3, 27, "Input"],
Cell[333187, 13262, 124, 3, 27, "Input"],
Cell[333314, 13267, 282, 8, 27, "Input"],
Cell[333599, 13277, 75, 1, 31, "Text"],
Cell[333677, 13280, 66, 1, 27, "Input"]
}, Open  ]]
}, Open  ]]
}, Closed]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

