(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[      8287,        293]
NotebookOptionsPosition[      7252,        257]
NotebookOutlinePosition[      7622,        273]
CellTagsIndexPosition[      7579,        270]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " and Direction Fields"
}], "Subtitle",
 ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Notes and a template for direction fields.  Edit and replace comments with \
your own.\
\>", "Text",
 Background->RGBColor[1, 0, 1]],

Cell[TextData[{
 "Modified from Abel & Braselton Differential Equations with ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " p 60-6"
}], "Text",
 ImageRegion->{{0, 1}, {0, 1}},
 FontSize->13],

Cell["\<\
Execute this next cell before doing anything else if you use the \
PlotVectorField command!!!!!!!\
\>", "Text",
 Background->RGBColor[1, 0, 1]],

Cell["<<Graphics`PlotField`", "Input",
 InitializationCell->True,
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 "This command tells ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to load the package called \"PlotField\".\nMake sure you use the upper \
left key, the one with the tilde ( ~ ), to make the back quote ( ` ).\n\nYou \
make a text cell like this one by choosing \"Cell Style\" from the \"Style\" \
menu.\nYou may then customize it with other Style choices.  When you are \
finished typing, simply click below that cell to get a new input (or text) \
cell.  Trying to hit 'enter' will get a beep since a text cell can't be \
evaluated.  "
}], "Text",
 ImageRegion->{{0, 1}, {0, 1}},
 FontSize->13],

Cell["\<\
Use text to annotate your work.  If you wish, you may do the work first, then \
later insert text.  This is particularly useful if you are running out of \
memory.\
\>", "Text",
 ImageRegion->{{0, 1}, {0, 1}},
 FontSize->13,
 Background->RGBColor[1, 0, 1]],

Cell["\<\
p1 = PlotVectorField[
{1, Exp[-x] - 2 y},
{x, -1., 1.}, {y, -1., 1.}];\
\>", "Input",
 ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Notes you'll need to make changes for other problems.

Also note that long term behavior can't be determined by the independent \
variable only going to 1!\
\>", "Text",
 Background->RGBColor[1, 0, 1]],

Cell[TextData[{
 StyleBox["The above graph is the direction field associated with the \
differential equation \n",
  FontSize->13],
 StyleBox["dy/dx = Exp[-x] - 2 y .\n",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox["Note the syntax is \n",
  FontSize->13],
 "p1 = PlotVectorField[\n      {1, ",
 StyleBox["whatever y' is equal to in x",
  FontSlant->"Italic"],
 "},\n      {x, -1., 1.}, {y, -1., 1.}]\nChange the graphing upper and lower \
limits for x and y as needed.  It is helpful to use decimal values.",
 StyleBox["\n",
  FontSize->13]
}], "Text",
 ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Now we can use the built-in DEsolver, list and graph a few representative \
solution curves.\
\>", "Text",
 Background->RGBColor[1, 0, 1]],

Cell[BoxData[
 RowBox[{"DSolve", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"y", "'"}], "[", "x", "]"}], "+", 
     RowBox[{"2", " ", 
      RowBox[{"y", "[", "x", "]"}]}]}], "\[Equal]", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", "x"}]]}], ",", 
   RowBox[{"y", "[", "x", "]"}], ",", "x"}], "]"}]], "Input"],

Cell["\<\
I copied and pasted the solution part in below, replacing the \"C[1]\" with \
\"a\".\
\>", "Text"],

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", "x"}]], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "2"}], " ", "x"}]], " ", "a"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"a", ",", 
     RowBox[{"-", "2"}], ",", "2", ",", ".5"}], "}"}]}], "]"}]], "Input"],

Cell["\<\
I copied and pasted the resulting list into the Plot command below.  Again, \
long term behavior cannot usually be determined by an x value of 2.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"p2", "=", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "2"}], " ", "x"}]]}], "+", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", "x"}]]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "1.5`"}], " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "2"}], " ", "x"}]]}], "+", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", "x"}]]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "1.`"}], " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "2"}], " ", "x"}]]}], "+", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", "x"}]]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "0.5`"}], " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "2"}], " ", "x"}]]}], "+", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", "x"}]]}], ",", 
       RowBox[{
        RowBox[{"0.`", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "2"}], " ", "x"}]]}], "+", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", "x"}]]}], ",", 
       RowBox[{
        RowBox[{"0.5`", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "2"}], " ", "x"}]]}], "+", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", "x"}]]}], ",", 
       RowBox[{
        RowBox[{"1.`", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "2"}], " ", "x"}]]}], "+", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", "x"}]]}], ",", 
       RowBox[{
        RowBox[{"1.5`", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "2"}], " ", "x"}]]}], "+", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", "x"}]]}], ",", 
       RowBox[{
        RowBox[{"2.`", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "2"}], " ", "x"}]]}], "+", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", "x"}]]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "2"}], ",", "2"}], "}"}]}], "]"}]}], ";"}]], "Input"],

Cell["\<\
Show[p1,p2,
\tPlotRange->{ {-1,1}, {-1,1}},
\tAxes -> True];\
\>", "Input",
 ImageRegion->{{0, 1}, {0, 1}}],

Cell["another view.", "Text"],

Cell["\<\
p3 = PlotVectorField[
{1, Exp[-x] - 2 y},
{x, -2, 2}, {y, -4., 4}];\
\>", "Input",
 ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Show[p3,p2,
\tPlotRange->{ {-2,2}, {-4,4}},
\tAxes -> True];\
\>", "Input",
 ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]]
},
AutoGeneratedPackage->None,
WindowSize->{805, 822},
WindowMargins->{{4, Automatic}, {Automatic, 4}},
FrontEndVersion->"8.0 for Microsoft Windows (64-bit) (November 7, 2010)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 137, 5, 49, "Subtitle"],
Cell[719, 29, 142, 4, 45, "Text"],
Cell[864, 35, 198, 7, 29, "Text"],
Cell[1065, 44, 153, 4, 45, "Text"],
Cell[1221, 50, 97, 2, 31, "Input",
 InitializationCell->True],
Cell[1321, 54, 621, 13, 119, "Text"],
Cell[1945, 69, 266, 7, 63, "Text"],
Cell[2214, 78, 127, 5, 65, "Input"],
Cell[2344, 85, 211, 6, 81, "Text"],
Cell[2558, 93, 599, 17, 156, "Text"],
Cell[3160, 112, 148, 4, 45, "Text"],
Cell[3311, 118, 349, 11, 33, "Input"],
Cell[3663, 131, 108, 3, 29, "Text"],
Cell[3774, 136, 373, 12, 33, "Input"],
Cell[4150, 150, 169, 3, 29, "Text"],
Cell[4322, 155, 2515, 76, 55, "Input"],
Cell[6840, 233, 117, 5, 57, "Input"],
Cell[6960, 240, 29, 0, 32, "Text"],
Cell[6992, 242, 124, 5, 57, "Input"],
Cell[7119, 249, 117, 5, 57, "Input"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

