(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='%s' *)
(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       131,          6]
NotebookDataLength[     11387,        443]
NotebookOptionsPosition[      8257,        321]
NotebookOutlinePosition[      8820,        348]
CellTagsIndexPosition[      8777,        345]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{


Cell[CellGroupData[{Cell["Eigensystems", "Title",
 ImageRegion->{{0., 1.}, {0., 1.}}],

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " commands used:\nEigenvalues\t\t\t\t\t\t\t\t\t\t\t\tEigenvectors\t\t\t\t\t\t\
\t\t\t\tEigensystem\t\t\t\t\t\t\t\t\t\t\t\tIdentityMatrix       MatrixForm\n\
Det\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\tSolve\t\t\t\t\t\t\t\t\t\
\t\t\t\t\t\t\t\t\t\t\t\tNullspace"
}], "Text",
 ImageRegion->{{0., 1.}, {0., 1.}}],

Cell["\<\
Consider the following matrix.  (Boyce&DriPrima 7.5 #17 3rd ed.)\
\>", "Text",
 ImageRegion->{{0., 1.}, {0., 1.}}],

Cell[CellGroupData[{Cell["A = {{3,2,2},{1,4,1},{-2,-4,-1}}", "Input",
 ImageRegion->{{0., 1.}, {0., 1.}},
 FontSize->14],

Cell[OutputFormData["\<\
{{3, 2, 2}, {1, 4, 1}, {-2, -4, -1}}\
\>", "\<\
{{3, 2, 2}, {1, 4, 1}, {-2, -4, -1}}\
\>"], "Output",
 ImageRegion->{{0., 1.}, {0., 1.}},
 FontSize->14]}, Open]],

Cell[CellGroupData[{Cell["Automatic computation", "Section",
 ImageRegion->{{0., 1.}, {0., 1.}}],

Cell[TextData[{
 "You can have ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " automatically compute the eigensystem like this:"
}], "Text",
 ImageRegion->{{0., 1.}, {0., 1.}}],

Cell[CellGroupData[{Cell["Eigenvalues[A]", "Input",
 ImageRegion->{{0., 1.}, {0., 1.}},
 FontSize->14],

Cell[OutputFormData["\<\
{1, 2, 3}\
\>", "\<\
{1, 2, 3}\
\>"], "Output",
 ImageRegion->{{0., 1.}, {0., 1.}},
 FontSize->14]}, Open]],

Cell[CellGroupData[{Cell["Eigenvectors[A]", "Input",
 ImageRegion->{{0., 1.}, {0., 1.}},
 FontSize->14],

Cell[OutputFormData["\<\
{{-1, 0, 1}, {-2, 1, 0}, {0, -1, 1}}\
\>", "\<\
{{-1, 0, 1}, {-2, 1, 0}, {0, -1, 1}}\
\>"], "Output",
 ImageRegion->{{0., 1.}, {0., 1.}},
 FontSize->14]}, Open]],

Cell["or like this", "Text",
 ImageRegion->{{0., 1.}, {0., 1.}}],

Cell[CellGroupData[{Cell["Eigensystem[A]", "Input",
 ImageRegion->{{0., 1.}, {0., 1.}},
 FontSize->14],

Cell[OutputFormData["\<\
{{1, 2, 3}, {{-1, 0, 1}, {-2, 1, 0}, {0, -1, 1}}}\
\>", "\<\
{{1, 2, 3}, {{-1, 0, 1}, {-2, 1, 0}, {0, -1, 1}}}\
\>"], "Output",
 ImageRegion->{{0., 1.}, {0., 1.}},
 FontSize->14]}, Open]]}, Open]],

Cell[CellGroupData[{Cell["Semi-manual calculations", "Section",
 ImageRegion->{{0., 1.}, {0., 1.}}],

Cell["\<\
Alternatively, you can do it somewhat manually.  Defining a function is \
somewhat simpler but unnecessary.\
\>", "Text",
 ImageRegion->{{0., 1.}, {0., 1.}}],

Cell[CellGroupData[{Cell["f[t_] = A - t IdentityMatrix[3]", "Input",
 ImageRegion->{{0., 1.}, {0., 1.}},
 FontSize->14],

Cell[OutputFormData["\<\
{{3 - t, 2, 2}, {1, 4 - t, 1}, {-2, -4, -1 - t}}\
\>", "\<\
{{3 - t, 2, 2}, {1, 4 - t, 1}, {-2, -4, -1 - t}}\
\>"], "Output",
 ImageRegion->{{0., 1.}, {0., 1.}},
 FontSize->14]}, Open]],

Cell["You can view any matrix more naturally.", "Text",
 ImageRegion->{{0., 1.}, {0., 1.}}],

Cell[CellGroupData[{Cell["MatrixForm[%]", "Input",
 ImageRegion->{{0., 1.}, {0., 1.}},
 FontSize->14],

Cell[OutputFormData["\<\
MatrixForm[{{3 - t, 2, 2}, {1, 4 - t, 1}, {-2, -4, -1 - t}}]\
\>", "\<\
3 - t    2        2

1        4 - t    1

-2       -4       -1 - t\
\>"], "Output",
 ImageRegion->{{0., 1.}, {0., 1.}},
 FontSize->14]}, Open]],

Cell["eigenvalues", "Subsection",
 PageBreakAbove->True,
 ImageRegion->{{0., 1.}, {0., 1.}}],

Cell[CellGroupData[{Cell["d = Det[%]", "Input",
 ImageRegion->{{0., 1.}, {0., 1.}},
 FontSize->14],

Cell[OutputFormData["\<\
6 - 11*t + 6*t^2 - t^3\
\>", "\<\
              2    3
6 - 11 t + 6 t  - t\
\>"], "Output",
 ImageRegion->{{0., 1.}, {0., 1.}},
 FontSize->14]}, Open]],

Cell[CellGroupData[{Cell["Solve[d==0,t]", "Input",
 ImageRegion->{{0., 1.}, {0., 1.}},
 FontSize->14],

Cell[OutputFormData["\<\
{{t -> 1}, {t -> 2}, {t -> 3}}\
\>", "\<\
{{t -> 1}, {t -> 2}, {t -> 3}}\
\>"], "Output",
 ImageRegion->{{0., 1.}, {0., 1.}},
 FontSize->14]}, Open]],

Cell[CellGroupData[{Cell["eigenvector as solution to vector equation", "Subsection",
 ImageRegion->{{0., 1.}, {0., 1.}}],

Cell[CellGroupData[{Cell["A2 = f[1]", "Input",
 ImageRegion->{{0., 1.}, {0., 1.}},
 FontSize->14],

Cell[OutputFormData["\<\
{{2, 2, 2}, {1, 3, 1}, {-2, -4, -2}}\
\>", "\<\
{{2, 2, 2}, {1, 3, 1}, {-2, -4, -2}}\
\>"], "Output",
 ImageRegion->{{0., 1.}, {0., 1.}},
 FontSize->14]}, Open]],

Cell[CellGroupData[{Cell["A2 .{x2,y2,z2}", "Input",
 ImageRegion->{{0., 1.}, {0., 1.}},
 FontSize->14],

Cell[OutputFormData["\<\
{2*x2 + 2*y2 + 2*z2, x2 + 3*y2 + z2, -2*x2 - 4*y2 - 2*z2}\
\>", "\<\
{2 x2 + 2 y2 + 2 z2, x2 + 3 y2 + z2, -2 x2 - 4 y2 - 2 z2}\
\>"], "Output",
 ImageRegion->{{0., 1.}, {0., 1.}},
 FontSize->14]}, Open]],

Cell[CellGroupData[{Cell["Solve[A2 .{x2,y2,z2} == {0,0,0},{x2,y2,z2}]", "Input",
 ImageRegion->{{0., 1.}, {0., 1.}},
 FontSize->14],

Cell[OutputFormData["\<\
{{x2 -> -z2, y2 -> 0}}\
\>", "\<\
{{x2 -> -z2, y2 -> 0}}\
\>"], "Output",
 ImageRegion->{{0., 1.}, {0., 1.}},
 FontSize->14]}, Open]],

Cell[TextData[{
 "Note that ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " will allow you to just specify 0 rather than a vector, but I think \
students need to specify it precisely."
}], "Text",
 ImageRegion->{{0., 1.}, {0., 1.}}],

Cell[CellGroupData[{Cell["Solve[A2 .{x2,y2,z2} == 0,{x2,y2,z2}]", "Input",
 ImageRegion->{{0., 1.}, {0., 1.}},
 FontSize->14],

Cell[OutputFormData["\<\
{{x2 -> -z2, y2 -> 0}}\
\>", "\<\
{{x2 -> -z2, y2 -> 0}}\
\>"], "Output",
 ImageRegion->{{0., 1.}, {0., 1.}},
 FontSize->14]}, Open]],

Cell[TextData[{
 StyleBox["eigenvector is ",
  FontFamily->"Times",
  FontWeight->"Plain"],
 "{-z2,0,z2} ",
 StyleBox["or ",
  FontFamily->"Times",
  FontWeight->"Plain"],
 "z2{-1,0,1}",
 StyleBox["  .",
  FontFamily->"Times",
  FontWeight->"Plain"]
}], "Input",
 ImageRegion->{{0., 1.}, {0., 1.}},
 FontSize->14]}, Open]],

Cell[CellGroupData[{Cell["eigenvector via manual Guass elimination", "Subsection",
 ImageRegion->{{0., 1.}, {0., 1.}}],

Cell[CellGroupData[{Cell["mat = f[3]", "Input",
 ImageRegion->{{0., 1.}, {0., 1.}},
 FontSize->14],

Cell[OutputFormData["\<\
{{0, 2, 2}, {1, 1, 1}, {-2, -4, -4}}\
\>", "\<\
{{0, 2, 2}, {1, 1, 1}, {-2, -4, -4}}\
\>"], "Output",
 ImageRegion->{{0., 1.}, {0., 1.}},
 FontSize->14]}, Open]],

Cell[CellGroupData[{Cell["mat2 = {mat[[2]],  mat[[1]],   mat[[3]] + 2 mat[[2]]}", "Input",
 ImageRegion->{{0., 1.}, {0., 1.}},
 FontSize->14],

Cell[OutputFormData["\<\
{{1, 1, 1}, {0, 2, 2}, {0, -2, -2}}\
\>", "\<\
{{1, 1, 1}, {0, 2, 2}, {0, -2, -2}}\
\>"], "Output",
 ImageRegion->{{0., 1.}, {0., 1.}},
 FontSize->14]}, Open]],

Cell[CellGroupData[{Cell["\<\
mat3 = {mat2[[1]] - 1/2 mat2[[2]], 1/2 mat2[[2]],
        mat2[[2]] + mat2[[3]]}\
\>", "Input",
 ImageRegion->{{0., 1.}, {0., 1.}},
 FontSize->14],

Cell[OutputFormData["\<\
{{1, 0, 0}, {0, 1, 1}, {0, 0, 0}}\
\>", "\<\
{{1, 0, 0}, {0, 1, 1}, {0, 0, 0}}\
\>"], "Output",
 ImageRegion->{{0., 1.}, {0., 1.}},
 FontSize->14]}, Open]],

Cell["\<\
Thus, for the eigenvector {x3, y3, z3}, we must have x3 = 0 and y3 = - z3.
That is, {0, -z3, z3} or {0, -1, 1}.\
\>", "Text",
 ImageRegion->{{0., 1.}, {0., 1.}}]}, Open]],

Cell[CellGroupData[{Cell["eigenvector as basis for the nullspace", "Subsection",
 ImageRegion->{{0., 1.}, {0., 1.}}],

Cell[CellGroupData[{Cell["A3 = f[2]", "Input",
 ImageRegion->{{0., 1.}, {0., 1.}},
 FontSize->14],

Cell[OutputFormData["\<\
{{1, 2, 2}, {1, 2, 1}, {-2, -4, -3}}\
\>", "\<\
{{1, 2, 2}, {1, 2, 1}, {-2, -4, -3}}\
\>"], "Output",
 ImageRegion->{{0., 1.}, {0., 1.}},
 FontSize->14]}, Open]],

Cell[CellGroupData[{Cell["NullSpace[A3]", "Input",
 ImageRegion->{{0., 1.}, {0., 1.}},
 FontSize->14],

Cell[OutputFormData["\<\
{{-2, 1, 0}}\
\>", "\<\
{{-2, 1, 0}}\
\>"], "Output",
 ImageRegion->{{0., 1.}, {0., 1.}},
 FontSize->14]}, Open]]}, Open]]}, Open]]}, Open]]
},
WindowToolbars->{},
CellGrouping->Manual,
Evaluatable->False,
CellHorizontalScrolling->False,
PageBreakWithin->Automatic,
ShowCellLabel->True,
ShowCellTags->False,
AspectRatioFixed->True,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
FontFamily->"Times",
FontSize->12,
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (April 28, 2007)",
StyleDefinitions->"Default.nb"
]

(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[576, 22, 65, 1, 70, "Title"],
Cell[644, 25, 385, 8, 70, "Text"],
Cell[1032, 35, 124, 3, 70, "Text"],
Cell[CellGroupData[{
Cell[1179, 40, 100, 2, 70, "Input"],
Cell[1282, 44, 177, 6, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1491, 52, 76, 1, 70, "Section"],
Cell[1570, 55, 183, 6, 70, "Text"],
Cell[CellGroupData[{
Cell[1776, 63, 82, 2, 70, "Input"],
Cell[1861, 67, 123, 6, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2016, 75, 83, 2, 70, "Input"],
Cell[2102, 79, 177, 6, 70, "Output"]
}, Open  ]],
Cell[2291, 87, 64, 1, 70, "Text"],
Cell[CellGroupData[{
Cell[2378, 90, 82, 2, 70, "Input"],
Cell[2463, 94, 203, 6, 70, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2707, 102, 79, 1, 70, "Section"],
Cell[2789, 105, 167, 4, 70, "Text"],
Cell[CellGroupData[{
Cell[2979, 111, 99, 2, 70, "Input"],
Cell[3081, 115, 201, 6, 70, "Output"]
}, Open  ]],
Cell[3294, 123, 91, 1, 70, "Text"],
Cell[CellGroupData[{
Cell[3408, 126, 81, 2, 70, "Input"],
Cell[3492, 130, 231, 10, 70, "Output"]
}, Open  ]],
Cell[3735, 142, 92, 2, 70, "Subsection",
 PageBreakAbove->True],
Cell[CellGroupData[{
Cell[3850, 146, 78, 2, 70, "Input"],
Cell[3931, 150, 167, 7, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4130, 159, 81, 2, 70, "Input"],
Cell[4214, 163, 165, 6, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4411, 171, 100, 1, 70, "Subsection"],
Cell[CellGroupData[{
Cell[4534, 174, 77, 2, 70, "Input"],
Cell[4614, 178, 177, 6, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4823, 186, 82, 2, 70, "Input"],
Cell[4908, 190, 219, 6, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5159, 198, 111, 2, 70, "Input"],
Cell[5273, 202, 149, 6, 70, "Output"]
}, Open  ]],
Cell[5434, 210, 239, 7, 70, "Text"],
Cell[CellGroupData[{
Cell[5696, 219, 105, 2, 70, "Input"],
Cell[5804, 223, 149, 6, 70, "Output"]
}, Open  ]],
Cell[5965, 231, 313, 14, 70, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6310, 247, 98, 1, 70, "Subsection"],
Cell[CellGroupData[{
Cell[6431, 250, 78, 2, 70, "Input"],
Cell[6512, 254, 177, 6, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6721, 262, 121, 2, 70, "Input"],
Cell[6845, 266, 175, 6, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7052, 274, 156, 5, 70, "Input"],
Cell[7211, 281, 171, 6, 70, "Output"]
}, Open  ]],
Cell[7394, 289, 171, 4, 70, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7597, 295, 96, 1, 70, "Subsection"],
Cell[CellGroupData[{
Cell[7716, 298, 77, 2, 70, "Input"],
Cell[7796, 302, 177, 6, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[8005, 310, 81, 2, 70, "Input"],
Cell[8089, 314, 129, 6, 70, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)
