(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    107340,       2836]
NotebookOptionsPosition[    102351,       2671]
NotebookOutlinePosition[    102884,       2691]
CellTagsIndexPosition[    102841,       2688]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Frobenius Solution to Coupled Differential Equations", "Title"],

Cell["Paul Abbott", "Text",
 CellMargins->{{Inherited, Inherited}, {Inherited, 40}}],

Cell[TextData[{
 "School of Physics\nThe University of Western Australia\n35 Stirling Highway\
\nCrawley WA 6009, Australia",
 "\n",
 "\n",
 ButtonBox["paul@physics.uwa.edu.au",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["mailto:paul@physics.uwa.edu.au"], None}],
 "\n",
 ButtonBox["physics.uwa.edu.au/~paul",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://physics.uwa.edu.au/~paul"], None}]
}], "Text"],

Cell[CellGroupData[{

Cell["Equations", "Section"],

Cell["Here are your coupled differential equations:", "Text"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"eqns", "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          SuperscriptBox["u", "\[Prime]\[Prime]",
           MultilineFunction->None], "(", "s", ")"}], " ", 
         SuperscriptBox["s", "2"]}], "+", 
        RowBox[{
         RowBox[{
          SuperscriptBox["u", "\[Prime]",
           MultilineFunction->None], "(", "s", ")"}], " ", "s"}], "-", 
        RowBox[{
         SuperscriptBox["\[Mu]", "2"], " ", 
         RowBox[{"u", "(", "s", ")"}]}], "+", 
        RowBox[{
         SuperscriptBox["\[Mu]", "2"], " ", 
         RowBox[{"cot", "(", "\[Alpha]", ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"s", " ", "\[Nu]", " ", 
            RowBox[{
             SuperscriptBox["w", "\[Prime]",
              MultilineFunction->None], "(", "s", ")"}]}], "-", 
           RowBox[{"w", "(", "s", ")"}]}], ")"}]}]}], "\[LongEqual]", "0"}], 
      ",", 
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox["\[Eta]", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["s", "2"], " ", 
            RowBox[{
             SuperscriptBox["w", "\[Prime]\[Prime]",
              MultilineFunction->None], "(", "s", ")"}]}], "-", 
           RowBox[{"s", " ", 
            RowBox[{
             SuperscriptBox["w", "\[Prime]",
              MultilineFunction->None], "(", "s", ")"}]}]}], ")"}]}], "-", 
        RowBox[{
         RowBox[{"cot", "(", "\[Alpha]", ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"\[Nu]", " ", 
            RowBox[{
             SuperscriptBox["u", "\[Prime]",
              MultilineFunction->None], "(", "s", ")"}], " ", 
            SuperscriptBox["s", "3"]}], "+", 
           RowBox[{
            RowBox[{"cot", "(", "\[Alpha]", ")"}], " ", 
            RowBox[{"w", "(", "s", ")"}], " ", 
            SuperscriptBox["s", "2"]}], "+", 
           RowBox[{"u", "(", "s", ")"}]}], ")"}]}]}], "\[LongEqual]", "0"}]}],
      "}"}]}], ";"}], TraditionalForm]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Numerical Example", "Section"],

Cell["As a particular example, for the parameters", "Text"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"params", "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"\[Alpha]", "\[Rule]", 
       FormBox[
        FractionBox["\[Pi]", "4"],
        TraditionalForm]}], ",", 
      RowBox[{"\[Nu]", "\[Rule]", 
       FractionBox["1", "3"]}], ",", 
      RowBox[{"\[Mu]", "\[Rule]", "3"}], ",", 
      RowBox[{"\[Eta]", "\[Rule]", "1"}]}], "}"}]}], ";"}], 
  TraditionalForm]], "Input"],

Cell[TextData[{
 "here is the numerical solution of the coupled system for a particular set \
of initial (final) conditions over ",
 Cell[BoxData[
  FormBox[
   RowBox[{"0", "<", "s", "\[LessEqual]", "1"}], TraditionalForm]]],
 "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{"nsoln", "=", 
   RowBox[{"First", "@", 
    RowBox[{"NDSolve", "[", 
     RowBox[{
      RowBox[{"Join", "[", 
       RowBox[{
        RowBox[{"eqns", "/.", "params"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"u", "(", "1", ")"}], "\[Equal]", "4"}], ",", 
          RowBox[{
           RowBox[{
            SuperscriptBox["u", "\[Prime]"], "(", "1", ")"}], "\[Equal]", 
           "5"}], ",", 
          RowBox[{
           RowBox[{"w", "(", "1", ")"}], "\[Equal]", "6"}], ",", 
          RowBox[{
           RowBox[{
            SuperscriptBox["w", "\[Prime]"], "(", "1", ")"}], "\[Equal]", 
           RowBox[{"-", "1"}]}]}], "}"}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"u", ",", "w"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"s", ",", 
        SuperscriptBox["10", 
         RowBox[{"-", "30"}]], ",", "1"}], "}"}]}], "]"}]}]}], 
  TraditionalForm]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"u", "\[Rule]", 
    TagBox[
     RowBox[{"InterpolatingFunction", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"9.999999999999999`*^-31", ",", "1.`"}], "}"}], "}"}], 
       ",", "\<\"<>\"\>"}], "]"}],
     False,
     Editable->False]}], ",", 
   RowBox[{"w", "\[Rule]", 
    TagBox[
     RowBox[{"InterpolatingFunction", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"9.999999999999999`*^-31", ",", "1.`"}], "}"}], "}"}], 
       ",", "\<\"<>\"\>"}], "]"}],
     False,
     Editable->False]}]}], "}"}]], "Output",
 CellChangeTimes->{3.43520761759375*^9}]
}, Open  ]],

Cell[TextData[{
 "These solutions are singular at ",
 Cell[BoxData[
  FormBox[
   RowBox[{"s", "=", "0"}], TraditionalForm]]],
 ". For example, here are the values of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", "(", "0.01", ")"}], ",", 
     RowBox[{"w", "(", "0.01", ")"}]}], "}"}], TraditionalForm]]],
 "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", "(", "0.01", ")"}], ",", 
     RowBox[{"w", "(", "0.01", ")"}]}], "}"}], "/.", "nsoln"}], 
  TraditionalForm]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"8.782849819711367`*^6", ",", "532482.906779215`"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.4352076196875*^9}]
}, Open  ]],

Cell[TextData[{
 "Later analysis shows that the maximal singulartity is of the form ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["s", "\[Sigma]"], TraditionalForm]]],
 " where, for this particular set of parameters, ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Sigma]", "\[TildeTilde]", 
    RowBox[{"-", "3.18194"}]}], TraditionalForm]]],
 ". Dividing the solutions by this singular term leads to finite behaviour at \
",
 Cell[BoxData[
  FormBox[
   RowBox[{"s", "=", "0"}], TraditionalForm]]],
 ". Here are the initial values of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"f", "(", "0", ")"}], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"g", "(", "0", ")"}], TraditionalForm]]],
 "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{"initial", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["s", "3.18194"], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"u", "(", "s", ")"}], ",", 
        RowBox[{"w", "(", "s", ")"}]}], "}"}]}], "/.", 
     RowBox[{"s", "\[Rule]", 
      SuperscriptBox["10", 
       RowBox[{"-", "30"}]]}]}], "/.", "nsoln"}]}], TraditionalForm]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"3.8004857983220144`", ",", "0.23049101969181326`"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.43520762159375*^9}]
}, Open  ]],

Cell[TextData[{
 "Here is a plot of ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["s", "\[Sigma]"], 
    RowBox[{"u", "(", "s", ")"}]}], TraditionalForm]]],
 " (",
 StyleBox["\[LongDash]",
  FontColor->RGBColor[1, 0, 0]],
 ") and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["s", "\[Sigma]"], 
    RowBox[{"w", "(", "s", ")"}]}], TraditionalForm]]],
 " (",
 StyleBox["\[LongDash]",
  FontColor->RGBColor[0, 0, 1]],
 ")."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{"nplot", "=", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"Evaluate", "[", 
      RowBox[{
       RowBox[{
        SuperscriptBox["s", "3.18194"], 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"u", "(", "s", ")"}], ",", 
          RowBox[{"w", "(", "s", ")"}]}], "}"}]}], "/.", "nsoln"}], "]"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"s", ",", "0", ",", "1"}], "}"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Red", ",", "Blue"}], "}"}]}]}], "]"}]}], 
  TraditionalForm]], "Input"],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[1, 0, 0], LineBox[CompressedData["
1:eJwV13c81G8cAHB0Z+ZkFUq2JEklGurzWBGyKZGdQiRlJRkRPzKTCkXSoERG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     "]]}, 
   {RGBColor[0, 0, 1], LineBox[CompressedData["
1:eJwV13c4le8fB3AjksrKiIgiLaUhIvU+RAMNpSG+SkRmKt9jNOxRFC0rGjRQ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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{0, 1}, {0., 5.999999630782868}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.435207623640625*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Separable Solution", "Section"],

Cell[TextData[{
 "A trivial separable solution is obtained if ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"cot", "(", "\[Alpha]", ")"}], "\[Rule]", "0"}], 
   TraditionalForm]]],
 ","
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{"DSolve", "[", 
   RowBox[{
    RowBox[{"eqns", "/.", 
     RowBox[{
      RowBox[{"cot", "(", "\[Alpha]", ")"}], "\[Rule]", "0"}]}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"u", "(", "s", ")"}], ",", 
      RowBox[{"w", "(", "s", ")"}]}], "}"}], ",", "s"}], "]"}], 
  TraditionalForm]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"u", "[", "s", "]"}], "\[Rule]", 
     RowBox[{
      RowBox[{
       RowBox[{"C", "[", "1", "]"}], " ", 
       RowBox[{"Cosh", "[", 
        RowBox[{"\[Mu]", " ", 
         RowBox[{"Log", "[", "s", "]"}]}], "]"}]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"C", "[", "2", "]"}], " ", 
       RowBox[{"Sinh", "[", 
        RowBox[{"\[Mu]", " ", 
         RowBox[{"Log", "[", "s", "]"}]}], "]"}]}]}]}], ",", 
    RowBox[{
     RowBox[{"w", "[", "s", "]"}], "\[Rule]", 
     RowBox[{
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox["s", "2"], " ", 
       RowBox[{"C", "[", "3", "]"}]}], "+", 
      RowBox[{"C", "[", "4", "]"}]}]}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.435207633203125*^9}]
}, Open  ]],

Cell["and the hyperbolic trig functions reduce to simple powers.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"u", "(", "s", ")"}], "/.", 
    RowBox[{"First", "[", "%", "]"}]}], "//", "TrigToExp"}], 
  TraditionalForm]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox["s", 
    RowBox[{"-", "\[Mu]"}]], " ", 
   RowBox[{"C", "[", "1", "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox["s", "\[Mu]"], " ", 
   RowBox[{"C", "[", "1", "]"}]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
   SuperscriptBox["s", 
    RowBox[{"-", "\[Mu]"}]], " ", 
   RowBox[{"C", "[", "2", "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
   SuperscriptBox["s", "\[Mu]"], " ", 
   RowBox[{"C", "[", "2", "]"}]}]}]], "Output",
 CellChangeTimes->{3.435207636203125*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Frobenius Solution", "Section"],

Cell[TextData[{
 "Let's use the method of Frobenius, assuming that the series solutions are \
of the form ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"u", "(", "s", ")"}], "=", 
    RowBox[{
     RowBox[{
      SuperscriptBox["s", "\[Sigma]"], 
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"k", "=", "0"}], "\[Infinity]"], 
       RowBox[{
        SubscriptBox["u", "k"], 
        SuperscriptBox["s", "k"]}]}]}], "=", 
     RowBox[{
      SuperscriptBox["s", "\[Sigma]"], 
      RowBox[{"f", "(", "s", ")"}]}]}]}], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"w", "(", "s", ")"}], "=", 
    RowBox[{
     RowBox[{
      SuperscriptBox["s", "\[Sigma]"], 
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"k", "=", "0"}], "\[Infinity]"], 
       RowBox[{
        SubscriptBox["w", "k"], 
        SuperscriptBox["s", "k"]}]}]}], "=", 
     RowBox[{
      SuperscriptBox["s", "\[Sigma]"], 
      RowBox[{"g", "(", "s", ")"}]}]}]}], TraditionalForm]]],
 ". These (truncated) series expansions can implemented as follows:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"u", "(", "s_", ")"}], "=", 
   RowBox[{"Series", "[", 
    RowBox[{
     RowBox[{
      SuperscriptBox["s", "\[Sigma]"], 
      RowBox[{"f", "(", "s", ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"s", ",", "0", ",", "7"}], "}"}]}], "]"}]}], 
  TraditionalForm]], "Input"],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["s", "\[Sigma]"], " ", 
  RowBox[{"(", 
   InterpretationBox[
    RowBox[{
     RowBox[{"f", "[", "0", "]"}], "+", 
     RowBox[{
      RowBox[{
       SuperscriptBox["f", "\[Prime]",
        MultilineFunction->None], "[", "0", "]"}], " ", "s"}], "+", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{
       SuperscriptBox["f", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "0", "]"}], " ", 
      SuperscriptBox["s", "2"]}], "+", 
     RowBox[{
      FractionBox["1", "6"], " ", 
      RowBox[{
       SuperscriptBox["f", 
        TagBox[
         RowBox[{"(", "3", ")"}],
         Derivative],
        MultilineFunction->None], "[", "0", "]"}], " ", 
      SuperscriptBox["s", "3"]}], "+", 
     RowBox[{
      FractionBox["1", "24"], " ", 
      RowBox[{
       SuperscriptBox["f", 
        TagBox[
         RowBox[{"(", "4", ")"}],
         Derivative],
        MultilineFunction->None], "[", "0", "]"}], " ", 
      SuperscriptBox["s", "4"]}], "+", 
     RowBox[{
      FractionBox["1", "120"], " ", 
      RowBox[{
       SuperscriptBox["f", 
        TagBox[
         RowBox[{"(", "5", ")"}],
         Derivative],
        MultilineFunction->None], "[", "0", "]"}], " ", 
      SuperscriptBox["s", "5"]}], "+", 
     RowBox[{
      FractionBox["1", "720"], " ", 
      RowBox[{
       SuperscriptBox["f", 
        TagBox[
         RowBox[{"(", "6", ")"}],
         Derivative],
        MultilineFunction->None], "[", "0", "]"}], " ", 
      SuperscriptBox["s", "6"]}], "+", 
     FractionBox[
      RowBox[{
       RowBox[{
        SuperscriptBox["f", 
         TagBox[
          RowBox[{"(", "7", ")"}],
          Derivative],
         MultilineFunction->None], "[", "0", "]"}], " ", 
       SuperscriptBox["s", "7"]}], "5040"], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "s", "]"}], "8"],
      SeriesData[$CellContext`s, 0, {}, 0, 8, 1],
      Editable->False]}],
    SeriesData[$CellContext`s, 0, {
      $CellContext`f[0], 
      Derivative[1][$CellContext`f][0], Rational[1, 2] 
      Derivative[2][$CellContext`f][0], Rational[1, 6] 
      Derivative[3][$CellContext`f][0], Rational[1, 24] 
      Derivative[4][$CellContext`f][0], Rational[1, 120] 
      Derivative[5][$CellContext`f][0], Rational[1, 720] 
      Derivative[6][$CellContext`f][0], Rational[1, 5040] 
      Derivative[7][$CellContext`f][0]}, 0, 8, 1],
    Editable->False], ")"}]}]], "Output",
 CellChangeTimes->{3.435207639359375*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"w", "(", "s_", ")"}], "=", 
   RowBox[{"Series", "[", 
    RowBox[{
     RowBox[{
      SuperscriptBox["s", "\[Sigma]"], 
      RowBox[{"g", "(", "s", ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"s", ",", "0", ",", "7"}], "}"}]}], "]"}]}], 
  TraditionalForm]], "Input"],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["s", "\[Sigma]"], " ", 
  RowBox[{"(", 
   InterpretationBox[
    RowBox[{
     RowBox[{"g", "[", "0", "]"}], "+", 
     RowBox[{
      RowBox[{
       SuperscriptBox["g", "\[Prime]",
        MultilineFunction->None], "[", "0", "]"}], " ", "s"}], "+", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{
       SuperscriptBox["g", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "0", "]"}], " ", 
      SuperscriptBox["s", "2"]}], "+", 
     RowBox[{
      FractionBox["1", "6"], " ", 
      RowBox[{
       SuperscriptBox["g", 
        TagBox[
         RowBox[{"(", "3", ")"}],
         Derivative],
        MultilineFunction->None], "[", "0", "]"}], " ", 
      SuperscriptBox["s", "3"]}], "+", 
     RowBox[{
      FractionBox["1", "24"], " ", 
      RowBox[{
       SuperscriptBox["g", 
        TagBox[
         RowBox[{"(", "4", ")"}],
         Derivative],
        MultilineFunction->None], "[", "0", "]"}], " ", 
      SuperscriptBox["s", "4"]}], "+", 
     RowBox[{
      FractionBox["1", "120"], " ", 
      RowBox[{
       SuperscriptBox["g", 
        TagBox[
         RowBox[{"(", "5", ")"}],
         Derivative],
        MultilineFunction->None], "[", "0", "]"}], " ", 
      SuperscriptBox["s", "5"]}], "+", 
     RowBox[{
      FractionBox["1", "720"], " ", 
      RowBox[{
       SuperscriptBox["g", 
        TagBox[
         RowBox[{"(", "6", ")"}],
         Derivative],
        MultilineFunction->None], "[", "0", "]"}], " ", 
      SuperscriptBox["s", "6"]}], "+", 
     FractionBox[
      RowBox[{
       RowBox[{
        SuperscriptBox["g", 
         TagBox[
          RowBox[{"(", "7", ")"}],
          Derivative],
         MultilineFunction->None], "[", "0", "]"}], " ", 
       SuperscriptBox["s", "7"]}], "5040"], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "s", "]"}], "8"],
      SeriesData[$CellContext`s, 0, {}, 0, 8, 1],
      Editable->False]}],
    SeriesData[$CellContext`s, 0, {
      $CellContext`g[0], 
      Derivative[1][$CellContext`g][0], Rational[1, 2] 
      Derivative[2][$CellContext`g][0], Rational[1, 6] 
      Derivative[3][$CellContext`g][0], Rational[1, 24] 
      Derivative[4][$CellContext`g][0], Rational[1, 120] 
      Derivative[5][$CellContext`g][0], Rational[1, 720] 
      Derivative[6][$CellContext`g][0], Rational[1, 5040] 
      Derivative[7][$CellContext`g][0]}, 0, 8, 1],
    Editable->False], ")"}]}]], "Output",
 CellChangeTimes->{3.435207642140625*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Solving the first equation", "Subsection"],

Cell[TextData[{
 "Solving the first equation for the undetermined coefficients ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["g", 
     TagBox[
      RowBox[{"(", "n", ")"}],
      Derivative],
     MultilineFunction->None], "(", "0", ")"}], TraditionalForm]]],
 " yields"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{"gsoln", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"ExpandAll", "[", 
         FractionBox[
          RowBox[{"eqns", "\[LeftDoubleBracket]", 
           RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}], 
          SuperscriptBox["s", "\[Sigma]"]], "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{
          SuperscriptBox["g", 
           TagBox[
            RowBox[{"(", "n", ")"}],
            Derivative],
           MultilineFunction->None], "(", "0", ")"}], ",", 
         RowBox[{"{", 
          RowBox[{"n", ",", "0", ",", "7"}], "}"}]}], "]"}]}], "]"}], "//", 
     "Simplify"}], "//", "First"}]}], TraditionalForm]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"g", "[", "0", "]"}], "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["\[Mu]", "2"], "-", 
        SuperscriptBox["\[Sigma]", "2"]}], ")"}], " ", 
      RowBox[{"f", "[", "0", "]"}], " ", 
      RowBox[{"Tan", "[", "\[Alpha]", "]"}]}], 
     RowBox[{
      SuperscriptBox["\[Mu]", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{"\[Nu]", " ", "\[Sigma]"}]}], ")"}]}]]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["g", "\[Prime]",
      MultilineFunction->None], "[", "0", "]"}], "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["\[Mu]", "2"], "-", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "+", "\[Sigma]"}], ")"}], "2"]}], ")"}], " ", 
      RowBox[{"Tan", "[", "\[Alpha]", "]"}], " ", 
      RowBox[{
       SuperscriptBox["f", "\[Prime]",
        MultilineFunction->None], "[", "0", "]"}]}], 
     RowBox[{
      SuperscriptBox["\[Mu]", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "\[Nu]", "+", 
        RowBox[{"\[Nu]", " ", "\[Sigma]"}]}], ")"}]}]]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["g", "\[Prime]\[Prime]",
      MultilineFunction->None], "[", "0", "]"}], "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["\[Mu]", "2"], "-", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"2", "+", "\[Sigma]"}], ")"}], "2"]}], ")"}], " ", 
      RowBox[{"Tan", "[", "\[Alpha]", "]"}], " ", 
      RowBox[{
       SuperscriptBox["f", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "0", "]"}]}], 
     RowBox[{
      SuperscriptBox["\[Mu]", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{"\[Nu]", " ", 
         RowBox[{"(", 
          RowBox[{"2", "+", "\[Sigma]"}], ")"}]}]}], ")"}]}]]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["g", 
      TagBox[
       RowBox[{"(", "3", ")"}],
       Derivative],
      MultilineFunction->None], "[", "0", "]"}], "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["\[Mu]", "2"], "-", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"3", "+", "\[Sigma]"}], ")"}], "2"]}], ")"}], " ", 
      RowBox[{"Tan", "[", "\[Alpha]", "]"}], " ", 
      RowBox[{
       SuperscriptBox["f", 
        TagBox[
         RowBox[{"(", "3", ")"}],
         Derivative],
        MultilineFunction->None], "[", "0", "]"}]}], 
     RowBox[{
      SuperscriptBox["\[Mu]", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{"\[Nu]", " ", 
         RowBox[{"(", 
          RowBox[{"3", "+", "\[Sigma]"}], ")"}]}]}], ")"}]}]]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["g", 
      TagBox[
       RowBox[{"(", "4", ")"}],
       Derivative],
      MultilineFunction->None], "[", "0", "]"}], "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["\[Mu]", "2"], "-", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"4", "+", "\[Sigma]"}], ")"}], "2"]}], ")"}], " ", 
      RowBox[{"Tan", "[", "\[Alpha]", "]"}], " ", 
      RowBox[{
       SuperscriptBox["f", 
        TagBox[
         RowBox[{"(", "4", ")"}],
         Derivative],
        MultilineFunction->None], "[", "0", "]"}]}], 
     RowBox[{
      SuperscriptBox["\[Mu]", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{"\[Nu]", " ", 
         RowBox[{"(", 
          RowBox[{"4", "+", "\[Sigma]"}], ")"}]}]}], ")"}]}]]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["g", 
      TagBox[
       RowBox[{"(", "5", ")"}],
       Derivative],
      MultilineFunction->None], "[", "0", "]"}], "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["\[Mu]", "2"], "-", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"5", "+", "\[Sigma]"}], ")"}], "2"]}], ")"}], " ", 
      RowBox[{"Tan", "[", "\[Alpha]", "]"}], " ", 
      RowBox[{
       SuperscriptBox["f", 
        TagBox[
         RowBox[{"(", "5", ")"}],
         Derivative],
        MultilineFunction->None], "[", "0", "]"}]}], 
     RowBox[{
      SuperscriptBox["\[Mu]", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{"\[Nu]", " ", 
         RowBox[{"(", 
          RowBox[{"5", "+", "\[Sigma]"}], ")"}]}]}], ")"}]}]]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["g", 
      TagBox[
       RowBox[{"(", "6", ")"}],
       Derivative],
      MultilineFunction->None], "[", "0", "]"}], "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["\[Mu]", "2"], "-", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"6", "+", "\[Sigma]"}], ")"}], "2"]}], ")"}], " ", 
      RowBox[{"Tan", "[", "\[Alpha]", "]"}], " ", 
      RowBox[{
       SuperscriptBox["f", 
        TagBox[
         RowBox[{"(", "6", ")"}],
         Derivative],
        MultilineFunction->None], "[", "0", "]"}]}], 
     RowBox[{
      SuperscriptBox["\[Mu]", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{"\[Nu]", " ", 
         RowBox[{"(", 
          RowBox[{"6", "+", "\[Sigma]"}], ")"}]}]}], ")"}]}]]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["g", 
      TagBox[
       RowBox[{"(", "7", ")"}],
       Derivative],
      MultilineFunction->None], "[", "0", "]"}], "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["\[Mu]", "2"], "-", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"7", "+", "\[Sigma]"}], ")"}], "2"]}], ")"}], " ", 
      RowBox[{"Tan", "[", "\[Alpha]", "]"}], " ", 
      RowBox[{
       SuperscriptBox["f", 
        TagBox[
         RowBox[{"(", "7", ")"}],
         Derivative],
        MultilineFunction->None], "[", "0", "]"}]}], 
     RowBox[{
      SuperscriptBox["\[Mu]", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{"\[Nu]", " ", 
         RowBox[{"(", 
          RowBox[{"7", "+", "\[Sigma]"}], ")"}]}]}], ")"}]}]]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.4352076478125*^9}]
}, Open  ]],

Cell["Clearly, in general one has that", "Text"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FractionBox[
     RowBox[{"tan", "(", "\[Alpha]", ")"}], 
     SuperscriptBox["\[Mu]", "2"]], 
    RowBox[{
     SuperscriptBox["f", 
      TagBox[
       RowBox[{"(", "n", ")"}],
       Derivative],
      MultilineFunction->None], "(", "0", ")"}]}], "\[LongEqual]", 
   RowBox[{
    FractionBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Nu]", " ", 
        RowBox[{"(", 
         RowBox[{"\[Sigma]", "+", "n"}], ")"}]}], "-", "1"}], ")"}], 
     RowBox[{
      SuperscriptBox["\[Mu]", "2"], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"\[Sigma]", "+", "n"}], ")"}], "2"]}]], 
    RowBox[{
     RowBox[{
      SuperscriptBox["g", 
       TagBox[
        RowBox[{"(", "n", ")"}],
        Derivative],
       MultilineFunction->None], "(", "0", ")"}], "."}]}]}], 
  TraditionalForm]], "DisplayFormula"],

Cell["Partial fraction decomposition of the right-hand side,", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{"Apart", "[", 
   FractionBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{"\[Nu]", " ", 
       RowBox[{"(", 
        RowBox[{"\[Sigma]", "+", "n"}], ")"}]}], "-", "1"}], ")"}], 
    RowBox[{
     SuperscriptBox["\[Mu]", "2"], "-", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"\[Sigma]", "+", "n"}], ")"}], "2"]}]], "]"}], 
  TraditionalForm]], "Input"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{"1", "-", 
    RowBox[{"\[Mu]", " ", "\[Nu]"}]}], 
   RowBox[{"2", " ", "\[Mu]", " ", 
    RowBox[{"(", 
     RowBox[{"n", "-", "\[Mu]", "+", "\[Sigma]"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{
    RowBox[{"-", "1"}], "-", 
    RowBox[{"\[Mu]", " ", "\[Nu]"}]}], 
   RowBox[{"2", " ", "\[Mu]", " ", 
    RowBox[{"(", 
     RowBox[{"n", "+", "\[Mu]", "+", "\[Sigma]"}], ")"}]}]]}]], "Output",
 CellChangeTimes->{3.43520765525*^9}]
}, Open  ]],

Cell["and using", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"1", "-", 
        RowBox[{"\[Mu]", " ", "\[Nu]"}]}], 
       RowBox[{"2", "\[Mu]"}]], 
      SuperscriptBox["x", 
       RowBox[{"\[Mu]", "-", "\[Sigma]"}]], 
      RowBox[{"\[Integral]", 
       RowBox[{
        SuperscriptBox["x", 
         RowBox[{"n", "+", "\[Sigma]", "-", "\[Mu]", "-", "1"}]], 
        RowBox[{"\[DifferentialD]", "x"}]}]}]}], "-", 
     RowBox[{
      FractionBox[
       RowBox[{"1", "+", 
        RowBox[{"\[Mu]", " ", "\[Nu]"}]}], 
       RowBox[{"2", "\[Mu]"}]], 
      SuperscriptBox["x", 
       RowBox[{
        RowBox[{"-", "\[Sigma]"}], "-", "\[Mu]"}]], 
      RowBox[{"\[Integral]", 
       RowBox[{
        SuperscriptBox["x", 
         RowBox[{"n", "+", "\[Sigma]", "+", "\[Mu]", "-", "1"}]], 
        RowBox[{"\[DifferentialD]", "x"}]}]}]}]}], "//", "Together"}], "//", 
   "FullSimplify"}], TraditionalForm]], "Input"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["x", "n"], " ", 
   RowBox[{"(", 
    RowBox[{"1", "-", 
     RowBox[{"\[Nu]", " ", 
      RowBox[{"(", 
       RowBox[{"n", "+", "\[Sigma]"}], ")"}]}]}], ")"}]}], 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"n", "-", "\[Mu]", "+", "\[Sigma]"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"n", "+", "\[Mu]", "+", "\[Sigma]"}], ")"}]}]]], "Output",
 CellChangeTimes->{3.4352076581875*^9}]
}, Open  ]],

Cell["shows that", "Text"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"f", "(", "s", ")"}], "=", 
   RowBox[{"\[Mu]", " ", 
    RowBox[{"cot", "(", "\[Alpha]", ")"}], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       FractionBox[
        RowBox[{"1", "-", 
         RowBox[{"\[Mu]", " ", "\[Nu]"}]}], "2"], 
       SuperscriptBox["s", 
        RowBox[{"\[Mu]", "-", "\[Sigma]"}]], 
       RowBox[{
        SuperscriptBox["\[Integral]", "s"], 
        RowBox[{
         RowBox[{"g", "(", "x", ")"}], 
         SuperscriptBox["x", 
          RowBox[{"\[Sigma]", "-", "\[Mu]", "-", "1"}]], 
         RowBox[{"\[DifferentialD]", "x"}]}]}]}], "-", 
      RowBox[{
       FractionBox[
        RowBox[{"1", "+", 
         RowBox[{"\[Mu]", " ", "\[Nu]"}]}], "2"], 
       SuperscriptBox["s", 
        RowBox[{
         RowBox[{"-", "\[Sigma]"}], "-", "\[Mu]"}]], 
       RowBox[{
        SuperscriptBox["\[Integral]", "s"], 
        RowBox[{
         RowBox[{"g", "(", "x", ")"}], 
         SuperscriptBox["x", 
          RowBox[{"\[Sigma]", "+", "\[Mu]", "-", "1"}]], 
         RowBox[{"\[DifferentialD]", "x"}]}]}]}]}], ")"}]}]}], 
  TraditionalForm]], "DisplayFormula"],

Cell["or equivalently", "Text"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"u", "(", "s", ")"}], "\[LongEqual]", 
   RowBox[{
    FractionBox["1", "2"], "\[Mu]", " ", 
    RowBox[{"cot", "(", "\[Alpha]", ")"}], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{"\[Mu]", " ", "\[Nu]"}]}], ")"}], 
       SuperscriptBox["s", "\[Mu]"], 
       RowBox[{
        SuperscriptBox["\[Integral]", "s"], 
        RowBox[{
         RowBox[{"w", "(", "x", ")"}], 
         SuperscriptBox["x", 
          RowBox[{
           RowBox[{"-", "\[Mu]"}], "-", "1"}]], 
         RowBox[{"\[DifferentialD]", "x"}]}]}]}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"\[Mu]", " ", "\[Nu]"}]}], ")"}], 
       SuperscriptBox["s", 
        RowBox[{"-", "\[Mu]"}]], 
       RowBox[{
        SuperscriptBox["\[Integral]", "s"], 
        RowBox[{
         RowBox[{"w", "(", "x", ")"}], 
         SuperscriptBox["x", 
          RowBox[{"\[Mu]", "-", "1"}]], 
         RowBox[{"\[DifferentialD]", "x"}]}]}]}]}], ")"}]}], "\[LongEqual]", 
   RowBox[{
    FractionBox["1", "2"], "\[Mu]", " ", 
    RowBox[{"cot", "(", "\[Alpha]", ")"}], 
    RowBox[{
     SuperscriptBox["\[Integral]", "s"], 
     RowBox[{
      FractionBox[
       RowBox[{"w", "(", "x", ")"}], "x"], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "-", 
           RowBox[{"\[Mu]", " ", "\[Nu]"}]}], ")"}], 
         SuperscriptBox[
          RowBox[{"(", 
           FractionBox["s", "x"], ")"}], "\[Mu]"]}], "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", 
           RowBox[{"\[Mu]", " ", "\[Nu]"}]}], ")"}], 
         SuperscriptBox[
          RowBox[{"(", 
           FractionBox["x", "s"], ")"}], "\[Mu]"]}]}], ")"}], 
      RowBox[{"\[DifferentialD]", "x"}]}]}]}]}], 
  TraditionalForm]], "DisplayFormula"],

Cell["\<\
As a check, we substitute this solution back into the first equation.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{
     FormBox[
      RowBox[{"eqns", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}],
      TraditionalForm], "/.", 
     RowBox[{"u", "\[Rule]", 
      RowBox[{"Function", "[", 
       RowBox[{"s", ",", 
        RowBox[{
         FractionBox["1", "2"], "\[Mu]", " ", 
         RowBox[{"cot", "(", "\[Alpha]", ")"}], 
         RowBox[{
          SubsuperscriptBox["\[Integral]", "1", "s"], 
          RowBox[{
           FractionBox[
            RowBox[{"w", "(", "x", ")"}], "x"], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "-", 
                RowBox[{"\[Mu]", " ", "\[Nu]"}]}], ")"}], 
              SuperscriptBox[
               RowBox[{"(", 
                FractionBox["s", "x"], ")"}], "\[Mu]"]}], "-", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "+", 
                RowBox[{"\[Mu]", " ", "\[Nu]"}]}], ")"}], 
              SuperscriptBox[
               RowBox[{"(", 
                FractionBox["x", "s"], ")"}], "\[Mu]"]}]}], ")"}], 
           RowBox[{"\[DifferentialD]", "x"}]}]}]}]}], "]"}]}]}], "/.", 
    "gsoln"}], "//", "Simplify"}], TraditionalForm]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox["s", "\[Sigma]"], " ", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "s", "]"}], "8"],
    SeriesData[$CellContext`s, 0, {}, 8, 8, 1],
    Editable->False]}], "\[Equal]", "0"}]], "Output",
 CellChangeTimes->{3.435207662875*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Solving the second equation", "Subsection"],

Cell[TextData[{
 "Substituting the values of ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["g", 
     TagBox[
      RowBox[{"(", "n", ")"}],
      Derivative],
     MultilineFunction->None], "(", "0", ")"}], TraditionalForm]]],
 " into the left-hand side of the second equation yields"
}], "Text"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"fseries", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"ExpandAll", "[", 
       FractionBox[
        RowBox[{"eqns", "\[LeftDoubleBracket]", 
         RowBox[{"2", ",", "1"}], "\[RightDoubleBracket]"}], 
        SuperscriptBox["s", "\[Sigma]"]], "]"}], "\[Equal]", "0"}], "/.", 
     "gsoln"}]}], ";"}], TraditionalForm]], "Input"],

Cell[TextData[{
 "To solve the pair of differential equations, the coefficient of each power \
of ",
 Cell[BoxData[
  FormBox["s", TraditionalForm]]],
 " in this series solution must vanish identically. The simplest non-trivial \
solution arises when ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"f", "(", "0", ")"}], "\[NotEqual]", "0"}], TraditionalForm]]],
 ". "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"Coefficient", "[", 
    RowBox[{
     RowBox[{"First", "@", "fseries"}], ",", "s", ",", "0"}], "]"}], "//", 
   "Simplify"}], TraditionalForm]], "Input"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{
    RowBox[{"f", "[", "0", "]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox["\[Mu]", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         RowBox[{"\[Nu]", " ", "\[Sigma]"}]}], ")"}], " ", 
       RowBox[{"Cot", "[", "\[Alpha]", "]"}]}], "+", 
      RowBox[{
       SuperscriptBox["\[Eta]", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "2"}], "+", "\[Sigma]"}], ")"}], " ", "\[Sigma]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["\[Mu]", "2"]}], "+", 
         SuperscriptBox["\[Sigma]", "2"]}], ")"}], " ", 
       RowBox[{"Tan", "[", "\[Alpha]", "]"}]}]}], ")"}]}], 
   RowBox[{
    SuperscriptBox["\[Mu]", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{"\[Nu]", " ", "\[Sigma]"}]}], ")"}]}]]}]], "Output",
 CellChangeTimes->{3.435207671515625*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Indicial equation", "Subsection"],

Cell[TextData[{
 "Assuming that ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"\[Sigma]", " ", "\[Nu]"}], "\[NotEqual]", "1"}], 
   TraditionalForm]]],
 ", one requires that"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"soln", "[", "0", "]"}], "=", 
   RowBox[{
    RowBox[{
     FractionBox[
      RowBox[{"Numerator", "[", "%", "]"}], 
      RowBox[{"f", "(", "0", ")"}]], "\[LongEqual]", "0"}], "//", 
    "FullSimplify"}]}], TraditionalForm]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    SuperscriptBox["\[Mu]", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{"\[Nu]", " ", "\[Sigma]"}]}], ")"}], " ", 
    RowBox[{"Cot", "[", "\[Alpha]", "]"}]}], "+", 
   RowBox[{
    SuperscriptBox["\[Eta]", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "2"}], "+", "\[Sigma]"}], ")"}], " ", "\[Sigma]", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["\[Mu]", "2"]}], "+", 
      SuperscriptBox["\[Sigma]", "2"]}], ")"}], " ", 
    RowBox[{"Tan", "[", "\[Alpha]", "]"}]}]}], "\[Equal]", "0"}]], "Output",
 CellChangeTimes->{3.43520767634375*^9}]
}, Open  ]],

Cell[TextData[{
 "The roots of this quartic in ",
 Cell[BoxData[
  FormBox["\[Sigma]", TraditionalForm]]],
 " determine the Frobenius solution; however, in general, the solutions in \
terms of radicals are messy. "
}], "Text"],

Cell[TextData[{
 "Assuming that",
 " ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"\[Sigma]", "\[NotEqual]", "0"}], ",", "2", ",", 
    RowBox[{"\[PlusMinus]", "\[Mu]"}]}], TraditionalForm]]],
 " (reasonable, since these are not, in general, solutions to the quartic), \
one can eliminate ",
 Cell[BoxData[
  FormBox["\[Eta]", TraditionalForm]]],
 " as follows:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"soln", "[", "0", "]"}], "/.", 
    RowBox[{
     SuperscriptBox["\[Eta]", "2"], "\[Rule]", 
     FractionBox[
      RowBox[{
       SuperscriptBox["\[Mu]", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Nu]", " ", "\[Sigma]"}], "-", "1"}], ")"}], " ", 
       RowBox[{
        SuperscriptBox["cot", "2"], "(", "\[Alpha]", ")"}]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Sigma]", "-", "2"}], ")"}], " ", "\[Sigma]", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["\[Mu]", "2"], "-", 
         SuperscriptBox["\[Sigma]", "2"]}], ")"}]}]]}]}], "//", "Simplify"}], 
  TraditionalForm]], "Input"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.43520767865625*^9}]
}, Open  ]],

Cell[TextData[{
 "With this implied relation for ",
 Cell[BoxData[
  FormBox["\[Sigma]", TraditionalForm]]],
 ", one can determine the ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", "n", ")"}],
      Derivative],
     MultilineFunction->None], "(", "0", ")"}], TraditionalForm]]],
 " as follows."
}], "Text"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"fsoln", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{"fseries", "/.", 
         RowBox[{
          SuperscriptBox["\[Eta]", "2"], "\[Rule]", 
          FractionBox[
           RowBox[{
            SuperscriptBox["\[Mu]", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"\[Nu]", " ", "\[Sigma]"}], "-", "1"}], ")"}], " ", 
            RowBox[{
             SuperscriptBox["cot", "2"], "(", "\[Alpha]", ")"}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"\[Sigma]", "-", "2"}], ")"}], " ", "\[Sigma]", " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["\[Mu]", "2"], "-", 
              SuperscriptBox["\[Sigma]", "2"]}], ")"}]}]]}]}], ",", 
        RowBox[{
         FormBox["Table",
          TraditionalForm], "[", 
         RowBox[{
          RowBox[{
           SuperscriptBox["f", 
            TagBox[
             RowBox[{"(", "n", ")"}],
             Derivative],
            MultilineFunction->None], "(", "0", ")"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "7"}], "}"}]}], "]"}]}], "]"}], "//", 
      "FullSimplify"}], "//", "First"}]}], ";"}], TraditionalForm]], "Input"],

Cell[TextData[{
 "Substituting the ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", "n", ")"}],
      Derivative],
     MultilineFunction->None], "(", "0", ")"}], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["g", 
     TagBox[
      RowBox[{"(", "n", ")"}],
      Derivative],
     MultilineFunction->None], "(", "0", ")"}], TraditionalForm]]],
 " back into series expansion, one obtains the solutions ",
 Cell[BoxData[
  FormBox[
   RowBox[{"u", "(", "s", ")"}], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"w", "(", "s", ")"}], TraditionalForm]]]
}], "Text"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"u", "(", "s_", ")"}], "=", 
    RowBox[{
     RowBox[{
      RowBox[{"u", "(", "s", ")"}], "/.", "fsoln"}], "//", "Simplify"}]}], 
   ";"}], TraditionalForm]], "Input"],

Cell["and ", "Text"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"w", "(", "s_", ")"}], "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"w", "(", "s", ")"}], "/.", "gsoln"}], "/.", "fsoln"}], "//", 
     "Simplify"}]}], ";"}], TraditionalForm]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Numerical example", "Subsection"],

Cell["\<\
For the numerical parameters above, the indicial equation becomes\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"First", "@", 
     RowBox[{"soln", "[", "0", "]"}]}], "/.", "params"}], "//", "Factor"}], 
  TraditionalForm]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", "3"}], "+", "\[Sigma]"}], ")"}], " ", 
  RowBox[{"(", 
   RowBox[{"3", "-", 
    RowBox[{"6", " ", "\[Sigma]"}], "+", 
    SuperscriptBox["\[Sigma]", "2"], "+", 
    SuperscriptBox["\[Sigma]", "3"]}], ")"}]}]], "Output",
 CellChangeTimes->{3.435207709453125*^9}]
}, Open  ]],

Cell["\<\
Although exact solution is possible, numerical solution suffices.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{"nroots", "=", 
   RowBox[{"NSolve", "[", 
    RowBox[{
     RowBox[{"%", "\[Equal]", "0"}], ",", "\[Sigma]"}], "]"}]}], 
  TraditionalForm]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\[Sigma]", "\[Rule]", 
     RowBox[{"-", "3.181943336052393`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Sigma]", "\[Rule]", "0.5935793453672887`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Sigma]", "\[Rule]", "1.5883639906851044`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Sigma]", "\[Rule]", "3.`"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.4352077113125*^9}]
}, Open  ]],

Cell[TextData[{
 "Also, for these parameters, here are the Frobenius solutions, divided by ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["s", "\[Sigma]"], 
    RowBox[{"f", "(", "0", ")"}]}], TraditionalForm]]],
 "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{"Frobenius", "=", 
   RowBox[{
    RowBox[{
     FractionBox[
      RowBox[{"{", 
       RowBox[{
        RowBox[{"u", "(", "s", ")"}], ",", 
        RowBox[{"w", "(", "s", ")"}]}], "}"}], 
      RowBox[{
       SuperscriptBox["s", "\[Sigma]"], 
       RowBox[{"f", "(", "0", ")"}]}]], "/.", "params"}], "//", 
    "Simplify"}]}], TraditionalForm]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   InterpretationBox[
    RowBox[{"1", "-", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "2"}], "+", "\[Sigma]"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"3", "+", "\[Sigma]"}], ")"}], " ", 
       SuperscriptBox["s", "2"]}], 
      RowBox[{"16", "+", 
       RowBox[{"6", " ", "\[Sigma]"}]}]], "+", 
     FractionBox[
      RowBox[{"\[Sigma]", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "6"}], "+", "\[Sigma]", "+", 
          SuperscriptBox["\[Sigma]", "2"]}], ")"}], "2"], " ", 
       SuperscriptBox["s", "4"]}], 
      RowBox[{"8", " ", 
       RowBox[{"(", 
        RowBox[{"112", "+", 
         RowBox[{"154", " ", "\[Sigma]"}], "+", 
         RowBox[{"66", " ", 
          SuperscriptBox["\[Sigma]", "2"]}], "+", 
         RowBox[{"9", " ", 
          SuperscriptBox["\[Sigma]", "3"]}]}], ")"}]}]], "-", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["\[Sigma]", "2"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "6"}], "+", "\[Sigma]", "+", 
            SuperscriptBox["\[Sigma]", "2"]}], ")"}], "3"]}], ")"}], " ", 
       SuperscriptBox["s", "6"]}], 
      RowBox[{"48", " ", 
       RowBox[{"(", 
        RowBox[{"4032", "+", 
         RowBox[{"7784", " ", "\[Sigma]"}], "+", 
         RowBox[{"5792", " ", 
          SuperscriptBox["\[Sigma]", "2"]}], "+", 
         RowBox[{"2106", " ", 
          SuperscriptBox["\[Sigma]", "3"]}], "+", 
         RowBox[{"378", " ", 
          SuperscriptBox["\[Sigma]", "4"]}], "+", 
         RowBox[{"27", " ", 
          SuperscriptBox["\[Sigma]", "5"]}]}], ")"}]}]], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "s", "]"}], "8"],
      SeriesData[$CellContext`s, 0, {}, 0, 8, 1],
      Editable->False]}],
    SeriesData[$CellContext`s, 0, {
     1, 0, -(-2 + $CellContext`\[Sigma]) (3 + $CellContext`\[Sigma])/(16 + 
      6 $CellContext`\[Sigma]), 0, 
      Rational[1, 
        8] $CellContext`\[Sigma] (-6 + $CellContext`\[Sigma] + $CellContext`\
\[Sigma]^2)^2/(112 + 154 $CellContext`\[Sigma] + 66 $CellContext`\[Sigma]^2 + 
      9 $CellContext`\[Sigma]^3), 0, 
      Rational[-1, 
        48] $CellContext`\[Sigma]^2 (-6 + $CellContext`\[Sigma] + \
$CellContext`\[Sigma]^2)^3/(4032 + 7784 $CellContext`\[Sigma] + 
      5792 $CellContext`\[Sigma]^2 + 2106 $CellContext`\[Sigma]^3 + 
      378 $CellContext`\[Sigma]^4 + 27 $CellContext`\[Sigma]^5)}, 0, 8, 1],
    Editable->False], ",", 
   InterpretationBox[
    RowBox[{
     RowBox[{
      FractionBox["1", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "3"}], "-", "\[Sigma]"}], ")"}]}], "+", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "2"}], "+", "\[Sigma]"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"3", "+", "\[Sigma]"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"5", "+", "\[Sigma]"}], ")"}], " ", 
       SuperscriptBox["s", "2"]}], 
      RowBox[{"6", " ", 
       RowBox[{"(", 
        RowBox[{"8", "+", 
         RowBox[{"3", " ", "\[Sigma]"}]}], ")"}]}]], "-", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Sigma]", " ", 
         RowBox[{"(", 
          RowBox[{"7", "+", "\[Sigma]"}], ")"}], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "6"}], "+", "\[Sigma]", "+", 
            SuperscriptBox["\[Sigma]", "2"]}], ")"}], "2"]}], ")"}], " ", 
       SuperscriptBox["s", "4"]}], 
      RowBox[{"24", " ", 
       RowBox[{"(", 
        RowBox[{"112", "+", 
         RowBox[{"154", " ", "\[Sigma]"}], "+", 
         RowBox[{"66", " ", 
          SuperscriptBox["\[Sigma]", "2"]}], "+", 
         RowBox[{"9", " ", 
          SuperscriptBox["\[Sigma]", "3"]}]}], ")"}]}]], "+", 
     FractionBox[
      RowBox[{
       SuperscriptBox["\[Sigma]", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"9", "+", "\[Sigma]"}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "6"}], "+", "\[Sigma]", "+", 
          SuperscriptBox["\[Sigma]", "2"]}], ")"}], "3"], " ", 
       SuperscriptBox["s", "6"]}], 
      RowBox[{"144", " ", 
       RowBox[{"(", 
        RowBox[{"4032", "+", 
         RowBox[{"7784", " ", "\[Sigma]"}], "+", 
         RowBox[{"5792", " ", 
          SuperscriptBox["\[Sigma]", "2"]}], "+", 
         RowBox[{"2106", " ", 
          SuperscriptBox["\[Sigma]", "3"]}], "+", 
         RowBox[{"378", " ", 
          SuperscriptBox["\[Sigma]", "4"]}], "+", 
         RowBox[{"27", " ", 
          SuperscriptBox["\[Sigma]", "5"]}]}], ")"}]}]], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "s", "]"}], "8"],
      SeriesData[$CellContext`s, 0, {}, 0, 8, 1],
      Editable->False]}],
    SeriesData[$CellContext`s, 0, {
     Rational[1, 3] (-3 - $CellContext`\[Sigma]), 0, 
      Rational[1, 6] (-2 + $CellContext`\[Sigma]) (
       3 + $CellContext`\[Sigma]) (5 + $CellContext`\[Sigma])/(8 + 
      3 $CellContext`\[Sigma]), 0, 
      Rational[-1, 24] $CellContext`\[Sigma] (
       7 + $CellContext`\[Sigma]) (-6 + $CellContext`\[Sigma] + $CellContext`\
\[Sigma]^2)^2/(112 + 154 $CellContext`\[Sigma] + 66 $CellContext`\[Sigma]^2 + 
      9 $CellContext`\[Sigma]^3), 0, 
      Rational[1, 144] $CellContext`\[Sigma]^2 (
       9 + $CellContext`\[Sigma]) (-6 + $CellContext`\[Sigma] + $CellContext`\
\[Sigma]^2)^3/(4032 + 7784 $CellContext`\[Sigma] + 
      5792 $CellContext`\[Sigma]^2 + 2106 $CellContext`\[Sigma]^3 + 
      378 $CellContext`\[Sigma]^4 + 27 $CellContext`\[Sigma]^5)}, 0, 8, 1],
    Editable->False]}], "}"}]], "Output",
 CellChangeTimes->{3.435207713203125*^9}]
}, Open  ]],

Cell[TextData[{
 "Using the numerically computed initial value ",
 Cell[BoxData[
  FormBox[
   RowBox[{"f", "(", "0", ")"}], TraditionalForm]]],
 ", and the most singular value of ",
 Cell[BoxData[
  FormBox["\[Sigma]", TraditionalForm]]],
 ", we compare the numerical solution to the Frobenius solution."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{"<<", "Graphics`"}], TraditionalForm]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"General", "::", "\<\"obspkg\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"\\!\\(\\\"Graphics`\\\"\\) is now obsolete. The legacy \
version being loaded may conflict with current Mathematica functionality. See \
the Compatibility Guide for updating information. \\!\\(\\*ButtonBox[\\\"\
\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:Compatibility/Guides/Graphics/\
GraphicsUpgradingInformation\\\", ButtonNote -> \\\"General::obspkg\\\"]\\)\"\
\>"}]], "Message", "MSG",
 CellChangeTimes->{3.435207716671875*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{"DisplayTogether", "[", 
   RowBox[{"nplot", ",", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"Evaluate", "[", 
       RowBox[{
        RowBox[{
         FormBox[
          RowBox[{
          "initial", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}],
          TraditionalForm], 
         RowBox[{"Normal", "[", "Frobenius", "]"}]}], "/.", 
        RowBox[{"First", "[", "nroots", "]"}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"s", ",", "0", ",", "1"}], "}"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"LightPink", ",", "LightBlue"}], "}"}]}]}], "]"}]}], "]"}], 
  TraditionalForm]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"DisplayTogether", "::", "\<\"obslt\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"The DisplayTogether and DisplayTogetherArray functions are \
obsolete in Version 6. GraphicsArray and Show may be used directly in the \
same role.\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.4352077185625*^9}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {RGBColor[1, 0, 0], LineBox[CompressedData["
1:eJwV13c81G8cAHB0Z+ZkFUq2JEklGurzWBGyKZGdQiRlJRkRPzKTCkXSoERG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      "]]}, 
    {RGBColor[0, 0, 1], LineBox[CompressedData["
1:eJwV13c4le8fB3AjksrKiIgiLaUhIvU+RAMNpSG+SkRmKt9jNOxRFC0rGjRQ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      "]]}}, {{}, {}, 
    {RGBColor[1., 0.713706, 0.756905], LineBox[CompressedData["
1:eJwV13c8lW8UAPAySuhVWmYKSWVVVL+G8xZtZEuJrGRkhYwyCskmGSFChQhZ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      "]]}, 
    {RGBColor[0.678396, 0.847102, 0.902005], LineBox[CompressedData["
1:eJwV13c8Vf8fB3AjpTIiDTuFlFGpb0bpdcsqSURGSZEoyiwRhYxkpOJrRAgN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      "]]}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  DisplayFunction:>$DisplayFunction,
  PlotRange->{{0, 1}, {0., 5.999999630782868}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.435207718640625*^9}]
}, Open  ]],

Cell[TextData[{
 "The agreement is, as expected, very good for small ",
 Cell[BoxData[
  FormBox["s", TraditionalForm]]],
 "."
}], "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1016, 651},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
PageHeaders->{{Inherited, Inherited, None}, {None, Inherited, Inherited}},
PrintingOptions->{"FirstPageHeader"->False},
Magnification->1,
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (April 28, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[590, 23, 69, 0, 83, "Title"],
Cell[662, 25, 84, 1, 62, "Text"],
Cell[749, 28, 421, 14, 137, "Text"],
Cell[CellGroupData[{
Cell[1195, 46, 28, 0, 71, "Section"],
Cell[1226, 48, 61, 0, 29, "Text"],
Cell[1290, 50, 2124, 60, 34, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3451, 115, 36, 0, 71, "Section"],
Cell[3490, 117, 59, 0, 29, "Text"],
Cell[3552, 119, 427, 14, 48, "Input"],
Cell[3982, 135, 243, 7, 29, "Text"],
Cell[CellGroupData[{
Cell[4250, 146, 963, 29, 34, "Input"],
Cell[5216, 177, 680, 23, 33, "Output"]
}, Open  ]],
Cell[5911, 203, 353, 13, 29, "Text"],
Cell[CellGroupData[{
Cell[6289, 220, 203, 7, 30, "Input"],
Cell[6495, 229, 152, 4, 33, "Output"]
}, Open  ]],
Cell[6662, 236, 719, 24, 47, "Text"],
Cell[CellGroupData[{
Cell[7406, 264, 402, 13, 32, "Input"],
Cell[7811, 279, 154, 4, 30, "Output"]
}, Open  ]],
Cell[7980, 286, 461, 20, 29, "Text"],
Cell[CellGroupData[{
Cell[8466, 310, 581, 19, 34, "Input"],
Cell[9050, 331, 17723, 299, 249, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[26822, 636, 37, 0, 71, "Section"],
Cell[26862, 638, 204, 8, 29, "Text"],
Cell[CellGroupData[{
Cell[27091, 650, 342, 11, 30, "Input"],
Cell[27436, 663, 826, 25, 45, "Output"]
}, Open  ]],
Cell[28277, 691, 74, 0, 29, "Text"],
Cell[CellGroupData[{
Cell[28376, 695, 179, 6, 30, "Input"],
Cell[28558, 703, 648, 20, 45, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[29255, 729, 37, 0, 71, "Section"],
Cell[29295, 731, 1115, 37, 49, "Text"],
Cell[CellGroupData[{
Cell[30435, 772, 321, 11, 30, "Input"],
Cell[30759, 785, 2517, 77, 48, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[33313, 867, 321, 11, 30, "Input"],
Cell[33637, 880, 2517, 77, 48, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[36191, 962, 48, 0, 36, "Subsection"],
Cell[36242, 964, 298, 11, 29, "Text"],
Cell[CellGroupData[{
Cell[36565, 979, 783, 23, 48, "Input"],
Cell[37351, 1004, 6477, 216, 143, "Output"]
}, Open  ]],
Cell[43843, 1223, 48, 0, 29, "Text"],
Cell[43894, 1225, 883, 32, 44, "DisplayFormula"],
Cell[44780, 1259, 70, 0, 29, "Text"],
Cell[CellGroupData[{
Cell[44875, 1263, 403, 14, 52, "Input"],
Cell[45281, 1279, 484, 15, 47, "Output"]
}, Open  ]],
Cell[45780, 1297, 25, 0, 29, "Text"],
Cell[CellGroupData[{
Cell[45830, 1301, 965, 30, 51, "Input"],
Cell[46798, 1333, 440, 14, 48, "Output"]
}, Open  ]],
Cell[47253, 1350, 26, 0, 29, "Text"],
Cell[47282, 1352, 1145, 35, 41, "DisplayFormula"],
Cell[48430, 1389, 31, 0, 29, "Text"],
Cell[48464, 1391, 1904, 60, 41, "DisplayFormula"],
Cell[50371, 1453, 93, 2, 29, "Text"],
Cell[CellGroupData[{
Cell[50489, 1459, 1265, 36, 48, "Input"],
Cell[51757, 1497, 300, 9, 30, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[52106, 1512, 49, 0, 36, "Subsection"],
Cell[52158, 1514, 311, 11, 29, "Text"],
Cell[52472, 1527, 381, 11, 48, "Input"],
Cell[52856, 1540, 385, 12, 29, "Text"],
Cell[CellGroupData[{
Cell[53266, 1556, 200, 6, 30, "Input"],
Cell[53469, 1564, 998, 31, 53, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[54516, 1601, 39, 0, 36, "Subsection"],
Cell[54558, 1603, 193, 8, 29, "Text"],
Cell[CellGroupData[{
Cell[54776, 1615, 283, 9, 50, "Input"],
Cell[55062, 1626, 687, 21, 33, "Output"]
}, Open  ]],
Cell[55764, 1650, 226, 6, 29, "Text"],
Cell[55993, 1658, 382, 13, 29, "Text"],
Cell[CellGroupData[{
Cell[56400, 1675, 712, 22, 55, "Input"],
Cell[57115, 1699, 72, 1, 30, "Output"]
}, Open  ]],
Cell[57202, 1703, 359, 14, 29, "Text"],
Cell[57564, 1719, 1289, 38, 55, "Input"],
Cell[58856, 1759, 674, 27, 29, "Text"],
Cell[59533, 1788, 228, 8, 30, "Input"],
Cell[59764, 1798, 20, 0, 29, "Text"],
Cell[59787, 1800, 263, 9, 30, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[60087, 1814, 39, 0, 36, "Subsection"],
Cell[60129, 1816, 89, 2, 29, "Text"],
Cell[CellGroupData[{
Cell[60243, 1822, 180, 6, 30, "Input"],
Cell[60426, 1830, 331, 10, 33, "Output"]
}, Open  ]],
Cell[60772, 1843, 89, 2, 29, "Text"],
Cell[CellGroupData[{
Cell[60886, 1849, 185, 6, 30, "Input"],
Cell[61074, 1857, 457, 12, 30, "Output"]
}, Open  ]],
Cell[61546, 1872, 242, 8, 29, "Text"],
Cell[CellGroupData[{
Cell[61813, 1884, 392, 13, 50, "Input"],
Cell[62208, 1899, 5856, 156, 107, "Output"]
}, Open  ]],
Cell[68079, 2058, 317, 9, 29, "Text"],
Cell[CellGroupData[{
Cell[68421, 2071, 82, 2, 30, "Input"],
Cell[68506, 2075, 585, 11, 21, "Message"]
}, Open  ]],
Cell[CellGroupData[{
Cell[69128, 2091, 697, 20, 30, "Input"],
Cell[69828, 2113, 323, 7, 21, "Message"],
Cell[70154, 2122, 32004, 536, 249, "Output"]
}, Open  ]],
Cell[102173, 2661, 138, 5, 29, "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

