(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     15638,        540]*)
(*NotebookOutlinePosition[     17029,        582]*)
(*  CellTagsIndexPosition[     16985,        578]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["An Exercise", "Subtitle",
  TextAlignment->Center],

Cell[TextData[{
  "in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", Laplace transforms, limits, etc."
}], "Subsubtitle",
  TextAlignment->Center],

Cell[CellGroupData[{

Cell["Reminder", "Subsection"],

Cell["\<\
Keep in mind that I'm not trying to show you the most efficient way \
to do this.  I'm purposely going up wrong alleys because I think it's \
instructional.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The \"answer\"", "Subsection"],

Cell[TextData[{
  "Suppose we're trying to find the Laplace Transform of ",
  Cell[BoxData[
      \(t\^2\)]],
  "sint. \nWe can look it up to see what we're trying for."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(LaplaceTransform[t^2\ Sin[t], t, s]\)], "Input"],

Cell[BoxData[
    \(\(\(-2\) + 6\ s\^2\)\/\((1 + s\^2)\)\^3\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["One way to get \"the answer\" (with side trips).", "Subsection"],

Cell[TextData[{
  "Let's first find the appropriate antiderivative, like we were doing it by \
hand.  Note, however, that ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " gives a fairly surprising result.  There aren't any complex numbers in \
the \"answer\"!  Notice, though, that the denominator below should multiply \
to be the same denominator above."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Integral]t^2\ Sin[t] Exp[\(-s\)\ t] \[DifferentialD]t\)], "Input"],

Cell[BoxData[
    \(\(-\(\(\[ExponentialE]\^\(\(-s\)\ t\)\ \((\(-2\) + 6\ s\^2 + 4\ s\ t + 
                  4\ s\^3\ t + t\^2 + 2\ s\^2\ t\^2 + s\^4\ t\^2)\)\ Cos[
                t]\)\/\(\((\(-\[ImaginaryI]\) + s)\)\^3\ \((\[ImaginaryI] + \
s)\)\^3\)\)\) - \(\[ExponentialE]\^\(\(-s\)\ t\)\ \((\(-6\)\ s + 2\ s\^3 - 2\ \
t + 2\ s\^4\ t + s\ t\^2 + 2\ s\^3\ t\^2 + s\^5\ t\^2)\)\ Sin[t]\)\/\(\((\(-\
\[ImaginaryI]\) + s)\)\^3\ \((\[ImaginaryI] + s)\)\^3\)\)], "Output"]
}, Open  ]],

Cell["\<\
We can try getting a common denominator.  This doesn't help the \
complex value problem.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Together[%]\)], "Input"],

Cell[BoxData[
    \(\(-\(\((\[ExponentialE]\^\(\(-s\)\ t\)\ \((\(-2\)\ Cos[t] + 
                6\ s\^2\ Cos[t] + 4\ s\ t\ Cos[t] + 4\ s\^3\ t\ Cos[t] + 
                t\^2\ Cos[t] + 2\ s\^2\ t\^2\ Cos[t] + s\^4\ t\^2\ Cos[t] - 
                6\ s\ Sin[t] + 2\ s\^3\ Sin[t] - 2\ t\ Sin[t] + 
                2\ s\^4\ t\ Sin[t] + s\ t\^2\ Sin[t] + 
                2\ s\^3\ t\^2\ Sin[t] + 
                s\^5\ t\^2\ Sin[
                    t])\))\)/\((\((\(-\[ImaginaryI]\) + s)\)\^3\ \((\
\[ImaginaryI] + s)\)\^3)\)\)\)\)], "Output"]
}, Open  ]],

Cell["\<\
Peel off the denominator, multiply it out, then factor it. That's \
better.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Denominator[%]\)], "Input"],

Cell[BoxData[
    \(\[ExponentialE]\^\(s\ t\)\ \((\(-\[ImaginaryI]\) + s)\)\^3\ \((\
\[ImaginaryI] + s)\)\^3\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Expand[%]\)], "Input"],

Cell[BoxData[
    \(\[ExponentialE]\^\(s\ t\) + 3\ \[ExponentialE]\^\(s\ t\)\ s\^2 + 
      3\ \[ExponentialE]\^\(s\ t\)\ s\^4 + \[ExponentialE]\^\(s\ t\)\ \
s\^6\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Factor[%]\)], "Input"],

Cell[BoxData[
    \(\[ExponentialE]\^\(s\ t\)\ \((1 + s\^2)\)\^3\)], "Output"]
}, Open  ]],

Cell["\<\
Peel off the numerator and try to factor.  This doesn't work well \
with this one.  However, we can collect the cost terms and the sint \
terms.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Numerator[Out[3]]\)], "Input"],

Cell[BoxData[
    \(2\ Cos[t] - 6\ s\^2\ Cos[t] - 4\ s\ t\ Cos[t] - 4\ s\^3\ t\ Cos[t] - 
      t\^2\ Cos[t] - 2\ s\^2\ t\^2\ Cos[t] - s\^4\ t\^2\ Cos[t] + 
      6\ s\ Sin[t] - 2\ s\^3\ Sin[t] + 2\ t\ Sin[t] - 2\ s\^4\ t\ Sin[t] - 
      s\ t\^2\ Sin[t] - 2\ s\^3\ t\^2\ Sin[t] - 
      s\^5\ t\^2\ Sin[t]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Factor[%]\)], "Input"],

Cell[BoxData[
    \(2\ Cos[t] - 6\ s\^2\ Cos[t] - 4\ s\ t\ Cos[t] - 4\ s\^3\ t\ Cos[t] - 
      t\^2\ Cos[t] - 2\ s\^2\ t\^2\ Cos[t] - s\^4\ t\^2\ Cos[t] + 
      6\ s\ Sin[t] - 2\ s\^3\ Sin[t] + 2\ t\ Sin[t] - 2\ s\^4\ t\ Sin[t] - 
      s\ t\^2\ Sin[t] - 2\ s\^3\ t\^2\ Sin[t] - 
      s\^5\ t\^2\ Sin[t]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Collect[%, {Cos[t], Sin[t]}]\)], "Input"],

Cell[BoxData[
    \(\((2 - 6\ s\^2 - 4\ s\ t - 4\ s\^3\ t - t\^2 - 2\ s\^2\ t\^2 - 
            s\^4\ t\^2)\)\ Cos[
          t] + \((6\ s - 2\ s\^3 + 2\ t - 2\ s\^4\ t - s\ t\^2 - 
            2\ s\^3\ t\^2 - s\^5\ t\^2)\)\ Sin[t]\)], "Output"]
}, Open  ]],

Cell["\<\
Here's the coefficient of cost in the above expression.  Factoring \
doesn't work for this polynomial in 2 variables.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Coefficient[%, Cos[t]]\)], "Input"],

Cell[BoxData[
    \(2 - 6\ s\^2 - 4\ s\ t - 4\ s\^3\ t - t\^2 - 2\ s\^2\ t\^2 - 
      s\^4\ t\^2\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Factor[%]\)], "Input"],

Cell[BoxData[
    \(2 - 6\ s\^2 - 4\ s\ t - 4\ s\^3\ t - t\^2 - 2\ s\^2\ t\^2 - 
      s\^4\ t\^2\)], "Output"]
}, Open  ]],

Cell["\<\
Let's look at the mess in a better form and apply the limits of \
integration.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(expression1 = Out[9]/Out[6]\)], "Input"],

Cell[BoxData[
    \(\(\(1\/\((1 + s\^2)\)\^3\)\((\[ExponentialE]\^\(\(-s\)\ t\)\ \((\((2 - 
                  6\ s\^2 - 4\ s\ t - 4\ s\^3\ t - t\^2 - 2\ s\^2\ t\^2 - 
                  s\^4\ t\^2)\)\ Cos[
                t] + \((6\ s - 2\ s\^3 + 2\ t - 2\ s\^4\ t - s\ t\^2 - 
                  2\ s\^3\ t\^2 - s\^5\ t\^2)\)\ Sin[t])\))\)\)\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "We can try to have ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " evaluate the limit as t-> \[Infinity], but it can't."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Limit[expression1, t \[Rule] \[Infinity]]\)], "Input"],

Cell[BoxData[
    RowBox[{"Limit", "[", 
      RowBox[{\(\(1\/\((1 + s\^2)\)\^3\)\((\[ExponentialE]\^\(\(-s\)\ t\)\ \
\((\((2 - 6\ s\^2 - 4\ s\ t - 4\ s\^3\ t - t\^2 - 2\ s\^2\ t\^2 - 
                      s\^4\ t\^2)\)\ Cos[
                    t] + \((6\ s - 2\ s\^3 + 2\ t - 2\ s\^4\ t - s\ t\^2 - 
                      2\ s\^3\ t\^2 - s\^5\ t\^2)\)\ Sin[t])\))\)\), ",", 
        RowBox[{"t", "\[Rule]", 
          InterpretationBox["\[Infinity]",
            DirectedInfinity[ 1]]}]}], "]"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Limit", "[", 
      RowBox[{\(\[ExponentialE]\^\(\(-s\)\ t\)\ \((2 - 6\ s\^2 - 4\ s\ t - 
              4\ s\^3\ t - t\^2 - 2\ s\^2\ t\^2 - s\^4\ t\^2)\)\), ",", 
        RowBox[{"t", "\[Rule]", 
          InterpretationBox["\[Infinity]",
            DirectedInfinity[ 1]]}]}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"Limit", "[", 
      RowBox[{\(\[ExponentialE]\^\(\(-s\)\ t\)\ \((2 - 6\ s\^2 - 4\ s\ t - 
              4\ s\^3\ t - t\^2 - 2\ s\^2\ t\^2 - s\^4\ t\^2)\)\), ",", 
        RowBox[{"t", "\[Rule]", 
          InterpretationBox["\[Infinity]",
            DirectedInfinity[ 1]]}]}], "]"}]], "Output"]
}, Open  ]],

Cell["\<\
Since it's the variable t that's tending toward infinity, s is a \
constant.  Let's look at this as an expression in t.\
\>", "Text"],

Cell[CellGroupData[{

Cell["We can essentially ignore the sint and cost because...", "Subsubsection"],

Cell[TextData[{
  "Since sint and cost are bounded between +-1, neither has an effect on the \
limit.\nIf we want to be technical, consider this example.\n-1 \[LessEqual] \
cost \[LessEqual] 1\n",
  Cell[BoxData[
      \(\(-e\^\(-t\)\)\)]],
  "\[LessEqual] ",
  Cell[BoxData[
      \(e\^\(-t\)\)]],
  "cost \[LessEqual] ",
  Cell[BoxData[
      \(e\^\(-t\)\)]],
  " (multiply all sides of the inequality by the positive quantity ",
  Cell[BoxData[
      \(e\^\(-t\)\)]],
  ".)\nAs t\[Rule]\[Infinity], -",
  Cell[BoxData[
      \(e\^\(-t\)\)]],
  "\[Rule]0 and ",
  Cell[BoxData[
      \(e\^\(-t\)\)]],
  "\[Rule]0.  By the Squeezing theorem of,",
  Cell[BoxData[
      \(e\^\(-t\)\)]],
  "cost \[Rule]0 also."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Back to the problem.", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Collect[
      2 - 6\ s\^2 - 4\ s\ t - 4\ s\^3\ t - t\^2 - 2\ s\^2\ t\^2 - 
        s\^4\ t\^2, {1, t, t^2}]\)], "Input"],

Cell[BoxData[
    \(2 - 
      6\ s\^2 + \((\(-4\)\ s - 4\ s\^3)\)\ t + \((\(-1\) - 2\ s\^2 - 
            s\^4)\)\ t\^2\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "We can at least say that this polynomial in t times ",
  Cell[BoxData[
      \(\[ExponentialE]\^\(\(-s\)\ t\)\)]],
  " will tend to 0 as t-> infinity; exponential decay will dominate the \
polynomial.\n\nWe'll still have the antiderivative evaluated at t=0.  Voila!"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(expression1 /. t \[Rule] 0\)], "Input"],

Cell[BoxData[
    \(\(2 - 6\ s\^2\)\/\((1 + s\^2)\)\^3\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Mimicking integration by hand.", "Subsection"],

Cell[TextData[{
  "We would use integration by parts, letting u=t^2 and dv=sint ",
  Cell[BoxData[
      \(\[ExponentialE]\^\(\(-s\)\ t\)\)]],
  " .  We'll use integration by parts."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(u = t^2\), "\[IndentingNewLine]", 
    \(dv = Sin[t] Exp[\(-s\)\ t]\), "\[IndentingNewLine]", 
    \(du = D[u, t]\), "\[IndentingNewLine]", 
    \(v = \[Integral]dv \[DifferentialD]t\)}], "Input"],

Cell[BoxData[
    \(t\^2\)], "Output"],

Cell[BoxData[
    \(\[ExponentialE]\^\(\(-s\)\ t\)\ Sin[t]\)], "Output"],

Cell[BoxData[
    \(2\ t\)], "Output"],

Cell[BoxData[
    \(\(-\(\(\[ExponentialE]\^\(\(-s\)\ t\)\ Cos[
                t]\)\/\(\((\(-\[ImaginaryI]\) + s)\)\ \((\[ImaginaryI] + 
                  s)\)\)\)\) - \(\[ExponentialE]\^\(\(-s\)\ t\)\ s\ \
Sin[t]\)\/\(\((\(-\[ImaginaryI]\) + s)\)\ \((\[ImaginaryI] + s)\)\)\)], \
"Output"]
}, Open  ]],

Cell["\<\
Since Mathematica gave us a weird form, we'll manipulate it into \
something we like better.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Together[%]\)], "Input"],

Cell[BoxData[
    \(\(-\(\(\[ExponentialE]\^\(\(-s\)\ t\)\ \((Cos[t] + 
                s\ Sin[t])\)\)\/\(\((\(-\[ImaginaryI]\) + 
                s)\)\ \((\[ImaginaryI] + s)\)\)\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Numerator[%]/Factor[Expand[Denominator[%]]]\)], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-s\)\ t\)\ \((\(-Cos[t]\) - s\ Sin[t])\)\)\/\(1 \
+ s\^2\)\)], "Output"]
}, Open  ]],

Cell["Rename our better form for v.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(v = %\)], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-s\)\ t\)\ \((\(-Cos[t]\) - s\ Sin[t])\)\)\/\(1 \
+ s\^2\)\)], "Output"]
}, Open  ]],

Cell["The integration by parts.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(u\ v\  - \ \[Integral]v\ du\ \[DifferentialD]t\)], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-s\)\ t\)\ t\^2\ \((\(-Cos[t]\) - s\ Sin[t])\)\)\
\/\(1 + s\^2\) - \(2\ \((\(\[ExponentialE]\^\(\(-s\)\ t\)\ \((\(-1\) + 3\ \
s\^2 + 2\ s\ t + 2\ s\^3\ t)\)\ Cos[t]\)\/\(\((\(-\[ImaginaryI]\) + s)\)\^2\ \
\((\[ImaginaryI] + s)\)\^2\) + \(\[ExponentialE]\^\(\(-s\)\ t\)\ \((\(-3\)\ s \
+ s\^3 - t + s\^4\ t)\)\ Sin[t]\)\/\(\((\(-\[ImaginaryI]\) + s)\)\^2\ \((\
\[ImaginaryI] + s)\)\^2\))\)\)\/\(1 + s\^2\)\)], "Output"]
}, Open  ]],

Cell["\<\
Sigh!  Fix it again.  It's still faster than doing it by \
hand.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Together[%]\)], "Input"],

Cell[BoxData[
    \(\(-\(\((\[ExponentialE]\^\(\(-s\)\ t\)\ \((\(-2\)\ Cos[t] + 
                6\ s\^2\ Cos[t] + 4\ s\ t\ Cos[t] + 4\ s\^3\ t\ Cos[t] + 
                t\^2\ Cos[t] + 2\ s\^2\ t\^2\ Cos[t] + s\^4\ t\^2\ Cos[t] - 
                6\ s\ Sin[t] + 2\ s\^3\ Sin[t] - 2\ t\ Sin[t] + 
                2\ s\^4\ t\ Sin[t] + s\ t\^2\ Sin[t] + 
                2\ s\^3\ t\^2\ Sin[t] + 
                s\^5\ t\^2\ Sin[
                    t])\))\)/\((\((\(-\[ImaginaryI]\) + s)\)\^3\ \((\
\[ImaginaryI] + s)\)\^3)\)\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Numerator[%]/Factor[Expand[Denominator[%]]]\)], "Input"],

Cell[BoxData[
    \(\(\(1\/\((1 + s\^2)\)\^3\)\((\[ExponentialE]\^\(\(-s\)\ t\)\ \((2\ Cos[
                t] - 6\ s\^2\ Cos[t] - 4\ s\ t\ Cos[t] - 4\ s\^3\ t\ Cos[t] - 
            t\^2\ Cos[t] - 2\ s\^2\ t\^2\ Cos[t] - s\^4\ t\^2\ Cos[t] + 
            6\ s\ Sin[t] - 2\ s\^3\ Sin[t] + 2\ t\ Sin[t] - 
            2\ s\^4\ t\ Sin[t] - s\ t\^2\ Sin[t] - 2\ s\^3\ t\^2\ Sin[t] - 
            s\^5\ t\^2\ Sin[t])\))\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Collect[%, {Cos[t], Sin[t]}]\)], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-s\)\ t\)\ \((2 - 6\ s\^2 - 4\ s\ t - 4\ s\^3\ t \
- t\^2 - 2\ s\^2\ t\^2 - s\^4\ t\^2)\)\ Cos[t]\)\/\((1 + s\^2)\)\^3 + \(\
\[ExponentialE]\^\(\(-s\)\ t\)\ \((6\ s - 2\ s\^3 + 2\ t - 2\ s\^4\ t - s\ \
t\^2 - 2\ s\^3\ t\^2 - s\^5\ t\^2)\)\ Sin[t]\)\/\((1 + s\^2)\)\^3\)], "Output"]
}, Open  ]],

Cell["\<\
OK.  Now this is in a form that we can use limits with.
As t->\[Infinity], everything goes to zero.  This is because exponentials \
dominate polynomials, so
(exp) (polynomial in t) has the same limit as (exp).  As shown above, the \
cost and sint have no effect on the limit by the squeezing theorem. \
\>", \
"Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(%\  /. \ t \[Rule] 0\)], "Input"],

Cell[BoxData[
    \(\(2 - 6\ s\^2\)\/\((1 + s\^2)\)\^3\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 832}, {0, 604}},
WindowSize->{520, 482},
WindowMargins->{{1, Automatic}, {Automatic, 1}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
PageHeaders->{{Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
        TextData[ {
          ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
        TextData[ {
          ValueBox[ "FileName"]}], "Header"], Inherited, Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"]}},
PrintingOptions->{"PrintingMargins"->{{54, 54}, {54, 54}},
"PrintCellBrackets"->True,
"PrintRegistrationMarks"->True,
"PrintMultipleHorizontalPages"->False},
MacintoshSystemPageSetup->"\<\
00<0004/0B`000003C@9o?m`ogD=``Z60fL5:0?l0080004/0B`000000]P2:001
0000FP0000400`<300000BL?00400@6/4g0000000000060801T1T00000000000
00000000004000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 56, 1, 61, "Subtitle"],
Cell[1798, 54, 159, 6, 53, "Subsubtitle"],

Cell[CellGroupData[{
Cell[1982, 64, 30, 0, 46, "Subsection"],
Cell[2015, 66, 180, 4, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2232, 75, 36, 0, 46, "Subsection"],
Cell[2271, 77, 181, 5, 46, "Text"],

Cell[CellGroupData[{
Cell[2477, 86, 68, 1, 27, "Input"],
Cell[2548, 89, 73, 1, 47, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[2670, 96, 70, 0, 46, "Subsection"],
Cell[2743, 98, 378, 8, 66, "Text"],

Cell[CellGroupData[{
Cell[3146, 110, 88, 1, 41, "Input"],
Cell[3237, 113, 471, 6, 84, "Output"]
}, Open  ]],
Cell[3723, 122, 112, 3, 30, "Text"],

Cell[CellGroupData[{
Cell[3860, 129, 44, 1, 27, "Input"],
Cell[3907, 132, 541, 9, 79, "Output"]
}, Open  ]],
Cell[4463, 144, 99, 3, 30, "Text"],

Cell[CellGroupData[{
Cell[4587, 151, 47, 1, 27, "Input"],
Cell[4637, 154, 122, 2, 28, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4796, 161, 42, 1, 27, "Input"],
Cell[4841, 164, 176, 3, 28, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5054, 172, 42, 1, 27, "Input"],
Cell[5099, 175, 78, 1, 29, "Output"]
}, Open  ]],
Cell[5192, 179, 168, 4, 46, "Text"],

Cell[CellGroupData[{
Cell[5385, 187, 50, 1, 27, "Input"],
Cell[5438, 190, 320, 5, 79, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5795, 200, 42, 1, 27, "Input"],
Cell[5840, 203, 320, 5, 79, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6197, 213, 61, 1, 27, "Input"],
Cell[6261, 216, 245, 4, 45, "Output"]
}, Open  ]],
Cell[6521, 223, 141, 3, 46, "Text"],

Cell[CellGroupData[{
Cell[6687, 230, 55, 1, 27, "Input"],
Cell[6745, 233, 111, 2, 28, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6893, 240, 42, 1, 27, "Input"],
Cell[6938, 243, 111, 2, 28, "Output"]
}, Open  ]],
Cell[7064, 248, 102, 3, 30, "Text"],

Cell[CellGroupData[{
Cell[7191, 255, 60, 1, 27, "Input"],
Cell[7254, 258, 354, 5, 79, "Output"]
}, Open  ]],
Cell[7623, 266, 162, 5, 32, "Text"],

Cell[CellGroupData[{
Cell[7810, 275, 74, 1, 27, "Input"],
Cell[7887, 278, 510, 9, 86, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8434, 292, 321, 6, 50, "Input"],
Cell[8758, 300, 322, 6, 28, "Output"]
}, Open  ]],
Cell[9095, 309, 143, 3, 46, "Text"],

Cell[CellGroupData[{
Cell[9263, 316, 79, 0, 42, "Subsubsection"],
Cell[9345, 318, 722, 25, 94, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10104, 348, 45, 0, 42, "Subsubsection"],

Cell[CellGroupData[{
Cell[10174, 352, 141, 3, 50, "Input"],
Cell[10318, 357, 134, 3, 28, "Output"]
}, Open  ]],
Cell[10467, 363, 297, 6, 78, "Text"],

Cell[CellGroupData[{
Cell[10789, 373, 59, 1, 27, "Input"],
Cell[10851, 376, 68, 1, 47, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[10980, 384, 52, 0, 46, "Subsection"],
Cell[11035, 386, 194, 5, 46, "Text"],

Cell[CellGroupData[{
Cell[11254, 395, 217, 4, 90, "Input"],
Cell[11474, 401, 38, 1, 28, "Output"],
Cell[11515, 404, 72, 1, 27, "Output"],
Cell[11590, 407, 38, 1, 26, "Output"],
Cell[11631, 410, 291, 5, 44, "Output"]
}, Open  ]],
Cell[11937, 418, 116, 3, 30, "Text"],

Cell[CellGroupData[{
Cell[12078, 425, 44, 1, 27, "Input"],
Cell[12125, 428, 196, 3, 44, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12358, 436, 76, 1, 27, "Input"],
Cell[12437, 439, 115, 2, 42, "Output"]
}, Open  ]],
Cell[12567, 444, 45, 0, 30, "Text"],

Cell[CellGroupData[{
Cell[12637, 448, 38, 1, 27, "Input"],
Cell[12678, 451, 115, 2, 42, "Output"]
}, Open  ]],
Cell[12808, 456, 41, 0, 30, "Text"],

Cell[CellGroupData[{
Cell[12874, 460, 79, 1, 41, "Input"],
Cell[12956, 463, 461, 6, 93, "Output"]
}, Open  ]],
Cell[13432, 472, 88, 3, 30, "Text"],

Cell[CellGroupData[{
Cell[13545, 479, 44, 1, 27, "Input"],
Cell[13592, 482, 541, 9, 79, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14170, 496, 76, 1, 27, "Input"],
Cell[14249, 499, 433, 6, 113, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14719, 510, 61, 1, 27, "Input"],
Cell[14783, 513, 324, 4, 87, "Output"]
}, Open  ]],
Cell[15122, 520, 327, 7, 78, "Text"],

Cell[CellGroupData[{
Cell[15474, 531, 53, 1, 27, "Input"],
Cell[15530, 534, 68, 1, 47, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

