(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     76227,       2135]*)
(*NotebookOutlinePosition[     76865,       2157]*)
(*  CellTagsIndexPosition[     76821,       2153]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Rectangular Roots", "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Stan Wagon \n",
  StyleBox["wagon@macalstr.edu",
    FontFamily->"Courier",
    FontWeight->"Bold"]
}], "Text",
  CellMargins->{{56, Inherited}, {Inherited, Inherited}},
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The ",
  StyleBox["StablePoints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function defined below finds all the roots of two equations in two \
unknowns, ",
  StyleBox["f[x,y] == g[x,y] == 0",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", over a rectangular region. The values of ",
  StyleBox["g[x,y]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " on a dataset obtained from a ",
  StyleBox["ContourPlot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " of ",
  StyleBox["f[x,y] == 0",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " are examined to generate seed values by finding the sign changes on this \
dataset. Given a seed value, ",
  StyleBox["FindMinimum",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is then applied to ",
  StyleBox["f[x,y]^2 + g[x,y]^2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". Although the code may look long it is quite powerful and makes good use \
of ",
  StyleBox["ContourPlot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["The number of plot points required is machine dependent:", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Options[StablePoints] = {StablePlotPoints \[Rule] 60, 
          PrecisionGoal \[Rule] 5};\)\)], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "First we deal with a single seed, ",
  StyleBox["{x0, y0}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ":"
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Needs["\<Utilities`FilterOptions`\>"]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(StablePoints[funcs_List, {x_, x0_}, {y_, y0_}, opts___] := 
      Module[{temp}, 
        temp = FindMinimum[Plus @@ \(funcs\^2\), {x, x0}, {y, y0}, 
            Evaluate[FilterOptions[FindMinimum, opts]]]; 
        If[Abs[First[temp]] < 1\/10\^5, {x, y} /. Last[temp], 
          Null]]\)], "Input",
  AspectRatioFixed->True],

Cell["\<\
Now we generate seeds, and use the preceding routine to locate the \
actual solutions:\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(elimDups[data_, tol_] := 
      Union[FoldList[If[\((#2 - #1)\) . \((#2 - #1)\) > tol\^2, #2, #1] &, 
          First[data], Rest[data]]]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(SetOptions[ContourPlot, Contours \[Rule] {0}, 
        PlotPoints \[Rule] StablePlotPoints /. Options[StablePoints], 
        ContourShading \[Rule] False, 
        DisplayFunction \[Rule] Identity];\)\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(StablePoints[funcs_List, {x_, xmin_, xmax_}, {y_, ymin_, ymax_}, 
        opts___] := 
      Module[{spp, prec, tt, 
          fy = Compile[{x, y}, 
              Evaluate[
                funcs\[LeftDoubleBracket]2\[RightDoubleBracket]]]}, {spp, 
            prec} = \({StablePlotPoints, PrecisionGoal} /. {opts}\) /. 
            Options[StablePoints]; 
        Select[elimDups[\((StablePoints[
                    funcs, {x, #1\[LeftDoubleBracket]1\[RightDoubleBracket]}, \
{y, #1\[LeftDoubleBracket]2\[RightDoubleBracket]}, opts] &)\) /@ 
              Flatten[\((#1\[LeftDoubleBracket]1 + 
                          Flatten[
                            Position[
                              Rest[tt = Sign[Apply[fy, #1, 2]]]\ Rest[
                                  RotateRight[
                                    tt]], \(-1\)]]\[RightDoubleBracket] &)\) /@ \
\((First /@ Select[Flatten[List @@ 
                              Graphics[
                                ContourPlot[
                                  funcs\[LeftDoubleBracket]1\
\[RightDoubleBracket], {x, xmin, xmax}, {y, xmin, xmax}, 
                                  PlotPoints \[Rule] spp]], 5], 
                          Head[#1] === Line &] /. Line \[Rule] List)\), 1], 
            10\^\(3 - prec\)], 
          xmin < #1\[LeftDoubleBracket]1\[RightDoubleBracket] < xmax && 
              ymin < #1\[LeftDoubleBracket]2\[RightDoubleBracket] < 
                ymax &]]\)], "Input",
  AspectRatioFixed->True],

Cell["Here is an example:", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(f[x_, 
          y_] = \((x\^2 + y\^2 - 9)\)\ \((x\^2 + y\^2 - 16)\);\)\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(g[x_, y_] = Cos[x + y] + Sin[x + y\^2] - 1;\)\)], "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(solns = 
      StablePoints[{f[x, y], g[x, y]}, {x, \(-4\), 4}, {y, \(-4\), 4}, 
        StablePlotPoints \[Rule] 60]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(-3.489059057907922`\), \(-1.9561357034803843`\)},
            {\(-3.419527300015905`\), "2.0752910746316844`"},
            {\(-3.152282544009567`\), "2.462339286680981`"},
            {\(-3.1503493975491077`\), \(-2.464812096968566`\)},
            {\(-2.6473343605198334`\), "2.9986031387316077`"},
            {\(-2.6253181753348556`\), \(-3.0178973604575265`\)},
            {\(-2.4886107601243577`\), "1.6753556292880716`"},
            {\(-2.2217703143814886`\), "3.3262195763556743`"},
            {\(-2.164641687168828`\), \(-3.3636775062673774`\)},
            {\(-1.9791341315066708`\), "2.2545571825760566`"},
            {\(-1.2066011430112074`\), \(-3.8136745642076004`\)},
            {\(-0.8471947892797289`\), \(-3.909253252095098`\)},
            {"1.341684611745621`", \(-2.6832596599288956`\)},
            {"1.5356318461955782`", "3.6934854586083317`"},
            {"1.9329382342394574`", \(-3.5019637037832014`\)},
            {"2.2168960341614494`", \(-2.021230311894574`\)},
            {"2.295817716341095`", \(-3.275548963660053`\)},
            {"2.35742665135792`", "3.231491851060164`"},
            {"3.15376571098448`", "2.4604393591833422`"},
            {"3.15790247093282`", \(-2.455127692010359`\)},
            {"3.4702909352499347`", \(-1.989241268605486`\)},
            {"3.590789670484168`", "1.762449869455633`"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output"]
}, Closed]],

Cell["The solutions can be verified by back-substitution:", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\((Chop[#1, 1\/10\^4] &)\)[
      N[Apply[Function[{x, y}, {f[x, y], g[x, y]}], solns, 1]]]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"0", "0"},
            {"0", "0"},
            {"0", "0"},
            {"0", "0"},
            {"0", "0"},
            {"0", "0"},
            {"0", "0"},
            {"0", "0"},
            {"0", "0"},
            {"0", "0"},
            {"0", "0"},
            {"0", "0"},
            {"0", "0"},
            {"0", "0"},
            {"0", "0"},
            {"0", "0"},
            {"0", "0"},
            {"0", "0"},
            {"0", "0"},
            {"0", "0"},
            {"0", "0"},
            {"0", "0"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output"]
}, Closed]],

Cell["and visualized:", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(ContourPlot[g[x, y], {x, \(-4\), 4}, {y, \(-4\), 4}];\)\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Graphics[ContourPlot[f[x, y], {x, \(-4\), 4}, {y, \(-4\), 4}]] /. 
        GrayLevel[0. ] \[Rule] RGBColor[1, 0, 0];\)\)], "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[%%, %, DisplayFunction \[Rule] $DisplayFunction, 
        Epilog \[Rule] {RGBColor[0, 0, 1], AbsolutePointSize[7], 
            Point /@ solns}];\)\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.500085 0.119069 [
[.02381 -0.0125 -6 -9 ]
[.02381 -0.0125 6 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .02381 -12 -4.5 ]
[-0.0125 .02381 0 4.5 ]
[-0.0125 .26195 -12 -4.5 ]
[-0.0125 .26195 0 4.5 ]
[-0.0125 .50009 -6 -4.5 ]
[-0.0125 .50009 0 4.5 ]
[-0.0125 .73822 -6 -4.5 ]
[-0.0125 .73822 0 4.5 ]
[-0.0125 .97636 -6 -4.5 ]
[-0.0125 .97636 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-4)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-2)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(2)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.08333 0 m
.08333 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.20238 0 m
.20238 .00375 L
s
.32143 0 m
.32143 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.44048 0 m
.44048 .00375 L
s
.55952 0 m
.55952 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.67857 0 m
.67857 .00375 L
s
.79762 0 m
.79762 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .02381 m
.00625 .02381 L
s
[(-4)] -0.0125 .02381 1 0 Mshowa
0 .26195 m
.00625 .26195 L
s
[(-2)] -0.0125 .26195 1 0 Mshowa
0 .50009 m
.00625 .50009 L
s
[(0)] -0.0125 .50009 1 0 Mshowa
0 .73822 m
.00625 .73822 L
s
[(2)] -0.0125 .73822 1 0 Mshowa
0 .97636 m
.00625 .97636 L
s
[(4)] -0.0125 .97636 1 0 Mshowa
.125 Mabswid
0 .08334 m
.00375 .08334 L
s
0 .14288 m
.00375 .14288 L
s
0 .20241 m
.00375 .20241 L
s
0 .32148 m
.00375 .32148 L
s
0 .38102 m
.00375 .38102 L
s
0 .44055 m
.00375 .44055 L
s
0 .55962 m
.00375 .55962 L
s
0 .61915 m
.00375 .61915 L
s
0 .67869 m
.00375 .67869 L
s
0 .79776 m
.00375 .79776 L
s
0 .85729 m
.00375 .85729 L
s
0 .91683 m
.00375 .91683 L
s
.25 Mabswid
0 0 m
0 1 L
s
.02381 .99375 m
.02381 1 L
s
.2619 .99375 m
.2619 1 L
s
.5 .99375 m
.5 1 L
s
.7381 .99375 m
.7381 1 L
s
.97619 .99375 m
.97619 1 L
s
.125 Mabswid
.08333 .99625 m
.08333 1 L
s
.14286 .99625 m
.14286 1 L
s
.20238 .99625 m
.20238 1 L
s
.32143 .99625 m
.32143 1 L
s
.38095 .99625 m
.38095 1 L
s
.44048 .99625 m
.44048 1 L
s
.55952 .99625 m
.55952 1 L
s
.61905 .99625 m
.61905 1 L
s
.67857 .99625 m
.67857 1 L
s
.79762 .99625 m
.79762 1 L
s
.85714 .99625 m
.85714 1 L
s
.91667 .99625 m
.91667 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .02381 m
1 .02381 L
s
.99375 .26195 m
1 .26195 L
s
.99375 .50009 m
1 .50009 L
s
.99375 .73822 m
1 .73822 L
s
.99375 .97636 m
1 .97636 L
s
.125 Mabswid
.99625 .08334 m
1 .08334 L
s
.99625 .14288 m
1 .14288 L
s
.99625 .20241 m
1 .20241 L
s
.99625 .32148 m
1 .32148 L
s
.99625 .38102 m
1 .38102 L
s
.99625 .44055 m
1 .44055 L
s
.99625 .55962 m
1 .55962 L
s
.99625 .61915 m
1 .61915 L
s
.99625 .67869 m
1 .67869 L
s
.99625 .79776 m
1 .79776 L
s
.99625 .85729 m
1 .85729 L
s
.99625 .91683 m
1 .91683 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.49193 .33027 m
.50807 .32664 L
.52421 .32482 L
.54036 .32402 L
.5565 .32393 L
.57264 .32447 L
.58878 .32562 L
.60492 .32742 L
.62107 .32998 L
.62419 .33056 L
.63721 .33339 L
.65335 .33803 L
.66949 .34431 L
.67459 .34671 L
.68563 .35264 L
.69976 .36285 L
.70178 .36445 L
.7151 .379 L
.71792 .38205 L
.72433 .39514 L
.72883 .41129 L
.72922 .42743 L
.72581 .44358 L
.71878 .45972 L
.71792 .4613 L
.70834 .47587 L
.70178 .48413 L
.6948 .49201 L
.68563 .50146 L
.6787 .50816 L
.66949 .51664 L
.66095 .5243 L
.65335 .53101 L
.64277 .54045 L
.63721 .54548 L
.62551 .55659 L
.62107 .56096 L
.6099 .57274 L
.60492 .57814 L
.59559 .58888 L
.58878 .5967 L
.58138 .60503 L
.57264 .61475 L
.56594 .62117 L
.5565 .63071 L
.54824 .63732 L
.54036 .64434 L
.5276 .65346 L
.52421 .65609 L
.50807 .66737 L
Mistroke
.50366 .66961 L
.49193 .67726 L
.47615 .68575 L
.47579 .68596 L
.45964 .69502 L
.44493 .7019 L
.4435 .70262 L
.42736 .71057 L
.41122 .7175 L
.40974 .71804 L
.39508 .72448 L
.37893 .73104 L
.37011 .73419 L
.36279 .73703 L
.34665 .7431 L
.33051 .74864 L
.32503 .75033 L
.31437 .75387 L
.29822 .75903 L
.28208 .76382 L
.272 .76648 L
.26594 .76809 L
.2498 .77231 L
.23366 .77629 L
.21751 .77989 L
.20279 .78262 L
.20137 .78287 L
.18523 .78568 L
.16909 .78833 L
.15295 .79073 L
.1368 .7929 L
.12066 .795 L
.10452 .79775 L
.08838 .79505 L
.07224 .79502 L
.05609 .79414 L
.03995 .79139 L
.03155 .78262 L
.03995 .77448 L
.05277 .76648 L
.05609 .76473 L
.07224 .75674 L
.08593 .75033 L
.08838 .74904 L
.10452 .74057 L
.12066 .73436 L
.12265 .73419 L
.1368 .72776 L
.15295 .72082 L
.16044 .71804 L
Mistroke
.16909 .71427 L
.18523 .70729 L
.1983 .7019 L
.20137 .70057 L
.21751 .69356 L
.23366 .68663 L
.23575 .68575 L
.2498 .6796 L
.26594 .6725 L
.27254 .66961 L
.28208 .66536 L
.29822 .6581 L
.30851 .65346 L
.31437 .6508 L
.33051 .64335 L
.34342 .63732 L
.34665 .6358 L
.36279 .62807 L
.37689 .62117 L
.37893 .62016 L
.39508 .61197 L
.40824 .60503 L
.41122 .60342 L
.42736 .59434 L
.43642 .58888 L
.4435 .58444 L
.45964 .57314 L
.46016 .57274 L
.47579 .55914 L
.47818 .55659 L
.49022 .54045 L
.49193 .53757 L
.49692 .5243 L
.49968 .50816 L
.49972 .49201 L
.49794 .47587 L
.49489 .45972 L
.49193 .44713 L
.49088 .44358 L
.48609 .42743 L
.48074 .41129 L
.47579 .39708 L
.47512 .39514 L
.46984 .379 L
.4663 .36285 L
.46822 .34671 L
.47579 .33774 L
.49102 .33056 L
.49193 .33027 L
Mfstroke
.63721 .18369 m
.65335 .1813 L
.66949 .178 L
.68563 .17824 L
.70178 .17865 L
.71792 .17929 L
.73406 .18018 L
.7502 .18139 L
.76634 .18294 L
.78249 .18479 L
.78637 .18526 L
.79863 .18686 L
.81477 .18976 L
.83091 .19351 L
.84705 .198 L
.85825 .2014 L
.8632 .20241 L
.87934 .20809 L
.89548 .21612 L
.89807 .21755 L
.91162 .22516 L
.92403 .23369 L
.92776 .23722 L
.93452 .24984 L
.92776 .25806 L
.91162 .26352 L
.89548 .26596 L
.89529 .26598 L
.87934 .26727 L
.8632 .26776 L
.84705 .26768 L
.83091 .26711 L
.81477 .26607 L
.81358 .26598 L
.79863 .26465 L
.78249 .26263 L
.76634 .25995 L
.7502 .25656 L
.73406 .25246 L
.72483 .24984 L
.71792 .24781 L
.70178 .24218 L
.68563 .23554 L
.68142 .23369 L
.66949 .23008 L
.65335 .22043 L
.64911 .21755 L
.63721 .2101 L
.62627 .2014 L
.63111 .18526 L
Mistroke
.63721 .18369 L
Mfstroke
.02381 .93584 m
.03995 .93306 L
.05609 .93019 L
.07224 .9297 L
.08435 .92793 L
.08838 .92728 L
.10452 .92651 L
.12066 .92301 L
.1368 .91924 L
.15295 .9155 L
.16909 .91212 L
.17099 .91178 L
.18523 .90848 L
.20137 .9082 L
.21751 .90228 L
.23366 .89682 L
.23736 .89564 L
.2498 .89204 L
.26594 .88723 L
.28208 .88225 L
.29063 .87949 L
.29822 .8765 L
.31437 .86921 L
.32379 .86335 L
.31437 .85467 L
.29822 .85246 L
.28208 .85169 L
.26594 .85162 L
.2498 .85203 L
.23366 .84907 L
.21751 .85242 L
.20137 .85477 L
.18523 .85702 L
.16909 .85936 L
.15295 .86172 L
.13997 .86335 L
.1368 .86351 L
.12066 .86583 L
.10452 .86908 L
.08838 .87262 L
.07224 .8762 L
.0563 .87949 L
.05609 .87954 L
.03995 .88069 L
.02381 .88527 L
s
.02381 .26093 m
.03995 .26338 L
.05609 .2652 L
.0653 .26598 L
.07224 .26647 L
.08838 .26735 L
.10452 .26776 L
.12066 .26767 L
.1368 .26694 L
.14771 .26598 L
.15295 .26531 L
.16909 .26221 L
.18523 .25325 L
.18652 .24984 L
.18523 .24463 L
.17604 .23369 L
.16909 .22866 L
.15295 .21906 L
.15007 .21755 L
.1368 .2106 L
.12066 .20398 L
.11025 .2014 L
.10452 .19964 L
.08838 .19495 L
.07224 .19094 L
.05609 .18775 L
.03995 .18544 L
.03834 .18526 L
.02381 .18353 L
s
.02381 .11389 m
.03995 .11479 L
.05609 .11957 L
.06006 .12068 L
.07224 .1236 L
.08838 .12771 L
.10452 .13143 L
.12066 .13447 L
.1368 .13649 L
.14318 .13682 L
.15295 .13777 L
.16909 .13934 L
.18523 .14068 L
.20137 .14177 L
.21751 .14264 L
.23366 .1434 L
.2498 .1442 L
.26594 .14128 L
.28208 .13991 L
.29822 .13702 L
.29892 .13682 L
.29822 .12116 L
.29753 .12068 L
.28208 .11347 L
.26594 .10716 L
.25859 .10453 L
.2498 .10132 L
.23366 .09537 L
.21751 .09 L
.20137 .08973 L
.19474 .08839 L
.18523 .0881 L
.16909 .0852 L
.15295 .08232 L
.1368 .07986 L
.12066 .0777 L
.10452 .07555 L
.08838 .07714 L
.07224 .07664 L
.05609 .07643 L
.03995 .07652 L
.02381 .07702 L
s
.97619 .89862 m
.96005 .90424 L
.94391 .91028 L
.92776 .90975 L
.91899 .91178 L
.91162 .91319 L
.89548 .91675 L
.87934 .92053 L
.8632 .92425 L
.84705 .9275 L
.83233 .92793 L
.83091 .92814 L
.81477 .92836 L
.79863 .93118 L
.78249 .93401 L
.76634 .9368 L
.7502 .94016 L
.73406 .93812 L
.71792 .9389 L
.70178 .9394 L
.68563 .93958 L
.66949 .93933 L
.65335 .93839 L
.63721 .93562 L
.63384 .92793 L
.63721 .92629 L
.65335 .91989 L
.66949 .9143 L
.67715 .91178 L
.68563 .90698 L
.70178 .90487 L
.71792 .90052 L
.73406 .89624 L
.73636 .89564 L
.7502 .89172 L
.76634 .88692 L
.78249 .88214 L
.79863 .88076 L
.80429 .87949 L
.81477 .87738 L
.83091 .87384 L
.84705 .87026 L
.8632 .86687 L
.87934 .8641 L
.88796 .86335 L
.89548 .86246 L
.91162 .86017 L
.92776 .8578 L
.94391 .85552 L
.96005 .85325 L
Mistroke
.97619 .85046 L
Mfstroke
.97619 .77756 m
.96005 .78098 L
.95081 .78262 L
.94391 .78383 L
.92776 .7866 L
.91162 .78917 L
.89548 .79149 L
.87934 .7936 L
.8632 .79578 L
.84705 .79474 L
.83091 .79511 L
.81477 .79484 L
.79863 .79353 L
.78249 .7891 L
.77941 .78262 L
.78249 .77891 L
.79863 .7677 L
.80077 .76648 L
.81477 .75937 L
.83091 .75172 L
.83392 .75033 L
.84705 .74339 L
.8632 .7358 L
.87064 .73419 L
.87934 .73024 L
.89548 .72307 L
.90844 .71804 L
.91162 .71666 L
.92776 .70963 L
.94391 .70285 L
.9463 .7019 L
.96005 .69593 L
.97619 .68896 L
s
.97619 .14315 m
.96005 .14237 L
.94391 .14143 L
.92776 .14026 L
.91162 .13883 L
.89548 .13723 L
.8912 .13682 L
.87934 .13595 L
.8632 .13353 L
.84705 .13024 L
.83091 .12634 L
.81477 .12223 L
.80806 .12068 L
.79863 .118 L
.78249 .11307 L
.76634 .10992 L
.75809 .10453 L
.7502 .10113 L
.73406 .09276 L
.72865 .08839 L
.73406 .08224 L
.7502 .07874 L
.76634 .07731 L
.78249 .07664 L
.79863 .07642 L
.81477 .07654 L
.83091 .07694 L
.84705 .07473 L
.8632 .07699 L
.87934 .0791 L
.89548 .08144 L
.91162 .08418 L
.92776 .08721 L
.94272 .08839 L
.94391 .08862 L
.96005 .09205 L
.97619 .09344 L
s
.97619 .04114 m
.96637 .03995 L
.96005 .03912 L
.94391 .03668 L
.92776 .03384 L
.91162 .03067 L
.89548 .02733 L
.87934 .02405 L
.8781 .02381 L
s
.37633 .02381 m
.37893 .0245 L
.39508 .03009 L
.3989 .03995 L
.39508 .04138 L
.37893 .04422 L
.36279 .04549 L
.34665 .04611 L
.33051 .04634 L
.31437 .04981 L
.29822 .04751 L
.28208 .04578 L
.26594 .04404 L
.2498 .04204 L
.23366 .04173 L
.21834 .03995 L
.21751 .03985 L
.20137 .03756 L
.18523 .03485 L
.16909 .03177 L
.15295 .02846 L
.1368 .02514 L
.13009 .02381 L
s
1 0 0 r
.42736 .15039 m
.4435 .14744 L
.45964 .14523 L
.47579 .14376 L
.49193 .14302 L
.50807 .14302 L
.52421 .14376 L
.54036 .14523 L
.5565 .14744 L
.57264 .15039 L
.58432 .15297 L
.58878 .1541 L
.60492 .15869 L
.62107 .16408 L
.63435 .16911 L
.63721 .1703 L
.65335 .17753 L
.66873 .18526 L
.66949 .18567 L
.68563 .19496 L
.69588 .2014 L
.70178 .20537 L
.71792 .21709 L
.71852 .21755 L
.73406 .2303 L
.73792 .23369 L
.7502 .24521 L
.75483 .24984 L
.76634 .26212 L
.76973 .26598 L
.78249 .28152 L
.78295 .28213 L
.79466 .29827 L
.79863 .30417 L
.80507 .31442 L
.81436 .33056 L
.81477 .33132 L
.8225 .34671 L
.82973 .36285 L
.83091 .36572 L
.83594 .379 L
.84134 .39514 L
.84592 .41129 L
.84705 .41575 L
.84963 .42743 L
.85258 .44358 L
.85479 .45972 L
.85626 .47587 L
.857 .49201 L
.857 .50816 L
Mistroke
.85626 .5243 L
.85479 .54045 L
.85258 .55659 L
.84963 .57274 L
.84705 .58442 L
.84592 .58888 L
.84134 .60503 L
.83594 .62117 L
.83091 .63446 L
.82973 .63732 L
.8225 .65346 L
.81477 .66885 L
.81436 .66961 L
.80507 .68575 L
.79863 .696 L
.79466 .7019 L
.78295 .71804 L
.78249 .71865 L
.76973 .73419 L
.76634 .73805 L
.75483 .75033 L
.7502 .75496 L
.73792 .76648 L
.73406 .76987 L
.71852 .78262 L
.71792 .78309 L
.70178 .7948 L
.69588 .79877 L
.68563 .80521 L
.66949 .8145 L
.66873 .81491 L
.65335 .82264 L
.63721 .82987 L
.63435 .83106 L
.62107 .83609 L
.60492 .84148 L
.58878 .84607 L
.58432 .8472 L
.57264 .84978 L
.5565 .85273 L
.54036 .85494 L
.52421 .85641 L
.50807 .85715 L
.49193 .85715 L
.47579 .85641 L
.45964 .85494 L
.4435 .85273 L
.42736 .84978 L
.41568 .8472 L
.41122 .84607 L
Mistroke
.39508 .84148 L
.37893 .83609 L
.36565 .83106 L
.36279 .82987 L
.34665 .82264 L
.33127 .81491 L
.33051 .8145 L
.31437 .80521 L
.30412 .79877 L
.29822 .7948 L
.28208 .78309 L
.28148 .78262 L
.26594 .76987 L
.26208 .76648 L
.2498 .75496 L
.24517 .75033 L
.23366 .73805 L
.23027 .73419 L
.21751 .71865 L
.21705 .71804 L
.20534 .7019 L
.20137 .696 L
.19493 .68575 L
.18564 .66961 L
.18523 .66885 L
.1775 .65346 L
.17027 .63732 L
.16909 .63446 L
.16406 .62117 L
.15866 .60503 L
.15408 .58888 L
.15295 .58442 L
.15037 .57274 L
.14742 .55659 L
.14521 .54045 L
.14374 .5243 L
.143 .50816 L
.143 .49201 L
.14374 .47587 L
.14521 .45972 L
.14742 .44358 L
.15037 .42743 L
.15295 .41575 L
.15408 .41129 L
.15866 .39514 L
.16406 .379 L
.16909 .36572 L
.17027 .36285 L
.1775 .34671 L
.18523 .33132 L
Mistroke
.18564 .33056 L
.19493 .31442 L
.20137 .30417 L
.20534 .29827 L
.21705 .28213 L
.21751 .28152 L
.23027 .26598 L
.23366 .26212 L
.24517 .24984 L
.2498 .24521 L
.26208 .23369 L
.26594 .2303 L
.28148 .21755 L
.28208 .21709 L
.29822 .20537 L
.30412 .2014 L
.31437 .19496 L
.33051 .18567 L
.33127 .18526 L
.34665 .17753 L
.36279 .1703 L
.36565 .16911 L
.37893 .16408 L
.39508 .15869 L
.41122 .1541 L
.41568 .15297 L
.42736 .15039 L
Mfstroke
.37893 .0395 m
.39508 .03604 L
.41122 .03335 L
.42736 .03119 L
.4435 .02919 L
.45964 .02714 L
.47579 .02521 L
.49193 .02398 L
.50807 .02398 L
.52421 .02521 L
.54036 .02714 L
.5565 .02919 L
.57264 .03119 L
.58878 .03335 L
.60492 .03604 L
.62107 .0395 L
.62294 .03995 L
.63721 .04383 L
.65335 .04902 L
.66949 .05497 L
.67236 .0561 L
.68563 .06132 L
.70178 .0686 L
.70925 .07224 L
.71792 .07646 L
.73406 .08525 L
.73946 .08839 L
.7502 .09471 L
.76525 .10453 L
.76634 .10525 L
.78249 .1166 L
.7879 .12068 L
.79863 .129 L
.80804 .13682 L
.81477 .14261 L
.82612 .15297 L
.83091 .15752 L
.8425 .16911 L
.84705 .1739 L
.85741 .18526 L
.8632 .19199 L
.87102 .2014 L
.87934 .21214 L
.88342 .21755 L
.89477 .23369 L
.89548 .23478 L
.9053 .24984 L
.91162 .26059 L
.91476 .26598 L
.92354 .28213 L
Mistroke
.92776 .29079 L
.93141 .29827 L
.93869 .31442 L
.94391 .32769 L
.94503 .33056 L
.95098 .34671 L
.95617 .36285 L
.96005 .37712 L
.9605 .379 L
.96396 .39514 L
.96665 .41129 L
.96882 .42743 L
.97081 .44358 L
.97286 .45972 L
.97479 .47587 L
.97602 .49201 L
.97602 .50816 L
.97479 .5243 L
.97286 .54045 L
.97081 .55659 L
.96882 .57274 L
.96665 .58888 L
.96396 .60503 L
.9605 .62117 L
.96005 .62305 L
.95617 .63732 L
.95098 .65346 L
.94503 .66961 L
.94391 .67248 L
.93869 .68575 L
.93141 .7019 L
.92776 .70938 L
.92354 .71804 L
.91476 .73419 L
.91162 .73958 L
.9053 .75033 L
.89548 .76539 L
.89477 .76648 L
.88342 .78262 L
.87934 .78803 L
.87102 .79877 L
.8632 .80818 L
.85741 .81491 L
.84705 .82627 L
.8425 .83106 L
.83091 .84265 L
.82612 .8472 L
.81477 .85756 L
.80804 .86335 L
.79863 .87117 L
Mistroke
.7879 .87949 L
.78249 .88357 L
.76634 .89492 L
.76525 .89564 L
.7502 .90546 L
.73946 .91178 L
.73406 .91492 L
.71792 .92371 L
.70925 .92793 L
.70178 .93157 L
.68563 .93885 L
.67236 .94407 L
.66949 .9452 L
.65335 .95115 L
.63721 .95634 L
.62294 .96022 L
.62107 .96067 L
.60492 .96413 L
.58878 .96682 L
.57264 .96898 L
.5565 .97098 L
.54036 .97303 L
.52421 .97496 L
.50807 .97619 L
.49193 .97619 L
.47579 .97496 L
.45964 .97303 L
.4435 .97098 L
.42736 .96898 L
.41122 .96682 L
.39508 .96413 L
.37893 .96067 L
.37706 .96022 L
.36279 .95634 L
.34665 .95115 L
.33051 .9452 L
.32764 .94407 L
.31437 .93885 L
.29822 .93157 L
.29075 .92793 L
.28208 .92371 L
.26594 .91492 L
.26054 .91178 L
.2498 .90546 L
.23475 .89564 L
.23366 .89492 L
.21751 .88357 L
.2121 .87949 L
.20137 .87117 L
.19196 .86335 L
Mistroke
.18523 .85756 L
.17388 .8472 L
.16909 .84265 L
.1575 .83106 L
.15295 .82627 L
.14259 .81491 L
.1368 .80818 L
.12898 .79877 L
.12066 .78803 L
.11658 .78262 L
.10523 .76648 L
.10452 .76539 L
.0947 .75033 L
.08838 .73958 L
.08524 .73419 L
.07646 .71804 L
.07224 .70938 L
.06859 .7019 L
.06131 .68575 L
.05609 .67248 L
.05497 .66961 L
.04902 .65346 L
.04383 .63732 L
.03995 .62305 L
.0395 .62117 L
.03604 .60503 L
.03335 .58888 L
.03118 .57274 L
.02919 .55659 L
.02714 .54045 L
.02521 .5243 L
.02398 .50816 L
.02398 .49201 L
.02521 .47587 L
.02714 .45972 L
.02919 .44358 L
.03118 .42743 L
.03335 .41129 L
.03604 .39514 L
.0395 .379 L
.03995 .37712 L
.04383 .36285 L
.04902 .34671 L
.05497 .33056 L
.05609 .32769 L
.06131 .31442 L
.06859 .29827 L
.07224 .29079 L
.07646 .28213 L
.08524 .26598 L
Mistroke
.08838 .26059 L
.0947 .24984 L
.10452 .23478 L
.10523 .23369 L
.11658 .21755 L
.12066 .21214 L
.12898 .2014 L
.1368 .19199 L
.14259 .18526 L
.15295 .1739 L
.1575 .16911 L
.16909 .15752 L
.17388 .15297 L
.18523 .14261 L
.19196 .13682 L
.20137 .129 L
.2121 .12068 L
.21751 .1166 L
.23366 .10525 L
.23475 .10453 L
.2498 .09471 L
.26054 .08839 L
.26594 .08525 L
.28208 .07646 L
.29075 .07224 L
.29822 .0686 L
.31437 .06132 L
.32764 .0561 L
.33051 .05497 L
.34665 .04902 L
.36279 .04383 L
.37706 .03995 L
.37893 .0395 L
Mfstroke
0 0 1 r
7 Mabswid
.08464 .26717 Mdot
.09291 .74719 Mdot
.12473 .79327 Mdot
.12496 .2066 Mdot
.18484 .85713 Mdot
.18746 .14075 Mdot
.20374 .69957 Mdot
.2355 .89613 Mdot
.2423 .09958 Mdot
.26439 .76853 Mdot
.35636 .046 Mdot
.39914 .03461 Mdot
.65972 .18059 Mdot
.68281 .93986 Mdot
.73011 .08311 Mdot
.76392 .25942 Mdot
.77331 .11007 Mdot
.78065 .88486 Mdot
.87545 .79305 Mdot
.87594 .20776 Mdot
.91313 .26323 Mdot
.92747 .70994 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`005oooool3o`0003cooooo1Ol0000kooooo`;o0000
??ooool5o`0003kooooo0ol00006ooooo`006?ooool00ol0003oooooooooo`0looooo`04o`000?oo
ooooooooo`0003[ooooo00Co0000oooooooooooo0000??ooool01?l0003oooooooooool0000ooooo
o`03o`000?oooooooooo00Gooooo000?ooooo`Go000000?oooooo`000?l000000ol0000fooooo`Go
00000oooool00ol0003oooooooooo`0jooooo`04o`000?ooooooooooo`0003gooooo00?o0000oooo
ooooool0??ooool5o`0000Kooooo000Eooooo`04o`000?ooooooooooo`00043ooooo00?o0000oooo
ooooool0>Oooool01?l0003oooooooooool0000nooooo`03o`000?oooooooooo03_ooooo00Co0000
oooooooooooo00001oooool001Kooooo00?o0000ooooool00000?Oooool01Ol0003ooooooooooooo
oooo000003[ooooo00Co0000oooooooooooo0000>oooool01Ol0003ooooooooooooooooo000003go
oooo00?o0000ooooool000001oooool001Oooooo0_l0000mooooo`05o`000?ooooooooooooooool0
0000>_ooool01?l0003oooooooooool0000kooooo`05o`000?ooooooooooooooool00000?_ooool2
o`0000Oooooo000Hooooo`03o`000?oooooooooo03cooooo0ol0000looooo`;o0000?Oooool3o`00
043ooooo00?o0000ooooooooool01Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Ooo
ool00?oooooo8Oooool000ooooooool0000Ao`00007ooooo000?ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`03ooooo`7o00000Oooool000oooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo
00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00?ooooo
0Ol00001ooooo`003oooool00ol0003oooooooooo`3oooooo`gooooo0Ol00001ooooo`002?ooool3
o`0000Cooooo00?o0000ooooooooool0ooooool=ooooo`7o00000Oooool000Wooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`3oooooo`gooooo0Ol00001ooooo`001Ol000000ooooooo
0000o`000003o`0000Cooooo00?o0000ooooooooool0ooooool=ooooo`7o00000Oooool000Kooooo
00Co0000oooooooooooo00001Oooool3o`00023ooooo1Ol0000nooooo`?o00000_ooool3o`00oa7o
oooo4ooo001Looooo`Co00007?ooool2o`00007ooooo0007ooooo`03o`000?oooooo000000Gooooo
00?o0000ooooooooool09Oooool5o`0003cooooo00?o0000o`00ool00?l00ol00?l7ooooo`Woo`00
4oooool8ool005Sooooo1?l0000Iooooo`7o00000Oooool000Sooooo0_l00005ooooo`03o`000?oo
oooooooo02[ooooo1?l0000hooooo`Oo003o0_ooool4ool002Cooooo1Ooo001Gooooo`Go00005?oo
ool1o`00007ooooo0009ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0;_ooool5
o`0002[ooooo0ol00?l6ooooo`Oo003o0_oo000]ooooo`Woo`00Doooool9o`0000_ooooo0Ol00001
ooooo`003oooool00ol0003oooooooooo`0cooooo`So00008Oooool5o`00o`Goo`001ol00?lhoooo
o`Coo`00F?ooool5o`0000Kooooo0Ol00001ooooo`003oooool00ol0003oooooooooo`0kooooo`go
00004oooool7o`00o`Go00001Ol00?lmooooo`?oo`00F_ooool00ol0003oooooooooo`03ooooo`7o
00000Oooool000oooooo00?o0000ooooooooool0B?ooool9o`0000Cooooo1_l00007o`00o`Kooooo
0ol00?m1ooooo`;oo`00G_ooool1o`00007ooooo000?ooooo`03o`000?oooooooooo057ooooo1?l0
0004ooooo`;oo`001ol00?m<ooooo`Coo`00F_ooool1o`00007ooooo000?ooooo`03o`000?oooooo
oooo05Oooooo0_oo0003ooooo`Go003oDOooool2ool005Sooooo0Ol00001ooooo`003oooool00ol0
003oooooooooo`1Dooooo`?oo`001_ooool3o`00oe?ooooo0ooo001Fooooo`7o00000Oooool000oo
oooo00?o0000ooooooooool0DOooool3ool006;ooooo0ooo001Cooooo`7o00000Oooool000oooooo
00?o0000ooooooooool0Coooool2ool006Sooooo0_oo001Aooooo`7o00000Oooool000oooooo00?o
0000ooooooooool0COooool2ool006cooooo0_oo001?ooooo`7o00000Oooool000oooooo00?o0000
ooooooooool0Boooool2ool0073ooooo0ooo0002ooooo`?o003oAoooool1o`00007ooooo000?oooo
o`03o`000?oooooooooo00?ooooo6_l0000[ooooo`?oo`00MOooool00ooo003o003oo`00o`03o`00
o`Gooooo8?l0000Qooooo`7o00000Oooool000oooooo00?o0000ooooooooool07Oooool8o`0002;o
oooo00?oo`00ooooooooool0M_ooool7o`00o`Co00008?ooool4o`0001gooooo0Ol00001ooooo`00
3oooool2o`0002Kooooo1Ol0000Looooo`03ool00?oooooooooo07Oooooo1ol00?lXooooo`Wo0000
4oooool2o`00007ooooo000?ooooo`03o`000?oooooooooo02[ooooo2_l0000:ooooo`?o003o0_oo
ool3ool007[ooooo1ol00?l00ooo003oooooooooo`0^ooooo`Ko00003_ooool1o`00007ooooo000?
ooooo`03o`000?oooooooooo03Cooooo1ol00002ooooo`Go003o00?oo`00ooooooooool0O?ooool5
o`00o`;ooooo00?oo`00ooooooooool0<_ooool8o`0000Oooooo0Ol00001ooooo`003oooool00ol0
003oooooooooo`0kooooo`03o`000?l00?oo003o00Go003oOoooool3o`00o`04o`000?oooooooooo
ooooo`;oo`00>_ooool2o`0000Gooooo0Ol00001ooooo`003oooool00ol0003oooooooooo`0loooo
o`Oo003oPoooool3o`0000;ooooo00?oo`00ooooooooool00ol00?lkooooo`7o00000Oooool000oo
oooo00?o0000ooooooooool0??ooool7o`00ohKooooo0_l000000oooooooo`00o`00o`04o`00oc[o
oooo0Ol00001ooooo`003oooool00ol0003oooooooooo`0kooooo`;oo`001Ol00?l00ooooooo0000
o`000026ooooo`03o`000?l00?oo003o00Go003o>Oooool1o`00007ooooo000?ooooo`03o`000?oo
oooooooo03[ooooo00Coo`00oooooooooooooooo0ol00?l4ooooo`?o0000Q?ooool7o`00ocWooooo
0Ol00001ooooo`003oooool00ol0003oooooooooo`03ooooo`Co0000<_ooool00ooo003ooooooooo
o`0<ooooo`?o0000POooool7o`00o`;o0000=oooool1o`00007ooooo000?ooooo`03o`000?oooooo
oooo00Oooooo1?l0000/ooooo`;oo`004_ooool3o`0007oooooo1Ol00?l00ooo003oooooooooo`03
o`0003Cooooo0Ol00001ooooo`003oooool00ol0003oooooooooo`0;ooooo`Go00009_ooool00ooo
003oooooooooo`0Eooooo`03o`000?oooooooooo07gooooo0ol00?l2ooooo`;oo`000oooool2o`00
03;ooooo0Ol00001ooooo`003oooool00ol0003oooooooooo`0@ooooo`Co00008Oooool00ooo003o
ooooooooo`0Fooooo`03o`000?oooooooooo08Cooooo00?oo`00ooooooooool00_ooool3o`0002oo
oooo0Ol00001ooooo`003oooool00ol0003oooooooooo`0Dooooo`Co00007?ooool00ooo003ooooo
ooooo`0Gooooo`03o`000?oooooooooo08Gooooo00?oo`00ooooooooool01?ooool5o`0002[ooooo
0Ol00001ooooo`003oooool00ol0003oooooooooo`0Hooooo`Go00004_ooool3o`00o`03oooooooo
003ooooo01Wooooo00?o0000ooooooooool0QOooool00ooo003oooooooooo`09ooooo`Co00009_oo
ool1o`00007ooooo000?ooooo`03o`000?oooooooooo01gooooo1?l0000=ooooo`Go003o6oooool0
0ol0003oooooooooo`26ooooo`03ool00?oooooooooo00cooooo2Ol0000Mooooo`7o00000Oooool0
00oooooo00?o0000ooooooooool08Oooool<o`0000Oo003o4oooool8o`0008Wooooo0_oo000Eoooo
o`Wo00005?ooool1o`00007ooooo000?ooooo`;o0000;_ooool7o`00o`co00000oooool4o`0003Go
oooo4ooo001;ooooo`03ool00?oooooooooo01_ooooo3ol00004ooooo`;o00000Oooool000oooooo
00?o0000ooooooooool0;Oooool7o`00o`cooooo0ol0000`ooooo`Woo`004oooool8ool004Cooooo
00?oo`00ooooooooool0;_ooool1o`00007ooooo000?ooooo`03o`000?oooooooooo02gooooo00?o
o`00o`00ool00?l00ol00?lmooooo`?oo`009?ooool4ool0047ooooo00?oo`00ooooooooool0;Ooo
ool1o`00007ooooo000?ooooo`03o`000?oooooooooo02cooooo00?oo`00ooooooooool00ol00?lj
ooooo`Coo`00:oooool4ool003kooooo00?oo`00ooooooooool0;?ooool1o`00007ooooo000?oooo
o`03o`000?oooooooooo02_ooooo00?oo`00ooooooooool0>oooool3ool003?ooooo0_oo000moooo
o`;oo`00;?ooool1o`00007ooooo000?ooooo`03o`000?oooooooooo02[ooooo00?oo`00oooooooo
ool0>Oooool3ool003Sooooo1?oo000kooooo`03ool00?oooooooooo02Wooooo0Ol00001ooooo`00
3oooool00ol0003oooooooooo`0Yooooo`03ool00?oooooooooo03Kooooo1?oo000oooooo`Coo`00
>?ooool00ooo003oooooooooo`0Xooooo`7o00000Oooool000oooooo00?o0000ooooooooool0:?oo
ool00ooo003oooooooooo`0eooooo`;oo`00Aoooool00ooo003oooooooooo`03ooooo`?o003o<?oo
ool00ooo003oooooooooo`0Wooooo`7o00000Oooool000oooooo00?o0000ooooooooool09oooool0
0ooo003oooooooooo`0dooooo`;oo`00B_ooool2ool000;ooooo1Ol00?l_ooooo`03ool00?oooooo
oooo02Oooooo0Ol00001ooooo`003oooool00ol0003oooooooooo`0Vooooo`03ool00?oooooooooo
03?ooooo0_oo001>ooooo`03ool00?l00?oo003o00Go003o;oooool00ooo003oooooooooo`0Voooo
o`7o00000Oooool000oooooo00?o0000ooooooooool09_ooool00ooo003oooooooooo`0aooooo`;o
o`00DOooool7o`00oaCo00007?ooool00ooo003oooooooooo`0Uooooo`7o00000Oooool000oooooo
00?o0000ooooooooool00oooool3o`0001oooooo00?oo`00ooooooooool0<?ooool2ool004oooooo
1?l00007o`00oaCooooo2?l0000Eooooo`03ool00?oooooooooo02Cooooo0Ol00001ooooo`003ooo
ool00ol0003oooooooooo`06ooooo`[o00005?ooool00ooo003oooooooooo`0_ooooo`;oo`00D?oo
ool00ol0003oooooooooo`03ooooo`Go003o0_oo000Kooooo`Wo00003Oooool00ooo003ooooooooo
o`0Sooooo`7o00000Oooool000oooooo00?o0000ooooooooool04?ooool4o`0000oooooo00?oo`00
ooooooooool0;Oooool3ool005;ooooo00?o0000ooooooooool01?ooool3o`00o`?ooooo0_oo000R
ooooo`Co00002Oooool00ooo003oooooooooo`0Sooooo`7o00000Oooool000oooooo00?o0000oooo
ooooool05?ooool3o`0000_ooooo00?oo`00ooooooooool0;?ooool2ool005Gooooo00?o0000oooo
ooooool03?ooool2ool002Cooooo1Ol00005ooooo`03ool00?oooooooooo02;ooooo0Ol00001oooo
o`003oooool00ol0003oooooooooo`0Gooooo`;o00001Oooool3o`00o`03ool00?oooooooooo02co
oooo00?oo`00ooooooooool0E?ooool00ol0003oooooooooo`0?ooooo`03ool00?oooooooooo02Ko
oooo1?l00002ooooo`03ool00?oooooo003o00;o003o7oooool1o`00007ooooo000?ooooo`;o0000
6_ooool4o`0000Go003o;Oooool00ooo003oooooooooo`1Eooooo`;o00004Oooool00ooo003ooooo
ooooo`0Yooooo`?o00001Ol00?lMooooo`;o00000Oooool000oooooo00?o0000ooooooooool07?oo
ool7o`00ob[ooooo0_oo001Jooooo`03o`000?oooooooooo00oooooo0_oo000[ooooo`Oo003o7Ooo
ool1o`00007ooooo000?ooooo`03o`000?oooooooooo01cooooo1ol00?lXooooo`;oo`00GOooool0
0ol0003oooooooooo`0@ooooo`;oo`00:Oooool7o`00oagooooo0Ol00001ooooo`003oooool00ol0
003oooooooooo`0Looooo`Oo003o00?o0000ooooooooool09?ooool00ooo003oooooooooo`1Noooo
o`03o`000?oooooooooo017ooooo00?oo`00ooooooooool09_ooool7o`00o`03o`000?oooooooooo
01[ooooo0Ol00001ooooo`003oooool00ol0003oooooooooo`0Mooooo`Go003o0_ooool2o`0002?o
oooo00?oo`00ooooooooool0H?ooool00ol0003oooooooooo`0Aooooo`03ool00?oooooooooo02Ko
oooo1Ol00?l2ooooo`03o`000?oooooooooo01Wooooo0Ol00001ooooo`003oooool00ol0003ooooo
ooooo`0Mooooo`04ool00?l00?oo003oo`00o`Gooooo0_l0000Pooooo`;oo`00Hoooool3o`00013o
oooo0_oo000Xooooo`?o003o00Coo`00oooooooooooooooo0_l0000Iooooo`7o00000Oooool000oo
oooo00?o0000ooooooooool07?ooool00ooo003oooooooooo`09ooooo`;o00007Oooool00ooo003o
ooooooooo`1Vooooo`;o00004?ooool00ooo003oooooooooo`0Xooooo`03ool00?oooooooooo00?o
oooo00?o0000ooooooooool05_ooool1o`00007ooooo000?ooooo`03o`000?oooooooooo01_ooooo
00?oo`00ooooooooool03?ooool00ol0003oooooooooo`0Iooooo`03ool00?oooooooooo06Wooooo
00?o0000ooooooooool03_ooool00ooo003oooooooooo`0Xooooo`03ool00?oooooooooo00?ooooo
0_l0000Fooooo`7o00000Oooool000oooooo00?o0000ooooooooool06_ooool00ooo003ooooooooo
o`0>ooooo`;o00006?ooool00ooo003oooooooooo`1[ooooo`?o00003_ooool00ooo003ooooooooo
o`0Xooooo`03ool00?oooooooooo00Cooooo0_l0000Dooooo`7o00000Oooool000oooooo00?o0000
ooooooooool06Oooool00ooo003oooooooooo`0Aooooo`03o`000?oooooooooo01Cooooo00?oo`00
ooooooooool0Koooool3o`0000cooooo0_oo000Yooooo`03ool00?oooooooooo00Gooooo00?o0000
ooooooooool04Oooool1o`00007ooooo000?ooooo`03o`000?oooooooooo01Wooooo00?oo`00oooo
ooooool04Oooool00ol0003oooooooooo`0Cooooo`03ool00?oooooooooo07?ooooo0_l0000<oooo
o`03ool00?oooooooooo02Kooooo00?oo`00ooooooooool01_ooool00ol0003oooooooooo`0@oooo
o`7o00000Oooool000oooooo00?o0000ooooooooool06?ooool00ooo003oooooooooo`0Cooooo`03
o`000?oooooooooo017ooooo00?oo`00ooooooooool0M_ooool2o`0000_ooooo00?oo`00oooooooo
ool09_ooool00ooo003oooooooooo`05ooooo`03o`000?oooooooooo013ooooo0Ol00001ooooo`00
3oooool00ol0003oooooooooo`0Hooooo`03ool00?oooooooooo01Cooooo00?o0000ooooooooool0
3_ooool2ool007_ooooo0ol00009ooooo`03ool00?oooooooooo02Kooooo00?oo`00ooooooooool0
1Oooool00ol0003oooooooooo`0?ooooo`7o00000Oooool000oooooo00?o0000ooooooooool05ooo
ool00ooo003oooooooooo`0Fooooo`03o`000?oooooooooo00cooooo00?oo`00ooooooooool0O_oo
ool4o`0000Kooooo00Coo`00o`00ool00?oo003o9Oooool00ooo003oooooooooo`05ooooo`03o`00
0?oooooooooo00kooooo0Ol00001ooooo`001_ooool5o`0000Cooooo00?o0000ooooooooool05ooo
ool00ooo003oooooooooo`0Dooooo`;o00003oooool00ooo003oooooooooo`22ooooo`Co00000_oo
ool5o`00obCooooo00Coo`00o`00ool00?oo003o1?ooool00ol0003oooooooooo`0>ooooo`7o0000
0Oooool000Oooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0Cooooo`?o003o
00?oo`00ooooooooool05?ooool00ol0003oooooooooo`0>ooooo`03ool00?oooooooooo08Oooooo
00?o0000o`00ool00?l01Ol00?lSooooo`Go003o0_ooool00ol0003oooooooooo`0?ooooo`7o0000
0Oooool000Go00000oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo1?l0
000;ooooo`Go003o5Oooool00ol0003oooooooooo`0>ooooo`03ool00?oooooooooo08Wooooo1ol0
0?lRooooo`Oo003o00?o0000ooooooooool04?ooool1o`00007ooooo0009ooooo`03o`000?oooooo
oooo00?ooooo0ol00007ooooo`So00000_ooool7o`00o`kooooo1_l0000@ooooo`03ool00?oooooo
oooo08[ooooo1ol00?l9o`0001Wooooo1ol00?lBooooo`;o00000Oooool000Kooooo00Go0000oooo
ooooooooooooo`000004ooooo`03o`000?oooooooooo00oooooo0_l00007o`00o`ko00005Oooool0
0ooo003oooooooooo`2<ooooo`Go003o2_oooolIo`0000Oo003o4oooool1o`00007ooooo0006oooo
o`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0Aooooo`Oo003o8oooool0
0ooo003oooooooooo`2=ooooo`?o003o00?oo`00ooooooooool08_ooool5o`00oaCooooo0Ol00001
ooooo`001oooool3o`0000Gooooo00?o0000ooooooooool04_ooool5o`00ob?ooooo00?oo`00oooo
ooooool0T_ooool00ooo003oooooooooo`0Rooooo`?o003o5Oooool1o`00007ooooo000?ooooo`03
o`000?oooooooooo01?ooooo0ol00?lSooooo`03ool00?oooooooooo09Cooooo00?oo`00oooooooo
ool09?ooool00ooo003oooooooooo`0Booooo`7o00000Oooool000oooooo00?o0000ooooooooool0
4_ooool00ooo003oooooooooo`0Sooooo`03ool00?oooooooooo09Kooooo00?oo`00ooooooooool0
9?ooool00ooo003oooooooooo`0Aooooo`7o00000Oooool000oooooo00?o0000ooooooooool04_oo
ool00ooo003oooooooooo`0Sooooo`03ool00?oooooooooo09Oooooo00?oo`00ooooooooool08ooo
ool00ooo003oooooooooo`0Aooooo`7o00000Oooool000oooooo00?o0000ooooooooool04Oooool0
0ooo003oooooooooo`0Sooooo`03ool00?oooooooooo09Wooooo00?oo`00ooooooooool08oooool0
0ooo003oooooooooo`0@ooooo`7o00000Oooool000oooooo00?o0000ooooooooool04Oooool00ooo
003oooooooooo`0Rooooo`03ool00?oooooooooo09_ooooo00?oo`00ooooooooool08_ooool00ooo
003oooooooooo`0@ooooo`7o00000Oooool000oooooo00?o0000ooooooooool04?ooool00ooo003o
ooooooooo`0Rooooo`03ool00?oooooooooo09gooooo00?oo`00ooooooooool08_ooool00ooo003o
ooooooooo`0?ooooo`7o00000Oooool000oooooo00?o0000ooooooooool04?ooool00ooo003ooooo
ooooo`0Rooooo`03ool00?oooooooooo09gooooo00?oo`00ooooooooool08_ooool00ooo003ooooo
ooooo`0?ooooo`7o00000Oooool000oooooo00?o0000ooooooooool03oooool00ooo003ooooooooo
o`0Rooooo`03ool00?oooooooooo09oooooo00?oo`00ooooooooool08_ooool00ooo003ooooooooo
o`0>ooooo`7o00000Oooool000oooooo00?o0000ooooooooool03oooool00ooo003oooooooooo`0R
ooooo`03ool00?oooooooooo09oooooo00?oo`00ooooooooool08_ooool00ooo003oooooooooo`0>
ooooo`7o00000Oooool000oooooo00?o0000ooooooooool03oooool00ooo003oooooooooo`0Qoooo
o`03ool00?oooooooooo0:7ooooo00?oo`00ooooooooool08Oooool00ooo003oooooooooo`0>oooo
o`7o00000Oooool000oooooo00?o0000ooooooooool03_ooool00ooo003oooooooooo`0Qooooo`03
ool00?oooooooooo0:;ooooo00?oo`00ooooooooool08_ooool00ooo003oooooooooo`0=ooooo`7o
00000Oooool000oooooo00?o0000ooooooooool03_ooool00ooo003oooooooooo`0Qooooo`03ool0
0?oooooooooo0:;ooooo00?oo`00ooooooooool08_ooool00ooo003oooooooooo`0=ooooo`7o0000
0Oooool000oooooo0_l0000>ooooo`03ool00?oooooooooo027ooooo00?oo`00ooooooooool0F_oo
ool9o`00047ooooo00?oo`00ooooooooool08_ooool00ooo003oooooooooo`0;ooooo`;o00000Ooo
ool000oooooo00?o0000ooooooooool03?ooool00ooo003oooooooooo`0Qooooo`03ool00?oooooo
oooo05;ooooo2Ol00009ooooo`ko0000=?ooool00ooo003oooooooooo`0Qooooo`03ool00?oooooo
oooo00cooooo0Ol00001ooooo`003oooool00ol0003oooooooooo`0<ooooo`03ool00?oooooooooo
023ooooo00?oo`00ooooooooool0Coooool4o`00023ooooo1?l0000aooooo`03ool00?oooooooooo
023ooooo00?oo`00ooooooooool03?ooool1o`00007ooooo000?ooooo`03o`000?oooooooooo00co
oooo00?oo`00ooooooooool08?ooool00ooo003oooooooooo`1=ooooo`;o0000:?ooool4o`0002go
oooo00?oo`00ooooooooool08?ooool00ooo003oooooooooo`0<ooooo`7o00000Oooool000oooooo
00?o0000ooooooooool02oooool00ooo003oooooooooo`0Pooooo`03ool00?oooooooooo04gooooo
00?o0000ooooooooool0;?ooool3o`0002_ooooo00?oo`00ooooooooool08?ooool00ooo003ooooo
ooooo`0;ooooo`7o00000Oooool000oooooo00?o0000ooooooooool02oooool00ooo003ooooooooo
o`0Pooooo`03ool00?oooooooooo04gooooo00?o0000ooooooooool0;oooool3o`0002Sooooo00?o
o`00ooooooooool08?ooool00ooo003oooooooooo`0;ooooo`7o00000Oooool000oooooo00?o0000
ooooooooool02oooool00ooo003oooooooooo`0Pooooo`03ool00?oooooooooo04cooooo00?o0000
ooooooooool0<oooool00ol0003oooooooooo`0Uooooo`03ool00?oooooooooo023ooooo00?oo`00
ooooooooool02oooool1o`00007ooooo000?ooooo`03o`000?oooooooooo00[ooooo00?oo`00oooo
ooooool08?ooool00ooo003oooooooooo`1<ooooo`03o`000?oooooooooo03Gooooo0ol0000Uoooo
o`03ool00?oooooooooo023ooooo00?oo`00ooooooooool02_ooool1o`00007ooooo000?ooooo`03
o`000?oooooooooo00[ooooo00?oo`00ooooooooool08?ooool00ooo003oooooooooo`1<ooooo`03
o`000?oooooooooo03Sooooo0_l0000Sooooo`03ool00?oooooooooo023ooooo00?oo`00oooooooo
ool02_ooool1o`00007ooooo000?ooooo`03o`000?oooooooooo00[ooooo00?oo`00ooooooooool0
7oooool00ooo003oooooooooo`1=ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0
8Oooool00ooo003oooooooooo`0Oooooo`03ool00?oooooooooo00[ooooo0Ol00001ooooo`003ooo
ool00ol0003oooooooooo`09ooooo`03ool00?oooooooooo023ooooo00?oo`00ooooooooool0C?oo
ool00ol0003oooooooooo`0looooo`03o`000?oooooooooo023ooooo00?oo`00ooooooooool08?oo
ool00ooo003oooooooooo`09ooooo`7o00000Oooool000oooooo00?o0000ooooooooool02Oooool0
0ooo003oooooooooo`0Oooooo`03ool00?oooooooooo04gooooo00?o0000ooooooooool0?Oooool0
0ol0003oooooooooo`0Pooooo`03ool00?oooooooooo01oooooo00?oo`00ooooooooool02Oooool1
o`00007ooooo000?ooooo`03o`000?oooooooooo00Wooooo00?oo`00ooooooooool07oooool00ooo
003oooooooooo`1=ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool07oooool00ooo
003oooooooooo`0Oooooo`03ool00?oooooooooo00Wooooo0Ol00001ooooo`003oooool00ol0003o
ooooooooo`09ooooo`03ool00?oooooooooo01oooooo00?oo`00ooooooooool0COooool00ol0003o
ooooooooo`0oooooo`03o`000?oooooooooo01kooooo00?oo`00ooooooooool08?ooool00ooo003o
ooooooooo`08ooooo`7o00000Oooool000oooooo00?o0000ooooooooool02?ooool00ooo003ooooo
ooooo`0Oooooo`03ool00?oooooooooo04oooooo00?o0000ooooooooool0?oooool00ol0003ooooo
ooooo`0Nooooo`03ool00?oooooooooo01oooooo00?oo`00ooooooooool02?ooool1o`00007ooooo
000?ooooo`03o`000?oooooooooo00Sooooo00?oo`00ooooooooool07_ooool00ooo003ooooooooo
o`1@ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool07_ooool00ooo003ooooooooo
o`0Oooooo`03ool00?oooooooooo00Oooooo0Ol00001ooooo`003oooool2o`0000Wooooo00?oo`00
ooooooooool07_ooool00ooo003oooooooooo`1@ooooo`03o`000?oooooooooo047ooooo00?o0000
ooooooooool07Oooool00ooo003oooooooooo`0Oooooo`03ool00?oooooooooo00Kooooo0_l00001
ooooo`003oooool00ol0003oooooooooo`08ooooo`03ool00?oooooooooo01kooooo00?oo`00oooo
ooooool0DOooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo01gooooo00?oo`00oooo
ooooool07oooool00ooo003oooooooooo`07ooooo`7o00000Oooool000oooooo00?o0000oooooooo
ool01oooool00ooo003oooooooooo`0Nooooo`03ool00?oooooooooo05;ooooo00?o0000oooooooo
ool0@Oooool00ol0003oooooooooo`0Mooooo`03ool00?oooooooooo01oooooo00?oo`00oooooooo
ool01_ooool1o`00007ooooo000?ooooo`03o`000?oooooooooo00Oooooo00?oo`00ooooooooool0
7_ooool00ooo003oooooooooo`1Booooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0
7Oooool00ooo003oooooooooo`0Oooooo`03ool00?oooooooooo00Kooooo0Ol00001ooooo`003ooo
ool00ol0003oooooooooo`07ooooo`03ool00?oooooooooo01kooooo00?oo`00ooooooooool0Dooo
ool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo01cooooo00?oo`00ooooooooool07ooo
ool00ooo003oooooooooo`06ooooo`7o00000Oooool000oooooo00?o0000ooooooooool01oooool0
0ooo003oooooooooo`0Nooooo`03ool00?oooooooooo05?ooooo00?o0000ooooooooool0@Oooool0
0ol0003oooooooooo`0Looooo`03ool00?oooooooooo01oooooo00?oo`00ooooooooool01_ooool1
o`00007ooooo000?ooooo`03o`000?oooooooooo00Oooooo00?oo`00ooooooooool07_ooool00ooo
003oooooooooo`1Cooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool07Oooool00ooo
003oooooooooo`0Nooooo`03ool00?oooooooooo00Kooooo0Ol00001ooooo`003oooool00ol0003o
ooooooooo`06ooooo`03ool00?oooooooooo01kooooo00?oo`00ooooooooool0EOooool00ol0003o
ooooooooo`11ooooo`03o`000?oooooooooo01cooooo00?oo`00ooooooooool07_ooool00ooo003o
ooooooooo`06ooooo`7o00000Oooool000oooooo00?o0000ooooooooool01_ooool00ooo003ooooo
ooooo`0Nooooo`03ool00?oooooooooo05Gooooo00?o0000ooooooooool0@Oooool00ol0003ooooo
ooooo`0Mooooo`03ool00?oooooooooo01gooooo00?oo`00ooooooooool01_ooool1o`00007ooooo
000?ooooo`03o`000?oooooooooo00Kooooo00?oo`00ooooooooool07Oooool00ooo003ooooooooo
o`1Fooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool07Oooool00ooo003ooooooooo
o`0Mooooo`03ool00?oooooooooo00Kooooo0Ol00001ooooo`003oooool00ol0003oooooooooo`06
ooooo`03ool00?oooooooooo01gooooo00?oo`00ooooooooool0Eoooool00ol0003oooooooooo`10
ooooo`03o`000?oooooooooo01gooooo00?oo`00ooooooooool07Oooool00ooo003oooooooooo`06
ooooo`7o00000Oooool000oooooo00?o0000ooooooooool01Oooool00ooo003oooooooooo`0Noooo
o`03ool00?oooooooooo05Oooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0Noooo
o`03ool00?oooooooooo01gooooo00?oo`00ooooooooool01Oooool1o`00007ooooo000?ooooo`03
o`000?oooooooooo00Gooooo00?oo`00ooooooooool07_ooool00ooo003oooooooooo`1Hooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool07_ooool00ooo003oooooooooo`0Mooooo`03
ool00?oooooooooo00Gooooo0Ol00001ooooo`003oooool00ol0003oooooooooo`05ooooo`03ool0
0?oooooooooo01kooooo00?oo`00ooooooooool0F?ooool00ol0003oooooooooo`0oooooo`03o`00
0?oooooooooo01kooooo00?oo`00ooooooooool07Oooool00ooo003oooooooooo`05ooooo`7o0000
0Oooool000oooooo00?o0000ooooooooool01Oooool00ooo003oooooooooo`0Nooooo`03ool00?oo
oooooooo05Sooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0Nooooo`03ool00?oo
oooooooo01gooooo00?oo`00ooooooooool01Oooool1o`00007ooooo000?ooooo`03o`000?oooooo
oooo00Gooooo00?oo`00ooooooooool07Oooool00ooo003oooooooooo`1Jooooo`03o`000?oooooo
oooo03gooooo00?o0000ooooooooool07oooool00ooo003oooooooooo`0Mooooo`03ool00?oooooo
oooo00Gooooo0Ol00001ooooo`003oooool2o`0000Kooooo00?oo`00ooooooooool07Oooool00ooo
003oooooooooo`1Jooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool07oooool00ooo
003oooooooooo`0Mooooo`03ool00?oooooooooo00Cooooo0_l00001ooooo`003oooool00ol0003o
ooooooooo`05ooooo`03ool00?oooooooooo01gooooo00?oo`00ooooooooool0F_ooool00ol0003o
ooooooooo`0mooooo`03o`000?oooooooooo01oooooo00?oo`00ooooooooool07Oooool00ooo003o
ooooooooo`05ooooo`7o00000Oooool000oooooo00?o0000ooooooooool01Oooool00ooo003ooooo
ooooo`0Mooooo`03ool00?oooooooooo05[ooooo00?o0000ooooooooool0?Oooool00ol0003ooooo
ooooo`0Oooooo`03ool00?oooooooooo01gooooo00?oo`00ooooooooool01Oooool1o`00007ooooo
000?ooooo`03o`000?oooooooooo00Gooooo00?oo`00ooooooooool07Oooool00ooo003ooooooooo
o`1Jooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool08?ooool00ooo003ooooooooo
o`0Mooooo`03ool00?oooooooooo00Gooooo0Ol00001ooooo`003oooool00ol0003oooooooooo`04
ooooo`03ool00?oooooooooo01gooooo00?oo`00ooooooooool0G?ooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo027ooooo00?oo`00ooooooooool07Oooool00ooo003oooooooooo`04
ooooo`7o00000Oooool000oooooo00?o0000ooooooooool01?ooool00ooo003oooooooooo`0Moooo
o`03ool00?oooooooooo05cooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0Roooo
o`03ool00?oooooooooo01gooooo00?oo`00ooooooooool01?ooool1o`00007ooooo000?ooooo`03
o`000?oooooooooo00Cooooo00?oo`00ooooooooool07Oooool00ooo003oooooooooo`1Looooo`03
o`000?oooooooooo03[ooooo00?o0000ooooooooool08_ooool00ooo003oooooooooo`0Mooooo`03
ool00?oooooooooo00Cooooo0Ol00001ooooo`003oooool00ol0003oooooooooo`04ooooo`03ool0
0?oooooooooo01gooooo00?oo`00ooooooooool0G?ooool00ol0003oooooooooo`0jooooo`03o`00
0?oooooooooo02;ooooo00?oo`00ooooooooool07Oooool00ooo003oooooooooo`04ooooo`7o0000
0Oooool000oooooo00?o0000ooooooooool01?ooool00ooo003oooooooooo`0Mooooo`03ool00?oo
oooooooo05gooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Sooooo`03ool00?oo
oooooooo01kooooo00?oo`00ooooooooool00oooool1o`00007ooooo000?ooooo`03o`000?oooooo
oooo00Cooooo00?oo`00ooooooooool07Oooool00ooo003oooooooooo`1Mooooo`03o`000?oooooo
oooo03Oooooo00?o0000ooooooooool09?ooool00ooo003oooooooooo`0Nooooo`03ool00?oooooo
oooo00?ooooo0Ol00001ooooo`003oooool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo
01gooooo00?oo`00ooooooooool0GOooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo
02Gooooo00?oo`00ooooooooool07_ooool00ooo003oooooooooo`03ooooo`7o00000Oooool000oo
oooo00?o0000ooooooooool01?ooool00ooo003oooooooooo`0Mooooo`03ool00?oooooooooo05go
oooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0Vooooo`03ool00?oooooooooo01ko
oooo00?oo`00ooooooooool00oooool1o`00007ooooo000?ooooo`03o`000?oooooooooo00Cooooo
00?oo`00ooooooooool07Oooool00ooo003oooooooooo`1Mooooo`03o`000?oooooooooo03Cooooo
00?o0000ooooooooool09oooool00ooo003oooooooooo`0Nooooo`03ool00?oooooooooo00?ooooo
0Ol00001ooooo`003oooool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo01kooooo00?o
o`00ooooooooool0G_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02Sooooo00?o
o`00ooooooooool07Oooool00ooo003oooooooooo`03ooooo`7o00000Oooool000Sooooo0_l00005
ooooo`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool07_ooool00ooo003oooooooooo`1N
ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0:Oooool00ooo003oooooooooo`0M
ooooo`03ool00?oooooooooo00?ooooo0Ol00001ooooo`001oooool01?l0003oooooooooool00004
ooooo`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool07_ooool00ooo003oooooooooo`1N
ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0:_ooool00ooo003oooooooooo`0M
ooooo`03ool00?oooooooooo00?ooooo0Ol00001ooooo`001oooool01?l0003oooooooooool00004
ooooo`?o00000oooool00ooo003oooooooooo`0Nooooo`03ool00?oooooooooo05kooooo00?o0000
ooooooooool0<?ooool00ol0003oooooooooo`0[ooooo`03ool00?oooooooooo01gooooo00?oo`00
ooooooooool00_ooool2o`00007ooooo0007ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000
ooooooooool00oooool00ooo003oooooooooo`0Nooooo`03ool00?oooooooooo05kooooo00?o0000
ooooooooool0;_ooool2o`0002kooooo00?oo`00ooooooooool07Oooool00ooo003oooooooooo`03
ooooo`7o00000Oooool000Oooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`03
ooooo`03ool00?oooooooooo01kooooo00?oo`00ooooooooool0G_ooool00ol0003oooooooooo`0]
ooooo`03o`000?oooooooooo02kooooo00?oo`00ooooooooool07Oooool00ooo003oooooooooo`03
ooooo`7o00000Oooool000Oooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`03
ooooo`03ool00?oooooooooo01kooooo00?oo`00ooooooooool0G_ooool00ol0003oooooooooo`0]
ooooo`03o`000?oooooooooo02kooooo00?oo`00ooooooooool07Oooool00ooo003oooooooooo`03
ooooo`7o00000Oooool000Sooooo0_l00005ooooo`03o`000?oooooooooo00?ooooo00?oo`00oooo
ooooool07_ooool00ooo003oooooooooo`1Nooooo`03o`000?oooooooooo02cooooo00?o0000oooo
ooooool0;oooool00ooo003oooooooooo`0Mooooo`03ool00?oooooooooo00?ooooo0Ol00001oooo
o`003oooool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo01gooooo00?oo`00oooooooo
ool0GOooool00ol0003oooooooooo`0[ooooo`;o0000<Oooool00ooo003oooooooooo`0Nooooo`03
ool00?oooooooooo00?ooooo0Ol00001ooooo`003oooool00ol0003oooooooooo`04ooooo`03ool0
0?oooooooooo01gooooo00?oo`00ooooooooool0GOooool00ol0003oooooooooo`0Zooooo`03o`00
0?oooooooooo037ooooo00?oo`00ooooooooool07_ooool00ooo003oooooooooo`03ooooo`7o0000
0Oooool000oooooo00?o0000ooooooooool01?ooool00ooo003oooooooooo`0Mooooo`03ool00?oo
oooooooo05gooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0booooo`03ool00?oo
oooooooo01kooooo00?oo`00ooooooooool00oooool1o`00007ooooo000?ooooo`03o`000?oooooo
oooo00Cooooo00?oo`00ooooooooool07Oooool00ooo003oooooooooo`1Mooooo`03o`000?oooooo
oooo02Sooooo00?o0000ooooooooool0<oooool00ooo003oooooooooo`0Nooooo`03ool00?oooooo
oooo00?ooooo0Ol00001ooooo`003oooool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo
01gooooo00?oo`00ooooooooool0G?ooool00ol0003oooooooooo`0Wooooo`;o0000=_ooool00ooo
003oooooooooo`0Nooooo`03ool00?oooooooooo00?ooooo0Ol00001ooooo`003oooool00ol0003o
ooooooooo`04ooooo`03ool00?oooooooooo01gooooo00?oo`00ooooooooool0Foooool00ol0003o
ooooooooo`0Wooooo`03o`000?oooooooooo03Kooooo00?oo`00ooooooooool07Oooool00ooo003o
ooooooooo`04ooooo`7o00000Oooool000oooooo00?o0000ooooooooool01?ooool00ooo003ooooo
ooooo`0Mooooo`03ool00?oooooooooo05_ooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`0gooooo`03ool00?oooooooooo01gooooo00?oo`00ooooooooool01?ooool1o`00007ooooo
000?ooooo`03o`000?oooooooooo00Cooooo00?oo`00ooooooooool07Oooool00ooo003ooooooooo
o`1Kooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0=oooool00ooo003ooooooooo
o`0Mooooo`03ool00?oooooooooo00Cooooo0Ol00001ooooo`003oooool00ol0003oooooooooo`04
ooooo`03ool00?oooooooooo01gooooo00?oo`00ooooooooool0F_ooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo03Sooooo00?oo`00ooooooooool07Oooool00ooo003oooooooooo`04
ooooo`7o00000Oooool000oooooo00?o0000ooooooooool01Oooool00ooo003oooooooooo`0Moooo
o`03ool00?oooooooooo05Sooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0hoooo
o`03ool00?oooooooooo01gooooo00?oo`00ooooooooool01Oooool1o`00007ooooo000?ooooo`03
o`000?oooooooooo00Gooooo00?oo`00ooooooooool07Oooool00ooo003oooooooooo`1Hooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool0>Oooool00ooo003oooooooooo`0Mooooo`03
ool00?oooooooooo00Gooooo0Ol00001ooooo`003oooool2o`0000Kooooo00?oo`00ooooooooool0
7Oooool00ooo003oooooooooo`1Fooooo`;o00009oooool00ol0003oooooooooo`0jooooo`03ool0
0?oooooooooo01gooooo00?oo`00ooooooooool01?ooool2o`00007ooooo000?ooooo`03o`000?oo
oooooooo00Gooooo00?oo`00ooooooooool07Oooool00ooo003oooooooooo`1Eooooo`03o`000?oo
oooooooo02Gooooo0_l0000mooooo`03ool00?oooooooooo01gooooo00?oo`00ooooooooool01Ooo
ool1o`00007ooooo000?ooooo`03o`000?oooooooooo00Gooooo00?oo`00ooooooooool07Oooool0
0ooo003oooooooooo`1Dooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0?Oooool0
0ooo003oooooooooo`0Mooooo`03ool00?oooooooooo00Gooooo0Ol00001ooooo`003oooool00ol0
003oooooooooo`05ooooo`03ool00?oooooooooo01kooooo00?oo`00ooooooooool0D_ooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo03kooooo00?oo`00ooooooooool07Oooool00ooo
003oooooooooo`05ooooo`7o00000Oooool000oooooo00?o0000ooooooooool01Oooool00ooo003o
ooooooooo`0Nooooo`03ool00?oooooooooo053ooooo0_l0000Wooooo`03o`000?oooooooooo03oo
oooo00?oo`00ooooooooool07Oooool00ooo003oooooooooo`05ooooo`7o00000Oooool000oooooo
00?o0000ooooooooool01Oooool00ooo003oooooooooo`0Nooooo`03ool00?oooooooooo04kooooo
0_l0000Xooooo`03o`000?oooooooooo043ooooo00?oo`00ooooooooool07Oooool00ooo003ooooo
ooooo`05ooooo`7o00000Oooool000oooooo00?o0000ooooooooool01Oooool00ooo003ooooooooo
o`0Nooooo`03ool00?oooooooooo04gooooo00?o0000ooooooooool0:?ooool00ol0003ooooooooo
o`0oooooo`03ool00?oooooooooo01kooooo00?oo`00ooooooooool01Oooool1o`00007ooooo000?
ooooo`03o`000?oooooooooo00Kooooo00?oo`00ooooooooool07Oooool00ooo003oooooooooo`1;
ooooo`;o0000:_ooool00ol0003oooooooooo`10ooooo`03ool00?oooooooooo01gooooo00?oo`00
ooooooooool01_ooool1o`00007ooooo000?ooooo`03o`000?oooooooooo00Kooooo00?oo`00oooo
ooooool07_ooool00ooo003oooooooooo`19ooooo`03o`000?oooooooooo02Wooooo00?o0000oooo
ooooool0@Oooool00ooo003oooooooooo`0Mooooo`03ool00?oooooooooo00Kooooo0Ol00001oooo
o`003oooool00ol0003oooooooooo`06ooooo`03ool00?oooooooooo01kooooo00?oo`00oooooooo
ool0B?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo04;ooooo00?oo`00oooooooo
ool07Oooool00ooo003oooooooooo`06ooooo`7o00000Oooool000oooooo00?o0000ooooooooool0
1_ooool00ooo003oooooooooo`0Nooooo`03ool00?oooooooooo04Kooooo0_l0000[ooooo`03o`00
0?oooooooooo04;ooooo00?oo`00ooooooooool07_ooool00ooo003oooooooooo`06ooooo`7o0000
0Oooool000oooooo00?o0000ooooooooool01oooool00ooo003oooooooooo`0Nooooo`03ool00?oo
oooooooo04?ooooo0_l0000]ooooo`03o`000?oooooooooo04;ooooo00?oo`00ooooooooool07_oo
ool00ooo003oooooooooo`06ooooo`7o00000Oooool000oooooo00?o0000ooooooooool01oooool0
0ooo003oooooooooo`0Nooooo`03ool00?oooooooooo04;ooooo00?o0000ooooooooool0;?ooool0
0ol0003oooooooooo`13ooooo`03ool00?oooooooooo01kooooo00?oo`00ooooooooool01_ooool1
o`00007ooooo000?ooooo`03o`000?oooooooooo00Oooooo00?oo`00ooooooooool07_ooool00ooo
003oooooooooo`10ooooo`;o0000;Oooool2o`0004Gooooo00?oo`00ooooooooool07oooool00ooo
003oooooooooo`06ooooo`7o00000Oooool000oooooo00?o0000ooooooooool01oooool00ooo003o
ooooooooo`0Nooooo`03ool00?oooooooooo03kooooo0_l0000^ooooo`03o`000?oooooooooo04Go
oooo00?oo`00ooooooooool07oooool00ooo003oooooooooo`06ooooo`7o00000Oooool000oooooo
00?o0000ooooooooool01oooool00ooo003oooooooooo`0Nooooo`03ool00?oooooooooo03cooooo
0_l0000_ooooo`03o`000?oooooooooo04Kooooo00?oo`00ooooooooool07oooool00ooo003ooooo
ooooo`06ooooo`7o00000Oooool000oooooo00?o0000ooooooooool02?ooool00ooo003ooooooooo
o`0Nooooo`03ool00?oooooooooo03Wooooo0_l0000aooooo`03o`000?oooooooooo04Gooooo00?o
o`00ooooooooool07oooool00ooo003oooooooooo`07ooooo`7o00000Oooool000oooooo0_l00009
ooooo`03ool00?oooooooooo01kooooo00?oo`00ooooooooool0=_ooool3o`0003;ooooo00?o0000
ooooooooool0A_ooool00ooo003oooooooooo`0Oooooo`03ool00?oooooooooo00Kooooo0_l00001
ooooo`003oooool00ol0003oooooooooo`08ooooo`03ool00?oooooooooo01kooooo00?oo`00oooo
ooooool0=?ooool2o`0003Cooooo00?o0000ooooooooool0Aoooool00ooo003oooooooooo`0Ooooo
o`03ool00?oooooooooo00Oooooo0Ol00001ooooo`003oooool00ol0003oooooooooo`08ooooo`03
ool00?oooooooooo01oooooo00?oo`00ooooooooool0<Oooool2o`0003Gooooo00?o0000oooooooo
ool0Aoooool00ooo003oooooooooo`0Pooooo`03ool00?oooooooooo00Oooooo0Ol00001ooooo`00
3oooool00ol0003oooooooooo`09ooooo`03ool00?oooooooooo01kooooo00?oo`00ooooooooool0
;oooool2o`0003Gooooo0_l0001:ooooo`03ool00?oooooooooo01oooooo00?oo`00ooooooooool0
2?ooool1o`00007ooooo000?ooooo`03o`000?oooooooooo00Wooooo00?oo`00ooooooooool07ooo
ool00ooo003oooooooooo`0[ooooo`?o0000=_ooool00ol0003oooooooooo`19ooooo`03ool00?oo
oooooooo01oooooo00?oo`00ooooooooool02Oooool1o`00007ooooo000?ooooo`03o`000?oooooo
oooo00Wooooo00?oo`00ooooooooool07oooool00ooo003oooooooooo`0Zooooo`03o`000?oooooo
oooo03Kooooo00?o0000ooooooooool0B_ooool00ooo003oooooooooo`0Oooooo`03ool00?oooooo
oooo00Wooooo0Ol00001ooooo`003oooool00ol0003oooooooooo`09ooooo`03ool00?oooooooooo
023ooooo00?oo`00ooooooooool09oooool2o`0003Oooooo0_l0001<ooooo`03ool00?oooooooooo
023ooooo00?oo`00ooooooooool02Oooool1o`00007ooooo000?ooooo`03o`000?oooooooooo00[o
oooo00?oo`00ooooooooool07oooool00ooo003oooooooooo`0Tooooo`?o0000>?ooool00ol0003o
ooooooooo`1<ooooo`03ool00?oooooooooo01oooooo00?oo`00ooooooooool02_ooool1o`00007o
oooo000?ooooo`03o`000?oooooooooo00[ooooo00?oo`00ooooooooool07oooool00ooo003ooooo
ooooo`0Sooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0COooool00ooo003ooooo
ooooo`0Oooooo`03ool00?oooooooooo00[ooooo0Ol00001ooooo`003oooool00ol0003ooooooooo
o`0:ooooo`03ool00?oooooooooo023ooooo00?oo`00ooooooooool08?ooool2o`0003[ooooo00?o
0000ooooooooool0COooool00ooo003oooooooooo`0Pooooo`03ool00?oooooooooo00[ooooo0Ol0
0001ooooo`003oooool00ol0003oooooooooo`0:ooooo`03ool00?oooooooooo023ooooo00?oo`00
ooooooooool07Oooool3o`0003[ooooo0_l0001@ooooo`03ool00?oooooooooo023ooooo00?oo`00
ooooooooool02_ooool1o`00007ooooo000?ooooo`03o`000?oooooooooo00_ooooo00?oo`00oooo
ooooool08?ooool00ooo003oooooooooo`0Iooooo`?o0000??ooool00ol0003oooooooooo`1?oooo
o`03ool00?oooooooooo023ooooo00?oo`00ooooooooool02oooool1o`00007ooooo000?ooooo`03
o`000?oooooooooo00_ooooo00?oo`00ooooooooool08?ooool00ooo003oooooooooo`0Gooooo`;o
0000?_ooool00ol0003oooooooooo`1@ooooo`03ool00?oooooooooo023ooooo00?oo`00oooooooo
ool02oooool1o`00007ooooo000?ooooo`03o`000?oooooooooo00cooooo00?oo`00ooooooooool0
8?ooool00ooo003oooooooooo`0Dooooo`;o0000?Oooool3o`0005;ooooo00?oo`00ooooooooool0
8?ooool00ooo003oooooooooo`0<ooooo`7o00000Oooool000oooooo00?o0000ooooooooool03?oo
ool00ooo003oooooooooo`0Pooooo`03ool00?oooooooooo01;ooooo0_l0000mooooo`;o0000EOoo
ool00ooo003oooooooooo`0Pooooo`03ool00?oooooooooo00cooooo0Ol00001ooooo`003oooool0
0ol0003oooooooooo`0<ooooo`03ool00?oooooooooo027ooooo00?oo`00ooooooooool03oooool2
o`0003gooooo0_l0001Fooooo`03ool00?oooooooooo027ooooo00?oo`00ooooooooool03?ooool1
o`00007ooooo000?ooooo`;o00003_ooool00ooo003oooooooooo`0Qooooo`03ool00?oooooooooo
00cooooo0_l0000nooooo`03o`000?oooooooooo05Gooooo00?oo`00ooooooooool08_ooool00ooo
003oooooooooo`0;ooooo`;o00000Oooool000oooooo00?o0000ooooooooool03Oooool00ooo003o
ooooooooo`0Qooooo`03ool00?oooooooooo00[ooooo0_l0000oooooo`03o`000?oooooooooo05Ko
oooo00?oo`00ooooooooool08Oooool00ooo003oooooooooo`0=ooooo`7o00000Oooool000oooooo
00?o0000ooooooooool03_ooool00ooo003oooooooooo`0Qooooo`04ool00?l00?oo003oo`00o`Go
oooo0ol0000oooooo`;o0000F?ooool00ooo003oooooooooo`0Rooooo`03ool00?oooooooooo00Ko
oooo0_l00005ooooo`7o00000Oooool000oooooo00?o0000ooooooooool03_ooool00ooo003ooooo
ooooo`0Qooooo`Go003o0_ooool2o`00043ooooo0_l0001Jooooo`03ool00?oooooooooo02;ooooo
00?oo`00ooooooooool01?ooool2o`0000Oooooo0Ol00001ooooo`003oooool00ol0003ooooooooo
o`0?ooooo`03ool00?oooooooooo01oooooo1ol00?l00ol0003oooooooooo`0nooooo`;o0000Fooo
ool00ooo003oooooooooo`0Rooooo`03ool00?oooooooooo00?ooooo0_l00009ooooo`7o00000Ooo
ool000oooooo00?o0000ooooooooool03oooool00ooo003oooooooooo`0Oooooo`Oo003o?oooool2
o`0005gooooo00?oo`00ooooooooool07oooool3o`00o`04ool00?ooooooooooooooo`;o00002ooo
ool1o`00007ooooo000?ooooo`03o`000?oooooooooo013ooooo00?oo`00ooooooooool07_ooool7
o`00occooooo0ol0001Nooooo`03ool00?oooooooooo01oooooo1Ol00?l3o`0000gooooo0Ol00001
ooooo`003oooool00ol0003oooooooooo`0@ooooo`03ool00?oooooooooo01_ooooo0ol000000ooo
oooo003oo`00o`03o`00oc_ooooo0_l0001Pooooo`03ool00?oooooooooo01oooooo1ol00?l?oooo
o`7o00000Oooool000oooooo00?o0000ooooooooool04Oooool00ooo003oooooooooo`0Hooooo`;o
00001Oooool3o`00o`03ool00?oooooooooo03Oooooo0_l0001Qooooo`03ool00?oooooooooo023o
oooo1ol00?l?ooooo`7o00000Oooool000oooooo00?o0000ooooooooool04Oooool00ooo003ooooo
ooooo`0Fooooo`;o00002oooool00ooo003oooooooooo`0dooooo`;o0000H_ooool00ooo003ooooo
ooooo`0Pooooo`03o`000?l00?oo003o00Go003o3oooool1o`00007ooooo000?ooooo`03o`000?oo
oooooooo01;ooooo00?oo`00ooooooooool04_ooool3o`0000kooooo00?oo`00ooooooooool0<?oo
ool3o`0006?ooooo00?oo`00ooooooooool07oooool2o`0000;ooooo1Ol00?l@ooooo`7o00000Ooo
ool000oooooo00?o0000ooooooooool04_ooool00ooo003oooooooooo`0@ooooo`;o00004Oooool0
0ooo003oooooooooo`0^ooooo`;o0000I_ooool00ooo003oooooooooo`0Mooooo`;o00001Oooool3
o`00oa7ooooo0Ol00001ooooo`003oooool00ol0003oooooooooo`0Cooooo`03ool00?oooooooooo
00gooooo0_l0000Cooooo`03ool00?oooooooooo02cooooo0_l0001Xooooo`03ool00?oooooooooo
01_ooooo0_l00006ooooo`03ool00?oooooooooo01;ooooo0Ol00001ooooo`001_ooool5o`0000Co
oooo00?o0000ooooooooool04oooool00ooo003oooooooooo`0;ooooo`;o00005_ooool00ooo003o
ooooooooo`0Yooooo`;o0000JOooool00ooo003oooooooooo`0Jooooo`;o00001oooool00ooo003o
ooooooooo`0Cooooo`7o00000Oooool000Oooooo00Co0000oooooooooooo00001?ooool00ol0003o
ooooooooo`0Cooooo`03ool00?oooooooooo00Wooooo0_l0000Iooooo`03ool00?oooooooooo02Ko
oooo0_l0001Zooooo`03ool00?oooooooooo01Wooooo0_l00009ooooo`03ool00?oooooooooo01?o
oooo0Ol00001ooooo`002?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Cooooo
00Coo`00o`00ool00?oo003o1Oooool2o`0001cooooo00?oo`00ooooooooool08_ooool3o`0006_o
oooo00?oo`00ooooooooool05Oooool5o`0000[ooooo00?oo`00ooooooooool05?ooool1o`00007o
oooo0009ooooo`03o`000?oooooooooo00?ooooo0ol0000Dooooo`Go003o00Coooooo`000?l0003o
00007oooool00ooo003oooooooooo`0Nooooo`?o0000KOooool00ooo003oooooooooo`0Dooooo`;o
00003_ooool00ooo003oooooooooo`0Dooooo`;o00000Oooool000Kooooo00Go0000oooooooooooo
ooooo`000004ooooo`03o`000?oooooooooo01?ooooo1ol00?lSooooo`03ool00?oooooooooo01[o
oooo0ol0001_ooooo`03ool00?oooooooooo01?ooooo0_l0000@ooooo`03ool00?oooooooooo01Go
oooo0Ol00001ooooo`001_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooooooo
ool04oooool7o`00obCooooo00?oo`00ooooooooool05oooool2o`00077ooooo00?oo`00oooooooo
ool04_ooool2o`00017ooooo00?oo`00ooooooooool05_ooool1o`00007ooooo0007ooooo`?o0000
1Oooool00ol0003oooooooooo`0Cooooo`Oo003o9Oooool2ool001?ooooo1?l0001booooo`03ool0
0?oooooooooo01;ooooo00?o0000ooooooooool04Oooool00ooo003oooooooooo`0Fooooo`7o0000
0Oooool000oooooo00?o0000ooooooooool04_ooool00ol0003oooooo`00o`04o`00obSooooo00?o
o`00ooooooooool03Oooool3o`0007Gooooo00?oo`00ooooooooool04Oooool2o`0001Cooooo00?o
o`00ooooooooool05_ooool1o`00007ooooo000?ooooo`03o`000?oooooooooo013ooooo0_l00003
ooooo`?o003o00?oo`00ooooooooool09_ooool00ooo003oooooooooo`03o`00o`Sooooo0_l0001g
ooooo`03ool00?oooooooooo013ooooo0_l0000Eooooo`03ool00?oooooooooo01Oooooo0Ol00001
ooooo`003oooool00ol0003oooooooooo`0=ooooo`?o00002?ooool00ooo003oooooooooo`0Woooo
o`03ool00?l00?oo003o00?o003o1?ooool3o`0007Sooooo00?oo`00ooooooooool03oooool2o`00
01Kooooo00?oo`00ooooooooool06?ooool1o`00007ooooo000?ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool02_ooool00ooo003oooooooooo`0Vooooo`Oo003o0ol0001jooooo`03
ool00?oooooooooo00kooooo0_l0000Gooooo`03ool00?oooooooooo01Wooooo0Ol00001ooooo`00
3oooool00ol0003oooooooooo`0:ooooo`;o00003Oooool00ooo003oooooooooo`0Vooooo`Oo003o
Noooool2ool000oooooo0_l0000Iooooo`03ool00?oooooooooo01Wooooo0Ol00001ooooo`003ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00kooooo00?oo`00ooooooooool08_oo
ool3o`0000Oo003oN_ooool00ooo003oooooooooo`0=ooooo`;o00006oooool00ooo003ooooooooo
o`0Iooooo`7o00000Oooool000oooooo00?o0000ooooooooool01oooool2o`0001;ooooo00?oo`00
ooooooooool07?ooool5o`0000Cooooo1Ol00?mjooooo`03ool00?oooooooooo00gooooo00?o0000
ooooooooool06_ooool00ooo003oooooooooo`0Jooooo`7o00000Oooool000oooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0Cooooo`03ool00?oooooooooo01Oooooo1?l0000:oooo
o`?o003o00?oooooool00?ooool0Moooool00ooo003oooooooooo`0=ooooo`03o`000?oooooooooo
01[ooooo00?oo`00ooooooooool04?ooool6o`0000Gooooo0Ol00001ooooo`003oooool00ol0003o
ooooooooo`05ooooo`;o00005_ooool01?oo003o003oo`00ool00?lAooooo`Co00004oooool2ool0
07Cooooo0_oo000?ooooo`03o`000?oooooooooo01Oooooo0ol00?l00ooo003oooooooooo`0;oooo
o`Ko00002oooool1o`00007ooooo000?ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool04oooool5o`00o`Oooooo2Ol0000Iooooo`;oo`00L?ooool2ool0017ooooo00?o0000oooooooo
ool05_ooool5o`00o`Wooooo1?l0000Aooooo`7o00000Oooool000oooooo00?o0000ooooooooool0
2?ooool3o`00017ooooo1ol00?l00ooooooo0000o`000003o`0002Cooooo00?oo`00ooooooooool0
K?ooool00ooo003oooooooooo`0Booooo`Co00004oooool7o`00o`So00005Oooool1o`00007ooooo
000?ooooo`03o`000?oooooooooo00_ooooo3Ol00004ooooo`Oo003o00?o0000ooooooooool0:?oo
ool00ooo003oooooooooo`1Zooooo`03ool00?oooooooooo01Oooooo4ol00007o`00oagooooo0Ol0
0001ooooo`003oooool2o`0001Wooooo1?l00007o`00obcooooo0_oo001Xooooo`;oo`00;Oooool7
o`00oacooooo0_l00001ooooo`003oooool00ol0003oooooooooo`0Mooooo`Go003o;oooool00ooo
003oooooooooo`1Tooooo`03ool00?oooooooooo02kooooo1Ol00?lNooooo`7o00000Oooool000oo
oooo00?o0000ooooooooool07_ooool3o`00o`03ool00?oooooooooo02kooooo0_oo001Rooooo`;o
o`00<?ooool00ooo003oooooo`00o`02o`00oaoooooo0Ol00001ooooo`003oooool00ol0003ooooo
ooooo`0Rooooo`03ool00?oooooooooo02oooooo0_oo001Oooooo`03ool00?oooooooooo02oooooo
00?oo`00ooooooooool08_ooool1o`00007ooooo000?ooooo`03o`000?oooooooooo02?ooooo00?o
o`00ooooooooool0<?ooool00ooo003oooooooooo`1Kooooo`03ool00?oooooooooo033ooooo00?o
o`00ooooooooool08_ooool1o`00007ooooo000?ooooo`03o`000?oooooooooo02Cooooo00?oo`00
ooooooooool0<?ooool2ool005Sooooo0ooo000booooo`03ool00?oooooooooo02?ooooo0Ol00001
ooooo`003oooool00ol0003oooooooooo`0Tooooo`03ool00?oooooooooo03;ooooo0_oo001Doooo
o`;oo`00=?ooool00ooo003oooooooooo`0Tooooo`7o00000Oooool000oooooo00?o0000oooooooo
ool09Oooool00ooo003oooooooooo`0cooooo`;oo`00D?ooool2ool003Gooooo00?oo`00oooooooo
ool09Oooool1o`00007ooooo000?ooooo`03o`000?oooooooooo02Kooooo0_oo000eooooo`;oo`00
C?ooool2ool003Kooooo00?oo`00ooooooooool09_ooool1o`00007ooooo000?ooooo`03o`000?oo
oooooooo02Sooooo00?oo`00ooooooooool0=?ooool4ool004Gooooo0ooo000fooooo`;oo`00:Ooo
ool1o`00007ooooo000?ooooo`03o`000?oooooooooo02Wooooo00?oo`00ooooooooool0=oooool3
ool003oooooo0ooo000hooooo`03ool00?oooooooooo02Wooooo0Ol00001ooooo`003oooool00ol0
003oooooooooo`0Zooooo`03ool00?oooooooooo03Wooooo0_oo000jooooo`?oo`00>_ooool00ooo
003oooooooooo`0Zooooo`7o00000Oooool000oooooo00?o0000ooooooooool0:oooool00ooo003o
ooooooooo`0jooooo`Coo`00<oooool3ool003cooooo00?oo`00ooooooooool0:oooool1o`00007o
oooo000?ooooo`03o`000?oooooooooo02cooooo00?oo`00ooooool00?l00_l00?lkooooo`Goo`00
:Oooool5ool003kooooo00?oo`00ooooooooool0;?ooool1o`00007ooooo000?ooooo`03o`000?oo
oooooooo02gooooo1Ol00?l8ooooo`Ko0000<Oooool3ool002;ooooo1?oo0012ooooo`03ool00?oo
oooooooo02Gooooo0ol00005ooooo`7o00000Oooool000oooooo00?o0000ooooooooool0;?ooool7
o`00o`?ooooo1?l00006oooooa?o00008Oooool5ool001Wooooo1?oo0015ooooo`03ool00?oooooo
oooo02;ooooo1?l00008ooooo`7o00000Oooool000oooooo0_l0000]ooooo`Oo003o0ol0000Moooo
o`03o`000?oooooooooo02?ooooo6Ooo0018ooooo`03ool00?oooooooooo01[ooooo2Ol0000;oooo
o`;o00000Oooool000oooooo00?o0000ooooooooool09Oooool7o`0000Oo003o8Oooool00ol0003o
ooooooooo`22ooooo`03ool00?oooooooooo01Kooooo1Ol0000Eooooo`7o00000Oooool000oooooo
00?o0000ooooooooool08?ooool5o`0000Sooooo1Ol00?l00ooo003oooooooooo`0Oooooo`;o0000
P_ooool00ooo003oooooooooo`0?ooooo`So00006_ooool1o`00007ooooo000?ooooo`03o`000?oo
oooooooo01Oooooo2Ol0000>ooooo`?o003o0_ooool00ooo003oooooooooo`0Kooooo`?o0000Pooo
ool00ooo003oooooooooo`0;ooooo`Go00008_ooool1o`00007ooooo000?ooooo`03o`000?oooooo
oooo01?ooooo1?l0000Mooooo`03ool00?oooooooooo01Sooooo0_l00024ooooo`;oo`002_ooool4
o`0002Oooooo0Ol00001ooooo`003oooool00ol0003oooooooooo`0?ooooo`Co00008_ooool00ooo
003oooooooooo`0Eooooo`;o0000POooool3o`00o`03oooooooo003ooooo00Kooooo1Ol0000[oooo
o`7o00000Oooool000oooooo00?o0000ooooooooool02_ooool5o`0002Oooooo0_oo000Cooooo`;o
0000P_ooool5o`00o`?ooooo1Ol0000`ooooo`7o00000Oooool000oooooo00?o0000ooooooooool0
1_ooool4o`0002kooooo0_oo000=ooooo`Co0000Poooool7o`00o`;o0000=Oooool1o`00007ooooo
000?ooooo`03o`000?oooooooooo00?ooooo0ol0000dooooo`03ool00?oooooo003o00;o003o1Ooo
ool3o`0008Gooooo0_l00007o`00ocOooooo0Ol00001ooooo`003oooool00ol0003oooooooooo`0k
ooooo`Go003o0_ooool2o`0008Kooooo0_l00002ooooo`Oo003o=oooool1o`00007ooooo000?oooo
o`03o`000?oooooooooo03[ooooo1ol00?l00ol0003oooooooooo`23ooooo`?o00000oooool00ooo
003oooooo`00o`04o`00ocSooooo0Ol00001ooooo`003oooool00ol0003oooooooooo`0jooooo`Oo
003oPOooool5o`0000Gooooo0_oo0002ooooo`?o003o<_ooool2o`0000Gooooo0Ol00001ooooo`00
3oooool00ol0003oooooooooo`0gooooo`?o00001ol00?mmooooo`Co00002?ooool2ool003Oooooo
0_l00007ooooo`7o00000Oooool000oooooo00?o0000ooooooooool0=Oooool2o`0000Cooooo1Ol0
0?l00oooooooo`00ool0001fooooo`Go00002_ooool2ool003Oooooo0_l00009ooooo`7o00000Ooo
ool000oooooo00?o0000ooooooooool0;Oooool8o`0000Oooooo0ol00?l4ooooo`03ool00?oooooo
oooo073ooooo0ol0000>ooooo`03ool00?oooooooooo02kooooo1?l00002ooooo`?o00002oooool1
o`00007ooooo000?ooooo`03o`000?oooooooooo02Wooooo1?l0000Gooooo`03ool00?oooooooooo
06gooooo0_l0000?ooooo`;oo`00:oooool6o`0000Cooooo0_l0000>ooooo`7o00000Oooool000oo
oooo0_l0000Uooooo`Go00007?ooool2ool006[ooooo0ol0000?ooooo`;oo`00:Oooool4o`0001Wo
oooo0_l00001ooooo`003oooool00ol0003oooooooooo`0Pooooo`Co00008oooool2ool006Cooooo
1?l0000@ooooo`;oo`009oooool4o`0001kooooo0Ol00001ooooo`003oooool00ol0003ooooooooo
o`0Looooo`Co0000:Oooool3ool005oooooo0_l0000Booooo`;oo`009?ooool5o`0002;ooooo0Ol0
0001ooooo`003oooool00ol0003oooooooooo`0Cooooo`Wo0000<?ooool2ool005_ooooo0_l0000A
ooooo`?oo`006Oooool=o`0002Oooooo0Ol00001ooooo`003oooool00ol0003oooooooooo`0:oooo
o`Wo0000>oooool2ool005Wooooo00?o0000ooooooooool02Oooool3o`00o`;ooooo0_oo000Hoooo
o`Co0000=?ooool1o`00007ooooo000?ooooo`03o`000?oooooooooo00Kooooo1?l00016ooooo`;o
o`00F?ooool3o`0000Oooooo1Ol00?l00ooo003oooooooooo`0Cooooo`Go0000>?ooool1o`00007o
oooo000?ooooo`03o`000?oooooooooo00?ooooo0ol0001<ooooo`;oo`00FOooool6o`0000Oo003o
3_l00003ooooo`Co0000?Oooool1o`00007ooooo000?ooooo`03o`000?oooooooooo05Cooooo0_oo
001Mooooo`Oo003o3_ooool3o`00047ooooo0Ol00001ooooo`003oooool00ol0003oooooooooo`1F
ooooo`?oo`00FOooool00ooo003o003oo`00o`05o`00oe;ooooo0Ol00001ooooo`003oooool00ol0
003oooooooooo`1Iooooo`;oo`00E?ooool3ool000;ooooo1Ol00?mCooooo`7o00000Oooool000oo
oooo00?o0000ooooooooool0Foooool3ool004kooooo0ooo0006ooooo`?o003oE?ooool1o`00007o
oooo000?ooooo`03o`000?oooooooooo05kooooo1?oo0016ooooo`Coo`00H?ooool1o`00007ooooo
000?ooooo`03o`000?oooooooooo06;ooooo1Ooo000mooooo`Coo`00I?ooool1o`00007ooooo000?
ooooo`03o`000?oooooooooo06Oooooo1Ooo000cooooo`Goo`00J?ooool1o`00007ooooo0008oooo
o`?o00001?ooool00ol0003oooooooooo`1/ooooo`Coo`00:oooool4ool006gooooo0Ol00001oooo
o`002Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo073ooooo2Ooo000Iooooo`Wo
o`00LOooool1o`00007ooooo0006ooooo`Go00001?ooool00ol0003oooooooooo`1ioooooaWoo`00
N_ooool1o`00007ooooo0006ooooo`04o`000?ooooooooooo`0000Gooooo0ol0003oooooo`cooooo
0_l00001ooooo`001oooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo0?oooooo3Ooo
ool1o`00007ooooo0008ooooo`;o00001Oooool00ol0003oooooooooo`3oooooo`gooooo0Ol00001
ooooo`002Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo3Oooool1o`00
007ooooo000?ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0?_ooool00ol0003o
ooooooooo`0nooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0?_ooool00ol0003o
ooooooooo`03ooooo`7o00000Oooool000oooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00?ooooo0Ol00001ooooo`003oooooooo`00017o00000Ooo
ool00?oooooo8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-4.67633, -4.63175, 0.0309415, \
0.0309361}}]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.2 for Macintosh",
ScreenRectangle->{{0, 1436}, {0, 878}},
WindowSize->{520, 740},
WindowMargins->{{252, Automatic}, {52, Automatic}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 84, 2, 69, "Section",
  Evaluatable->False],
Cell[1863, 57, 236, 8, 49, "Text",
  Evaluatable->False],
Cell[2102, 67, 1132, 39, 140, "Text",
  Evaluatable->False],
Cell[3237, 108, 120, 2, 32, "Text",
  Evaluatable->False],
Cell[3360, 112, 153, 3, 43, "Input"],
Cell[3516, 117, 196, 8, 32, "Text",
  Evaluatable->False],
Cell[3715, 127, 96, 2, 27, "Input"],
Cell[3814, 131, 346, 7, 171, "Input"],
Cell[4163, 140, 158, 5, 32, "Text",
  Evaluatable->False],
Cell[4324, 147, 196, 4, 66, "Input"],
Cell[4523, 153, 262, 5, 75, "Input"],
Cell[4788, 160, 1508, 29, 397, "Input"],
Cell[6299, 191, 83, 2, 32, "Text",
  Evaluatable->False],
Cell[6385, 195, 132, 3, 31, "Input"],
Cell[6520, 200, 106, 2, 31, "Input"],

Cell[CellGroupData[{
Cell[6651, 206, 176, 4, 43, "Input"],
Cell[6830, 212, 1602, 29, 383, "Output"]
}, Closed]],
Cell[8447, 244, 115, 2, 29, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[8587, 250, 150, 3, 76, "Input"],
Cell[8740, 255, 760, 29, 383, "Output"]
}, Closed]],
Cell[9515, 287, 79, 2, 29, "Text",
  Evaluatable->False],
Cell[9597, 291, 116, 2, 27, "Input"],
Cell[9716, 295, 179, 3, 43, "Input"],

Cell[CellGroupData[{
Cell[9920, 302, 213, 4, 59, "Input"],
Cell[10136, 308, 66063, 1823, 296, 18015, 1225, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

