(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[    983784,      18218]
NotebookOptionsPosition[    683373,      12046]
NotebookOutlinePosition[    977487,      18047]
CellTagsIndexPosition[    977355,      18040]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[Cell[BoxData[GridBox[{
   {
    ButtonBox[
     StyleBox["\[FirstPage]", "SR"],
     BaseStyle->"SlideHyperlink",
     ButtonFunction:>FrontEndExecute[{
        FrontEndToken[
         FrontEnd`SelectedNotebook[], "ScrollPageFirst"]}],
     ButtonNote->"First Slide"], 
    ButtonBox[
     StyleBox["\[LeftPointer]", "SR"],
     BaseStyle->"SlideHyperlink",
     ButtonFunction:>FrontEndExecute[{
        FrontEndToken[
         FrontEnd`SelectedNotebook[], "ScrollPagePrevious"]}],
     ButtonNote->"Previous Slide"], 
    ButtonBox[
     StyleBox["\[RightPointer]", "SR"],
     BaseStyle->"SlideHyperlink",
     ButtonFunction:>FrontEndExecute[{
        FrontEndToken[
         FrontEnd`SelectedNotebook[], "ScrollPageNext"]}],
     ButtonNote->"Next Slide"], 
    ButtonBox[
     StyleBox["\[LastPage]", "SR"],
     BaseStyle->"SlideHyperlink",
     ButtonFunction:>FrontEndExecute[{
        FrontEndToken[
         FrontEnd`SelectedNotebook[], "ScrollPageLast"]}],
     ButtonNote->"Last Slide"], " ", 
    ButtonBox[
     StyleBox[
      RowBox[{
       CounterBox["SlideShowNavigationBar"], 
       RowBox[{" ", "of", " "}], 
       CounterBox["SlideShowNavigationBar", "LastSlide"]}], "SR"],
     Appearance->{Automatic, None}]}
  }]]]], "SlideShowNavigationBar"],

Cell[CellGroupData[{

Cell["Resonance", "Section"],

Cell[TextData[{
 "Paul Abbott\nSchool of Physics\nThe University of Western Australia\n\
Crawley, WA  6009, Australia\n\n",
 ButtonBox["paul@physics.uwa.edu.au",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["mailto:paul@physics.uwa.edu.au"], None}],
 "\n",
 ButtonBox["physics.uwa.edu.au/~paul",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://physics.uwa.edu.au/~paul"], None}]
}], "SubsectionIcon",
 ShowGroupOpener->False],

Cell[CellGroupData[{

Cell["Outline", "SubsectionIcon"],

Cell["\<\
Simple Harmonic Motion (SHM) (13.1, 13.2) \[Bullet] Mass-spring system (13.2) \
\[Bullet] Energy of simple harmonic oscillator (13.3) \[Bullet] Comparing SHM \
and circular motion \[Bullet] Damped oscillations (13.7) \[Bullet] Forced \
oscillations and Resonance (13.8) \
\>", "Text"],

Cell[TextData[{
 "Section numbers refer to ",
 StyleBox["University",
  FontSlant->"Italic"],
 " ",
 StyleBox["Physics",
  FontSlant->"Italic"],
 ", Young and Friedman, ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["11", "th"], TraditionalForm]]],
 " edition."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Pre-requisites", "Subsection"],

Cell[CellGroupData[{

Cell["Plotting", "Subsubsection"],

Cell[BoxData[
 FormBox[
  RowBox[{"<<", "Graphics`"}], TraditionalForm]], "Input",
 InitializationCell->True,
 CellLabel->"In[1]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"SetOptions", "[", 
    RowBox[{"Plot", ",", 
     RowBox[{"PlotPoints", "\[Rule]", "80"}]}], "]"}], ";"}], 
  TraditionalForm]], "Input",
 CellLabel->"In[342]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"$FormatType", "=", "TraditionalForm"}], ";"}], 
  TraditionalForm]], "Input",
 InitializationCell->True,
 CellLabel->"In[2]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"$TextStyle", "=", 
    RowBox[{"{", 
     RowBox[{"FontSize", "\[Rule]", "9"}], "}"}]}], ";"}], 
  TraditionalForm]], "Input",
 InitializationCell->True,
 CellLabel->"In[3]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["Equations", "Subsubsection"],

Cell[TextData[{
 "We modify ",
 Cell[BoxData[
  FormBox[
   StyleBox["Equal", "Input"], TraditionalForm]]],
 " so that ",
 Cell[BoxData[
  FormBox[
   StyleBox["Listable", "Input"], TraditionalForm]]],
 " operations are automatically applied to both sides of any equality:"
}], "Text",
 CellTags->{"Equal", "Listable"}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"Unprotect", "[", "Equal", "]"}], ";"}], TraditionalForm]], "Input",\

 InitializationCell->True,
 CellLabel->"In[4]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"listableQ", "(", "f_", ")"}], ":=", 
   RowBox[{"MemberQ", "(", 
    RowBox[{
     RowBox[{"Attributes", "(", "f", ")"}], ",", "Listable"}], ")"}]}], 
  TraditionalForm]], "Input",
 InitializationCell->True,
 CellLabel->"In[5]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"Equal", "/:", " ", 
   RowBox[{"lhs", ":", 
    RowBox[{
     RowBox[{"f_Symbol", "?", "listableQ"}], "[", 
     RowBox[{"___", ",", " ", "_Equal", ",", " ", "___"}], "]"}]}], " ", ":=",
    "\n", "        ", 
   RowBox[{"Thread", "[", " ", 
    RowBox[{
     RowBox[{"Unevaluated", "[", "lhs", "]"}], ",", " ", "Equal"}], " ", 
    "]"}]}], TraditionalForm]], "Input",
 InitializationCell->True,
 CellLabel->"In[6]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"Protect", "[", "Equal", "]"}], ";"}], TraditionalForm]], "Input",
 InitializationCell->True,
 CellLabel->"In[7]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["Subscript", "Subsubsection"],

Cell[BoxData[
 FormBox[
  RowBox[{"SetAttributes", "[", 
   RowBox[{"Subscript", ",", "NHoldAll"}], "]"}], TraditionalForm]], "Input",
 InitializationCell->True,
 CellLabel->"In[8]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["Notation", "Subsubsection"],

Cell[BoxData[
 FormBox[
  RowBox[{"<<", "Utilities`Notation`"}], TraditionalForm]], "Input",
 InitializationCell->True,
 CellLabel->"In[9]:="]
}, Closed]]
}, Closed]]
}, Open  ]],

Cell[TextData[Cell[BoxData[GridBox[{
   {
    ButtonBox[
     StyleBox["\[FirstPage]", "SR"],
     BaseStyle->"SlideHyperlink",
     ButtonFunction:>FrontEndExecute[{
        FrontEndToken[
         FrontEnd`SelectedNotebook[], "ScrollPageFirst"]}],
     ButtonNote->"First Slide"], 
    ButtonBox[
     StyleBox["\[LeftPointer]", "SR"],
     BaseStyle->"SlideHyperlink",
     ButtonFunction:>FrontEndExecute[{
        FrontEndToken[
         FrontEnd`SelectedNotebook[], "ScrollPagePrevious"]}],
     ButtonNote->"Previous Slide"], 
    ButtonBox[
     StyleBox["\[RightPointer]", "SR"],
     BaseStyle->"SlideHyperlink",
     ButtonFunction:>FrontEndExecute[{
        FrontEndToken[
         FrontEnd`SelectedNotebook[], "ScrollPageNext"]}],
     ButtonNote->"Next Slide"], 
    ButtonBox[
     StyleBox["\[LastPage]", "SR"],
     BaseStyle->"SlideHyperlink",
     ButtonFunction:>FrontEndExecute[{
        FrontEndToken[
         FrontEnd`SelectedNotebook[], "ScrollPageLast"]}],
     ButtonNote->"Last Slide"], " ", 
    ButtonBox[
     StyleBox[
      RowBox[{
       CounterBox["SlideShowNavigationBar"], 
       RowBox[{" ", "of", " "}], 
       CounterBox["SlideShowNavigationBar", "LastSlide"]}], "SR"],
     Appearance->{Automatic, None}]}
  }]]]], "SlideShowNavigationBar"],

Cell[CellGroupData[{

Cell["Simple Harmonic Motion", "Section"],

Cell["\<\
Oscillatory motion, where the motion is repetitive with time, is very \
important form of bounded motion important in physics and engineering.\
\>", "Text"],

Cell[TextData[{
 StyleBox["Definition 1",
  FontWeight->"Bold"],
 ": Simple harmonic motion (SHM) is defined as the motion for which the \
displacement versus time graph is exactly sinusoidal, ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"x", "(", "t", ")"}], "=", 
    RowBox[{"A", " ", 
     RowBox[{"sin", "(", 
      RowBox[{
       RowBox[{"\[Omega]", " ", "t"}], "+", "\[Phi]"}], ")"}]}]}], 
   TraditionalForm]]],
 "."
}], "Text"],

Cell[TextData[{
 "Plot of two SHM curves with the same amplitude, ",
 Cell[BoxData[
  FormBox["A", TraditionalForm]]],
 ", but with a phase difference of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"60", "\[Degree]"}], TraditionalForm]]],
 "."
}], "MathCaption"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"sin", "(", 
        RowBox[{"2", " ", "\[Pi]", " ", "t"}], ")"}], ",", 
       RowBox[{"sin", "(", 
        RowBox[{
         RowBox[{"2", " ", "\[Pi]", " ", "t"}], "+", 
         FractionBox["\[Pi]", "3"]}], ")"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "3"}], "}"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"t", ",", "x"}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"n", ",", 
            RowBox[{"n", " ", "T"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "3"}], "}"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "A"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "A"}], "}"}]}], "}"}]}], "}"}]}]}], "]"}], ";"}],
   TraditionalForm]], "HiddenInput",
 CellLabel->"In[543]:="]
}, Open  ]],

Cell[TextData[Cell[BoxData[GridBox[{
   {
    ButtonBox[
     StyleBox["\[FirstPage]", "SR"],
     BaseStyle->"SlideHyperlink",
     ButtonFunction:>FrontEndExecute[{
        FrontEndToken[
         FrontEnd`SelectedNotebook[], "ScrollPageFirst"]}],
     ButtonNote->"First Slide"], 
    ButtonBox[
     StyleBox["\[LeftPointer]", "SR"],
     BaseStyle->"SlideHyperlink",
     ButtonFunction:>FrontEndExecute[{
        FrontEndToken[
         FrontEnd`SelectedNotebook[], "ScrollPagePrevious"]}],
     ButtonNote->"Previous Slide"], 
    ButtonBox[
     StyleBox["\[RightPointer]", "SR"],
     BaseStyle->"SlideHyperlink",
     ButtonFunction:>FrontEndExecute[{
        FrontEndToken[
         FrontEnd`SelectedNotebook[], "ScrollPageNext"]}],
     ButtonNote->"Next Slide"], 
    ButtonBox[
     StyleBox["\[LastPage]", "SR"],
     BaseStyle->"SlideHyperlink",
     ButtonFunction:>FrontEndExecute[{
        FrontEndToken[
         FrontEnd`SelectedNotebook[], "ScrollPageLast"]}],
     ButtonNote->"Last Slide"], " ", 
    ButtonBox[
     StyleBox[
      RowBox[{
       CounterBox["SlideShowNavigationBar"], 
       RowBox[{" ", "of", " "}], 
       CounterBox["SlideShowNavigationBar", "LastSlide"]}], "SR"],
     Appearance->{Automatic, None}]}
  }]]]], "SlideShowNavigationBar"],

Cell[CellGroupData[{

Cell["Mass-spring System", "Section"],

Cell["\<\
Consider horizontal motion on a frictionless surface of a mass-spring system. \
The spring is loosely wound and can be compressed as well as stretched.\
\>", "Text"],

Cell[TextData[{
 "Graphs of ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox["v", TraditionalForm]]],
 ", and ",
 Cell[BoxData[
  FormBox["a", TraditionalForm]]],
 " for a mass-spring system."
}], "MathCaption"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"With", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"k", "=", 
          RowBox[{
           RowBox[{"sin", "(", 
            RowBox[{"2", " ", "\[Pi]", " ", "\[Tau]"}], ")"}], "+", "2"}]}], 
         ",", 
         RowBox[{"\[Alpha]", "=", 
          RowBox[{"13", " ", "\[Pi]"}]}]}], "}"}], ",", 
       RowBox[{"DisplayTogether", "(", 
        RowBox[{
         RowBox[{"Graphics", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Line", "[", 
             RowBox[{"(", "\[NoBreak]", GridBox[{
                {
                 RowBox[{"-", "4"}], "0"},
                {"0", "0"}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Decimal}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}], "\[NoBreak]", 
              ")"}], "]"}], ",", 
            RowBox[{"Line", "[", 
             RowBox[{"(", "\[NoBreak]", GridBox[{
                {
                 RowBox[{"k", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    FractionBox["\[Alpha]", "3"], "+", "2"}], ")"}]}], "0"},
                {
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    FractionBox["\[Alpha]", "3"], "+", "2"}], ")"}], " ", 
                   "k"}], "+", "10"}], "0"}
               }], "\[NoBreak]", ")"}], "]"}], ",", 
            RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
            RowBox[{"Line", "[", 
             RowBox[{"(", "\[NoBreak]", GridBox[{
                {
                 RowBox[{"-", "4"}], 
                 RowBox[{"-", "1"}]},
                {
                 RowBox[{"-", "4"}], "1"}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Decimal}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}], "\[NoBreak]", 
              ")"}], "]"}], ",", 
            RowBox[{"Rectangle", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    FractionBox["\[Alpha]", "3"], "+", "2"}], ")"}], " ", 
                  "k"}], "+", "10"}], ",", 
                RowBox[{"-", "0.5"}]}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    FractionBox["\[Alpha]", "3"], "+", "2"}], ")"}], " ", 
                  "k"}], "+", "30"}], ",", "0.5"}], "}"}]}], "]"}], ",", 
            RowBox[{"Rectangle", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"90", ",", 
                RowBox[{"-", "1"}]}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"160", ",", "1"}], "}"}], ",", 
              RowBox[{"Plot", "[", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"sin", "(", 
                   RowBox[{"2", " ", 
                    FractionBox["\[Pi]", "3"], " ", "t"}], ")"}], ",", 
                  RowBox[{"2", 
                   FractionBox["\[Pi]", "3"], " ", 
                   RowBox[{"cos", "(", 
                    RowBox[{"2", " ", 
                    FractionBox["\[Pi]", "3"], " ", "t"}], ")"}]}], ",", 
                  RowBox[{
                   RowBox[{"-", "4"}], 
                   FractionBox[
                    SuperscriptBox["\[Pi]", "2"], "9"], 
                   RowBox[{"sin", "(", 
                    RowBox[{"2", " ", 
                    FractionBox["\[Pi]", "3"], " ", "t"}], ")"}]}]}], "}"}], 
                ",", 
                RowBox[{"{", 
                 RowBox[{"t", ",", "0", ",", 
                  RowBox[{"3", "\[Tau]"}]}], "}"}], ",", 
                RowBox[{"PlotRange", "\[Rule]", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"{", 
                    RowBox[{"0", ",", "3"}], "}"}], ",", 
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "4"}], 
                    FractionBox[
                    SuperscriptBox["\[Pi]", "2"], "9"]}], ",", 
                    RowBox[{"4", 
                    FractionBox[
                    SuperscriptBox["\[Pi]", "2"], "9"]}]}], "}"}]}], "}"}]}], 
                ",", 
                RowBox[{"PlotStyle", "\[Rule]", 
                 RowBox[{"Table", "[", 
                  RowBox[{
                   RowBox[{"Hue", "[", "i", "]"}], ",", 
                   RowBox[{"{", 
                    RowBox[{"i", ",", "0", ",", "1", ",", 
                    FractionBox["1", "3"]}], "}"}]}], "]"}]}], ",", 
                RowBox[{"AxesLabel", "\[Rule]", 
                 RowBox[{"{", 
                  RowBox[{"t", ",", "\"\<\>\""}], "}"}]}], ",", 
                RowBox[{"PlotLegend", "\[Rule]", 
                 RowBox[{"{", 
                  RowBox[{"x", ",", "v", ",", "a"}], "}"}]}], ",", 
                RowBox[{"LegendPosition", "\[Rule]", 
                 RowBox[{"{", 
                  RowBox[{"0.5", ",", 
                   RowBox[{"-", "0.7"}]}], "}"}]}], ",", 
                RowBox[{"LegendSize", "\[Rule]", "0.4"}]}], "]"}]}], "]"}], 
            ",", 
            RowBox[{"Hue", "[", "0", "]"}], ",", 
            RowBox[{"Line", "[", 
             RowBox[{"(", "\[NoBreak]", GridBox[{
                {
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    FractionBox["\[Alpha]", "3"], "+", "2"}], ")"}], " ", 
                   "2"}], "+", "20"}], 
                 RowBox[{"-", "1"}]},
                {
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    FractionBox["\[Alpha]", "3"], "+", "2"}], ")"}], " ", 
                   "2"}], "+", "20"}], "1"}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Decimal}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}], "\[NoBreak]", 
              ")"}], "]"}]}], "}"}], "]"}], ",", 
         RowBox[{"ParametricPlot", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"k", " ", 
              RowBox[{"(", 
               RowBox[{
                FractionBox["\[Theta]", "3"], "-", 
                RowBox[{"cos", "(", "\[Theta]", ")"}], "+", "1"}], ")"}]}], 
             ",", 
             RowBox[{"sin", "(", "\[Theta]", ")"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\[Theta]", ",", "0", ",", "\[Alpha]"}], "}"}]}], "]"}], 
         ",", 
         RowBox[{"PlotRange", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "4"}], ",", "160"}], "}"}], ",", "All"}], "}"}]}], 
         ",", 
         RowBox[{"AspectRatio", "\[Rule]", 
          FractionBox["1", "4"]}]}], ")"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"\[Tau]", ",", "0.125", ",", "1", ",", "0.125"}], "}"}]}], 
    "]"}], ";"}], TraditionalForm]], "HiddenInput",
 CellLabel->"In[19]:="],

Cell[TextData[{
 "The acceleration is always toward the equilibrium position (",
 Cell[BoxData[
  FormBox[
   RowBox[{"x", "=", "0"}], TraditionalForm]]],
 ") and proportional to distance from the equilibrium position."
}], "Text"],

Cell[TextData[{
 StyleBox["Definition 2",
  FontWeight->"Bold"],
 ": SHM is produced by a force, ",
 Cell[BoxData[
  FormBox[
   RowBox[{"F", "\[Proportional]", "x"}], TraditionalForm]]],
 ", directed towards ",
 Cell[BoxData[
  FormBox[
   RowBox[{"x", "=", "0"}], TraditionalForm]]],
 ". That is ",
 Cell[BoxData[
  FormBox[
   RowBox[{"F", "=", 
    RowBox[{
     RowBox[{"-", "k"}], " ", "x"}]}], TraditionalForm]]],
 "."
}], "Text"],

Cell[TextData[{
 StyleBox["Definition 3",
  FontWeight->"Bold"],
 ": Since ",
 Cell[BoxData[
  FormBox[
   RowBox[{"F", "=", 
    RowBox[{
     RowBox[{"-", "k"}], " ", "x"}]}], TraditionalForm]]],
 ", the differential equation for SHM reads"
}], "Text"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"m", " ", 
     FractionBox[
      RowBox[{
       SuperscriptBox["\[DifferentialD]", "2"], 
       RowBox[{"x", "(", "t", ")"}]}], 
      RowBox[{"\[DifferentialD]", 
       SuperscriptBox["t", "2"]}]]}], "+", 
    RowBox[{"k", " ", 
     RowBox[{"x", "(", "t", ")"}]}]}], "=", "0."}], 
  TraditionalForm]], "DisplayFormula"]
}, Open  ]],

Cell[TextData[Cell[BoxData[GridBox[{
   {
    ButtonBox[
     StyleBox["\[FirstPage]", "SR"],
     BaseStyle->"SlideHyperlink",
     ButtonFunction:>FrontEndExecute[{
        FrontEndToken[
         FrontEnd`SelectedNotebook[], "ScrollPageFirst"]}],
     ButtonNote->"First Slide"], 
    ButtonBox[
     StyleBox["\[LeftPointer]", "SR"],
     BaseStyle->"SlideHyperlink",
     ButtonFunction:>FrontEndExecute[{
        FrontEndToken[
         FrontEnd`SelectedNotebook[], "ScrollPagePrevious"]}],
     ButtonNote->"Previous Slide"], 
    ButtonBox[
     StyleBox["\[RightPointer]", "SR"],
     BaseStyle->"SlideHyperlink",
     ButtonFunction:>FrontEndExecute[{
        FrontEndToken[
         FrontEnd`SelectedNotebook[], "ScrollPageNext"]}],
     ButtonNote->"Next Slide"], 
    ButtonBox[
     StyleBox["\[LastPage]", "SR"],
     BaseStyle->"SlideHyperlink",
     ButtonFunction:>FrontEndExecute[{
        FrontEndToken[
         FrontEnd`SelectedNotebook[], "ScrollPageLast"]}],
     ButtonNote->"Last Slide"], " ", 
    ButtonBox[
     StyleBox[
      RowBox[{
       CounterBox["SlideShowNavigationBar"], 
       RowBox[{" ", "of", " "}], 
       CounterBox["SlideShowNavigationBar", "LastSlide"]}], "SR"],
     Appearance->{Automatic, None}]}
  }]]]], "SlideShowNavigationBar"],

Cell[CellGroupData[{

Cell["Mass-spring System", "SectionTwo"],

Cell[TextData[{
 "Acceleration is ",
 StyleBox["not",
  FontSlant->"Italic"],
 " constant in SHM."
}], "MathCaption"],

Cell[TextData[Cell[BoxData[
 FormBox[
  TagBox[
   StyleBox[GridBox[{
      {
       RowBox[{"\[AlignmentMarker]", Cell["Constant acceleration"]}], 
       RowBox[{"\[AlignmentMarker]", "SHM"}], Cell[
       "\[AlignmentMarker]Maxima"]},
      {
       RowBox[{"x", "=", "\[AlignmentMarker]", 
        RowBox[{
         SubscriptBox["x", "0"], "+", 
         RowBox[{
          SubscriptBox["v", "0"], "t"}], "+", 
         RowBox[{
          FractionBox["1", "2"], "a", " ", 
          SuperscriptBox["t", "2"]}]}]}], 
       RowBox[{"x", "=", "\[AlignmentMarker]", 
        RowBox[{"A", " ", 
         RowBox[{"sin", "(", 
          RowBox[{
           RowBox[{"\[Omega]", " ", "t"}], "+", "\[Phi]"}], ")"}]}]}], 
       RowBox[{
        SubscriptBox["x", "max"], "=", "\[AlignmentMarker]", "A"}]},
      {
       RowBox[{"v", "=", "\[AlignmentMarker]", 
        RowBox[{
         FractionBox[
          RowBox[{"\[DifferentialD]", "x"}], 
          RowBox[{"\[DifferentialD]", "t"}]], "=", 
         RowBox[{
          SubscriptBox["v", "0"], "+", 
          RowBox[{"a", " ", "t"}]}]}]}], 
       RowBox[{"v", "=", "\[AlignmentMarker]", 
        RowBox[{
         FractionBox[
          RowBox[{"\[DifferentialD]", "x"}], 
          RowBox[{"\[DifferentialD]", "t"}]], "=", 
         RowBox[{"A", " ", "\[Omega]", " ", 
          RowBox[{"cos", "(", 
           RowBox[{
            RowBox[{"\[Omega]", " ", "t"}], "+", "\[Phi]"}], ")"}]}]}]}], 
       RowBox[{
        SubscriptBox["v", "max"], "=", "\[AlignmentMarker]", 
        RowBox[{"A", " ", "\[Omega]"}]}]},
      {
       RowBox[{"a", "=", "\[AlignmentMarker]", 
        RowBox[{
         FractionBox[
          RowBox[{"\[DifferentialD]", "v"}], 
          RowBox[{"\[DifferentialD]", "t"}]], "=", 
         RowBox[{
          FractionBox[
           RowBox[{
            SuperscriptBox["\[DifferentialD]", "2"], "x"}], 
           RowBox[{"\[DifferentialD]", 
            SuperscriptBox["t", "2"]}]], "=", "a", " "}]}]}], 
       RowBox[{"a", "=", "\[AlignmentMarker]", 
        RowBox[{
         FractionBox[
          RowBox[{"\[DifferentialD]", "v"}], 
          RowBox[{"\[DifferentialD]", "t"}]], "=", 
         RowBox[{
          FractionBox[
           RowBox[{
            SuperscriptBox["\[DifferentialD]", "2"], "x"}], 
           RowBox[{"\[DifferentialD]", 
            SuperscriptBox["t", "2"]}]], "=", 
          RowBox[{
           RowBox[{"-", "A"}], " ", 
           SuperscriptBox["\[Omega]", "2"], 
           RowBox[{"sin", "(", 
            RowBox[{
             RowBox[{"\[Omega]", " ", "t"}], "+", "\[Phi]"}], ")"}]}]}]}]}], 
       RowBox[{
        SubscriptBox["a", "max"], "=", "\[AlignmentMarker]", 
        RowBox[{"A", " ", 
         SuperscriptBox["\[Omega]", "2"]}]}]}
     },
     GridBoxDividers->{"Columns" -> {
         AbsoluteThickness[2], True, {False}, 
         AbsoluteThickness[2]}, "ColumnsIndexed" -> {}, "Rows" -> {
         AbsoluteThickness[2], True, {False}, 
         AbsoluteThickness[2]}, "RowsIndexed" -> {}}],
    Background->GrayLevel[0.8],
    GridBoxOptions->{
    GridBoxAlignment->{
     "Columns" -> {{"\[AlignmentMarker]"}}, "ColumnsIndexed" -> {}, 
      "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}}],
   DisplayForm], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False]], "Text"]
}, Open  ]],

Cell[TextData[Cell[BoxData[GridBox[{
   {
    ButtonBox[
     StyleBox["\[FirstPage]", "SR"],
     BaseStyle->"SlideHyperlink",
     ButtonFunction:>FrontEndExecute[{
        FrontEndToken[
         FrontEnd`SelectedNotebook[], "ScrollPageFirst"]}],
     ButtonNote->"First Slide"], 
    ButtonBox[
     StyleBox["\[LeftPointer]", "SR"],
     BaseStyle->"SlideHyperlink",
     ButtonFunction:>FrontEndExecute[{
        FrontEndToken[
         FrontEnd`SelectedNotebook[], "ScrollPagePrevious"]}],
     ButtonNote->"Previous Slide"], 
    ButtonBox[
     StyleBox["\[RightPointer]", "SR"],
     BaseStyle->"SlideHyperlink",
     ButtonFunction:>FrontEndExecute[{
        FrontEndToken[
         FrontEnd`SelectedNotebook[], "ScrollPageNext"]}],
     ButtonNote->"Next Slide"], 
    ButtonBox[
     StyleBox["\[LastPage]", "SR"],
     BaseStyle->"SlideHyperlink",
     ButtonFunction:>FrontEndExecute[{
        FrontEndToken[
         FrontEnd`SelectedNotebook[], "ScrollPageLast"]}],
     ButtonNote->"Last Slide"], " ", 
    ButtonBox[
     StyleBox[
      RowBox[{
       CounterBox["SlideShowNavigationBar"], 
       RowBox[{" ", "of", " "}], 
       CounterBox["SlideShowNavigationBar", "LastSlide"]}], "SR"],
     Appearance->{Automatic, None}]}
  }]]]], "SlideShowNavigationBar"],

Cell[CellGroupData[{

Cell["Mass-spring System", "SectionTwo"],

Cell[TextData[{
 "Plot of ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox["v", TraditionalForm]]],
 ", and ",
 Cell[BoxData[
  FormBox["a", TraditionalForm]]],
 " for ",
 Cell[BoxData[
  FormBox[
   RowBox[{"x", "=", 
    RowBox[{
     RowBox[{"sin", "(", 
      RowBox[{"2", "\[Pi]", " ", "f", " ", "t"}], ")"}], "=", 
     RowBox[{"sin", "(", 
      RowBox[{"\[Omega]", " ", "t"}], ")"}]}]}], TraditionalForm]]],
 " where ",
 Cell[BoxData[
  FormBox[
   RowBox[{"f", "=", 
    RowBox[{
     RowBox[{"1", "/", 
      RowBox[{"3", "\[DoubleLongLeftRightArrow]", "\[Omega]"}]}], "=", 
     RowBox[{"2", 
      RowBox[{"\[Pi]", "/", "3"}]}]}]}], TraditionalForm]]],
 "."
}], "MathCaption"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"Evaluate", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        FractionBox[
         RowBox[{
          SuperscriptBox["\[PartialD]", "n"], 
          RowBox[{"sin", "(", 
           RowBox[{"2", " ", "\[Pi]", " ", 
            FractionBox["1", "3"], " ", "t"}], ")"}]}], 
         RowBox[{"\[PartialD]", 
          SuperscriptBox["t", "n"]}],
         MultilineFunction->None], ",", 
        RowBox[{"{", 
         RowBox[{"n", ",", "0", ",", "2"}], "}"}]}], "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "3"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"Hue", "[", "i", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "0", ",", "1", ",", 
          FractionBox["1", "3"]}], "}"}]}], "]"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"t", ",", "\"\<\>\""}], "}"}]}], ",", 
     RowBox[{"PlotLegend", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"x", ",", "v", ",", "a"}], "}"}]}], ",", 
     RowBox[{"LegendPosition", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0.5", ",", 
        RowBox[{"-", "0.7"}]}], "}"}]}], ",", 
     RowBox[{"LegendSize", "\[Rule]", "0.4"}]}], "]"}], ";"}], 
  TraditionalForm]], "HiddenInput",
 CellLabel->"In[16]:="],

Cell[TextData[{
 "Note the phase relationship between phase of ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox["v", TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox["a", TraditionalForm]]],
 ": ",
 Cell[BoxData[
  FormBox["v", TraditionalForm]]],
 " is ",
 Cell[BoxData[
  FormBox[
   RowBox[{"90", "\[Degree]"}], TraditionalForm]]],
 " ahead of ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"90", "\[Degree]"}], TraditionalForm]]],
 " behind ",
 Cell[BoxData[
  FormBox["a", TraditionalForm]]],
 "."
}], "Warning"],

Cell[TextData[{
 StyleBox["Example",
  FontWeight->"Bold"],
 ": Consider a tuning fork vibrating at ",
 Cell[BoxData[
  FormBox[
   RowBox[{"f", "=", 
    RowBox[{"256", " \[ThinSpace]", "Hz"}]}], TraditionalForm]]],
 "; the tip of each prong executes SHM with ",
 Cell[BoxData[
  FormBox[
   RowBox[{"A", "=", 
    RowBox[{
     SubscriptBox["x", "max"], "=", 
     RowBox[{"1", " \[ThinSpace]", "mm"}]}]}], TraditionalForm]]],
 " (if you hit it hard). Find ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["v", "max"], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", "max"], TraditionalForm]]],
 "."
}], "Text"],

Cell[TextData[{
 
 CounterBox["List"],
 ". ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Omega]", "=", 
    RowBox[{
     RowBox[{"2", "\[Pi]", " ", "f"}], "=", 
     RowBox[{
      RowBox[{"512", "\[Pi]"}], "\[TildeTilde]", 
      RowBox[{"1600", " ", 
       RowBox[{"rad", "\[CenterDot]", 
        SuperscriptBox["s", 
         RowBox[{"-", "1"}]]}]}]}]}]}], TraditionalForm]]],
 "."
}], "BeginNumberedList"],

Cell[TextData[{
 
 CounterBox["List"],
 ". ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["v", "max"], "=", 
    RowBox[{
     RowBox[{"A", " ", "\[Omega]"}], "=", 
     RowBox[{
      RowBox[{
       SuperscriptBox["10", 
        RowBox[{"-", "3"}]], "\[Times]", 
       RowBox[{"(", 
        RowBox[{"1.6", "\[Times]", 
         SuperscriptBox["10", "3"]}], ")"}]}], "\[TildeTilde]", 
      RowBox[{"1.6", "  ", 
       RowBox[{"m", "\[CenterDot]", 
        SuperscriptBox["s", 
         RowBox[{"-", "1"}]]}]}]}]}]}], TraditionalForm]]],
 " (walking speed)"
}], "NumberedList"],

Cell[TextData[{
 
 CounterBox["List"],
 ". ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["a", "max"], "=", 
    RowBox[{
     RowBox[{"A", " ", 
      SuperscriptBox["\[Omega]", "2"]}], "="}]}], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["10", 
       RowBox[{"-", "3"}]], "\[Times]", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1.6", "\[Times]", 
         SuperscriptBox["10", "3"]}], ")"}], "2"]}], "\[TildeTilde]", 
     RowBox[{"2.6", "\[Times]", 
      SuperscriptBox["10", "3"], 
      RowBox[{
       SuperscriptBox["m", "2"], "\[CenterDot]", 
       SuperscriptBox["s", 
        RowBox[{"-", "1"}]]}]}]}], "=", 
    RowBox[{"260", " ", 
     SubscriptBox["g", "Earth"]}]}], TraditionalForm]]],
 "!"
}], "NumberedList"]
}, Open  ]],

Cell[TextData[Cell[BoxData[GridBox[{
   {
    ButtonBox[
     StyleBox["\[FirstPage]", "SR"],
     BaseStyle->"SlideHyperlink",
     ButtonFunction:>FrontEndExecute[{
        FrontEndToken[
         FrontEnd`SelectedNotebook[], "ScrollPageFirst"]}],
     ButtonNote->"First Slide"], 
    ButtonBox[
     StyleBox["\[LeftPointer]", "SR"],
     BaseStyle->"SlideHyperlink",
     ButtonFunction:>FrontEndExecute[{
        FrontEndToken[
         FrontEnd`SelectedNotebook[], "ScrollPagePrevious"]}],
     ButtonNote->"Previous Slide"], 
    ButtonBox[
     StyleBox["\[RightPointer]", "SR"],
     BaseStyle->"SlideHyperlink",
     ButtonFunction:>FrontEndExecute[{
        FrontEndToken[
         FrontEnd`SelectedNotebook[], "ScrollPageNext"]}],
     ButtonNote->"Next Slide"], 
    ButtonBox[
     StyleBox["\[LastPage]", "SR"],
     BaseStyle->"SlideHyperlink",
     ButtonFunction:>FrontEndExecute[{
        FrontEndToken[
         FrontEnd`SelectedNotebook[], "ScrollPageLast"]}],
     ButtonNote->"Last Slide"], " ", 
    ButtonBox[
     StyleBox[
      RowBox[{
       CounterBox["SlideShowNavigationBar"], 
       RowBox[{" ", "of", " "}], 
       CounterBox["SlideShowNavigationBar", "LastSlide"]}], "SR"],
     Appearance->{Automatic, None}]}
  }]]]], "SlideShowNavigationBar"],

Cell[CellGroupData[{

Cell["Comparing SHM and Circular Motion", "Section"],

Cell[TextData[{
 "The ",
 Cell[BoxData[
  FormBox["y", TraditionalForm]]],
 "\[Dash]component of the circular motion is SHM, ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"y", "(", "t", ")"}], "=", 
    RowBox[{"A", " ", 
     RowBox[{"sin", "(", 
      RowBox[{"\[Omega]", " ", "t"}], ")"}]}]}], TraditionalForm]]],
 "."
}], "MathCaption"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"DisplayTogetherArray", "[", 
      RowBox[{"GraphicsArray", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"ParametricPlot", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"cos", "(", 
              RowBox[{"2", " ", "\[Pi]", " ", "t"}], ")"}], ",", 
             RowBox[{"sin", "(", 
              RowBox[{"2", " ", "\[Pi]", " ", "t"}], ")"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"t", ",", "0", ",", "\[Tau]"}], "}"}], ",", 
           RowBox[{"AspectRatio", "\[Rule]", "Automatic"}], ",", 
           RowBox[{"PlotRange", "\[Rule]", 
            RowBox[{"1.1", " ", 
             RowBox[{"(", "\[NoBreak]", GridBox[{
                {
                 RowBox[{"-", "1"}], "1"},
                {
                 RowBox[{"-", "1"}], "1"}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Decimal}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}], "\[NoBreak]", 
              ")"}]}]}], ",", 
           RowBox[{"AxesLabel", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"x", ",", "y"}], "}"}]}], ",", 
           RowBox[{"Epilog", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Hue", "[", "1", "]"}], ",", 
              RowBox[{"AbsolutePointSize", "[", "6", "]"}], ",", 
              RowBox[{"Point", "[", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"cos", "(", 
                  RowBox[{"2", " ", "\[Pi]", " ", "\[Tau]"}], ")"}], ",", 
                 RowBox[{"sin", "(", 
                  RowBox[{"2", " ", "\[Pi]", " ", "\[Tau]"}], ")"}]}], "}"}], 
               "]"}]}], "}"}]}]}], "]"}], ",", 
         RowBox[{"Plot", "[", 
          RowBox[{
           RowBox[{"sin", "(", 
            RowBox[{"2", " ", "\[Pi]", " ", "t"}], ")"}], ",", 
           RowBox[{"{", 
            RowBox[{"t", ",", "0", ",", "\[Tau]"}], "}"}], ",", 
           RowBox[{"PlotRange", "\[Rule]", 
            RowBox[{"1.1", " ", 
             RowBox[{"(", "\[NoBreak]", GridBox[{
                {"0", "1"},
                {
                 RowBox[{"-", "1"}], "1"}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Decimal}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}], "\[NoBreak]", 
              ")"}]}]}], ",", 
           RowBox[{"AspectRatio", "\[Rule]", "1.2"}], ",", 
           RowBox[{"AxesLabel", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"t", ",", "y"}], "}"}]}], ",", 
           RowBox[{"Ticks", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Table", "[", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"t", ",", 
                  RowBox[{"t", " ", "T"}]}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"t", ",", "0", ",", "1", ",", 
                  RowBox[{"1", "/", "4"}]}], "}"}]}], "]"}], ",", 
              "Automatic"}], "}"}]}], ",", 
           RowBox[{"Epilog", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Hue", "[", "1", "]"}], ",", 
              RowBox[{"AbsolutePointSize", "[", "6", "]"}], ",", 
              RowBox[{"Point", "[", 
               RowBox[{"{", 
                RowBox[{"\[Tau]", ",", 
                 RowBox[{"sin", "(", 
                  RowBox[{"2", " ", "\[Pi]", " ", "\[Tau]"}], ")"}]}], "}"}], 
               "]"}]}], "}"}]}]}], "]"}]}], "}"}], "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"\[Tau]", ",", "0.2", ",", "1", ",", "0.1"}], "}"}]}], "]"}], 
   ";"}], TraditionalForm]], "HiddenInput",
 CellLabel->"In[14]:="]
}, Open  ]],

Cell[TextData[Cell[BoxData[GridBox[{
   {
    ButtonBox[
     StyleBox["\[FirstPage]", "SR"],
     BaseStyle->"SlideHyperlink",
     ButtonFunction:>FrontEndExecute[{
        FrontEndToken[
         FrontEnd`SelectedNotebook[], "ScrollPageFirst"]}],
     ButtonNote->"First Slide"], 
    ButtonBox[
     StyleBox["\[LeftPointer]", "SR"],
     BaseStyle->"SlideHyperlink",
     ButtonFunction:>FrontEndExecute[{
        FrontEndToken[
         FrontEnd`SelectedNotebook[], "ScrollPagePrevious"]}],
     ButtonNote->"Previous Slide"], 
    ButtonBox[
     StyleBox["\[RightPointer]", "SR"],
     BaseStyle->"SlideHyperlink",
     ButtonFunction:>FrontEndExecute[{
        FrontEndToken[
         FrontEnd`SelectedNotebook[], "ScrollPageNext"]}],
     ButtonNote->"Next Slide"], 
    ButtonBox[
     StyleBox["\[LastPage]", "SR"],
     BaseStyle->"SlideHyperlink",
     ButtonFunction:>FrontEndExecute[{
        FrontEndToken[
         FrontEnd`SelectedNotebook[], "ScrollPageLast"]}],
     ButtonNote->"Last Slide"], " ", 
    ButtonBox[
     StyleBox[
      RowBox[{
       CounterBox["SlideShowNavigationBar"], 
       RowBox[{" ", "of", " "}], 
       CounterBox["SlideShowNavigationBar", "LastSlide"]}], "SR"],
     Appearance->{Automatic, None}]}
  }]]]], "SlideShowNavigationBar"],

Cell[CellGroupData[{

Cell["Comparing SHM and Circular motion", "SectionTwo"],

Cell[TextData[{
 "Similarly, the ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]]],
 "\[Dash]component is ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"x", "(", "t", ")"}], "=", 
    RowBox[{"A", " ", 
     RowBox[{"cos", "(", 
      RowBox[{"\[Omega]", " ", "t"}], ")"}]}]}], TraditionalForm]]],
 "."
}], "MathCaption"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"DisplayTogetherArray", "[", 
      RowBox[{"GraphicsArray", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"ParametricPlot", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Cos", "[", 
                RowBox[{"2", " ", "\[Pi]", " ", "t"}], "]"}], ",", "t"}], 
              "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"t", ",", "0", ",", "\[Tau]"}], "}"}], ",", 
             RowBox[{"PlotRange", "\[Rule]", 
              RowBox[{"1.1", " ", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"0", ",", "1"}], "}"}]}], "}"}]}]}], ",", 
             RowBox[{"AspectRatio", "\[Rule]", "1.2"}], ",", 
             RowBox[{"AxesLabel", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{"x", ",", "t"}], "}"}]}], ",", 
             RowBox[{"Ticks", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{"Automatic", ",", 
                RowBox[{"Table", "[", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{"u", ",", 
                    RowBox[{"u", " ", "T"}]}], "}"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"u", ",", "0", ",", "1", ",", 
                    FractionBox["1", "4"]}], "}"}]}], "]"}]}], "}"}]}], ",", 
             RowBox[{"Epilog", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"Hue", "[", "1", "]"}], ",", 
                RowBox[{"AbsolutePointSize", "[", "6", "]"}], ",", 
                RowBox[{"Point", "[", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "\[Pi]", " ", "\[Tau]"}], "]"}], ",", 
                   "\[Tau]"}], "}"}], "]"}]}], "}"}]}]}], "]"}], ",", 
           RowBox[{"Graphics", "[", 
            RowBox[{"{", "}"}], "]"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"ParametricPlot", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Cos", "[", 
                RowBox[{"2", " ", "\[Pi]", " ", "t"}], "]"}], ",", 
               RowBox[{"Sin", "[", 
                RowBox[{"2", " ", "\[Pi]", " ", "t"}], "]"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"t", ",", "0", ",", "\[Tau]"}], "}"}], ",", 
             RowBox[{"AspectRatio", "\[Rule]", "Automatic"}], ",", 
             RowBox[{"PlotRange", "\[Rule]", 
              RowBox[{"1.1", " ", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "}"}]}]}], ",", 
             RowBox[{"AxesLabel", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{"x", ",", "y"}], "}"}]}], ",", 
             RowBox[{"Epilog", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"Hue", "[", "1", "]"}], ",", 
                RowBox[{"AbsolutePointSize", "[", "6", "]"}], ",", 
                RowBox[{"Point", "[", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "\[Pi]", " ", "\[Tau]"}], "]"}], ",", 
                   RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", "\[Pi]", " ", "\[Tau]"}], "]"}]}], 
                  "}"}], "]"}]}], "}"}]}]}], "]"}], ",", 
           RowBox[{"ParametricPlot", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"t", ",", 
               RowBox[{"Sin", "[", 
                RowBox[{"2", " ", "\[Pi]", " ", "t"}], "]"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"t", ",", "0", ",", "\[Tau]"}], "}"}], ",", 
             RowBox[{"PlotRange", "\[Rule]", 
              RowBox[{"1.1", " ", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{"0", ",", "1"}], "}"}], ",", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "}"}]}]}], ",", 
             RowBox[{"AspectRatio", "\[Rule]", "1.2"}], ",", 
             RowBox[{"AxesLabel", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{"t", ",", "y"}], "}"}]}], ",", 
             RowBox[{"Ticks", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"Table", "[", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{"u", ",", 
                    RowBox[{"u", " ", "T"}]}], "}"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"u", ",", "0", ",", "1", ",", 
                    FractionBox["1", "4"]}], "}"}]}], "]"}], ",", 
                "Automatic"}], "}"}]}], ",", 
             RowBox[{"Epilog", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"Hue", "[", "1", "]"}], ",", 
                RowBox[{"AbsolutePointSize", "[", "6", "]"}], ",", 
                RowBox[{"Point", "[", 
                 RowBox[{"{", 
                  RowBox[{"\[Tau]", ",", 
                   RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", "\[Pi]", " ", "\[Tau]"}], "]"}]}], 
                  "}"}], "]"}]}], "}"}]}]}], "]"}]}], "}"}]}], "}"}], "]"}], 
      "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"\[Tau]", ",", "0.2", ",", "1", ",", "0.1"}], "}"}]}], "]"}], 
   ";"}], TraditionalForm]], "HiddenInput",
 CellLabel->"In[15]:="],

Cell[TextData[{
 StyleBox["Definition 4",
  FontWeight->"Bold"],
 ": SHM is the projection of circular motion on to ",
 StyleBox["any",
  FontSlant->"Italic"],
 " diameter. "
}], "Text"]
}, Open  ]],

Cell[TextData[Cell[BoxData[GridBox[{
   {
    ButtonBox[
     StyleBox["\[FirstPage]", "SR"],
     BaseStyle->"SlideHyperlink",
     ButtonFunction:>FrontEndExecute[{
        FrontEndToken[
         FrontEnd`SelectedNotebook[], "ScrollPageFirst"]}],
     ButtonNote->"First Slide"], 
    ButtonBox[
     StyleBox["\[LeftPointer]", "SR"],
     BaseStyle->"SlideHyperlink",
     ButtonFunction:>FrontEndExecute[{
        FrontEndToken[
         FrontEnd`SelectedNotebook[], "ScrollPagePrevious"]}],
     ButtonNote->"Previous Slide"], 
    ButtonBox[
     StyleBox["\[RightPointer]", "SR"],
     BaseStyle->"SlideHyperlink",
     ButtonFunction:>FrontEndExecute[{
        FrontEndToken[
         FrontEnd`SelectedNotebook[], "ScrollPageNext"]}],
     ButtonNote->"Next Slide"], 
    ButtonBox[
     StyleBox["\[LastPage]", "SR"],
     BaseStyle->"SlideHyperlink",
     ButtonFunction:>FrontEndExecute[{
        FrontEndToken[
         FrontEnd`SelectedNotebook[], "ScrollPageLast"]}],
     ButtonNote->"Last Slide"], " ", 
    ButtonBox[
     StyleBox[
      RowBox[{
       CounterBox["SlideShowNavigationBar"], 
       RowBox[{" ", "of", " "}], 
       CounterBox["SlideShowNavigationBar", "LastSlide"]}], "SR"],
     Appearance->{Automatic, None}]}
  }]]]], "SlideShowNavigationBar"],

Cell[CellGroupData[{

Cell["Damped Oscillations", "Section"],

Cell["\<\
A damped oscillator. SHM is damped by the plunger immersed in the liquid.\
\>", "MathCaption"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"Show", "[", 
    RowBox[{
    "Import", "[", 
     "\"\</Users/paul/Physics/Courses/ElectroMagnetism/Software/Tipler \
Art/11-15/F14-21.JPG\>\"", "]"}], "]"}], ";"}], 
  TraditionalForm]], "HiddenInput",
 CellLabel->"In[512]:="],

Cell[TextData[{
 "The damping force, ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["F", "d"], "=", 
    RowBox[{
     RowBox[{"-", "b"}], " ", "v"}]}], TraditionalForm]]],
 ", opposes the motion and is proportional to the instantaneous velocity. \
From Newton II, the differential equation describing the motion of the mass is"
}], "Text"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"m", " ", 
     FractionBox[
      RowBox[{
       SuperscriptBox["\[DifferentialD]", "2"], 
       RowBox[{"x", "(", "t", ")"}]}], 
      RowBox[{"\[DifferentialD]", 
       SuperscriptBox["t", "2"]}]]}], "+", 
    RowBox[{"b", 
     FractionBox[
      RowBox[{"\[DifferentialD]", 
       RowBox[{"x", "(", "t", ")"}]}], 
      RowBox[{"\[DifferentialD]", "t"}]]}], "+", 
    RowBox[{"k", " ", 
     RowBox[{"x", "(", "t", ")"}]}]}], "=", "0."}], 
  TraditionalForm]], "DisplayFormula"],

Cell[TextData[{
 "Without solving this equation, you should have an ",
 StyleBox["intuitive feel",
  FontSlant->"Italic"],
 " for the behaviour of this system. If the spring is stretched and then \
released, the mass will undergo SHM but the viscous damping will reduce the \
amplitude over time. If the damping is sufficiently large, the mass will not \
oscillate at all."
}], "Text"]
}, Open  ]],

Cell[TextData[Cell[BoxData[GridBox[{
   {
    ButtonBox[
     StyleBox["\[FirstPage]", "SR"],
     BaseStyle->"SlideHyperlink",
     ButtonFunction:>FrontEndExecute[{
        FrontEndToken[
         FrontEnd`SelectedNotebook[], "ScrollPageFirst"]}],
     ButtonNote->"First Slide"], 
    ButtonBox[
     StyleBox["\[LeftPointer]", "SR"],
     BaseStyle->"SlideHyperlink",
     ButtonFunction:>FrontEndExecute[{
        FrontEndToken[
         FrontEnd`SelectedNotebook[], "ScrollPagePrevious"]}],
     ButtonNote->"Previous Slide"], 
    ButtonBox[
     StyleBox["\[RightPointer]", "SR"],
     BaseStyle->"SlideHyperlink",
     ButtonFunction:>FrontEndExecute[{
        FrontEndToken[
         FrontEnd`SelectedNotebook[], "ScrollPageNext"]}],
     ButtonNote->"Next Slide"], 
    ButtonBox[
     StyleBox["\[LastPage]", "SR"],
     BaseStyle->"SlideHyperlink",
     ButtonFunction:>FrontEndExecute[{
        FrontEndToken[
         FrontEnd`SelectedNotebook[], "ScrollPageLast"]}],
     ButtonNote->"Last Slide"], " ", 
    ButtonBox[
     StyleBox[
      RowBox[{
       CounterBox["SlideShowNavigationBar"], 
       RowBox[{" ", "of", " "}], 
       CounterBox["SlideShowNavigationBar", "LastSlide"]}], "SR"],
     Appearance->{Automatic, None}]}
  }]]]], "SlideShowNavigationBar"],

Cell[CellGroupData[{

Cell["Damped Oscillations", "SectionTwo"],

Cell[TextData[{
 "Importantly, this differential equation is ",
 StyleBox["equivalent",
  FontSlant->"Italic"],
 " to that for a series ",
 StyleBox["LCR",
  FontSlant->"Italic"],
 " circuit,"
}], "Text"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"L", " ", 
     FractionBox[
      RowBox[{
       SuperscriptBox["\[DifferentialD]", "2"], 
       RowBox[{"Q", "(", "t", ")"}]}], 
      RowBox[{"\[DifferentialD]", 
       SuperscriptBox["t", "2"]}]]}], "+", 
    RowBox[{"R", 
     FractionBox[
      RowBox[{"\[DifferentialD]", 
       RowBox[{"Q", "(", "t", ")"}]}], 
      RowBox[{"\[DifferentialD]", "t"}]]}], "+", 
    RowBox[{
     FractionBox["1", "C"], " ", 
     RowBox[{"Q", "(", "t", ")"}]}]}], "=", "0."}], 
  TraditionalForm]], "DisplayFormula"],

Cell["\<\
Correspondence between mechanical and electrical resonant systems.\
\>", "MathCaption"],

Cell[TextData[Cell[BoxData[
 FormBox[
  RowBox[{"\t\t\t", 
   TagBox[
    StyleBox[GridBox[{
       {Cell["Mechanical"], 
        RowBox[{"\[AlignmentMarker]", "Electrical"}]},
       {"m", "L"},
       {"b", "R"},
       {
        RowBox[{"1", "/", "k"}], "C"},
       {
        RowBox[{"x", "(", "t", ")"}], 
        RowBox[{"Q", "(", "t", ")"}]},
       {
        RowBox[{
         SubscriptBox["\[Omega]", "0"], "=", 
         SqrtBox[
          RowBox[{"k", "/", "m"}]]}], 
        RowBox[{
         SubscriptBox["\[Omega]", "0"], "=", 
         RowBox[{"1", "/", 
          SqrtBox[
           RowBox[{"L", " ", "C"}]]}]}]},
       {
        RowBox[{"Q", "=", 
         RowBox[{
          FractionBox[
           SubscriptBox["\[Omega]", "0"], "\[CapitalDelta]\[Omega]"], "=", 
          RowBox[{
           FractionBox["m", "b"], " ", 
           SubscriptBox["\[Omega]", "0"]}]}]}], 
        RowBox[{"Q", "=", 
         RowBox[{
          FractionBox[
           SubscriptBox["\[Omega]", "0"], "\[CapitalDelta]\[Omega]"], "=", 
          RowBox[{
           FractionBox["L", "R"], " ", 
           SubscriptBox["\[Omega]", "0"]}]}]}]}
      },
      GridBoxDividers->{"Columns" -> {
          AbsoluteThickness[2], True, {False}, 
          AbsoluteThickness[2]}, "ColumnsIndexed" -> {}, "Rows" -> {
          AbsoluteThickness[2], True, {False}, 
          AbsoluteThickness[2]}, "RowsIndexed" -> {}}],
     Background->GrayLevel[0.8],
     GridBoxOptions->{
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
        "RowsIndexed" -> {}}}],
    DisplayForm]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False]], "Text"],

Cell[TextData[{
 "With this correspondence, (and equivalent initial conditions), the \
behaviour of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"x", "(", "t", ")"}], TraditionalForm]]],
 " is ",
 StyleBox["identical",
  FontSlant->"Italic"],
 " to that of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"Q", "(", "t", ")"}], TraditionalForm]]],
 ". This means that you can build an electrical analog of a mechanical \
circuit and ",
 StyleBox["vice versa",
  FontSlant->"Italic"],
 ". Also, you can use your intuition about the expected behaviour of a \
mechanical system to predict the behaviour of an electrical one. Importantly, \
we immediately know the resonant frequency, ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[Omega]", "0"], "=", 
    SqrtBox[
     RowBox[{"k", "/", "m"}]]}], TraditionalForm]]],
 ", and the quality factor, ",
 Cell[BoxData[
  FormBox[
   RowBox[{"Q", "=", 
    RowBox[{"m", " ", 
     RowBox[{
      SubscriptBox["\[Omega]", "0"], "/", "b"}]}]}], TraditionalForm]]],
 " for our mechanical system."
}], "Text"]
}, Open  ]],

Cell[TextData[Cell[BoxData[GridBox[{
   {
    ButtonBox[
     StyleBox["\[FirstPage]", "SR"],
     BaseStyle->"SlideHyperlink",
     ButtonFunction:>FrontEndExecute[{
        FrontEndToken[
         FrontEnd`SelectedNotebook[], "ScrollPageFirst"]}],
     ButtonNote->"First Slide"], 
    ButtonBox[
     StyleBox["\[LeftPointer]", "SR"],
     BaseStyle->"SlideHyperlink",
     ButtonFunction:>FrontEndExecute[{
        FrontEndToken[
         FrontEnd`SelectedNotebook[], "ScrollPagePrevious"]}],
     ButtonNote->"Previous Slide"], 
    ButtonBox[
     StyleBox["\[RightPointer]", "SR"],
     BaseStyle->"SlideHyperlink",
     ButtonFunction:>FrontEndExecute[{
        FrontEndToken[
         FrontEnd`SelectedNotebook[], "ScrollPageNext"]}],
     ButtonNote->"Next Slide"], 
    ButtonBox[
     StyleBox["\[LastPage]", "SR"],
     BaseStyle->"SlideHyperlink",
     ButtonFunction:>FrontEndExecute[{
        FrontEndToken[
         FrontEnd`SelectedNotebook[], "ScrollPageLast"]}],
     ButtonNote->"Last Slide"], " ", 
    ButtonBox[
     StyleBox[
      RowBox[{
       CounterBox["SlideShowNavigationBar"], 
       RowBox[{" ", "of", " "}], 
       CounterBox["SlideShowNavigationBar", "LastSlide"]}], "SR"],
     Appearance->{Automatic, None}]}
  }]]]], "SlideShowNavigationBar"],

Cell[CellGroupData[{

Cell["Damped Oscillations", "SectionTwo"],

Cell[TextData[{
 "Damped oscillation. For the initial conditions ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"x", "(", "0", ")"}], "=", 
    SubscriptBox["x", "0"]}], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SuperscriptBox["x", "\[Prime]"], "(", "0", ")"}], "=", 
    RowBox[{
     RowBox[{"v", "(", "0", ")"}], "=", "0"}]}], TraditionalForm]]],
 ", the solution to the differential equation is ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["x", "0"], " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "t"}], "/", 
      RowBox[{"(", 
       RowBox[{"2", "\[Tau]"}], ")"}]}]], 
    RowBox[{"cos", "(", 
     RowBox[{
      SuperscriptBox["\[Omega]", "\[Prime]"], " ", "t"}], ")"}]}], 
   TraditionalForm]]],
 " where ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Tau]", "=", 
    RowBox[{"m", "/", "b"}]}], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["\[Omega]", "\[Prime]"], "=", 
    RowBox[{
     SubscriptBox["\[Omega]", "0"], 
     SqrtBox[
      RowBox[{"1", "-", 
       RowBox[{"1", "/", 
        RowBox[{"(", 
         RowBox[{"4", 
          SuperscriptBox["Q", "2"]}], ")"}]}]}]]}]}], TraditionalForm]]],
 ". The ",
 StyleBox["envelope",
  FontWeight->"Bold"],
 " of the oscillation (",
 StyleBox["\[LongDash]",
  FontColor->GrayLevel[0.500008]],
 ") is ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"\[PlusMinus]", 
     SubscriptBox["x", "0"]}], 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "t"}], "/", 
      RowBox[{"(", 
       RowBox[{"2", "\[Tau]"}], ")"}]}]]}], TraditionalForm]]],
 "."
}], "MathCaption"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"params", "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"k", "\[Rule]", "10"}], ",", 
      RowBox[{"m", "\[Rule]", "1"}], ",", 
      RowBox[{"b", "\[Rule]", "0.2"}]}], "}"}]}], ";"}], 
  TraditionalForm]], "HiddenInput",
 CellLabel->"In[102]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"x", "(", "t_", ")"}], "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         SubscriptBox["x", "0"], " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "t"}], "/", 
           RowBox[{"(", 
            RowBox[{"2", "\[Tau]"}], ")"}]}]], 
         RowBox[{"cos", "(", 
          RowBox[{
           SuperscriptBox["\[Omega]", "\[Prime]"], " ", "t"}], ")"}]}], "/.", 
        
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           SubscriptBox["x", "0"], "\[Rule]", "1"}], ",", 
          RowBox[{
           SuperscriptBox["\[Omega]", "\[Prime]"], "\[Rule]", 
           RowBox[{
            SubscriptBox["\[Omega]", "0"], 
            SqrtBox[
             RowBox[{"1", "-", 
              RowBox[{"1", "/", 
               RowBox[{"(", 
                RowBox[{"4", 
                 SuperscriptBox["Q", "2"]}], ")"}]}]}]]}]}], ",", 
          RowBox[{"\[Tau]", "\[Rule]", 
           FractionBox["m", "b"]}]}], "}"}]}], "/.", 
       RowBox[{"Q", "\[Rule]", 
        RowBox[{"(", 
         RowBox[{"m", " ", 
          RowBox[{
           SubscriptBox["\[Omega]", "0"], "/", "b"}]}], ")"}]}]}], "/.", 
      RowBox[{
       SubscriptBox["\[Omega]", "0"], "\[Rule]", 
       SqrtBox[
        RowBox[{"k", "/", "m"}]]}]}], "/.", "params"}]}], ";"}], 
  TraditionalForm]], "HiddenInput",
 CellLabel->"In[103]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"With", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"s", "=", 
       RowBox[{
        RowBox[{
         RowBox[{
          FractionBox[
           RowBox[{"2", "\[Pi]"}], 
           RowBox[{
            SubscriptBox["\[Omega]", "0"], 
            SqrtBox[
             RowBox[{"1", "-", 
              RowBox[{"1", "/", 
               RowBox[{"(", 
                RowBox[{"4", 
                 SuperscriptBox["Q", "2"]}], ")"}]}]}]]}]], "/.", 
          RowBox[{"Q", "\[Rule]", 
           RowBox[{"(", 
            RowBox[{"m", " ", 
             RowBox[{
              SubscriptBox["\[Omega]", "0"], "/", "b"}]}], ")"}]}]}], "/.", 
         RowBox[{
          SubscriptBox["\[Omega]", "0"], "\[Rule]", 
          SqrtBox[
           RowBox[{"k", "/", "m"}]]}]}], "/.", "params"}]}], "}"}], ",", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"Evaluate", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "b"}], "/", 
              RowBox[{"(", 
               RowBox[{"2", "m"}], ")"}]}], "t"}]], ",", 
           RowBox[{"-", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "b"}], "/", 
               RowBox[{"(", 
                RowBox[{"2", "m"}], ")"}]}], "t"}]]}], ",", 
           RowBox[{"x", "(", "t", ")"}]}], "}"}], "/.", "params"}], "]"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"t", ",", "0", ",", "10"}], "}"}], ",", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"t", ",", "x"}], "}"}]}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"n", " ", "s"}], ",", 
              RowBox[{"n", " ", "T"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"n", ",", "6"}], "}"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{"{", 
              RowBox[{"1", ",", 
               SubscriptBox["x", "0"]}], "}"}]}], ",", 
            RowBox[{"{", 
             RowBox[{"1", ",", 
              SubscriptBox["x", "0"]}], "}"}]}], "}"}]}], "}"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"GrayLevel", "[", "0.5", "]"}], ",", 
          RowBox[{"GrayLevel", "[", "0.5", "]"}], ",", 
          RowBox[{"Hue", "[", "1", "]"}]}], "}"}]}]}], "]"}]}], "]"}], ";"}], 
  TraditionalForm]], "HiddenInput",
 CellLabel->"In[104]:="]
}, Open  ]],

Cell[TextData[Cell[BoxData[GridBox[{
   {
    ButtonBox[
     StyleBox["\[FirstPage]", "SR"],
     BaseStyle->"SlideHyperlink",
     ButtonFunction:>FrontEndExecute[{
        FrontEndToken[
         FrontEnd`SelectedNotebook[], "ScrollPageFirst"]}],
     ButtonNote->"First Slide"], 
    ButtonBox[
     StyleBox["\[LeftPointer]", "SR"],
     BaseStyle->"SlideHyperlink",
     ButtonFunction:>FrontEndExecute[{
        FrontEndToken[
         FrontEnd`SelectedNotebook[], "ScrollPagePrevious"]}],
     ButtonNote->"Previous Slide"], 
    ButtonBox[
     StyleBox["\[RightPointer]", "SR"],
     BaseStyle->"SlideHyperlink",
     ButtonFunction:>FrontEndExecute[{
        FrontEndToken[
         FrontEnd`SelectedNotebook[], "ScrollPageNext"]}],
     ButtonNote->"Next Slide"], 
    ButtonBox[
     StyleBox["\[LastPage]", "SR"],
     BaseStyle->"SlideHyperlink",
     ButtonFunction:>FrontEndExecute[{
        FrontEndToken[
         FrontEnd`SelectedNotebook[], "ScrollPageLast"]}],
     ButtonNote->"Last Slide"], " ", 
    ButtonBox[
     StyleBox[
      RowBox[{
       CounterBox["SlideShowNavigationBar"], 
       RowBox[{" ", "of", " "}], 
       CounterBox["SlideShowNavigationBar", "LastSlide"]}], "SR"],
     Appearance->{Automatic, None}]}
  }]]]], "SlideShowNavigationBar"],

Cell[CellGroupData[{

Cell["Damped Oscillations", "SectionTwo"],

Cell[TextData[{
 "Plot of the kinetic energy (",
 StyleBox["\[LongDash]",
  FontColor->RGBColor[1, 0, 0]],
 "), ",
 Cell[BoxData[
  FormBox[
   RowBox[{"K", "=", 
    RowBox[{
     FractionBox["1", "2"], "m", " ", 
     SuperscriptBox["v", "2"]}]}], TraditionalForm]]],
 ", spring potential energy (",
 StyleBox["\[LongDash]",
  FontColor->RGBColor[0, 0, 1]],
 "), ",
 Cell[BoxData[
  FormBox[
   RowBox[{"U", "=", 
    RowBox[{
     FractionBox["1", "2"], "k", " ", 
     SuperscriptBox["x", "2"]}]}], TraditionalForm]]],
 ", and total energy (",
 StyleBox["\[LongDash]",
  FontColor->GrayLevel[0.500008]],
 "), ",
 Cell[BoxData[
  FormBox[
   RowBox[{"E", "=", 
    RowBox[{"K", "+", "U"}]}], TraditionalForm]]],
 ", for the damped oscillator."
}], "MathCaption"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"With", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"s", "=", 
       RowBox[{
        RowBox[{
         RowBox[{
          FractionBox[
           RowBox[{"2", "\[Pi]"}], 
           RowBox[{
            SubscriptBox["\[Omega]", "0"], 
            SqrtBox[
             RowBox[{"1", "-", 
              RowBox[{"1", "/", 
               RowBox[{"(", 
                RowBox[{"4", 
                 SuperscriptBox["Q", "2"]}], ")"}]}]}]]}]], "/.", 
          RowBox[{"Q", "\[Rule]", 
           RowBox[{"(", 
            RowBox[{"m", " ", 
             RowBox[{
              SubscriptBox["\[Omega]", "0"], "/", "b"}]}], ")"}]}]}], "/.", 
         RowBox[{
          SubscriptBox["\[Omega]", "0"], "\[Rule]", 
          SqrtBox[
           RowBox[{"k", "/", "m"}]]}]}], "/.", "params"}]}], "}"}], ",", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"Evaluate", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            FractionBox["1", "2"], "m", " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["x", "\[Prime]"], "(", "t", ")"}], "2"]}], " ", 
           ",", 
           RowBox[{
            FractionBox["1", "2"], "k", " ", 
            SuperscriptBox[
             RowBox[{"x", "(", "t", ")"}], "2"]}], ",", 
           RowBox[{
            RowBox[{
             FractionBox["1", "2"], "m", " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox["x", "\[Prime]"], "(", "t", ")"}], "2"]}], " ", 
            "+", 
            RowBox[{
             FractionBox["1", "2"], "k", " ", 
             SuperscriptBox[
              RowBox[{"x", "(", "t", ")"}], "2"]}]}]}], "}"}], "/.", 
         "params"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"t", ",", "0", ",", "6"}], "}"}], ",", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"t", ",", "x"}], "}"}]}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"n", " ", "s"}], ",", 
              RowBox[{"n", " ", "T"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"n", ",", "6"}], "}"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{
               FractionBox["1", "2"], "k", " ", 
               SuperscriptBox[
                RowBox[{"x", "(", "0", ")"}], "2"]}], "/.", "params"}], " ", 
             ",", 
             RowBox[{
              FractionBox["1", "2"], "k", " ", 
              SubsuperscriptBox["x", "0", "2"]}]}], " ", "}"}], "}"}]}], 
         "}"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Hue", "[", "1", "]"}], ",", 
          RowBox[{"Hue", "[", 
           RowBox[{"2", "/", "3"}], "]"}], ",", 
          RowBox[{"GrayLevel", "[", "0.5", "]"}]}], "}"}]}]}], "]"}]}], "]"}],
    ";"}], TraditionalForm]], "HiddenInput",
 CellLabel->"In[122]:="],

Cell[TextData[{
 " Energy is dissipated only when the mass is moving. For this reason, the \
total energy decays exponentially only on ",
 StyleBox["average",
  FontSlant->"Italic"],
 ". "
}], "Warning"]
}, Open  ]],

Cell[TextData[Cell[BoxData[GridBox[{
   {
    ButtonBox[
     StyleBox["\[FirstPage]", "SR"],
     BaseStyle->"SlideHyperlink",
     ButtonFunction:>FrontEndExecute[{
        FrontEndToken[
         FrontEnd`SelectedNotebook[], "ScrollPageFirst"]}],
     ButtonNote->"First Slide"], 
    ButtonBox[
     StyleBox["\[LeftPointer]", "SR"],
     BaseStyle->"SlideHyperlink",
     ButtonFunction:>FrontEndExecute[{
        FrontEndToken[
         FrontEnd`SelectedNotebook[], "ScrollPagePrevious"]}],
     ButtonNote->"Previous Slide"], 
    ButtonBox[
     StyleBox["\[RightPointer]", "SR"],
     BaseStyle->"SlideHyperlink",
     ButtonFunction:>FrontEndExecute[{
        FrontEndToken[
         FrontEnd`SelectedNotebook[], "ScrollPageNext"]}],
     ButtonNote->"Next Slide"], 
    ButtonBox[
     StyleBox["\[LastPage]", "SR"],
     BaseStyle->"SlideHyperlink",
     ButtonFunction:>FrontEndExecute[{
        FrontEndToken[
         FrontEnd`SelectedNotebook[], "ScrollPageLast"]}],
     ButtonNote->"Last Slide"], " ", 
    ButtonBox[
     StyleBox[
      RowBox[{
       CounterBox["SlideShowNavigationBar"], 
       RowBox[{" ", "of", " "}], 
       CounterBox["SlideShowNavigationBar", "LastSlide"]}], "SR"],
     Appearance->{Automatic, None}]}
  }]]]], "SlideShowNavigationBar"],

Cell[CellGroupData[{

Cell["Forced Oscillations and Resonance", "Section"],

Cell[TextData[{
 "The term ",
 StyleBox["resonance",
  FontSlant->"Italic"],
 " appears over and over in physics. Resonance is derived from the latin \
roots ",
 StyleBox["re",
  FontSlant->"Italic"],
 "- (again) and ",
 StyleBox["sonare",
  FontSlant->"Italic"],
 " (to make a sound). A resonance is literally an echo. Resonance occurs when \
a system echoes energy that is put into it from an outside source. So far, \
resonance has appeared in our discussions of electrical oscillations and \
mechanical oscillations. Technologies based on resonance include Magnetic \
Resonance Imaging (MRI), time and frequency standards, and a wide range of \
measurement devices."
}], "Text"],

Cell["\<\
Energy is most easily transferred to the system at its resonant frequency. If \
you have ever pushed someone on a swing, you have experienced this for \
yourself \[LongDash] the best way to get someone swinging is to push each \
time they have swung back and are stationary near you.\
\>", "Text"],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Video",
  FontWeight->"Bold"],
 ": Tacoma Narrows Bridge collapse."
}], "Quote",
 CellGroupingRules->"InputGrouping"],

Cell[GraphicsData["PICT", "\<\
]U`000000E<1k@0A0_l<0?on0000B00004P000000001D`7]0000000N00402P00
0001D`7]09X0003oQk@000000E<1k@0000@0000004P000180000400P00<02000
0001iVj4000000000001D`7]0000005C0Nd000<BnNgil?WknOjYocGeoj:BKWjV
XZEoIf3DmOolmo[oYO3oo_oioooioo3oO7YjH86FRiEiG;7okooonooaom__onnW
ooWnnol=o_ckn_Win_cooocloOkho`[hl?lT8<;okooojoco0oknoOWmo`7loOko
0_Who?[o1ockooojooojo_lQmoofooCokd`dooS`k_;gn_[ooogkn_[ko?WenOoo
noWnnoko2ogloooknOSlooonn_go0o_fmOKhoaOlmo?cmocoooknoOckn_[gm_Ge
m_Sjo?Onn0_flno]kNk`lO7`k^gik1cWj>_^ko3_k^k[jnodmO7/i>GVi^OXjNWT
in^fCoW]nO3inoWnZOlemOnRTVinYZ:UOfMPe?Goo?OjojG`ookonOoonOo`ogaj
NV21UX^ENEbaonoooo_olOoKkoo_Yooio__o3Oklno[inO[looolo?gnn?l:n?3o
9232onooon_lo`?no_gioOl1o?gno`;in?cjo`Olnooon_oon_ko8OOom_odonm<
=?ohl>kbmo[jooomno[jnocimOWooo_io__no`_mo?oonoWho?ooo_[mo`?km_Gf
n?lGo?OcloOlooono_glno[jmoKemOKhn_cgo_P;m_?_kNg^l?7al>k]nN`LinS[
k^o`knk^jn__m?Gak>CUi^KWj>WYi>O[]ToikOW`nO_ioZWo=OGoXY9^OZJRYGmW
H=Ceoocgn_nUl?onooWoooWol?mlNWYPPIJ;UGUL/Oo_oookoo7ofnookjOonOkk
o`gno?_jnOWjo?ooo?cmo_So2_S`ob@P`_o_ooo[o?l3o_kmnOgo0Ocmo_l2nOSl
n_l7o?_ooo[ooo[nob7gooKom?o_C3Con?3^l_Ojn_oooO_jn__lnOGioooknOkk
o_l;oOcooo_in?coookjoOl3noKem_So5ocglo?go?ooo_kmo?_jn_OfmOGfn?[l
mokh2oKckng]k_3alO3^kOW/7>OXjnk_l>o^k^_[koCelNcTiNKVinSYjNCWjkI?
0coioo7lnOjYocOcohAmJh6NSY5aHVCKn?olmOokbLkon_onooohoo[nIFM_GH6G
RHaYBikolOooo?ogn_Zci?SoljWonOkkob?mo?WhmoKfn?[km_Ohn?Wjno_on_om
k?g_Za]Ce_ocooocm?CnmE[dlo;^m?WjmoGgn_omm_Gjo_kmoOooo?KenOk_m??^
lo_gj^[ofnWoOC6Vno?[jNgbm?C`kncZjNWZjncWjoOhk^_aiNW/jnOVjNg^k>_^
loGakNW]kn_TgmoQnNPHl^oYi^KYko;^kNg/jn[YjN7QgmoPh^GVhokT2n;Og=[O
hN;Ti>;QgoWQ7=cMgn7RhN3Oh=kMhNKWhmoIfM[Kg=gMg^;Sm^ZknOoao?WnZOlg
lon4OF^1WXjALF9TfoSoo?GonlW>oo[oo_oon?ojoVEWKef1UhV<JD^Noo7oooco
mo[j/nChoo>YooWnnolSoOcin?Ofm_SjnoKgn?Sin__koo[ooNcmkj/KDmKolooo
loCdo_EJm??bk_Cin_Oemo[ooOKen_knoOgooocfmOWnkoCck_?kmn[Zom_Yogda
Y__cjnW]l_Cdl>o/j^WYj^_/in_gn>k[lNGYk>_Wi^W]k^c[k_?elNgYkNo[i=oO
hOWX6?;_jNKVjNobk^g]k>_ZjNWQhMoOh>;Ui^?ni0_RgmcJgn7Ri>CRhMoihAcL
gMoQh^7Pgn3NgN7Vin?OfMWJfmcMgMkRhoKZ^oWolOcioZWo=o?oQ7e[PIj>TG5R
I=_hooceoo_9c_ojookoooSon_iUIfmMPIN9S6U;W_oaooolooOjn[?Tn?ocZOoi
o__o8oglnOSgm_Khn__fmoShnO[knoojoog/oNn[6e?Foo?ooo?dm?keF_Ccl^kd
nO[gmOOjoogfmO[no_gmooolm_Gio^odlnkcnoOZj_oKjOmm<JKkln_YkO;dm?3_
k>[YjN[[k>O[moS^jo7UjNc[inKYkNk/jnkcmO7]jNg_jnCOgn7ij1SbknWVi^W_
l^k]kNc[j^WYhN7Ogn3RiNKSo^@;h]oLf]oQh^CTh^7OnN4Lg=gOhN;Qh=oPg]gQ
i^OSgmWIf]_LgMgNh^?fj[/3@_7onOgioZWo:oWoJVa[QIQmNf5PKnSmoo_eon[c
[nGoo_oln?SoonAHFVULP9>2OE8mQoodo_l8oOodok2XooojZOoio__oOogknOSe
m??dmOOalO;cm?Gem_WbooSSo<Y07:3_oog[o?_]k^oalO3^kNK/loGdloOjooWb
l_Kjn_Wfn?Wel>ocn??hmo;fo_W/i_o@olHFH?gekNGSinc_ko?akng/k>g^hmkS
k^oUhnSSin[Xi>;UjNOShNCYjnWUin[[in3L0McOnNDHjNGPg=cPiNWRhN7PgmkM
gMoNgMgNh>;ThokT2n;Og=[FemWJf]WGe_WJ7=KGf=WHe]CCe]CDemgNf]GCdmCE
eMKGel[0d=[=lOoioOWnZOl[nOmZK6^5V7ekHF1_j?gonoGoj_>_iOonoochn?oo
i5QJJEb0Th9mDSf7ooCno`SmooCo/:SoooZYooWnnomooO_in?GdloCemo7al_?d
mOGfnO;on>?lbT0LX>oooN_lnng^ko7al>k]i^ccmOCcmo[onO;bm_[jnOKhnOG`
ko?hloSgl_KnnNcVom3oaQIPoOG]iN?Wk>o_lo7_kNc/kNkSg^?^knGSj>?Wj^ST
h^GYin?Qi>W[jNGWj^_Wh=`1g=oiiASYiN3Lg>3UjN;QhN3Og]gMgmkMgMkPh^CS
o^@;h]oLf]KGfM[JfMOFnMXLe]OHfMSFe=?Fe=CGgMkJeM?Ce=GEe]OGb/3@f/ga
ooWmnOjYob_iofY/JhFHOG]QH6oXoOokmOoZljoUookoo?ShoooTF5YYG82CPWeB
?HOom?ko2?gom?n`Z?oonZWonOkkogomnoWhmOCcm?GglO7bloCemOKil_ohhoc:
@1bPkoomjockkNk_lO7`k^gVk??em??gn_oil_;fn_[im_SimO3_loScn?Obm_ki
k>Kod?o65V3mmNgUhnO/knoclNo]k>c]k^?Nhnk_iN?XhnOZj>CRiNWWhn7TjN_Y
iNOZjnOPg07LgoWU6>WUh=cLh>GYh^7Qh=oNgMgOg]gMg^3Ri>?ni0_RgmcJe]OI
f][IemKifQcFemSIf=KDdmKDe=OMg][Edm?DeMGFemO:`=3Jc@<inO[iooWmnOjW
oc9XKFf3U7Y_FVJ0mooonOSok_nd_oonooggnOoodW9IJe]iRgiiBTEmooKoo_ol
ooofj8ZVooWno?l@o_cjno[gmOCem_O`l?7al_?nm6knn?Coi7L7=^GkoooTnO[_
lOGgn?OdlnG[loOgn?coo?G_k_;fmoGdm_Ock^gamOSmo?Kiooc_nlgmoe8Udocd
k>CRi^_]kOSgm?;al_?ciN3Tl?3Wi>[YkNo]j>KXk>[Vh^CYk>_YkNo_j^?OhNGi
kQSZi^7MgN7Vj^CShn;Qh=oOi>?Rh^?Uj>WZo^/;jNKShMOHf]_Kf]SGnMh0f_kK
2]WGe=;GeMGHgMoKo]H:emSIf]_KimGKg/kin_WonOgioZOo<VQ]KH>DNVmJIX3g
oooin?o^okBoookooOOioooBLUU[FgV;OWU:AGgom_onoocoooKXRZKonOkloa3n
o?[kn_Oem?Gfmo3`lO7blokdK_khm?oTM`LfiO_oonCin^oamOOhmoCciN_cmoOh
o?olmNo^l_KgmOCfmo?^kO7en?glm_Woo>okcOgoDRGCo?C/i>;Vjng]n?Odl_7b
lo?Uh>C`l>OTj^W]kngXi^S/j^KRi>W/jnW]knoZhmoQiOW^6>[VhMgMhNKZi>?S
h^7PgmoThn;RhnGXjN[nj`_Yi^?QemSJfm_Jf=OigP3Jo]/:fMODd]OEeMSMgm_n
eP[Gf=WJfm_WeM_Nc_WjnOoioOWnYolbJ6e]PiAjKeYVP?OoooWhonko];ooo_om
moWoom9bFF]KNH]nNDY5OOofookoo?oom^R:Y_oio_co4?kln__jmoGdmOKgl?3a
lO;co_A^o_SdonAg1cKUnoooi?Wjko7emoSgm??Ujo?gmoSlooceknkbm_Oem?Kg
lnk]lOGhoOcfnOolko_=oOmB9M?lm>cTh^K[kNghmoCblO;clnGPi?3`inCZjNg_
kNSVj>cZi^;TjNc[jNg_kn[Sgn7UnNhHj^KQgMgQi^[Thn?RhN3OgnCSh^;SiNSY
j_k[2nWVhn7Gf=[Kfm[HeoWN0=[nf`[IemCBemGEf=gOfokF2]OHfM[KfnOEfmk>
0cWiooWmnOoioZOo2FmbIW>:OW5MKhono`7hoOko8MVXooolooklooo9Z5EXE6b3
Q8]NG7conO_iookgnn_o^kbWooSnoOmooO_ioOcjnOSinocbl_?dmOKfmoCok?Go
/B<LJ_okmOo^m?C`loSlo_chm^7Xl?Cem__onO?]k?3dmO?en?Sdknkbmo?hm_3c
nOCWomSoXQJBoncfk^KTj>k`l>g/jNOVi^OXin;VlO;Yi^_RiNOTgmcNh^gXhnCY
kNg/i^OVh=T2e]WNn>XFi^7MgN7Vj^SWinKUi>?SgMcKf]_Mh>7mh`_Qg]_IemSJ
fm_Jf=OigacKg=gLfmSEe=SEeMWNgm_FemSIfM[Kg=cZg^SYd_WonOgiooWnYol9
Kg9VLhYnLEe_Soko0OSmo_lQfJSooocoo_coolVXEFQDK8>4ReiLO?oinoWoo_Ok
jonk_:Oon?kmogomnoWmo?[in?Wko?;bloCem_Kgm?o/mOna8aaZoo_eonkdm?3c
n?cno?SfhNS`m?Gfnooilng/l?CeloGhn?C_k_;gloSfl??im>Oof?nR5Y;ok?K^
i^CXk_3`kNcYinKVinSWh^Kal^WVjn;UinCOg=kRkNSSi>W]kNcVinKPf@;FfMkh
jQKVhMgMhNKZj>OWi^GThn?Mg=_JfmgPhOgS2n7NfmWGf=[Kfm[HeoWO7=_LgMcK
f=GDf=GEfMkOfmKGf=WIf]_Lg>[Nj>WBnOoioOWonOjWo`U_LVIcRWiaGFn?o_l1
n?gnob7IZ?ooo?ono?oobJQEJ5A/PhB;GUalooWknOonmo_[ok^lYooho_goOogk
nOgln_WhnO_ll_;cm?Gfm_Odonceok4S76[onoGok_Cdl??ho?kln?KQj?3dmOKk
ooWckNc`m?GcmOShm>o^l_Ocn?K`loWdiooHoj8FT_o/m^kVi>S^l?3]k>WWi^KW
j>ORi_7bjNK[h^GWi=oLg^;]j>?TjNg]k>KWi^3I0]KIg_SZ5^KQgMgQi^[XinOV
iNCShmgLfm[KgN3QoN<;hMkKfMOHf]_Kf]SGnMlLfmcMg=_HeMCHeMGIg]oKe]OH
fMWJfmcLj]kXjM83B>WonOjYo`_moFY^G6>0OgEOLiKno`WlonoonoZam__ho_lK
mOnoeE1VCfB0SYebK7WoooOgoocokOojoh;onZWonOiooOkoookln_Skn_Win_go
ooCdmOKgn?Win_oZnoma4VFVooWYoogZmN[_mO_mn_Kcg>?[k^o`m?Silng/l?Cd
loOinOK`ko?hn?gjm?KmmnWcollJBo?]oOSaj>KZl?;bjnWWiNCTiNKTgn?^knKS
jN?VinCNfmgPk>KPh>GZjnX7inOUg]OEf]oijQSVh]gIfMgRi^GUi>?Rh^7PgMcK
fmcNh>;Qo^8;h=gJf=?De]OGe]CCnM/1e]OnfAOGeM?Dd]7Ef]_Gd]?Ce=GFemOH
d<SHfL7YooWnZOl;oOeZKUaSP7meGg>Fo_l9o?o_oo_j/OKkn?ko6oGo_mE@ITmT
P8jMLVaiooogmoolongon_n2ooZYooWnOognooono?[hno[inO[mooodm?GfmoSi
nO[oj__oLA9UY_oijOomj_GZkoGkoO[flmcSjnk_l?ChnO?]k?3dm??gnOWfl>oc
n?Smn_CfoOOYloo?6T_ckOghlNSVj_3bl^_YinGTi>GVi=oSk^oVhnWSi^OTg]_M
h>cVh>3Uj^_Z1nOWiMkGeM[OnNXHi^;MfMWMh^KUiNCSh^;Qh=gLfm_Lg^3RhOkR
2n3Mf]SCe=KGemKDdoWK0MKGo]TGemGCe=;AeM[Kem;CdmCEe]OGf=38f=W1jOoi
oZWo2ogmJViLHh1oMEmcU_ko2Ocokookn[7fnoSnoa_eokoED6I?I82>WG9/NOoo
moOoo?o]oo[oP_ojZOoioWomo_ooo_cjn?_jnOWjoOoom?Cem_OhnOWjon[kog4B
IJKonNWooN[ej^oenogjm_?Lhn_^ko3dn?WckNc`m?CcmoWim_3_loShoO[dm_gg
jO?ocaY;lngmn?7Xi^[`l_;[jNOUi>CUi^COhnk_i^?YhnKWi=kKgN3/i^3PiN[[
jPOWinGNemGJgoWZ6>KRgMWIgN;ViNGThn;RhN3Mg=_Kg=kPh^7nhP_PgM[HdmCF
emOFe=?if`7FeokI5mOEdmCBdMGJfmOBdm?DeMKGemS@b=SI`@=;nOkaooWnZOl=
mo5MJ5aTPX9cFVjCoo_no`3^o_l3dkgbn?ko5O?o/>EKLUUVOHZFIVY]ooojnOof
ooCno`:ae?fYooWn1ocmo_kmnoWgo_Alm_Wmooocm?Cem_Ohn?oTm?nZ=TZceoSn
hooogokXkOGlo__glmoVkO3_l??gn_C^kO7emOCemoSdknkbm_coo_OiooW[l?EX
7kSof_ogl>SUj^oalO;`k^c[jnc]iN3Tko3Wi>WZkNo[iN7Si^kWh=oTj^c/kno[
hmcKhNOik1SVhmgJf]gSi^?Sh^7PgmoNiNCSh^?Uj>WVo^L;iN;OgM?Ee]SHe]GC
nMTLe=GHfM[If=ODd]7Ef]_Gdm7Bd]?DeMKFhmGOh<_io_7onOjYo`gglEeXG6B2
PW=JKY?onoko0>kno`?C_O;ho_lElon`iE]bFFImRYIVJVgooo[iooKom?ko0[7D
oJWonOh7o?gno_gknOOnm7cfnOgooo?dm?GfmoShonCdojXfB[?Gn?kSoooOo^S]
mOcnnoOcgnK]l>o`loOjm>k]lOGem?Ggn?C_k_;fo?onmoWonN_`mFPO^?oJooO`
j>GZko7al_3^k>_[k>gUh>C_l>OTjN[]kn_UhN?Vk^OPgnCZk>c_kn_Sg=_QioW/
6>KSgM[JgN?Vhn?RhN3OgmkUi>?RhnGXjNKni`_Uh]oMdmGFf=SFeM?ifAcDeMSI
f]WHemCBdMGJfmOCdM;BdmCEe]KSeMoPboWnlOoioZWo3OOaGFQLI8:2LeY^Took
o_l0k_ko0m>ml_SnoaGcok3UFg9IIWf:UVIZKOoon_Wom_odo_l2/MCmZOoioPOl
oOknoO_imokdO?KioOooloCdmOKgn?Soi?CoZSI:/mOho^?oomonj>geo?kkmo?O
i^g`ko3cmo[dk^gamOGdmOOhm>o^l_KlookgnOoijo3eJ1nhom[omo3XiN[_lO7b
l>k/jn_/kNGPi>o`inCYj^g_jnGQhnK^in3Oi>[/k>o_jn?Lfn7WnN`Hi^?Mf][M
hnKShn;Qh=oOg^GThn;SiNSYi_kW2nGRgmgCeMKHf=KEdoWI7=CEf=WJfMSGe=;A
eM[Kem?Ad];Ce=GFe^?Egn3;0d;YooWnZOl=n>]CIFA`RhQ^E6N>o_Sno`OdmOoj
lXgYn_ko6oKoY>9]Q6Q/Ngj1BF5QoOoonoo_oooUon3oRORYooWn:_cmo_kmnoSg
k^o`l_Kkoooal_;cm?Gfm_o2oomH4h_Ql>Ooho;oeoo[lOWnoeSkmnS^mOOfmOSl
noG^k_;fm_GcmOGbkN__m?7el^_]lncOo:`TP_oalO3ek^KTj>g_ko3_k>[Yj^_/
j^GYm?G/jNoWj^_XhMgNhO?/iNCYko;bk>_WgmSGgOST6>_Wh]kNh^O[i>CShn;Q
h>3Qh=oOh>;Ui^7nhP_PgM[Hf=WKg=cKfMSig1cGfM_Nh>3OgmWGe][Oh=cGeMGF
emSIfM[NbLgCb>WonOjYo`ghje=UI72;R6iDIhknn?ko1oCeoo[bSNWjo_lKm_nT
hVf4J6akOX59HF7moookonooonGoh?n9n:WonOhZo?gno_gkn?O^ko3bm__ooo7b
l_?dmOKfol;ooePCRn7`iooSl_oGon_anOkoF?_gj>kemoKen?ckmNk^l_KfmO?e
mO;]jnodlOGbjngck=ol[2B2oo7al?G^i^CXkNo_l>o/j^WZjncZiNWdmNcYknOZ
jnSQgMkQlncUi>W_l_;/jnOOf=OMn>@HjnORg]kRin_Ti>?Sh^7Ph>7PgmoPh^GV
hOkR2n3Mf]SHfM_Lg=_If?WL7=OIfmkPh=oOfMOFf]oPg=OEeMKGf=WIf]k9cM?8
jOoioZWo3OS[DfETL8^8KUAWS_kho_l7m?Gon_:=jO[noa_fojCRKHAXK7]nPDUQ
HOgooo_okoooiOoPohWhZOoioR[loOknoO_hmnk_l?;fnooolO;bloCem_Ko`_oo
F1>;hO3Won?bomOojo7io_mHnoOXk_Ggm_Gho?_ek^kbm_KeloGel^g[koCamO;[
kO?/gob/98;olO7`mNkVi>S]kno`kncZjN[[k>[UjOCek>W_in[[j>7Mg^7ck>GT
jNobl^c[imoHemghi1S[in;Ng^;WjnCThn?RhN3PhN3Ogn3RiNKQo^8;h=gJf=SI
fmcLfmWHnM`LemWKg^3PgmoIemKJgn3LemGEe]OHfMWJg/W=dlP3Ni7onOh`oo1K
KVEiOWibD66?oocooocooo7enmb^oo_okooL_ne/L4eNMGInE5EgnocooOomo?go
2_S?Y_olnoool?;ofOkiomWnOoSdloKko_cimoOfm_OjoOkinoG]l_oon_OUok8S
:GZnfn;]moclnOKXlOcooOOdlnKYkNg[k_CjooGZi^_dnokdmOC_j^[`m_kQm_oS
kooOf3M0b_?^no3akng/kO;fn^kdl^SXlO;[k^GVl_K]inSTj_3`jnKTiO3Zi>?W
jn_ZEnKYj^OQgMoRi>GWj>SWiNCUgMSIf]SJgn3MgnOYh]cJg]gLg=gOhN?Si^;K
g^OSf=WIf=OFeMGDf][Lg=_Ie]GGf=[Kfm[HemGCd]KKgMWDd]?Ee]KEdm;nf07G
eI7onOh`oo1KKVEiOWibD66?oocooocooo7enmb^oo_okooL_ne/L4eNMGInE5Eg
nocooOomo?go2_S?Y_olnoool?;ofOkiomWnOoSdloKko_cimoOfm_OjoOkinoG]
l_oon_OUok8S:GZnfn;]moclnOKXlOcooOOdlnKYkNg[k_CjooGZi^_dnokdmOC_
j^[`m_kQm_oSkooOf3M0b_?^no3akng/kO;fn^kdl^SXlO;[k^GVl_K]inSTj_3`
jnKTiO3Zi>?Wjn_ZEnKYj^OQgMoRi>GWj>SWiNCUgMSIf]SJgn3MgnOYh]cJg]gL
g=gOhN?Si^;Kg^OSf=WIf=OFeMGDf][Lg=_Ie]GGf=[Kfm[HemGCd]KKgMWDd]?E
e]KEdm;nf07GeI7onOh`oo1KKVEiOWibD66?oocooocooo7enmb^oo_okooL_ne/
L4eNMGInE5EgnocooOomo?go2_S?Y_olnoool?;ofOkiomWnOoSdloKko_cimoOf
m_OjoOkinoG]l_oon_OUok8S:GZnfn;]moclnOKXlOcooOOdlnKYkNg[k_CjooGZ
i^_dnokdmOC_j^[`m_kQm_oSkooOf3M0b_?^no3akng/kO;fn^kdl^SXlO;[k^GV
l_K]inSTj_3`jnKTiO3Zi>?Wjn_ZEnKYj^OQgMoRi>GWj>SWiNCUgMSIf]SJgn3M
gnOYh]cJg]gLg=gOhN?Si^;Kg^OSf=WIf=OFeMGDf][Lg=_Ie]GGf=[Kfm[HemGC
d]KKgMWDd]?Ee]KEdm;nf07Ge@=hTOoioP_oheQUGW9lNgMEIYGmob3fooojoooP
/_?ooOooiL?mKGmUKG1XN5YEMo_loogooOcmo`[lfKGYookooo;onMWnnOoIoWol
n?KhoOolnOSgm_Kgn_cnoO_ck_Kon^WSon0d;:_UomoVkoOkn_OdjO;loocgm?CW
jno_k_3fnocdjnW^mO[kmOKel>_[l?KYiOklgo3gaWDcOogokO;Rm_?_k>c^lOC^
mO;Yj?3ajn_Rhnkcj^?Ui>[`l>_Vi>G`j^CSin_[jUcVjN[WhMgOh^CUinSXinGT
hmgIfmkPhNCYi^KYj^KSh]cKf][KgMoQg^?QfmkUh=?IfMSGe]GEe=[Jg=cKfMKE
emSJfm_Jf=OEdm;FfmgIe=;CeMKFeM?BemSHemFAooWn2ooSF6ENLWakMeEVUOgo
8?Kooo[oon2bloomoooU`oe]OfE]L6QhFUEgnocooOomo?go2_cI]NWoo_ool_oi
fOkiomWnOochm_Smoocin?Ofm_Ojo?kmno?^m_ojjN?oh3@/ZnGognK_mo_jmoCY
l_coo?Odm>O[kno^l?Kko?C[jNken__em_G`jn_`m^WUo_cOl?O6MC=ooOo]l^;f
lno/k>kam>kel^WXl?7[jn;Sk_?ZhnGTj_3`jnKTiO3Zi>?Wjn_ZG>KYj^OQgMoR
i>GWj>SWiNCSgMWKg^3Qi>WVi^WZi^?Rg=_Jf]_Mgn7Nhn7Kg^GPdmWIf=OFeMGD
f][Lg=_Ie]GGf=[Kfm[HemGCd]KKgMWDd]?Ee]KEdm;Gf=SGeI7onOh;on=HIEib
O7]gEFJEoOlPm_oon_ooh;;coogoonG3oFeoIFe`J7QJEGOko?omoogloOl:o=Ve
jOonooobooWIo_WofOioo?Sfn?goo?WhmoKfmo[lo_gklnkfoo[YhooP=2b[iOoO
i^ogno[gm>Wbo?olmoCdin__knk`m__lm>_Yk_GjnoGfmO3[jo3fjNGno=o`mlIe
<gomongbh_Kcknc/k_7dk_GbjNS`lN_[h^?^ln[SiNCZl?3[i^CUl>[ThnO[jnYL
i^WZin7Mgn;TiNOXj>OUi>?MfM_Nh>7TjNKVjN[Vhn;Lfm[JfmgOhMkShM_NiN3C
fMWHemKEeMCJf]cLfmWFeMOHf]_Kf]SGeM?Be]_MfMCBdmGFe]GCd]OHf=OE0gRA
ooWn4?o=EeYGK7YhKdaMS?oinokbo?lRj;oBooKoin;@oeQiJVeRE6eMEGOko?om
ooglo_gloooYc<3no`?goOo/fOkiomWnOoomn__noochnOSgm_OinogooOG`n?od
gn7oV01conkkin_bn?[hlo3Zl__nnoOemNS]l_?al_SmnO?]k?;gn?OfmoG`jn_a
mn7_oN_Oo_6X2C2coo_[nnkim_7]j^_]knoelnWXl?7ZjN3Pk?3WhN;Tj_3`jnKT
iO3Zi>?Wjn_ZF>KYj^OQgMoRi>GWj>SWiNCQgM[KhNKWhnKUhmoNgn3Pfm[IfM[L
g^3Jh>3LgnGNcmWIf=OFeMGDf][Lg=_Ie]GFemWJf]WGe]GCd]KKgMWDd]?Ee]KE
dm;Fo]L0eI7onOh@oleGFUM/NWQ_C5f<ooWko_;lob;X_m;om_oWh]3oF7UZKF9D
KEeEMo_loogooOcnoOcoonW<`?ko0oOmoncIo_WofOiooogjnokoo?Sin?OfmoWk
oOommO3hooCOhOnH07?ok__Wjo;hn_Scl>[bnokkmoGej>gblo7bn?gilng/l_Oh
moKgmO3[jo7ghNomjmonlJP9<;?onn_kk_WflNgZjng_koGcjNS`lN[Yh>3/l>OQ
h^CZl?3[i^CUl>[ThnO[jnYHi^WZin7Mgn;TiNOXj>OUi>7Mf]_Qi^OSi^GSgmkO
h>3Kf]WIf]cNh=[Ph=cOiMk?fMWHemKEeMCJf]cLfmWFeMKGfM[JfMOFeM?Be]_M
fMCBdmGFe]GCd]Kne`3ETOoioQ3ocEMJEfajN6m<GHconO_nl_co8^Rod_ofonOR
d?mHNFY]HUA]GEEgnocooOomo?kmo?oojLc0o_l3mogok=WnnOoIoWoooO[ko_ol
n?WhmoKgnO_moogel?Som=oQoiP0Loo^nnO[l_Sjn??`j_;ko__gmOGXkO;clO;h
oOWckNcbmoSgm_Oel>_[lOOQkog[gokaZ0T`/ookjo_^nOKakN[[kNo_mO?Yj?3a
j^WPh>c`in7Ri>[`l>_Vi>G`j^CSin_[jUSVjN[WhMgOh^CUinSXinGThMgJfn7V
in?ViN?Og]oPh=_JfMWJg=kPf^3Pg=oUg/oIfMSGe]GEe=[Jg=cKfMKEe]OIf][I
emKEdm;FfmgIe=;CeMKFeM?Be_kG0=D3N97onOh@ok=JE5I[O7I/BU^:ooKio?Kl
obWcekGYo?o[a>?o?F1EGUM<J5UEMo_loogooOcnnoWoooWT^^KonOGoooWIo_Wo
fOioooomoOooo?OjnOOfmoSjo?kooO?bnOO]okhl8lWoaN;^lOGhn?Gak^ccn_gj
m_Ggj>kdm_GenOgfl^k_m?SgmOOhm_7/k?;hko_bg>kofWLRL>7oiN[oo?Kckn_Z
jnk`lOOdjNO_knSZhN7]lNWRi>CZl?3[i^CUl>[ThnO[jnYLi^WZin7Mgn;TiNOX
j>OUi>;PfmONi^;Gh>KTfmOLh=kMg=_Kg=kQh][Qh]kQi]k?fMWHemKEeMCJf]cL
fmWFeMGFf=WIf=KEeM?Be]_MfMCBdmGFe]GCd]GFemOETOoioQ3o/eYDEV]lMVa:
Fh[om_Wlm_co:O?G]NWlon_4holmH5ENEdaXFEEgnocooOomo?kknOoonNBji_oi
mOoonMWnnOoIoWoooogmooolmo[imoKgn?[lo_omlo;imngo_S`SbOo5h^kamOSh
mO7^k??joO[fmOOXk_CfmOGioOKbk^odn?OemoSflNc/l_S_no;Lk_oJMb9`hOoU
j_olm_?_jn[[k_3amoCYino_j>[QhNgajN;Ti>[`l>_Vi>G`j^CSin_[jUcVjN[W
hMgOh^CUinSXinGTh^3KemkVh]OPi^CKemcPg]gLfm_Lg^7Rf^7Rg^7Vg/oIfMSG
e]GEe=[Jg=cKfMKEeMKHfMWHe]GEdm;FfmgIe=;CeMKFeM?BeMKGemFAooWn4?nc
FUAFJgafK4YKR_ofnOcfo?lYlmNejOcojlCSocePEEiGC6QIEGOko?omooglo__i
oooii;[VooWeoooifOkiomWnOooooOgooocgn_Wgm_Ohn_cnoogcl_WgkOnn?2?9
olGRk_7en?SelNk/lo[mn_KemnS^m?KemOWmm_;^koChmoGgn?Kak>cbn>okl]c^
omYg8W3QonGZoocflno[j^_^l?7gm>WWknoXj^7QkO7Yh^CTj_3`jnKTiO3Zi>?W
jn_ZG>KYj^OQgMoRi>GWj>SWiNCRh=_Gg^KRen3Vi=_Gg>3NgMcKfmcNhN;JhN;N
hNKNcmWIf=OFeMGDf][Lg=_Ie]GEe]SIfMSFeMGCd]KKgMWDd]?Ee]KEdm;Ee]OG
e@=bTOoioP_oTf5EGW20LgUGJ9Kkob7mn_ooo_2^a_ogoiOfnDENCEaQFVeBEGOk
o?omoogloo_go_l8lmR_oo7jomgofOkiomWnOooooOgooocgo?[hmoKgnO[ioood
j_7moom=3g7[onWoloGgn?Odl>k]lo[kn?Gfn>O]mOOfm_Skm_;^koChmoGhnOOb
kNgcnOWnk>SooYP/ULkoo^Gao^g_kN[Yj^kbmO;hm>WWk^kWkNCUlOG/i^OTj_3`
jnKTiO3Zi>?Wjn_Z3^KYj^OQgMoRi>GWj>SWiOkTAmcBf>;H`mCTj]oIh>?Lh=oN
gMkQhnGNhn?NhNOQd]WIf=OFeMGDf][Lg=_Ie]GDeMOHf=OEe=GCd]KKgMWDd]?E
e]KEdm;DeOkFTOoioP_oTf5EGW20LgUGJ9Kkob7mn_ooo_2^a_ogoiOfnDENCEaQ
FVeBEGOko?omoogloo_go_l8lmR_oo7jomgofOkiomWnOooooOgooocgo?[hmoKg
nO[iooodj_7moom=3g7[onWoloGgn?Odl>k]lo[kn?Gfn>O]mOOfm_Skm_;^koCh
moGhnOObkNgcnOWnk>SooYP/ULkoo^Gao^g_kN[Yj^kbmO;hm>WWk^kWkNCUlOG/
i^OTj_3`jnKTiO3Zi>?Wjn_Z3^KYj^OQgMoRi>GWj>SWiOkTAmcBf>;H`mCTj]oI
h>?Lh=oNgMkQhnGNhn?NhNOQd]WIf=OFeMGDf][Lg=_Ie]GDeMOHf=OEe=GCd]KK
gMWDd]?Ee]KEdm;DeOkFTOoioP_oTf5EGW20LgUGJ9Kkob7mn_ooo_2^a_ogoiOf
nDENCEaQFVeBEGOko?omoogloo_go_l8lmR_oo7jomgofOkiomWnOooooOgooocg
o?[hmoKgnO[iooodj_7moom=3g7[onWoloGgn?Odl>k]lo[kn?Gfn>O]mOOfm_Sk
m_;^koChmoGhnOObkNgcnOWnk>SooYP/ULkoo^Gao^g_kN[Yj^kbmO;hm>WWk^kW
kNCUlOG/i^OTj_3`jnKTiO3Zi>?Wjn_Z3^KYj^OQgMoRi>GWj>SWiOkTAmcBf>;H
`mCTj]oIh>?Lh=oNgMkQhnGNhn?NhNOQd]WIf=OFeMGDf][Lg=_Ie]GDeMOHf=OE
e=GCd]KKgMWDd]?Ee]KEdm;DeOkF0gFAooWn2oY`IUQYMh5[MeEVU?_o0_Wgnoko
9lBcmngoN?oaHW=JJWE]MU1EMo_loogooOcooOSmoooinIgKi_oodooIo_WofOio
oogjnokoo?SmnoWgm_OhnOKoooCZlOcoZA9;boKoonkfmoShm_Cal>odnO[fmOOj
hn_cmoKdm_Silng/l_OhmoWjn??^k_Cjlo[cooo0CaG1g_7amO[ai>cZj>OZk_?f
loWej^O]kNK_i^Kbm^kWjNCZl?3[i^CUl>[ThnO[jnYLi^WZin7Mgn;TiNOXj>OU
i>GWgLoFh]Bf/<kNe]3FdlKNg]cLgMoRhmoSgmOKhn3DfMWHemKEeMCJf]cLfmWF
eM?De]OGe]CCeM?Be]_MfMCBdmGFe]GCd];CeMKFTOoioP_jL6IHJGN1JgMEIYCk
o`;imo_nobO4/oO]ogSolF9cFVYeKGI@EGOko?omooglooghoOoonOVMfnKoom?o
fOkiomWnOoomn__noochoO_imoKgn?Wfooodj_7lojTBBl_fooo^m_Ohn?KdlO3_
m?Wjm_Ggn^?[loOfm?KhnO?]k?;gn?Oin_Sck^kdn_?jlooo`4lE`MkalOGjlNC/
j^SWj^kcm_?imN[WkNgVknKVl_K^inWTj_3`jnKTiO3Zi>?Wjn_ZG>KYj^OQgMoR
i>GWj>SWiNCUimg?e^;D][3>g]K@e]?6g]kLg=gOh^?OhmoGfn?Pe=WIf=OFeMGD
f][Lg=_Ie]GCe=KGemKDdmGCd]KKgMWDd]?Ee]KEdm;BdmGFeY7onOh;nW1VF6Ug
PF]gEFJDnol2nOOko_lWa;?gkOmhoo5RLeYZMFefD5EgnocooOomo?omn?goooWi
WM_VoooComWnnOoIoWoooO[ko_oln?gknOOfmoSim_oom>[ao?nY4T_;m_ook_Kg
n?Sfm?7`koCin_Kemo[Sjo?gm_Cfn?WckNcbmoSgnO[hlnk^m?[cn_?ool1?5L7N
lO7en_7Tk>[Xin[^loKcnOGZing]i^oVi_;fk^OYi>[`l>_Vi>G`j^CSin_[jUcV
jN[WhMgOh^CUinSXinGTiNOMcmKRe;J`c]kFd=KCa]kNg=cMgn;Sgn?Oem_Sh=CI
fMSGe]GEe=[Jg=cKfMKEdmCFemOFe=?Edm;FfmgIe=;CeMKFeM?Bd]?Ee]H3Ni7o
nOhojDmWFW5jOf1^C5f;ooSkoOomnO_no_ook;[DmomboOYPLee]MfmhDeEgnoco
oOomoOoonO_oooSo`9gKoogiomWnnOoIoQoln?KhoOolnOkln_Ofm_Ohm_[hl_Gj
lN4e7j[omoc]d?ggOoKem??`m?WhmOCgnn3XlOKel_?do?C[jNken__in_Wdknoe
nnkhn_oSL3]gbM?Jk_obho3_kN[Xj>__lOCjm^[WkNcUk>?Tl?C[iNKTj_3`jnKT
iO3Zi>?Wjn_Zi^WZin7Mgn;TiNOXj>OUi>?Xg/oHjMVfTkgIeLoCbkKIf=OF0]OJ
g?kN<]K<cm_LdmWIf=OFeMGDf][Lg=_Ie]GBe=GGemGDd]GCd]KKgMWDd]?Ee]KE
dm;AdmGFeY7onOhojDmWFW5jOf1^C5f;ooSkoOomnO_no_ook;[DmomboOYPLee]
MfmhDeEgnocooOomoOoonO_oooSo`9gKoogiomWnnOoIoQoln?KhoOolnOkln_Of
m_Ohm_[hl_GjlN4e7j[omoc]d?ggOoKem??`m?WhmOCgnn3XlOKel_?do?C[jNke
n__in_Wdknoennkhn_oSL3]gbM?Jk_obho3_kN[Xj>__lOCjm^[WkNcUk>?Tl?C[
iNKTj_3`jnKTiO3Zi>?Wjn_Zi^WZin7Mgn;TiNOXj>OUi>?Xg/oHjMVfTkgIeLoC
bkKIf=OF0]OJg?kN<]K<cm_LdmWIf=OFeMGDf][Lg=_Ie]GBe=GGemGDd]GCd]KK
gMWDd]?Ee]KEdm;AdmGFeY7onOhojDmWFW5jOf1^C5f;ooSkoOomnO_no_ook;[D
momboOYPLee]MfmhDeEgnocooOomoOoonO_oooSo`9gKoogiomWnnOoIoQoln?Kh
oOolnOkln_Ofm_Ohm_[hl_GjlN4e7j[omoc]d?ggOoKem??`m?WhmOCgnn3XlOKe
l_?do?C[jNken__in_Wdknoennkhn_oSL3]gbM?Jk_obho3_kN[Xj>__lOCjm^[W
kNcUk>?Tl?C[iNKTj_3`jnKTiO3Zi>?Wjn_Zi^WZin7Mgn;TiNOXj>OUi>?Xg/oH
jMVfTkgIeLoCbkKIf=OF0]OJg?kN<]K<cm_LdmWIf=OFeMGDf][Lg=_Ie]GBe=GG
emGDd]GCd]KKgMWDd]?Ee]KEdm;AdmGFeP=kTOoioSoL>VIKMG]kEg=AHY3ooOoo
o_[kooono?kob;GolgWgodEPDF=[I7=FEGOko?omoogmooojnooomOo[K]?ohooY
fOkiomWn7oSdloKko_cio_gjmoKfmoOhlng`oooU_aU5dooWh>Woo_OnmWoemO3e
n?Sem?OkgNK`mOCalO;omN[VjoCko_[knOC_koGkl__jmk<hDOKhl^goon7An?Ca
k>SWin[[mO[fj^O/k>CYh>7/lNSQhnCZl?3[i^CUl>[ThnO[jn[VjN[WhMgOh^CU
inSXinGThNSNd=c`h;^Ea^[YhnKI`=?CdM7Be3KGf=_Jcl?6e=O@fMWHemKEeMCJ
f]cLfmWFeM;CeMKFeM?BeM?Be]_MfMCBdmGFe]GCd]7Be=KFTOoioSoL>VIKMG]k
Eg=AHY3ooOooo_[kooono?kob;GolgWgodEPDF=[I7=FEGOko?omoogmooojnooo
mOo[K]?ohooYfOkiomWn7oSdloKko_cio_gjmoKfmoOhlng`oooU_aU5dooWh>Wo
o_OnmWoemO3en?Sem?OkgNK`mOCalO;omN[VjoCko_[knOC_koGkl__jmk<hDOKh
l^goon7An?Cak>SWin[[mO[fj^O/k>CYh>7/lNSQhnCZl?3[i^CUl>[ThnO[jn[V
jN[WhMgOh^CUinSXinGThNSNd=c`h;^Ea^[YhnKI`=?CdM7Be3KGf=_Jcl?6e=O@
fMWHemKEeMCJf]cLfmWFeM;CeMKFeM?BeM?Be]_MfMCBdmGFe]GCd]7Be=KFTOoi
oSoL>VIKMG]kEg=AHY3ooOooo_[kooono?kob;GolgWgodEPDF=[I7=FEGOko?om
oogmooojnooomOo[K]?ohooYfOkiomWn7oSdloKko_cio_gjmoKfmoOhlng`oooU
_aU5dooWh>Woo_OnmWoemO3en?Sem?OkgNK`mOCalO;omN[VjoCko_[knOC_koGk
l__jmk<hDOKhl^goon7An?Cak>SWin[[mO[fj^O/k>CYh>7/lNSQhnCZl?3[i^CU
l>[ThnO[jn[VjN[WhMgOh^CUinSXinGThNSNd=c`h;^Ea^[YhnKI`=?CdM7Be3KG
f=_Jcl?6e=O@fMWHemKEeMCJf]cLfmWFeM;CeMKFeM?BeM?Be]_MfMCBdmGFe]GC
d]7Be=KF0i>>o`3noOl=k25jFf66NFmQHU:XnoSfoa?hY=ko^OOoAFAHIfQPMEiI
E_koo_ko0?kmo`SnnoWooleihoGjo`;kn_cno`Cmn_SfmOWijOkion7n=?ShnO_l
oOkonoWhm_KhnO_aj^Woi?go8RFgooC/ooojmOOkoOgkmoGaloOjn_SelnKYkO7e
o_MoooO]jo3hoOkaooo`i>kgm_?Wm^DZ6nO]l=c]ooK`l>3^kN_YjN_]k^Wblng]
lo;Yj>;Sk>cSh^SYj^[Yj>GQgnkYhn?Vj>KSinKTh^7Ri>GTiNOXj>OUi>OTg]_K
g^CWVM?_c^GNQgi4NkcNgMGFgMCJa:>Ycmc:dMKKfmODeMPPe=GFe]GCdLoBdmGF
e]GCd]CFemWIemKDclo@dM;CdmCKo]`0fhko0?kmo`g/8GYKHHIiKf5RDZSkn?Ko
4oRTg_nimom5I5QWJ61eGUUFo_ono_l0o_go2?kknOoocGWSmO[o0__jo?ko1?gj
n?KenOWYo_WohOhdn?Sinocmo_oknOSfm_Sino7ZjOoToOlR9KOom>cooo[emo_m
oO_gmO7cmo[jn?Gci^W]lOGnmgoomng[l?Smo_7ooo3Tk_OflnOfiBXKing`g>go
m_3`h>k]jnWYjng^jO;ckNgcl^WXh^?/k>?Rj>WZj^WXiN7Ok^WShnKXi^?Wi^CR
hN;TiNCUinSXinGTinCNfm_Ni>NIdno>iMj7OTAk_=kMeMKMe=[4XjW?g<[Ae]_K
emCEf23DeMKFeM?Acm;CeMKFeM?Be=KGfMWGe]C?cm3Ad]?Ce=_ng03KS_l0o_go
3N`QNU]QQWU_HF9BZ?_hm_lCn:CNokWgodETF6MXH7ENFEKnookno`3noOl8o__i
ooo=NN?en_l2no[lo_l4oO[hm_GinNWnnOoQoSChn?Wko?gnoo_in?Kfn?WklN[Y
onCmob8U]oodk?oon_GgnogmnoOelO?gn_[hmO?VjNgamOkgOoogkN_`n?gnlOoo
l>C^moKcioKU:Q_WkO3LkOofl?3Pk^g[jNW[kNkYl_?]kO?bjNSRhnc/hn;XjN[Z
jNSUhMo^jN?Si^SVhnOVi>;Qh^CUi>GWj>SWiNCWi=kKfmkTiiWCklkUgXMnA7^l
g]gEe]gDf/BSZLoLb]7Ffm_Ge=GH8=CEe]KEdm7?d]?Ee]KEdm;De]OIfMOFe<o?
d=7Bdm?DfokL0=/3RXWo3MX^OFI[R7adIfUI[ooimolAoOGT`K37l_mAKEaWIUea
FV=Onol0o_go4OkknOoZn/VVonCjnOgooocjo?go1?gknOOfnOWYo_WohOhdnOWj
nocno_olnoWhn?Wko?olo?_okWL;Q>Soo__oooWemo_moO_gmNg`mOSjn?Kdin[^
l_Gnmgomm^o]loWko?komn_Yl__mnOooHRRlimofg^Wjknkcj>k/j^SXj^c^iNk_
j>S_k^GYh^C]kNCRjNWZj^WXiN7Ok^WShnKXi^?Xi^CRhN;Si>CUinSXinGTin?N
f][NhnNQdNk>hnJRYJZeb]SA`<;@g>CD];GDh]WAe]_KemCEf2CFemSHemGBdM;C
eMKFeM?Be=GGf=SGeMC?cm3Ad]?Ce=7Bdm?BROl=fRimIV^8O7AWJEV_ooWgoa7m
mNC1/<Oboe5]G6MVGG5JHeoko`3noOlAo__ion[jbJKoi?[ioOooo?[loOl4oO_i
moKinNWnnOoQoSCinO[ko?knoocknOShnO_looclnoo^M`^4j?onnooonOGgnogm
noOekO3en?[hm_CWj^kbmOkgOogfkngcnO_lo_ogjnWbnogioomR:;cWgoKNjO[_
k_?Xk^cZj>SZk>kUk^oXj>o^iNWRi>g]i>;YjN[ZjNSUhMo^jN?Si^SVhnSVi>;Q
h^?Ti>GWj>SWiNCWhmkJf]kSij7Ak/kSiZ:UZ[G:f=70`]3Li=Bd]MCRfM7Ffm_G
e=GH9=KGf=SGeM;Ad]?Ee]KEdm;DeMOHf=OEe<o?d=7Bdm?DdM;Cdm:9o`gJ;WeV
JhQlM6MYFJoonOOo4Ogei<6`ao;oDFeLIfIMLEYSGo_o0?kmoa7nnoWoj_[9Y_oT
n_Wmoooln_cmo`CmnoWgm_WijOkion7n=?Win__lo_koo?_in?Sinocoo?ckonig
2hCXookkoooimOOkoOgkmoG]l?Ghn_Sfm>OZk_;eo_MooOK_kO?inocnooO[jO;k
oOWoof8X_>OOm]kYn^o^lnS^k>[Xj>[/k^G^knSXknkUjN;TkNgTh^WYj^[Yj>GQ
gnkYhn?Vj>KSj>KTh^7RhnCTiNOXj>OUi>OSg][Jg^?WXM7^c^?VXZFZ]L[HdL32
d=cTe;Bee>;IdMKKfmODeMPTe]OHf=OEd]7BdmGFe]GCd]CEemSHemGDclo@dM;C
dmCAd]?CdP>@ROl?^D5bH65_IfAZKUnfoo_mo?So4?7o/7WbnOMPMf1VIE]_Ef]V
oOl2o?cnoOl@o__ionOooicbnO[cm_WimoSlo`Cmo?[in?WjjOkion7n=?[knocm
o_kooogln_[loOobh_3YolH7<=Cooo?in>gamOOkoOgkmoG[k_?hno_in>W[ko?f
o_MonOC`lOKjn_SomNobm>o^l^So/@9SoocNn=kUm>[/mnk_k>WVi^W/knO^knOW
knkWjN?Uk^kUhnWYj^[Yj>GQgnkYhn?Vj>KSjNOTh^7Qh^?TiNOXj>OUi>KSgM[J
gN?VZlc/dn7^a=CZe=;TglK5gMgXh<Fmcn3RdMKKfmODeMPTf=WJf]WGeM?BdmGF
e]GCd]?Ee]SHe]GCclo@dM;CdmC>cm3Ad8Wo3kU1LV1QKfMTJViO]_okoOchoa3a
ok1il_WgH7MPIVEKKeM[I_go0_clo_go4?kknOoWoonLl_WjloKinOOho?l4oOcj
nOSin^WnnOoQoSCjno_loOknooomo?[jo?gol^;`jOo61c3DooocnOS]lOGgnogm
noOejnkcn?_knOSYjnocm_kgOoWdl?7fn_[hooG_l_C_k_;Xok42Hoolg_SNiOCZ
k?O^kncYi^KYk>oWk^oWino^inWSiNk^iN?YjN[ZjNSUhMo^jN?Si^SVhnWWi>;Q
hN;Si>GWj>SWiNCVhmgJf]gSiZ_<k=?Qk/CDj]CBi=o6aMgMj>35_LoPh]7Ffm_G
e=GH9=SIf][IemGCd]?Ee]KEdm;CeMKHf=KEdlo?d=7Bdm?Dc/o@dM29o`ni@G9P
HFmWI6Y^GkKonogln?l@lOn`NO;imf1gH6IUFfmGJfKmo`;lo?kmoa3nnoWoiooo
W?;in_?fnOWgn?co1?gln_WhnO[Yo_WohOhdn__ko?gno_oooOcjn_cmoo;Rl>Wo
aPL`e?ooloWhkO7emo_moO_gmN_^loSknoWhjN__loKnmgoim?3am_[jn?oeko;d
knkbj?na0V?oo=khg^Gdj^cgk^o/jNKVjNc_ink_inO_k^OYhnG^k^GSjNWZj^WX
iN7Ok^WShnKXi^?YinCRhN7RhnCUinSXinGTi^?Mf][MhnJ[c>cChNk4e>[Dd^CO
a/GMgNSPaKg?h>;Ae]_KemCEf2CHfM[JfMOEdm;CeMKFeM?BdmGFf=SFeM??cm3A
d]?Ce<k?d=7@0hB<oa;noO^VJ6IGE5IGG6AYG[Ooo?gjn?lGmOo2O?oogFMiGVAU
GW=JIf?oookono_noOl@o__in?oPo=ebooofn?[hm_Slo`CnoOckn_WkjOkion7n
oOgmoPGoooglo?gkoaOaG@1Gko[`k?S]i?[emo_moO_gmNc`m_cnoeCnjngam?Kg
moKglo7dnO_imOS_l_kjin3WmlTM@MOlon3bfN?ek>kgkNo/inCTinc_jo;aj>Sa
l^_Zi>G^k^GTj^WZj^WXiN7Ok^WShnKXi^?Zj>GRo^5Eh^CUinSXinGTiN;LfMWL
h^Fe`^WMh_3HkN?:dO3U]jc7e^7Qc[g0d^7Ae]_KemCEf=[Kg=cKfMOEd]?Ee]KE
dm;Be=GGemGDd/o?d=7Bdm?De=GFemN<oa;noO^VJ6IGE5IGG6AYG[Ooo?gjn?lG
mOo2O?oogFMiGVAUGW=JIf?oookono_noOl@o__in?oPo=ebooofn?[hm_Slo`Cn
oOckn_WkjOkion7noOgmoPGoooglo?gkoaOaG@1Gko[`k?S]i?[emo_moO_gmNc`
m_cnoeCnjngam?KgmoKglo7dnO_imOS_l_kjin3WmlTM@MOlon3bfN?ek>kgkNo/
inCTinc_jo;aj>Sal^_Zi>G^k^GTj^WZj^WXiN7Ok^WShnKXi^?Zj>GRo^5Eh^CU
inSXinGTiN;LfMWLh^Fe`^WMh_3HkN?:dO3U]jc7e^7Qc[g0d^7Ae]_KemCEf=[K
g=cKfMOEd]?Ee]KEdm;Be=GGemGDd/o?d=7Bdm?De=GFemN<oa;noO^VJ6IGE5IG
G6AYG[Ooo?gjn?lGmOo2O?oogFMiGVAUGW=JIf?oookono_noOl@o__in?oPo=eb
ooofn?[hm_Slo`CnoOckn_WkjOkion7noOgmoPGoooglo?gkoaOaG@1Gko[`k?S]
i?[emo_moO_gmNc`m_cnoeCnjngam?KgmoKglo7dnO_imOS_l_kjin3WmlTM@MOl
on3bfN?ek>kgkNo/inCTinc_jo;aj>Sal^_Zi>G^k^GTj^WZj^WXiN7Ok^WShnKX
i^?Zj>GRo^5Eh^CUinSXinGTiN;LfMWLh^Fe`^WMh_3HkN?:dO3U]jc7e^7Qc[g0
d^7Ae]_KemCEf=[Kg=cKfMOEd]?Ee]KEdm;Be=GGemGDd/o?d=7Bdm?De=GFemL3
T97o0?kmoa;mn_NNVUeFFEUWMU]QEk;oo?kmmolFmn5kg?oaHgAHHFQTN5iKF?kn
noomo_kmoa7nnoWbolgjoeS=oO_noogin?glo`?no_gmnOcYo_WohOkmoogn2?oo
oOcloOook_ko5ZHPGL;iooSnoo7[ooGgnogmnoOelOGko?l3k_3cmOkgCOKglo7d
nO_imOOdmOK^i^kmog0E`_oJkN;VdnCklo7ej?3[i^7Qi^_`jNo/hn?/knW[iNO`
l>OUjnWZj^WXiN7Ok^WShnKXi^?[jNKShOkPE>CUinSXinGTi>7Kf=SKhNBn]NCW
h^cJjMk:dNC6RGZHe=_Pel:ga]gAe]_KemCEf=[Kg=cKfMOEd]?Ee]KEdm;AdmCF
e]CCdLo?d=7Bdm?De]OIfm^Ao`3noOlBoO[gWYYMEUUIIgIKHENboocnoOOo5_OQ
NmcolF=dF65XI7QNFeSno__ooOknoOlAo__il_o=n_mHcOgko_omnOSmo?l3o_km
oOWljOkion7noOomoPSoooglo?goonknoaJV85g2nOoho_oajooemo_moO_gmO7e
noco0nk`loGnmdgfmo?am?WknOGgm?Gfk^K^oOm`5L;of^gRi]?Tno?amNS`jnKQ
hNK[l>W_k>?Sk>oYjnGWl?3WiN_Yj^[Yj>GQgnkYhn?Vj>KSjnWVhn7nh5CTiNOX
j>OUi>CQfmSHfn7T_[GTin;/f^WNb]7TaXUjV=CKh=O2]lKMdMKKfmODeMSJfmcL
fmWGeM;CeMKFeM?BdM?De]KDdm7?cm3Ad]?Ce=KGfM_KTOl0o_go4_gjmijJGEII
FFMfFf5G/_olo_ggoaKghG_Loo5SM5QQJ6AhGU]Ho_kkoogno_go4OkknO;ocO[o
F<gmnokooOWhoOco0oknoOgio>WnnOoQo_gooOh8ooomo?cmooo^o_lFYR1M`_Wo
n?kolN_omOOkoOgkmoGamO_lo`?^l??eo_M=m_OclOCinoWemoCem^kVk_goL1G2
om[]h^KCi?_clOGXl>_VhN7Vjo3YkncShnc_jN_Uio3`inG[jN[ZjNSUhMo^jN?S
i^SVhn_Yi^?Qo^1Di>GWj>SWiNCThM_Hf=_Qi;jei>ORk=[Yg/[Ai<J9NYSDfn3G
`[O6gM7Ffm_Ge=GHf]_Lg=_IemGBdmGFe]GCd]7Ce=KFe=?Aclo@dM;CdmCFemWK
f`>7TOl1oOknoa3lmoB8^DQ?H5idQUYNDjkonoOo5?Gol_1[XmooG6eCH6]XNUaC
DOSjn_ko0?kmoa;nnoWhmNKomkeGg?Smooomn__mnOoioNWnnOoQo_co4oknoOom
o?[jo?goe_c]eThRb?OjoOl=lNOomOOkoOgkmoGdmogloeC`l_Cgn?Ofm_Wdl?7f
n_[ho_kchN3`o_nc6GgdoooKkn3>h_cfloGVl>_TgmoTjo3Uj^KLg>KZiNcVio3`
inK/jN[ZjNSUhMo^jN?Si^SVhngZin?Po]mDi>GWj>SWiNCSh=[Gem[PhlbXfN[O
imONi]KEekZAT[;Lf^7SckS1g=7Ffm_Ge=GHf=WJf]WGeM?BdmGFe]GCd]3BdmGE
dm;@clo@dM;CdmC@d]CFei7o0Ogno_l@o?OdR;U8Cf1NM8IJGU>^oo_goaCeoo;`
Jj?Ooea]Df1[J7YLDe7hn_[no`3noOlBo__in?GVooNmEmchoOoooO[koOWonOgY
o_WohOkloa?no_gooOcjn_cmomKlkMI>8/Sgn_go3O7WooGgnogmnoOem?Omo?mD
l?;dmoSgm_Kim?3am_[jn?knln7Pl?ko/aUmm?oofnoPc^;lm_?ei_3[i=oOi>_`
iN[Vg=cVj^G/i^O`l>OVk>WZj^WXiN7Ok^WShnKXi^?]j^OSh?kOE>CUinSXinGT
hn3JemOJh>?<Z=WZgnOGg^KFeMNjTI:bg=[Qhlnh`McAe]_KemCEf=SIf][IemGC
d]?Ee]KEdm;@d]?EeM?Bd<o?d=7Bdm?Dd=;De]NAo`7mo_ko4?cgm8RiB4mPGWB6
FUiC[_okmolDmOobl6^SgomLKE=PJfQjG5=An?[jo_l0o_go4_kknOSei_og_EOL
n?gooogjnogiooWmjOkion7no?lCo_kmoogln_[loOoFo>gFCR;8mo[mo`gaiooe
mo_moO_gmOCgoOcoE?3bm?OhmoKfnOC`lOKjn_Sno_?Qh?3nok<IOOCoom__h<kR
o?KcmNK`jnCOgnC[l>GZi]cLi^[Uk>KWl?3Wi^cYj^[Yj>GQgnkYhn?Vj>KSkN[W
hn3ngeCTiNOXj>OUi>?Pf]OGf^3Sc:SIj]oWemkVe]GG^Y6B/]cJhN??^<7LdMKK
fmODeMSHfM[JfMOEdm;CeMKFeM?Bd=;CeMGCd]3?cm3Ad]?Ce=3Be=KG0hZAo`7l
o_ko4?_elH3H?e5ZH6mjI6IG[OoimolDnOcol7k4WOmHJE5QKFQeDeEBn_cko_l0
o_go4_kknOoLoooVo7BUjoCnoooln_[ion7nnOoQo_coOoknoOcknOShnO_looo_
KaQLa/?iooclooKTloGgnogmnoOeloKjo_onnoWbloKgn?SfmOgfkngcnO_ln?oc
g>GhhK8j>]Gki?o_k>?>g_K`lOS]lN_SgMgSjo7[l>_Ph>_`jngVj?7aj>K]jN[Z
jNSUhMo^jN?Si^SVhnk[in?Po]iDi>GWj>SWiNCSgm[Fe][OhmjObnGJi=WJh]WF
em79d>3RemcYf;Zmem7Ffm_Ge=GHe]OHf=OEd]7BdmGFe]GCd]3AdmCDdm7@clo@
dM;CdmC=c]7Ce97o0Ocno_l@noGaP=PoDFYPKgYTIUN]ooWgoaCio?o`O/BMoeQY
DF5]J7ECEE;jo?_no`3noOlBo__iomcoonKlM:G[m?kooocjn_WohOkion7no?mo
o_kmo?_in?Sinocoonm_65c6`oWoo?com^CcmOOkoOgkmoGcm_[nookknO;cm_Oh
n?KeoOK_kO?inochoo?LiOSQ/SXjeO_Tono/hlkNm_3an>gajn?MgN?[lN_`jn3P
jo3[kNKXlO7Xi^gYj^[Yj>GQgnkYhn?Vj>KSk^_Whn3ngUCTiNOXj>OUi>?Of]KF
f]oSgYo;iM[TfM[RfMKGdLW@h>;Gg>WH^[gGdMKKfmODeMSFemSHemGBdM;CeMKF
eM?Bd=7Ce=CCdM3?cm3Ad]?Ce<g>dM?DTOl1o?knoa3kmO60f3mAJV1_NVAVEjgo
nOOo5?Wloo1na9goF6UAHFeXME=ED_[lnoko0?kmoa;nnoWog?ooi_adYN_do_oo
o?[jnOoQo_WohOklogono_glnoWhn?Wko?ookflHG<K3nOolo?ofi??emo_moO_g
mO?fn_koo__il_?fmoShm_Gmm^o]loWko?SolmcUn>6b>S[EnnCokncSc]kfl?7h
kO7[hmgMhn_ajo3[h>3[l>_]i^SalNSVkNWZj^WXiN7Ok^WShnKXi^?^jnOSh?kN
E>CUinSXinGThmoJe]KJgn?NWl_Uf^CIf^;Ie]OAbM3Ph]OLjMRj_MOAe]_KemCE
f=KGf=SGeM;Ad]?Ee]KEdm;@dM?De=?Ad<o?d=7Bdm?DcLkAdm@3Qi7o0O_no_l@
noC_T_m@IWmYKFm`Keb_ooSfoa?Uonb/ofg;F6UAHVeWL4]KF?ooo_ko0?kmoa;n
noWof_oYlnOaN]kZn?oooO[inOoQo_WohOkkobcnoO_in?Kfn?Wkj_k?6BgUooSn
ooSfoooaloGgnogmnoOelO?gn_[hmO?cm?Knn7ofmOogkN_`n?gniogiioGj/4/B
^OcokmOodNS@fnkYkocelN_Rg=cRjo7fnoGZj_Gkm^gWjO;bjNO]jN[ZjNSUhMo^
jN?Si^SVhnk/j>?Pg]gMi>GWj>SWiNCRgmWFe]WOh^ZK`=oEi=kMf]OEf^;VgmGR
dMGWf[Rfd=7Ffm_Ge1SEf=CEe]KEdm7?d]?Ee]KEdm;?dM;De=;Ao/l:d=7Bdm?D
c]3Ce]NAo`7ko_ko4?_dki;oD6IoJFe_L6mL[oohm_lCiOo/[?m]beQYDF9]Ig1;
FeSoookno`3noOlBo__iom[ojO?WlG[Nj_SooogjnOWohOkion7nnol/o_gknOSf
m_Sinn[ncaT]iOoho_ohm_oolO?emo_moO_gmO7cmo[jn?GcloCfo_Qom_Gomng[
l?Smo^OmnNOen[1;4[WlonoGom7Xd=_^jNolmO7[h]cLh^_am__ej^[enoK]inWb
l^WWkNWZj^WXiN7Ok^WShnKXi^?^k>SSh=kMgNCUinSXinGTh]oIe]KIgn;ZVl3O
eNCNgM[GeM[Ri]oEh]7EimZh]]3Ae]_Kem@HeMSDeMKFeM?Acm;CeMKFeM?Bcm7B
e=CBdOk?2]3Ad]?Ce<k@dmKGTOl1noknoa3km>nBoe1VOfU]Kg1_G:oon?Ko4nGo
k:coKL]HJE5RKFM`Be]Hooono_l0o_go4_kknOoJonWcio5jg^[hooomn_Wion7n
nOoQo__o;?kmnoWhm_KhnO_Zo/lI;NGon?kon?Kooo7cmOOkoOgkmoGaloOjn_Se
lo?dm_khOoKeooO]jo3hoOkWoOWWmOZ`Ba:io?o_eooAj=3Kk^W_o?Gajn;Lg>;[
lOKkmN[ZmO_fkNOYl_;YingYj^[Yj>GQgnkYhn?Vj>KSk^cXhn3NgMgTiNOXj>OU
i>;OfMKFfMoRjY_0gmGTg]gJemGJh^KOeN;AeNOJ^;K@dMKKfmOD6=GHe=GFe]GC
dLoBdmGFe]GCd/oAd]CDd]7nc`[@dM;CdmC>d=?Fe`>1dOoio/Wo5oconoomnOoD
^<U<HEa[R8=WGT[<m_olo?Wn;o[mo=bomo2@Rd=ENeeVP5m4C]oenoOooOKioOoo
o__iooOeno[cmOe^ooW]oo3jon7nnOoIo_Wk4?Koln7mn>SomOe4=LkhnO3no_l4
oO[gmOgnoQ3mn_Ofl_GioOklnOOhmoOfm_keCoWelO;gno[hiOo]i?c_/@0f[Ooi
i_OcdnSCho[bl_O[h>CVh]kRk_WYk^[Qh^ofl^k]kO7dlncVj>[[k>_ZinKWi>CX
k_3/j>W[jnGMemOInNA<in?MfMSJgn;IckSSl=?Uh]_Jf=OGf=[Kd>KFe>[4X/CA
f=oPg=SGf=GFf=WIf=KEd]?Ee]KEdm;>cm7CeMOIf/o?d=7Bd]?Cd];Ce=GAooWn
bOlGo?okoogiomBhbDaQG6^8PfMNB/cfooclnOh_n_glg;ogl92;@eEkGFJ0GdA>
goGkmoomm_WmooonnoWomoGkn_?eoFkonNgol?[ohOkiomWnnO/@m_ochOghj?oe
oD@ec_Sil?kno`Cmn_OeoOkn4?gjmoKbmOWmo_cimoSgmoKfo_E?nOGal_Okn_SU
ongTo>na03J]ooWVmo?Cj=?Sn_;bmn_Pi>KRg^;^nNW^j^7RkoKbk^g]lOCck>KX
j^_/jn[Wi^OTi>S^l>cXjN_[iMgGemWii4cWhmgIf=[Oh]W?^>?`dnGRfm[HemOH
f]_@i]KDj/BRa=7Hgn3Lf=OHeMKHfMWHe]GBdmGFe]GCd/k?dM?EemWJclo@dM;B
dm?Bd]?DeM7onOk9oaOloo_ooOWoe;S9C65LJhR3Iei:c?Koo?cioRojoOcL_oO`
T8]3EG]MIX1OA4kOmO_googfnOgoookknOogmO_jloGmK_oikOo`n_oQo_WofOki
na3foo?QoOSXooGmA3G>n?W`o_ko1?gjmoGmo_h@oO[gm_;enOgno?Wgn?Ogm_Kn
mDoimO7bmo_jn>GokNClkk40=ZgonNKglm?Xdn?jl_;gjn3Ti^;Nh^kijNkZhN;_
m_;^kNgam??/i^SZjnc[j^OVinCTj>k`k>SYjn_UgMOGfOWTC>OSgMWHf]oRfLnh
ho3CiN;Kf]SGemSJfm3Ve]CZa:;4dMSOh=cHemSEe]SIfMSFeM;CeMKFeM?Bc/oA
dmGGfM[?cm3Ad];Cdm;BdmCE0g_AooWnbOlGo?okoogjolc:bSiIHWJ:NVMPC<kg
oocmnOh/n_onb=[noK=gDF=mK6mfEeAMk?gnloo_loKjoOklnOOnmOCjnoCfolUk
o_oRo_oQo_WofOkio2Who__nonWQo?mh5HWono3_oOgnoO_hmO?loOknoO_hm_;e
n_gno?WgmOGnm_kg>OScko3fnOWgoo3ol?o8<TZLh?odioWjh^SDho[cl_S[i>OW
h]kRk?K_lnkSh^gakNk/kO7dlngVj>WnjQ;Xi^CUh^7Uj^cYiNS[jnGMf=SJnNA<
in?MfMSJgn;Kck?Mk]KUg=_Jf=OGf=[KdnKHenW8Z<?Ef]kNfMGFf=GFf=WIf=KE
d]?Ee]KEdm;?cm7CeMOIfM3AdM;Ce=GEd];Ce=GAooWnbOlGo?okoogjolc:bSiI
HWJ:NVMPC<kgoocmnOh/n_onb=[noK=gDF=mK6mfEeAMk?gnloo_loKjoOklnOOn
mOCjnoCfolUko_oRo_oQo_WofOkio2Who__nonWQo?mh5HWono3_oOgnoO_hmO?l
oOknoO_hm_;en_gno?WgmOGnm_kg>OScko3fnOWgoo3ol?o8<TZLh?odioWjh^SD
ho[cl_S[i>OWh]kRk?K_lnkSh^gakNk/kO7dlngVj>WnjQ;Xi^CUh^7Uj^cYiNS[
jnGMf=SJnNA<in?MfMSJgn;Kck?Mk]KUg=_Jf=OGf=[KdnKHenW8Z<?Ef]kNfMGF
f=GFf=WIf=KEd]?Ee]KEdm;?cm7CeMOIfM3AdM;Ce=GEd];Ce=GAooWnbOlGo?ok
oogjolc:bSiIHWJ:NVMPC<kgoocmnOh/n_onb=[noK=gDF=mK6mfEeAMk?gnloo_
loKjoOklnOOnmOCjnoCfolUko_oRo_oQo_WofOkio2Who__nonWQo?mh5HWono3_
oOgnoO_hmO?loOknoO_hm_;en_gno?WgmOGnm_kg>OScko3fnOWgoo3ol?o8<TZL
h?odioWjh^SDho[cl_S[i>OWh]kRk?K_lnkSh^gakNk/kO7dlngVj>WnjQ;Xi^CU
h^7Uj^cYiNS[jnGMf=SJnNA<in?MfMSJgn;Kck?Mk]KUg=_Jf=OGf=[KdnKHenW8
Z<?Ef]kNfMGFf=GFf=WIf=KEd]?Ee]KEdm;?cm7CeMOIfM3AdM;Ce=GEd];Ce=D3
O]7onOk9oaKloo_oo_co_^7<<E1WOh]cIV9@d_Soo?Sn;o[onjKmoooPKg1`K6]_
Ie=HH_;oooCojnkamOWjnOKdno;bn__fnOooD<oohOoomn7nnOoIo_Wm4?oboooi
jOOog0hhhooom>ojo_][nOKclO_loOkmnoWgloKjo_omn_SbloCemoSjn_Kbk^od
n?OeonSoooMb2Z_Nl_S[io7]g>WDi?_cloS/jn[XhmoRj_7cmo;Vhnc^j>g[k?3e
m>kWinSYjNSVhn7Uh^3RinWWhnOZj^GMf=SKnNA<in?MfMSJgn;OcZcDjmWUe=_J
f=OGf=[KenCLg>O>]<;Ig=kKeM;DemGFf=WIf=KEd]?Ee]KEdm;@d=7CeMOHf=?C
e=GFemOHdm?DeMKAooWnbOlFo?okooklokkQc35@Ign;LfIRD=;hoochoRojoo^V
oOooh6m`L6a[KfMCF6;booodon_^lOGin_Wfm?_bl_[km_Wooe3?on7oooOQo_Wo
fOkioA3ol_oonNWgom`>>>?oooC_n_kkJoWflo7ko?gnoO_imo?fn_kooO[hl_?d
mOOhn_[fl^k_m?SgmOoXooogLPZ[g_;hjnOakMcYe>Cklo?hk>_Zj>?Oh^[aloOb
i^?/k^S]jnc`mOC^inOXjNWXi^?QiN;Ph^OYin?Wj^[UgMSHfoWTC>OSgMWHf]oR
glj/e>_IiMCKf]SGemSJfmOTg=cWc[C2fMcNfmGBe=OEe]SIfMSFeM;CeMKFeM?B
d=3AdmGGf=SCdmCEe]OGf=?Ce=GFdOoio/Wo5_conoono?nnhL`aD6MoRg=VHU3B
n?oln?h_n_okY_goon1_L71/JfmWDeQRl_oom?o[k_7enO[im_Ckl_;jnoKioom@
cooQoooghOkiomWnnOd@oo;oooWYmooL3SSSooodko[nnf_im_?anocmo_gknOOc
m_[noogjn?;cm?Ggn?[jm_;^koChmoGoj?oomg8:Zmkbn>_WlNgLjMCTno?cn>c[
j^SSgn;ZlO?gl^KSk>kXkN_/l?Gdk^OWj>WYj>KShNGRh>;WjNOSin[ZiMgHf=_i
i4cWhmgIf=[Oh]o>[=C[fNGDfm[HemOHf]_Gi=cLiljd`]WLg]_Ed]CGeMKHfMWH
e]GBdmGFe]GCd]3@dM?EemSHdm?DeMKGemSCdmCEeP=ndOoio/Wo5o_on_ooo_f[
km8bDFIjR7IVIEKGn_olooWn;o[olHKonoolLhUeF6=^Hea;En_oooWolnW/lOGg
m_?an?3`nOchnookfIKXon[oln7nnOoIo_Wm3oocooo^ooohD2BmonWoo_;mnF_g
m?7_n__mo_gln_Wdmo_oookknO3aloGgn__lmO7]k_?gm_CXoo3nXQecg]cRjo?e
l>?Gj]GUo?CdnNgak^WShN?XkO3el^SVko3Zjn[[l?GeknWXj>WXinCQgn[Vh^?X
j^WVi^WYiMgIf]cii4cWhmgIf=[Oh^?@Z<_Vg>O?fm[HemOHf]_LhMoQi=C1_][L
gMWCd=?GeMKHfMWHe]GBdmGFe]GCd]7Ad]?Ee]OGeMGFe]OHfMWDe=GFem7onOk9
oaOkoo[oookmZnoB<U5VNXQfIVEFeo[oo?oioRojoo66oo_oo7>9MEQSKV=LBeO[
oooioo?Yk?7emoKclOS`l?Wln?_onmVFj?oZoo?Qo_WofOkio@ooloook_oon50T
_OoYookboOU[moCako[koOkmo?[im?OkooonnoW`lO?emo[ko?GakNkcmoKdj?o`
oZ8MLmkLh^_cmO3Sen[EiOcdm?W]lNkYhn7Sj>g`mO;Xi^o`j^_Zjo3emNoYj>SY
j>OThMoZi^;Sj>[Yi^KYjNGMfM[LnNA<in?MfMSJgn;Sd:S;i]cWcm_Jf=OGf=[K
g>7OhNCD`KkJg=gIdm3CemGFf=WIf=KEd]?Ee]KEdm;AdM;CeMKGemGEe]KGf=WI
e=CEe]OAooWnbOlGnoojooonoJ__dS9AIWZ8MVIUE]OjooconOh_n_oaQ_okooac
RGEHHfiSG4]GjooonOocjNcamOOflo7hl?3io?Skoo_IU^Soj_ochOkiomWnnOd?
oo?oonkoooQ@9;gojOonl_giJoOdlNojnognoOcjnOCgnoooo__il?7cmOOjnoce
lNg^loOfm>Sol?jR7G?Ng>;[loG`hmOZeNGlm?CikO7^jN?QhnS]l?Gbj>K_l>[[
j^_`mOG_jNSXjNSWi>7Oj^KRhnSZjNKVjNWUgMWJg?WTC>OSgMWHf]oRhm2XbnKL
iloKf]SGemSJfmcQgn7Te<6nf]cMfM?@dmOEe]SIfMSFeM;CeMKFeM?BdM7BdmGF
emOEeMKFemSIfMCDeMKG0g_AooWnbOl2noojo_lAmYObfSmKHV^2OfIXFmcloo_o
nOh_n_oON?ocmomYPgQVNHIgK4MCiO_om_oci^W^loGdl_7hl?3io?Skoo3o/j_o
o?oihOkiomWnn?l>n_ool?ooY0EnoocPoo;goOT>moCakoWjo?gnoO_jmOSlo_m0
o?[`lO?emo[ko?Kbk^odn?Oeg_ol/2HbhNKLi?CoooG^kN_Fi_gemO[^mO3Xhn?U
jN[YlO3Yj_Cfkn[Yjo3emO3njQG[j^SThMobk>OVj^g]j^GWj>CNf]_NnNA<in?M
fMSJgn;VeJW5h=cYc]_Jf=OGf=[Kh=_Qi=kIcKSFfMcIe=7BeMGFf=WIf=KEd]?E
e]KEdm;Bdm?De=GEe]GEe]KGf=WIeMGFemSAooWnbOl2noojo_lAmYObfSmKHV^2
OfIXFmcloo_onOh_n_oON?ocmomYPgQVNHIgK4MCiO_om_oci^W^loGdl_7hl?3i
o?Skoo3o/j_oo?oihOkiomWnn?l>n_ool?ooY0EnoocPoo;goOT>moCakoWjo?gn
oO_jmOSlo_m0o?[`lO?emo[ko?Kbk^odn?Oeg_ol/2HbhNKLi?CoooG^kN_Fi_ge
mO[^mO3Xhn?UjN[YlO3Yj_Cfkn[Yjo3emO3njQG[j^SThMobk>OVj^g]j^GWj>CN
f]_NnNA<in?MfMSJgn;VeJW5h=cYc]_Jf=OGf=[Kh=_Qi=kIcKSFfMcIe=7BeMGF
f=WIf=KEd]?Ee]KEdm;Bdm?De=GEe]GEe]KGf=WIeMGFemSAooWnbOl2noojo_lA
mYObfSmKHV^2OfIXFmcloo_onOh_n_oON?ocmomYPgQVNHIgK4MCiO_om_oci^W^
loGdl_7hl?3io?Skoo3o/j_oo?oihOkiomWnn?l>n_ool?ooY0EnoocPoo;goOT>
moCakoWjo?gnoO_jmOSlo_m0o?[`lO?emo[ko?Kbk^odn?Oeg_ol/2HbhNKLi?Co
ooG^kN_Fi_gemO[^mO3Xhn?UjN[YlO3Yj_Cfkn[Yjo3emO3njQG[j^SThMobk>OV
j^g]j^GWj>CNf]_NnNA<in?MfMSJgn;VeJW5h=cYc]_Jf=OGf=[Kh=_Qi=kIcKSF
fMcIe=7BeMGFf=WIf=KEd]?Ee]KEdm;Bdm?De=GEe]GEe]KGf=WIeMGFemP3Km7o
nOk9o`;joo[noa7`QO?OBVIQH7^3IV]QhOkonooioRclolj5ooG]oemUM8FGXI5c
F5oZn?O[n^OTj>gbmOGcl__bl_[km_Wooo3o]J_non7nnOoIo_Wo0O;lo_l;mjPe
@/KomOooho_jo_/>nOKclOOinognoOckm_Wmo_m1oO_bloCemoSjn_Wdl?;gno[h
oo_oHQ2dooCYl_WeknkcnNcGiokfm___mo3VhnGYjn[Vko7[kOOhlNWXj_3em_7[
o^hDkN[Vhn3gl>WXjnk^kN?Vj>CNfmcOnN@gin?MfMSJgn;Vg;75f][/dm_Jf=OG
f=[KhMCQiMOLek3=e=[Lf=CCe=GFf=WIf=KEd]?Ee]KEdm;ie0cCdmCEe]OGf=KF
emSIdOoio/Wo0_[on_ko4O25lmm:IV5PNh=VJf7Qo_okooWn;?cocXGomNgoGfEd
QINQTG=HGn[hmn_jinCXkO;emO?bno;bn__fnOool?neZokohOkiomWnnOl1l_cn
o`_gZ3E2a_oeoooSno[nn`kim_?amoWkoOkmo?_fnOgnod7mno;cm?Ggn?[jnOC`
l_Okn_SonomR4;Com>WbnOG_k_?ik=OWo_Kfnnogl>KSiNW[j^K_lN_]moSajNSZ
l?GflN_nkQC]j^KSh?O`jNS[k^k]hnKXi=kKg=oii3OWhmgIf=[Oh^KL/LGJf^cC
fm[HemOHf]_Qe>7UemcG/<gDf]cHe=?DeMKHfMWHe]GBdmGFe]GCd_WD3=?Ce=GF
emOHe]KGf=WAooWnbOl2n_ojo_lAl8GcgdYVHF1kPfI[HN7noo_onOh/o?o>QOoe
kOmOIGB5Uj6ALeQOj_Sgjo[Wi>S]l_Gelo;kl_;jnoKiooo`okF[o_oQo_WofOki
o`7bo?ko2oNX=D;6ooGoon?kn_kk3_Wflo7gnO_mo_glnoKioOko@Ogkl_?dmOOh
n_[im?3bmo_jn?okof8@]?odjO;imNo^loW/enOnm_KkkoO`i^?UjN_Zi^oajngg
n?7Yj>[`mOKajok^5>gZi^?Pmo3Yj>_^k^gSi^STg]_LgoWT=nOSgMWHf]oRi]ba
aM[Jk=?Kf]SGemSJfn7DhNGGg=N`cMCJg=SDdmCEe]SIfMSFeM;CeMKFeM?BnM@<
dm?DeMKGemSFe]OHf@=kdOoio/Wo0_[on_ko4N]gnN5<JfMQMWmVKFGUoookooWn
;ooo`j?oonooO51QQXNDUFaZKO7hl^Gfi>CXk_?fmoGdo_Gdn__dm_ood?o[T/;U
on7nnOoIo_Wo8_Ojmooo`Tl9[??gooofmo_moOkmnoSeloKhnogno_glmo[no_l3
o_cemOkfo_Lgo?SdmO[noO_oiJPnQOohn>Odm>GSl?;Yk=SXo_Ogo>ogk^CRing^
k>[cm>k^mOG/j>OYkoKgl^cnlQC`kNWUh_S`j>GXjnc[h^GWi=kKgN3ii3WWhmgI
f=[Oh^GT^/OEenoJfm[HemOHf]_Qc]oUd=kMZ/?=fMoMemCCeMKHfMWHe]GBdmGF
e]GCd]GEoM@>dm?@dM7BdmCEeMKGemSIdOoio/Wo0_[on_ko4N]gnN5<JfMQMWmV
KFGUoookooWn;ooo`j?oonooO51QQXNDUFaZKO7hl^Gfi>CXk_?fmoGdo_Gdn__d
m_ood?o[T/;Uon7nnOoIo_Wo8_Ojmooo`Tl9[??gooofmo_moOkmnoSeloKhnogn
o_glmo[no_l3o_cemOkfo_Lgo?SdmO[noO_oiJPnQOohn>Odm>GSl?;Yk=SXo_Og
o>ogk^CRing^k>[cm>k^mOG/j>OYkoKgl^cnlQC`kNWUh_S`j>GXjnc[h^GWi=kK
gN3ii3WWhmgIf=[Oh^GT^/OEenoJfm[HemOHf]_Qc]oUd=kMZ/?=fMoMemCCeMKH
fMWHe]GBdmGFe]GCd]GEoM@>dm?@dM7BdmCEeMKGemSIdOoio/Wo0_[on_ko4N]g
nN5<JfMQMWmVKFGUoookooWn;ooo`j?oonooO51QQXNDUFaZKO7hl^Gfi>CXk_?f
moGdo_Gdn__dm_ood?o[T/;Uon7nnOoIo_Wo8_Ojmooo`Tl9[??gooofmo_moOkm
noSeloKhnogno_glmo[no_l3o_cemOkfo_Lgo?SdmO[noO_oiJPnQOohn>Odm>GS
l?;Yk=SXo_Ogo>ogk^CRing^k>[cm>k^mOG/j>OYkoKgl^cnlQC`kNWUh_S`j>GX
jnc[h^GWi=kKgN3ii3WWhmgIf=[Oh^GT^/OEenoJfm[HemOHf]_Qc]oUd=kMZ/?=
fMoMemCCeMKHfMWHe]GBdmGFe]GCd]GEoM@>dm?@dM7BdmCEeMKGemSI0gkAooWn
bOlGn_ojo_oojFoohDQ/KVEeMfI^InOooo_onOh_oobn_?gom_nYCDa^GG69HW1a
l_Scj?_[iNS^m?OhmoGomoGkn_?eoOKol?nlFl?ohOkiomWnn?l?n^?noiLT7>Go
n_odh_oho_ko1ogjmoGfmo[mo_h3oOOjo_ko1_kln?Ogm_KnmBknn_Kgo?oooOSM
2c7ooncVg_?hk??on][]f>SomoOll?O]hn;Yko3]l?Shl>kcl?kW7NW_m_ObkOGe
m?;_jnKTm^kUhNCXjNSRiNOTg]_MhOWT=nOSgMWHf]oRi>S1bM?DlMoKf]SGemSJ
fn7:g^G<g^2V_LWIhN3Je=;Ee]SIfMSFeM;CeMKFeM?Bo]D1e=Cnd`c?cm3Ad];C
dmOGf=WJdOoio/Wo5o[on_koonU_on58K6iUMGMVKVOWoookooWn;ool_[cmooKo
ZDe<KUeaRF9`LO;hlnSkjnGXk_Cgn?OeooOeno[cmOgfoo3o_5_3on7nnOoIo_So
3o[So_nG91cUoo[om>;on?kno`Omn_Oem_OjoOkn0oggn_kno`Kno?SgmoKfo_D^
o_[fmocoooghg@/aooo/i]kcn>ccoo[JkMSXooOgo?3gkN?RjNo`kO3hn?3^lo3n
iagYkoKgl^gemOCbkn_Vi?K^iN7Tj>WXh^GWi=kKgN7ii3OWhmgIf=[Oh^CX`LWC
e?7Ofm[HemOHf]_Qb]kUc=kPY[g9fN7Pf]CBeMKHfMWHe]GBdmGFe]GCd_kE0MCD
o]<<clo@dM;Bdm?GemSIf]7onOk9oaOjoo[noooYKooQB6a^IGEgIViWiooonooi
oRooo;jloOofojU=C6iMLHURL77bn??Xnn_Uj>kdmoSgmOogmO_jloGmm_o`okaK
`ooQo_WofOkho`ojhokoUb@LiOojooCRooSno_l7oO[gmOKgn_gnoP?mmo[no_l6
o_chmoOfm_ke;_kjm_Olooomn=d;<Oook>KNloS/loojf^gHj?ogmoc`mngSh^W_
l>g`n?S`k_?`o^LMjNofmo;]mOGdl^o[i^Cfk^GQi>SYj>;UinCNfmgQnN@gin?M
fMSJgn;Tj<79dmCagm_Jf=OGf=[KhL[NiLcNh:JmbMWQh=[Dd]GFf=WIf=KEd]?E
e]KEdm;ne@7De?kC3<o?d=7Bd]?CemOHfMX3Ti3o5_Soon3o_lSoiUUEIiN;LfEN
JOOmnooonOhglon7nOKikonJD5a[LHN7XI:Hi_S]o>g_k^c]l_Wkn?CmmOKoooWj
ooCnooo_eKjbongoon3coooQo_WonOkionWn2?WodooX63EaoOkoOokjmO7hn_cn
o_glno?ho_olnogojoGhloGnoOG_m?SflO;jonWglnkimo;mg1hYa_Gion;[mOSb
lOGai_3GkN[`n^7dlncQfMWQjo?oo_WcloKckO?`ko7emO3Zl^oZi^CUinSck>CR
j>kal^S[k>OPg=gPg^3RiNOWi^KWhmgI5MSJgn;NjMNJj]_Of]WHe]GEe]SIg=gn
gQ;KfMNI_n[Sb]k^d]GFf=WIf=KEnM@D`<G@g>GTf]7<d=?Ee]WNh]KOh<jdT?lF
n?ooh?nob?oVFEEWUh]cIEiYmogkoooioSOcohOim_W_oiY@G6]aQhNQTYSVn>gl
kNo^k>gbnO_hm?gem_oonO[om?koonoE_[;okOooh??oon7nnOoio_WojOh8nOoC
onPH=G7mo_moo_[elOSjo?knoOckloSnoockoOo[mOScmOkmmNodn?Kal_[ojOOc
k_Wgl_gL7RW6mOWoh^_en?;amO7Vl=O]j_3jhOCck>7IfN7[loonnO?cm_?]lo3_
lOGel>[bkn[Vi>GWj??/i>;Xk_7bj>_/in3LgN3Nh>;UinOVi^OSgMTEf=[Oh]kY
ei[ZfmoJfMSFeMGFf=WLgOkN4]_IeiVoj^?:g^kBeMKHfMWHe]Gie1C0aM3LiNCJ
dLc@dmGFfMkRe]oPc[B@oaKhoooPoko8onIIEFNGRg=UGVWgoO_oooWn=o?oQoWf
nNooVU1LJg67Qj6BV>KhkOc]knk/kO;inoSdoOGfoooin_odo_ookmFn/_o]oooP
looohOkiooWnnOoYoPSiom?oj1PeLOgnogonn_Gan?[lo_kmo?_cn?koo?_mon_e
n??eo_gekoChm_7bn_oYmo?^nOOboM`N:LKenOoRjoGhl_7elNK`engZl?[Qm??/
hMWIhN_cookilo?flngcl>oamOG`j_;_j^KTiNOXlncTh^S^lO;XjncWh=cMh=kP
h^GWinKVin?MfAGHf]oRg^WGV^[Kgm[If=KEeMKHfMcMo]hBfmWGVKoZhl[Nk];E
e]SIfMSFeOWD5<35d=cUi=[Ac=3CeMKIg^;Fgn3>]0>CT?lFlOooj?nke_cPEUAV
TXA^I5iZn?kloooioSOgoh[gn?gbojeNIGAmShNISi_^onoij^kaknodnogjm_ge
m_oonO[oo?_mooc/eL;EoooZoooVnn7nnOoio_WojOh9jL[oof4Yb_omo_koOo[e
l_?dm_ShmoKdloWnoocjo?o/mOWdm_knmNgcnOWem?[oomSSoOKkooiTCZOonnoo
m>[en??bmO7VlMS^j_7jhOCajn?Mg^C]m>kak^S[m?Kal^o^lOGel>_bkn_WiNGW
j?3ZiNGZko3_j>_/in3LgN3Ph^CVinKUi>OSgMWH5=[Oh]kYf:7TfmoJfMSFeMGF
f=WLgOkN4]_Iej70in78f>G:eMKHfMWHe]GieaC_i=K=cLoAd=?Gg=gId/g9h/NJ
JTB@oaKaoooXok_Fo>1FE6JBQ6iTGV[ho_coooWn=oOoR_OhoO;o[EiUM7f?QiV?
VnkokoWZk_7_koCkoO[foOGfoooin_olnogoo>cE`]Goon[oonKkhOkiooWnnOoY
oPWYb_ooHBW:oogno_mon_GbloCfn?Sgm_CcnOkoo?[loncenOCfo_kekO?inOGd
n_oof>?mm__ooVA>Yookkoodj_Ghlo;elNKaf>kZlO[Qm?7[hmgNi>gdk_7^j>_d
m_7bknkamOG`jo;_jnOUiNOXl>[UiN[_l>oXjncWh=cMh>3Ri>KWi^GTin?MfMPD
f]oRg^WHXNCKgm[If=KEeMKHfMcMo]hBfmWGXL3WhLSHiL[Ee]SIfMSFeOWG5>oT
e/g=cm7@dmOLgMWBcLWRaiYZA93o5_7oonSo^mKlh5IDIY:4KVANJ_Sno?oonOhg
mon:moSml_n]GVEdOHn7VHnKk_o_nN[^lNo_m?_mn_KmmOKoooWjoockoOolk=G2
eOooj_ooi__Qo_WonOkionWn2NW:oomQ:L[ooOknogojmO;cm?Khn?Ofm??io_ol
n_cok?Gim?Kno_G]loWimOCjoooHhogfnoonI4jWoo__ooCZmOScl_Gai_7Hk^[a
n^7dlN_SgMkTkOC^lNkXjoCflO;_k_7emO3[l^o[inGUinS`j^GUj^o`knS[k>OP
g=gPh>;Ti^OViNCWhmgIf1CJgn;NjMRQi=_Of]WHe]GEe]SIg=gngQ;KfMNQ`>OQ
b=SUb]GFf=WIf=KEnMLDknCFcLg?dM3CemcMfM;=bN;7VVY40hf@oaK[oOodok7Y
n]iIG6bBPVmSGF[ioocoooSn=_nAmOcom_fbG5e^Nh]fO7>:jOo]m^_dmO?cn?ko
o?SmmOKoooWjooojmOcoonoKPNcokOookooQo_WonOkionWn2OoZokD6I>KOo?gn
ogCkm_?dmOOhn?OeloCioooln_cnk?KimOKoo_K/l_[ln_SinooKi_?Yoonb07G_
on7Gh=gYm?WdloK`i?7Hk^_ann;ekN[UhnCZl?C[l^oTiO7eko3^kO3dm?3[lNo/
jNOVinS]jNKYk_7_jnS[k>OPg=gPi>GniacUhn7WhmgIf=[Oh]oYfZgJfn7Kf]WG
e]KGfM[LgOkN4]_Iek74iNC<en7:e]OIf][IemKifQC3`lOAg>?ThM[Ec/S7b/oB
H4@U6RF@oaK[oOodok7Yn]iIG6bBPVmSGF[ioocoooSn=_nAmOcom_fbG5e^Nh]f
O7>:jOo]m^_dmO?cn?koo?SmmOKoooWjooojmOcoonoKPNcokOookooQo_WonOki
onWn2OoZokD6I>KOo?gnogCkm_?dmOOhn?OeloCioooln_cnk?KimOKoo_K/l_[l
n_SinooKi_?Yoonb07G_on7Gh=gYm?WdloK`i?7Hk^_ann;ekN[UhnCZl?C[l^oT
iO7eko3^kO3dm?3[lNo/jNOVinS]jNKYk_7_jnS[k>OPg=gPi>GniacUhn7WhmgI
f=[Oh]oYfZgJfn7Kf]WGe]KGfM[LgOkN4]_Iek74iNC<en7:e]OIf][IemKifQC3
`lOAg>?ThM[Ec/S7b/oBH4@U6RF@oaK[oOodok7Yn]iIG6bBPVmSGF[ioocoooSn
=_nAmOcom_fbG5e^Nh]fO7>:jOo]m^_dmO?cn?koo?SmmOKoooWjooojmOcoonoK
PNcokOookooQo_WonOkionWn2OoZokD6I>KOo?gnogCkm_?dmOOhn?OeloCioool
n_cnk?KimOKoo_K/l_[ln_SinooKi_?Yoonb07G_on7Gh=gYm?WdloK`i?7Hk^_a
nn;ekN[UhnCZl?C[l^oTiO7eko3^kO3dm?3[lNo/jNOVinS]jNKYk_7_jnS[k>OP
g=gPi>GniacUhn7WhmgIf=[Oh]oYfZgJfn7Kf]WGe]KGfM[LgOkN4]_Iek74iNC<
en7:e]OIf][IemKifQC3`lOAg>?ThM[Ec/S7b/oBH4@U6RD3Ti3o5^ggookoXOGn
hV5YMYF5Mf5MJo[ooOoonOhgoo:Nm?oonoRcEeEXNhY^Jde]fOOWlnklnOOgnooo
o_WmmOKoooWjooomn?gooogaPY[fonCbooWQo_WonOkionWn2O_o_R9@h>_In_cn
ogokmoCko?gnoOcin?GkooolnO[mkOOjm_OoooO/l_Wooogimngom]S`oj/`ALWo
l_GnknWXm?Wem?O`ho;Ikncbo>?fjn[XinW]lOGbo__XhnocjNk/jnkcm?3[lO3^
jnWXinOZj>S[lO;]jNS[k>OPg=gPj>SYjNOUh^3WhmgIf1CJgn;Pj=bmc=[Sfm_J
f=OGf=[Kg=gngQ;KfMO0a=oWeM[TdmOHf]_Kf]SGnMPDd]7Ae]_Ke]3BgNWT`XI3
5c4X9356T?lFkOOoo_nQmOkRHFUfUHEgHEe[n_omoooioSOolYkdoookn;=GEFQk
RVi[CFgImnOck_cimoOkooonnOgem_oonO[oooghoOoooO62V_Koi?;onN7nnOoi
o_WojOh9nonn8U3PjmWjo?koOo_gm?_loOkmo?WhmO_ooocin_g]mo[fmooomncb
nOoooOWgkOoff?3oZc15bOobmOk_jNSdnOGdmo3Sl]W_k?;lhoK[j^SWjNgamO;n
nnSSko?Yk^c[k_?dl>_al>k[jNSWin[Xj>_al^gYj>_/in3LgN3Xj>WYinGRh>OS
gMWH5=[Oh^3Xg;g<f^?Kfm[HemOHf]_LgOkN4]_Iel34gnOEf^CCemSJfm_Jf=Oi
f1CBdM7Ffm_Fd=;MjNC2QT<G<BPT<DJ@oaK]moonoj7eo^9QJGJEQGMQGF_joogo
ooWn=oobW_Cooo_h/eMEJ7^:KV]=KMWgio?^o?Wgmo_oookioOGfoooin_oooOSm
ooomlH:Jm_oTl_oihOkiooWnnOoYoPWkokhRD>3[fO[lo_monoOdnocmo_glnOSe
noooo?WjoNggn_Kgooogk?;iooomnOO]ooKHl?n[<4G9oo;eo^oYj?CimOCgl>?b
fNo/l_cSm^_Zj>OYkO7el_kkj>?_lnW^k>_^loC`jo7`k^_Yj>OWj^SXjo7bkNWX
jncWh=cMh>SXjNWWiN;Pin?MfMPDf]oRh>SL_LcJhm_Kf]SGemSJfmcMo]hBfmWG
`<COimGJi=?Gf=[Kfm[HeoWH5=;AdMKKfmK@d]gYi<:6@aLa:2@aAP>=T?lFn?Wo
ooZCnOkOH6afSh5jH5a[o?omoooioP?ogk3fo_lOmk]LFFj3UGMbAfSFm^OckO_k
nOSlooonnOgem_oonO[lo`_no?gnfJ[Con_con3Qo_WonOkionWnOnOoERS;ooOo
nO_noooln?GmoOknoO_hm_Oloookn?Wlk_SkmoSoooS_l_SnoookmnOolN3odST1
/_cig_oojNkVlo[gm_O_hO?Jl>gcoNCgkN_YinW/l??SnO_Vh?3dincYjNgcm?3/
l?3_k^cZj>KZj>S[lO;]jNS[k>OPg=gP8NWYj^[Xi^?Qin?MfMSJgn;Qj=k>_M[U
g=cKfMSHfM_Lg=gngQ;KfMO4^<kQe]SRf=SIfmcLfmWHnMDDhMS>c=?MiNSY^G8f
6Q/Z=T54BDi=T?lFn?WoooZCnOkOH6afSh5jH5a[o?omoooioP?ogk3fo_lOmk]L
FFj3UGMbAfSFm^OckO_knOSlooonnOgem_oonO[lo`_no?gnfJ[Con_con3Qo_Wo
nOkionWnOnOoERS;ooOonO_noooln?GmoOknoO_hm_Oloookn?Wlk_SkmoSoooS_
l_SnoookmnOolN3odST1/_cig_oojNkVlo[gm_O_hO?Jl>gcoNCgkN_YinW/l??S
nO_Vh?3dincYjNgcm?3/l?3_k^cZj>KZj>S[lO;]jNS[k>OPg=gP8NWYj^[Xi^?Q
in?MfMSJgn;Qj=k>_M[Ug=cKfMSHfM_Lg=gngQ;KfMO4^<kQe]SRf=SIfmcLfmWH
nMDDhMS>c=?MiNSY^G8f6Q/Z=T54BDi=T?lFn?WoooZCnOkOH6afSh5jH5a[o?om
oooioP?ogk3fo_lOmk]LFFj3UGMbAfSFm^OckO_knOSlooonnOgem_oonO[lo`_n
o?gnfJ[Con_con3Qo_WonOkionWnOnOoERS;ooOonO_noooln?GmoOknoO_hm_Ol
oookn?Wlk_SkmoSoooS_l_SnoookmnOolN3odST1/_cig_oojNkVlo[gm_O_hO?J
l>gcoNCgkN_YinW/l??SnO_Vh?3dincYjNgcm?3/l?3_k^cZj>KZj>S[lO;]jNS[
k>OPg=gP8NWYj^[Xi^?Qin?MfMSJgn;Qj=k>_M[Ug=cKfMSHfM_Lg=gngQ;KfMO4
^<kQe]SRf=SIfmcLfmWHnMDDhMS>c=?MiNSY^G8f6Q/Z=T54BDi=0hf?oaGmo?oj
SO_heUITK89hNEiKK?goo_konOh3olk5n_ko8OVfF5AWNXebLF5kh?c]m^[ao?[h
noooo?OmmOKoooWjoogno`_jm_[ooo>Z[oooj?GQo_WonOkionWn4?n=5XoonoSY
n?[mooomnOOho_U]moCakoSmoookmoSjkoWln?WoooWdm?Kkooomn?_ohOooPa=G
f_o`h?KXd>OUl__hmoS^h?CKlNkdo^GhlNgXi>?WkO30ho3OgO?hjNWWincbm?3/
l?3al>k[j>K]jNKYk_7_jnS[k>OPg=gPinSnjQcXi^CWhmgIf=[Oh^;Xh=j_f^OM
gMcJfMWJg=gLgOkN4]_IelN/_=WCd=[FfM[LgMgLf]Wie1C<d=KKf<RbXB`Z;CM1
@SP]<3Po@Cn?oaGmo?ojSO_heUITK89hNEiKK?goo_konOh3olk5n_ko8OVfF5AW
NXebLF5kh?c]m^[ao?[hnoooo?OmmOKoooWjoogno`_jm_[ooo>Z[oooj?GQo_Wo
nOkionWn4?n=5XoonoSYn?[mooomnOOho_U]moCakoSmoookmoSjkoWln?WoooWd
m?Kkooomn?_ohOooPa=Gf_o`h?KXd>OUl__hmoS^h?CKlNkdo^GhlNgXi>?WkO30
ho3OgO?hjNWWincbm?3/l?3al>k[j>K]jNKYk_7_jnS[k>OPg=gPinSnjQcXi^CW
hmgIf=[Oh^;Xh=j_f^OMgMcJfMWJg=gLgOkN4]_IelN/_=WCd=[FfM[LgMgLf]Wi
e1C<d=KKf<RbXB`Z;CM1@SP]<3Po@Cn?oaGmo?ojSO_heUITK89hNEiKK?goo_ko
nOh3olk5n_ko8OVfF5AWNXebLF5kh?c]m^[ao?[hnoooo?OmmOKoooWjoogno`_j
m_[ooo>Z[oooj?GQo_WonOkionWn4?n=5XoonoSYn?[mooomnOOho_U]moCakoSm
oookmoSjkoWln?WoooWdm?Kkooomn?_ohOooPa=Gf_o`h?KXd>OUl__hmoS^h?CK
lNkdo^GhlNgXi>?WkO30ho3OgO?hjNWWincbm?3/l?3al>k[j>K]jNKYk_7_jnS[
k>OPg=gPinSnjQcXi^CWhmgIf=[Oh^;Xh=j_f^OMgMcJfMWJg=gLgOkN4]_IelN/
_=WCd=[FfM[LgMgLf]Wie1C<d=KKf<RbXB`Z;CM1@SP]<3Po@Cl3RY7o4_Wooo7o
oi7onM=AH6EjM7aMFfcnooOn9_o1f?kmooom/UIAGVamJ6acQN7kl?[Yjo_imo[n
o_WdoOGfoooin_ko0?kno`Wmn_WobY3AooSohOkiooWnnOoYoP?;2C[Go_lTl_Ki
oOoooO[hnO[jnOOdl>kio_oonoOgnO3joOSjooojn_KcmokoL__oj?ClYD5Sco_o
ooSmm>[iho;knOShk]oeg?;_mOoVnOO`i]kMhNS][]_`hMofn^OXi^K[lOCak>oa
l_;`kNSVl>[UiN[_l>oXjncWh=cMh>GVjN[[j^WXin?MfMSJgn;Sj>;ZY=[Yg]kL
fmWIfmcNg=gngQ;KfMOG/;[Kf<oFe]WKg=kNg=_InMHDfM?7/Y1R<Q<m=2da>C/a
9d];AclhTOlBnOoolOooTOoide5PIGYdO5eKK?komohVol7Ho_gooofbEU5NK7eX
K7>5hO_`n^W[noWgn_knnOCmmOKoooWjo_l0o_ko2OgjnOo:T=7on?oQo_WonOki
onWn0l/9>]OnobCbm_Wmooomn_Sin_[imoC`k_WnoookmoOil?[mn?[ooo[jm_?g
o_mbnooXm?bU@F??nooon?gdj_WSl__in?S^goGLl^oeonKimo3Vg]gQj>f^fo3Q
goKjinSVi^_am?7/ko7bl_3]j>K`j^GUj^o`knS[k>OPg=gPiNKYj^_ZjNSWhmgI
f=[Oh^?Xh^ZTf^WNg]cKfMWKg=kLgOkN4]_IemN`^]_HcmKFfM_Lg]kLfmWieQCI
dlNbT68b4cdd;C4i>c4WBd]7?cRAoa;ioooaoonAooWCDF1UNWAlGE]/o_ogoRKo
`MSnoOoooK9FDEi/OFQ/LhGQno3jjN_knOOjo_kim?gem_oonO[no`3no_l9oO[i
olZ@dOohon7nnOoio_WojOh3b`Tjeoko9?;fnOgooogjn?Wjn_Wgm?3^nOkooo_g
moW`n_ghn_oon_[floOnog;konSdo:E1HlokooohoOCZnN?bnoWhn>kOmMcbkoGo
i_Wgl>KNgN7XkJkKl>7Om_[Wj>KVjo7dlNc_lO;bl>gXi_3ZiNGZko3_j>_/in3L
gN3Ui^WZjn[Yj>OSgMWHf]oRhnSRjZCJjMkNg=_IfM_Lg]cMo]hBfmWGek2jfmS?
e]KIfmcNg]cKfOWF5=WCak:@HS8C?C@]<CTk<BM;BdLo>0>:TOlBkOoojOkoUooo
eeARIgYhQ5eKKOkomoh[ok_Soo_loonoHeeVKWi/M75neo?^oN_[noSfnOclmo;m
mOKoooWjoookmOcno`Sel?oo]UN^ooGQo_WonOkionWn3cTJi?oSom_om_Wlooon
noSmogomnOKcn_kooo_gmoW`n_ginooon_kgl_Gmooomon[og24UbOodlN;Eg^k/
h>?bno[inNgNmMcbkoGoi_Wjl^GKf=cUk;CTo>[UnOWQinGUjo7dlNc_lO?clNgX
iO?/i>;Xk_7bj>_/in3LgN3SiNSZk>c[jnOSgMWHf]oRi>SSl0fOf^[Ng]gKf][K
gMkLgOkN4]_Ien^m`^GQe=WJf]_Mg]kMfm[ifABUQ5D`8BHd?Rl]<Ci9A34O@D10
@TBAoa;]oooYo_nGoooGE69WNWR4GE]]o_ogoR_o^n?onocookmSGFI^OVadLGkG
lnkmjn_kn?Kio?cgl_gem_oonO[ooo_eo?ko2?G`oonfEjkomN7nnOoio_WojOh?
>A[Ton?ofoofnOcoookkn?goOogim_?jo_oonoOgnO3joOWkooojo_ObmOgooogo
j_oL8BG9ooCah]GNk^cPho;kn_WikMkeg?;_mOoVnO[biM_Hg>G/]>Clj^GinN7W
iNG[lOCak>oalo?akNSUlncTh^S^lO;XjncWh=cMh>?Uj>[/k>_[in?MfMSJgn;T
j>?`3IoJj]kNgM_Jf]_Mg]cMo]hBfmWGjkg2iN7DfM[JfmgNg]gKf_WI5:F4EC0Q
9S@n;bda?TU4<Am1@412A97o4^goonWnoiOoomMDHVMjN8AMFfgnooOn:onkhook
o?oo_f=MIVinK7AaO]Ock_g[jo_hm_Wlo?OboOGfoooin_oonoGlo_l8mO3ookIG
[_oehOkiooWnnOoYoPli6^CohooKooKio?ooo__hoOmooOWflo[noookmoOil?[m
nO_ooo[nmo;eoOoooOoZom`Q9LWom?7ReMk^k>3Sl__jnOW]g_GLl^oeonKin_;U
fmSLiNbdi?cZiOWihNOUiN_am?7/ko7clo7]j>Gck>CRj>kal^S[k>OPg=gPhnGX
j^c/jn_WhmgIf=[Oh^CXho0=Wm[Zg]kMfm[JfmgNg=gngQ;KfMO[_L;UhMCIf][K
gMkNgM_JnMTDYHAE<24V=3h_;C4nBD@a7d50@4940jR@oac/ooKPjlcaokiNHeb8
MW]BKSSoloooo_kmno[ko?ko9Woon_ogoonkA4mMJ5n=GEI6om[oooCYo_[hnOck
mO3bkO7moo_kooWn3_ohoooCRkGomOoakOoom>SonOkionWnOoooi_oolNma1mKo
l_omnOCin__kn_Sfm?Sko_ooo?Wfo?gno_gkn?Oco?oin_oon??bkn_^mognjoSo
:Q[Sbl_jj/>Wj^o3omkRi?ooioG<jmSXn^gZln[Xln_Eg?Omjn:mnO?TnnCjhNGZ
ko7akngalO;akncYinSWinS[k_;d7no`knSPg=kRkno^k>_Yj>SWhmgIf=_Oh^C/
jnFZ/?cYnMcigbc@b/_Df]K?bn3Ke]GGf=GAcM7Ig]JiTWDJ83@a83E8=c]0?cTj
?cLX<dQ5@eB@oac/ooKPjlcaokiNHeb8MW]BKSSoloooo_kmno[ko?ko9Woon_og
oonkA4mMJ5n=GEI6om[oooCYo_[hnOckmO3bkO7moo_kooWn3_ohoooCRkGomOoa
kOoom>SonOkionWnOoooi_oolNma1mKol_omnOCin__kn_Sfm?Sko_ooo?Wfo?gn
o_gkn?Oco?oin_oon??bkn_^mognjoSo:Q[Sbl_jj/>Wj^o3omkRi?ooioG<jmSX
n^gZln[Xln_Eg?Omjn:mnO?TnnCjhNGZko7akngalO;akncYinSWinS[k_;d7no`
knSPg=kRkno^k>_Yj>SWhmgIf=_Oh^C/jnFZ/?cYnMcigbc@b/_Df]K?bn3Ke]GG
f=GAcM7Ig]JiTWDJ83@a83E8=c]0?cTj?cLX<dQ5@eB@oac/ooKPjlcaokiNHeb8
MW]BKSSoloooo_kmno[ko?ko9Woon_ogoonkA4mMJ5n=GEI6om[oooCYo_[hnOck
mO3bkO7moo_kooWn3_ohoooCRkGomOoakOoom>SonOkionWnOoooi_oolNma1mKo
l_omnOCin__kn_Sfm?Sko_ooo?Wfo?gno_gkn?Oco?oin_oon??bkn_^mognjoSo
:Q[Sbl_jj/>Wj^o3omkRi?ooioG<jmSXn^gZln[Xln_Eg?Omjn:mnO?TnnCjhNGZ
ko7akngalO;akncYinSWinS[k_;d7no`knSPg=kRkno^k>_Yj>SWhmgIf=_Oh^C/
jnFZ/?cYnMcigbc@b/_Df]K?bn3Ke]GGf=GAcM7Ig]JiTWDJ83@a83E8=c]0?cTj
?cLX<dQ5@e@3YI3oA_KooOOCiOom_EiVHY:2RD]W?oo`nOoZooomo?gnooohM_o/
oo7ooKU;E5]WG8ADC6i/i?Kil?olnOOho?chlo?^l_kono_onOh?oo[jooWC/JKo
hoooiO;oi>WonOkionWn3=koonOoog4IB>colOonmVOin__lnoWfmOWko_ooo?Se
o?gno_gkn?Oco?oin_oon?Gdo_ool>omoom29[g]oo?okljIi^oCojNgb?gom?oO
l^3_ooCan_;momREVnGoonC1m?;UnNOhh^GZko7`kngalO;akncYiogX2n_^lO?_
l>oXh=cNh_k]5>c[jn[Zj>CNfMSKh>?@dm[]_:[Pc_WLnMl/g<g1a=;Oi^[HemSM
hN7Le_OYd:j3CAP0<C90>R@a@2db>C`j@DY5>3e;@Ce@T?m6m_ommm?UoofmGVIR
TX:9BfLooo3ion[ooogloOkoooQfoncolOom^D]DFfMLQ5A<KVcTm_W`oocimoSl
o?Sclnkbo_oknooioPoon_[onM>aY_oSoooUl_oTjOoio_WojOh<g_ooioooLAU8
k?oaookfIoWjnocknOKenO_noooln?GloOknoO_hmo?looWjooohmOCnooo`kogo
od8V_Ngoloo_cYWVkm?oYkO8oOodomobh>oom?7jl_gof9FKiOooi<7dl^GiioSR
iN[_lO3_kO7al_7_k>WWoNP;jnkalno`knSPg=kRo^dDk>_[j^[Xi=kIf=_Phm3C
f^flZ^3>nMcigbcLcL74d]oVj]SGf=gQhMcFmnW@[X==600a<T0j9350;C8i?3Y1
BTDh?D]1?E2@odKfooggdnGooKeNIV:BPXU;Icool?Woj_oooOcmo_oon7Kok?oa
oofiBeAKIeb4E4a^K>CfnO3oo?Wgn?cln??ck_;noo_kooWn3oojn_oidk6Von?o
onGbonCYooWnnOoYoPcNoooWooma6DS/oo7oo_IWnO[ko?_im_GinokooochmOcm
o_kmnoSgloconO[oooSem?kooo3_oOoo@RJmkOocono>VNK_donW]lSmooCogo;P
koodlO[boOoHUI_UoooT`OCbiOWWn>;Uj^oal>o]lO7blNo/jNOmj0_[k_7cko3_
j>3Lg^;nkAC/jn_Zj^STg]WHfn3Sd=?JkKbZh<kig?WO;=c=`LCBgnKZf=OHgN7Q
g=KgjM2^PddH034b@3XT<D0]<STl>T5:ACPmBd4mD0>RSolEo?koX_cookiNI62@
P8M8I5GooOoon_ko;?kmo_oolX3jmOofoojdF5eJJemnCTY:FHWogo_Yn_Odmo_m
noOeko?ooo_kooWn3_oon_KoolMb]_;oo_coo^SonOkionWn6OCoomgocB10XOol
lOo_l_Kjnocmo?WgmO[lo_m_o?Odo?gno_gkn?Oco?oin_oon>cXm?oli^WoolT0
K_o_oo3oln6<h_3Yo82G[^G]io_@mN;booKdo?CSl/5_MLkli^S7jo3Vm^gehnK[
ko7`k^calO;akncYinWYj>WZkO3bko3_j>3Lg^;Zj^_[k?k]3nSTg][Ig>3Tk>?V
onFhhNSigOWO;=cDc];MhMO:j^;HdmGIfmZ[Q4`P52A0E3hiAD4[=D4^<SXm?DA?
Bci9CS`gCXoo5Ocnoj;loonnGVAPT827B6AEoogooo[nobcnoOkooo:0n_Gom_on
]5QMFV]OOTi:BUV9omokjO[gm?OkoO_gmNocoooknooioPkooo[fooo7L[Kbookl
ookXooWnnOoYoQWdoooMoldP@:7oo?7oko;fn__loOcimoGjo?koKocgm?cmo_km
noSgloconO[oooS/j?Coo>KYooo906kokoo`oo?QS>;`jOb0UjkUkNOkd?GRl_of
m?cdho;1KgG>o>KXan_`i_K]mN?Vjnoal>k/lO7blNo/jNOYjNSYj^g`l^o`knSP
g=kRj^[[jncnk@oXi=kJfMcPi>cSi_oU^>7XnMgigbcLe<kBgN7Gb^[Rf=?EfM_J
ZhA<81@T@5@n>DE1:cE1;S8j?Ce4Cd/nBDhl=dj?oaGlo_nRo?oo_UiTH920QdQT
EOomooojo_l/o_gnooobP?[eooKoo[AHGEY[Ggi>BTYIROoOnnWjmoCgnogkmoG_
looono_onOh>ooojm_ooag:fl_ono?onj?oio_WojOhIm?oogOo=842Qoocaonob
m_[ko?glnOOen_cnofolmoCloOknoO_hmo?looWjooohk>SdoocVjOoob@1^onoo
l?ochHcRl>WlP9N^iNgWnm3eh_;om_Clm>?b`Fmec_cVj<O[l>KfkOGSi^__lO3^
k?7al_7_k>WWjNWXjN[]l?;_l>oXh=cNh^[Zjn_/o^d?j>CNf]WLh>C/hnKoiKSQ
j?WMnMl/g=C>d]gQel[Zh]SCeMWKfZ^4C20D941D?SU5@B/e@Bhb>SdmA4m;?TU>
?3M>0jRAo`Gkonciog3no`_1GEiFPW5g@E=IjnkmobkmnoWhnO[kg8[looo]ooZP
GF5DL6IlCeDVcg7Em_WHnOGbmO[noO_glOGooo_kooWn3_CoooOloo6mAn;omOoo
m>SonOkionWn6Ooob_oo<C[1hOobm_o[l?7ko?gmo?[hm__mo_monoKco?gno_gk
n?Oco?oin_oon>[Zi^C[n?oo]QmLhoWjln?omOJAgoCfk<;Egooom_oFlMk^oo;`
n?3Xo_7;dOkok>k?gnkXlOG`i>O/ko3_kN_alO;akncYin_ZjNWZkNoako3_j>3L
g^;Xj>W[k>k_knWUgm_JgN7Uk=_>llH2OJSFnMkigbcIeLk<en3IbM7OlOSU]WeE
;bh];S8g>S/g;C]1<ce;?3U0@Ci2BT@fDE4i=U>Ao`Gkonciog3no`_1GEiFPW5g
@E=IjnkmobkmnoWhnO[kg8[looo]ooZPGF5DL6IlCeDVcg7Em_WHnOGbmO[noO_g
lOGooo_kooWn3_CoooOloo6mAn;omOoom>SonOkionWn6Ooob_oo<C[1hOobm_o[
l?7ko?gmo?[hm__mo_monoKco?gno_gkn?Oco?oin_oon>[Zi^C[n?oo]QmLhoWj
ln?omOJAgoCfk<;Egooom_oFlMk^oo;`n?3Xo_7;dOkok>k?gnkXlOG`i>O/ko3_
kN_alO;akncYin_ZjNWZkNoako3_j>3Lg^;Xj>W[k>k_knWUgm_JgN7Uk=_>llH2
OJSFnMkigbcIeLk<en3IbM7OlOSU]WeE;bh];S8g>S/g;C]1<ce;?3U0@Ci2BT@f
DE4i=U>Ao`Gkonciog3no`_1GEiFPW5g@E=IjnkmobkmnoWhnO[kg8[looo]ooZP
GF5DL6IlCeDVcg7Em_WHnOGbmO[noO_glOGooo_kooWn3_CoooOloo6mAn;omOoo
m>SonOkionWn6Ooob_oo<C[1hOobm_o[l?7ko?gmo?[hm__mo_monoKco?gno_gk
n?Oco?oin_oon>[Zi^C[n?oo]QmLhoWjln?omOJAgoCfk<;Egooom_oFlMk^oo;`
n?3Xo_7;dOkok>k?gnkXlOG`i>O/ko3_kN_alO;akncYin_ZjNWZkNoako3_j>3L
g^;Xj>W[k>k_knWUgm_JgN7Uk=_>llH2OJSFnMkigbcIeLk<en3IbM7OlOSU]WeE
;bh];S8g>S/g;C]1<ce;?3U0@Ci2BT@fDE4i=U<3UY7o5o_oioWoGoogol1KG5>1
LWU`Kg[IfNOfmoWo9lfOooolhoohOEIJA6iXMTeQA^KTN^_`n__fl_?ioOkln_Cg
oooknooioP3go_l;n?goojJHjoofloobjOoio_WojOhAn?choj/>N_7honcoongc
jocmo_h4noWgoOknocgjmO;loOknoO_hmo?looWjooohl_odhOOoolde2]_ohooU
n_CdojcFn?CQjoSbooK_olkag^kol_3hl?;am_ko@O_flmSCjn[]oN_Vj>c`l>k[
jO7al_7_k>WWk>_ZjN[/k^o_l>oXh=cNh^SXjN_/k^o_j^KPg=_Nh^KZi=;//DAN
X_7O;=WFa[W6i?Kfi=>fU79?<1`S;Si7A3PY7c<S<3he?T]0=cho>d17@C=BDSdk
Fi7o5o_oioWoGoogol1KG5>1LWU`Kg[IfNOfmoWo9lfOooolhoohOEIJA6iXMTeQ
A^KTN^_`n__fl_?ioOkln_CgoooknooioP3go_l;n?goojJHjoofloobjOoio_Wo
jOhAn?choj/>N_7honcoongcjocmo_h4noWgoOknocgjmO;loOknoO_hmo?looWj
ooohl_odhOOoolde2]_ohooUn_CdojcFn?CQjoSbooK_olkag^kol_3hl?;am_ko
@O_flmSCjn[]oN_Vj>c`l>k[jO7al_7_k>WWk>_ZjN[/k^o_l>oXh=cNh^SXjN_/
k^o_j^KPg=_Nh^KZi=;//DANX_7O;=WFa[W6i?Kfi=>fU79?<1`S;Si7A3PY7c<S
<3he?T]0=cho>d17@C=BDSdkFi7o5o_oioWoGoogol1KG5>1LWU`Kg[IfNOfmoWo
9lfOooolhoohOEIJA6iXMTeQA^KTN^_`n__fl_?ioOkln_CgoooknooioP3go_l;
n?goojJHjoofloobjOoio_WojOhAn?choj/>N_7honcoongcjocmo_h4noWgoOkn
ocgjmO;loOknoO_hmo?looWjooohl_odhOOoolde2]_ohooUn_CdojcFn?CQjoSb
ooK_olkag^kol_3hl?;am_ko@O_flmSCjn[]oN_Vj>c`l>k[jO7al_7_k>WWk>_Z
jN[/k^o_l>oXh=cNh^SXjN_/k^o_j^KPg=_Nh^KZi=;//DANX_7O;=WFa[W6i?Kf
i=>fU79?<1`S;Si7A3PY7c<S<3he?T]0=cho>d17@C=BDSdkF`>XTOm7o?o]oomi
ooWm^UMLFHf3SDhhA6ePHVabPh5nNgYiNWYC=X:UL5^2L5i?DcE[JW19HTg1oieR
lOoonO;bmo_mo?cfn?oono[onOh2ooWgo_l8o_ooZYS/ooKfj?oio_WojOhHm?oo
TaYe^n_co^ooononj_gnooono?[ho_koL?kim?3loOknoO_hmo?looWjooohkOkl
looo`68/_?W`oooPon[eom72mnSSh>oVl^KYoloeh_;om_Clm?KGbmcRf>7jnN38
j>cYonKWj^g`l>kZj?7al_7_k>WWkNc[jN[[kNk_l>oXh=cNh^[Zjn_/o^d?jnOQ
gMcOhnO[nNWob44jMoWPnMl/cN;Xe/_<`k2ONdHM3aX_?c@a:bHY=d]J?2D^?SDg
@CL_=cXi@D]7>diDADAPTOm7o?o]oomiooWm^UMLFHf3SDhhA6ePHVabPh5nNgYi
NWYC=X:UL5^2L5i?DcE[JW19HTg1oieRlOoonO;bmo_mo?cfn?oono[onOh2ooWg
o_l8o_ooZYS/ooKfj?oio_WojOhHm?ooTaYe^n_co^ooononj_gnooono?[ho_ko
L?kim?3loOknoO_hmo?looWjooohkOkllooo`68/_?W`oooPon[eom72mnSSh>oV
l^KYoloeh_;om_Clm?KGbmcRf>7jnN38j>cYonKWj^g`l>kZj?7al_7_k>WWkNc[
jN[[kNk_l>oXh=cNh^[Zjn_/o^d?jnOQgMcOhnO[nNWob44jMoWPnMl/cN;Xe/_<
`k2ONdHM3aX_?c@a:bHY=d]J?2D^?SDg@CL_=cXi@D]7>diDADAPTOm7o?o]oomi
ooWm^UMLFHf3SDhhA6ePHVabPh5nNgYiNWYC=X:UL5^2L5i?DcE[JW19HTg1oieR
lOoonO;bmo_mo?cfn?oono[onOh2ooWgo_l8o_ooZYS/ooKfj?oio_WojOhHm?oo
TaYe^n_co^ooononj_gnooono?[ho_koL?kim?3loOknoO_hmo?looWjooohkOkl
looo`68/_?W`oooPon[eom72mnSSh>oVl^KYoloeh_;om_Clm?KGbmcRf>7jnN38
j>cYonKWj^g`l>kZj?7al_7_k>WWkNc[jN[[kNk_l>oXh=cNh^[Zjn_/o^d?jnOQ
gMcOhnO[nNWob44jMoWPnMl/cN;Xe/_<`k2ONdHM3aX_?c@a:bHY=d]J?2D^?SDg
@CL_=cXi@D]7>diDADAP0j:AodOfoo7omJGoooVfDeUHSXJBPfAkQWMeOHJ3PGij
N7MhN7IAMIeWHHY/Ee]N>7EeM4mGC]?SoD>ijOolm?7enO[jo_Ojoooln_oioPko
ooWnooonm_onWX_`on_XooWnnOoYoQ3onlHN;m[cm^[ln_ool?o_o_go0_gknOgo
JokilnoloOknoO_hmo?looWjooohlNS^ooo6I1RKooGNonoQlnWhm^nUlMWajOki
oocoon?bh>oom?7jl_o_g^3VjoWooNJoinkVon;Xj^k`l>gYio7al_7_k>WWk^g[
j^WZk>g_l>oXh=cNh_k]5>c[jn[Zk>SRgMcOi>ODjM7]dEQ1L?WQnMl/b^[abIYj
FS`>6bm3C4@`7bThB4i4=2LQABL^@CLf?C<e?ClmA4e8>dUGCTaOTOm7m_oaooFU
oooi]U=IF8j6TX=TNhIgMGf6Ph5nNWQgN7QfDGFMIf6:K5MKGSQeMGA?EdkChoe3
^NWoo?CamOWjn_kgn_ooo?[onOh>oooio_ooo_KooYj;l?o[j?oio_WojOh@oo_6
7RoJloKZo?[ooo3okokmo`;mnoWmof_nnO?_o?gno_gkn?Oco?oin_oon?7Xk_oo
aV@HVooeg_o_hO?Yn?K_YO7IlNWnnOoloooSl^3_ooCan_;okmkPi^_ioogV_nO^
i_oRj>[^l?3]jNOalO;akncYink]jn[Yj^c]ko3_j>3Lg^;nkAC/jn_Zj^cXh]gL
gnCWe>WAkM5H@G3ihOWO;<[ZlLVJNUXl3Q/_@da4<1lY>4Q>A3@W8DDW;T4g=Sdc
=Cdo?DA=B3]9Edi<Gi7oAoKolOoeYOoonKICFER>QY:3I7^6MgEmQX>1OWYhMgQh
MU5eWFMQRVaGFehhMGEdCeM>dn?m@kWYoocdlOGin_[nmo[ooocjooWn3_oonOko
ookfoojNRo3ojnSonOkionWn4?okaQh_f_?fj_cjooo`ononoOl2oO_ioOm[o_Wc
kocmo_kmnoSgloconO[oooSaj>koolIT69_omMkokn7cjOSfkjGafO7Yo_Woo?oo
ho;PkoodlO[bonoNh>K[nOomi[oWk^Koh^SZk_3`kNWWlO7blNo/jNO^kN_ZjN[/
kNo`knSPg=kRo^dDk>_[j^[/j>;Mg=oTimCYdNgAF45`nN7igbc:j_79VWYJ?0hK
;d=<A30O:CQ8CT@d9b559bi1=cHm<cDm?ce4CDPkBEM>C5l3YI7oAn[okooW`ogo
nkIAE524NXE^D7IlMWR3T8j<R8F2PH:2TUmSSUiUSfIOKVm3Q8=nFD^0m_coee?E
ookelOChnOSnn?[ooocjooWno_l1n?7no`O/oon;Inooc^WonOkionWn2?oO7SCH
ooomi_ko1?O_ooGnoOl2oO_ioOmoo_Sbkocmo_kmnoSgloconO[oooSogn;oniLh
5?GloNk/m?;cjoc/oho/coo=i^C^h^Ce]n_Hj?[]j_?ZhN_[hnWgm>GojK[VknCo
h>W[k_3`kNWVlO7blNo/jNO_k^_ZjN[/kNo`knSPg=kRkno^k>_Yj>S]j>;NgN3T
j>kmeO<3nIj=^OWQnMl/g>G1L30S:2M2>cDd>Cm2@T0n>2dU:CQ5A2@/@S`j@SY5
BdU3ADU1<TIJE4mLTOm7j_o_onO3oOok]U5DD8AjQFi@MWafN8>@SXb8QH:1PX:B
Gf>>GVF?IUm^Kd>4PgiIBh3fo?oGDmGoo_Gam?Sin?khn_ooo?[onOkno`7hlOko
1ncooh]Wkoo>jOoio_WojOh8omlN==SooogVo_l4mnoomOkmo`;mnoWmogonn?;_
o?gno_gkn?Oco?oin_oon?oOh_okUcPDmOcmk^cdl_?[o>coSnc?olgVi>kRi?Fg
jmSXn^gZln[Qjn_SjOOdiOoY^^K_i?oPjN_^l?3]jNKalO;akncYino^jn[Yj^c]
ko3_j>3Lg^;_knk/jnWXj>gXh]kMh>CXk_gEl`?iWXfinN7igbcLiL5`<2<X9d8k
=C@i?d92@3hh;BDY>4E492a2?3Y2>TE;BD=5BD4bAUYDCebAodOZonooil?moo^f
DEA@Q7Z5KU1fO7IhPi2>S8R5PX62PY9OHhiNIHmVGfi_@hB3OUU;P?KlomMCeOon
mO7dn?Who_Sjoooln_oio_ko0OSao_l7k?ooRfO_olkYooWnnOoYoPSogahdf?oo
oNKno`Cgkooeo_go0_gknOgoOokhl^oloOknoO_hmo?looWjooohomoRoo^G>1Ce
o?g^k?Cbln_lk?n?k<oocNKTk^;TmKO[f>SjkN[cj^7[jn?YmoCUonVji^oTon3Y
jnk`l>gYi_7al_7_k>WWknk[j^WZk>g_l>oXh=cNh^o_k^c[jNSXkNSRg]gPi>S^
oMGc0oVNSKWihOWO;=cU`G0`8bPW@S/e=3To@T90?SP]9BThAD@T;48l>T8jAD]9
@dE9@C96FUA?G0?`T?m>l?oodMKomOfP@VEITh1hFee/P8EiL721Ohj7JG6;R6iO
Kg]YJh>9MU]QBG=RL5aOAmGioo;CN>cSonSoongon_?do?ggmoooo__in_goooWn
3o;oom^WZN;onO[loOcloooio^WolOhGonkjooOoomgo@CGBoo7monojoOWiooca
o_L6n?SinO[lo_ko1?[fl_cmoOl6oOc^onkogogo3nSRomDZ5[Shl^odno_aioCn
ogo9Z=ghjo_nloGom=_hi?7ol_3jlngZiN;Sj>kbhoo<e^?ofo7[kO7cl^o[jOCd
mOCbkncZm_3YjNkemoO`k>SVi^GQgNW/lOCdlNcYkNWTh>3TjNgMn]S?nMF/gMKK
hnSWh=SAf^?Oe=k_hlEhE2dN:S/n>SXe>4=6?cm7?TI;B1Pn=SDg=CDk@3T`=THd
>4a:<C@j9CQ@BD5HT?m>l?oodMKomOfP@VEITh1hFee/P8EiL721Ohj7JG6;R6iO
Kg]YJh>9MU]QBG=RL5aOAmGioo;CN>cSonSoongon_?do?ggmoooo__in_goooWn
3o;oom^WZN;onO[loOcloooio^WolOhGonkjooOoomgo@CGBoo7monojoOWiooca
o_L6n?SinO[lo_ko1?[fl_cmoOl6oOc^onkogogo3nSRomDZ5[Shl^odno_aioCn
ogo9Z=ghjo_nloGom=_hi?7ol_3jlngZiN;Sj>kbhoo<e^?ofo7[kO7cl^o[jOCd
mOCbkncZm_3YjNkemoO`k>SVi^GQgNW/lOCdlNcYkNWTh>3TjNgMn]S?nMF/gMKK
hnSWh=SAf^?Oe=k_hlEhE2dN:S/n>SXe>4=6?cm7?TI;B1Pn=SDg=CDk@3T`=THd
>4a:<C@j9CQ@BD5HT?m>l?oodMKomOfP@VEITh1hFee/P8EiL721Ohj7JG6;R6iO
Kg]YJh>9MU]QBG=RL5aOAmGioo;CN>cSonSoongon_?do?ggmoooo__in_goooWn
3o;oom^WZN;onO[loOcloooio^WolOhGonkjooOoomgo@CGBoo7monojoOWiooca
o_L6n?SinO[lo_ko1?[fl_cmoOl6oOc^onkogogo3nSRomDZ5[Shl^odno_aioCn
ogo9Z=ghjo_nloGom=_hi?7ol_3jlngZiN;Sj>kbhoo<e^?ofo7[kO7cl^o[jOCd
mOCbkncZm_3YjNkemoO`k>SVi^GQgNW/lOCdlNcYkNWTh>3TjNgMn]S?nMF/gMKK
hnSWh=SAf^?Oe=k_hlEhE2dN:S/n>SXe>4=6?cm7?TI;B1Pn=SDg=CDk@3T`=THd
>4a:<C@j9CQ@BD5H0mj@odGgooo4gooiojY=IEN:P7a;GGbDTX5lPg=`PH5/N9BD
MVMhPVe/P8A`FF=AO6M`Ee54f_conobnLOnhoogln_olmOGnooSin?oioPoonooo
j[c4lOoil_oonoGonOkYoo7n6OSoooGnm^ooS4N;ooofoN[ao?ojnoomlogmoO`3
no_lo_koOo[fl__mo_ooo_gkm_omooWok>ggi_oG22gNn?[dl?Glo??Yjoool>j@
iOO[nokcmOodfo_Wm?oflogflNgYi^O[lOGWomW?j?oUl>?Wk?7dm?;am?Cem?;_
k>[Zj>OZko7^j^o/jNOVi>3Nl>o^kNg^ko3^j^GPh>?XjnOoh]Sh?ljN`^KPem?F
hNgfenG_k=R]K3E1=S0gA4Pm<3/e=d53?3a3=ce3@3Tb<SDj=ca4@SPj@c`oDe8l
@TTdC65EAeN@odGgooo4gooiojY=IEN:P7a;GGbDTX5lPg=`PH5/N9BDMVMhPVe/
P8A`FF=AO6M`Ee54f_conobnLOnhoogln_olmOGnooSin?oioPoonoooj[c4lOoi
l_oonoGonOkYoo7n6OSoooGnm^ooS4N;ooofoN[ao?ojnoomlogmoO`3no_lo_ko
Oo[fl__mo_ooo_gkm_omooWok>ggi_oG22gNn?[dl?Glo??Yjoool>j@iOO[nokc
mOodfo_Wm?oflogflNgYi^O[lOGWomW?j?oUl>?Wk?7dm?;am?Cem?;_k>[Zj>OZ
ko7^j^o/jNOVi>3Nl>o^kNg^ko3^j^GPh>?XjnOoh]Sh?ljN`^KPem?FhNgfenG_
k=R]K3E1=S0gA4Pm<3/e=d53?3a3=ce3@3Tb<SDj=ca4@SPj@c`oDe8l@TTdC65E
AeN@odGgooo4gooiojY=IEN:P7a;GGbDTX5lPg=`PH5/N9BDMVMhPVe/P8A`FF=A
O6M`Ee54f_conobnLOnhoogln_olmOGnooSin?oioPoonoooj[c4lOoil_oonoGo
nOkYoo7n6OSoooGnm^ooS4N;ooofoN[ao?ojnoomlogmoO`3no_lo_koOo[fl__m
o_ooo_gkm_omooWok>ggi_oG22gNn?[dl?Glo??Yjoool>j@iOO[nokcmOodfo_W
m?oflogflNgYi^O[lOGWomW?j?oUl>?Wk?7dm?;am?Cem?;_k>[Zj>OZko7^j^o/
jNOVi>3Nl>o^kNg^ko3^j^GPh>?XjnOoh]Sh?ljN`^KPem?FhNgfenG_k=R]K3E1
=S0gA4Pm<3/e=d53?3a3=ce3@3Tb<SDj=ca4@SPj@c`oDe8l@TTdC65EAeL3kHoo
B_Go/NgloonZEf9IQHf>AEamTHYnR9f5NH>2JFf1Ogi`P8YbK7amKEQVF8E_LeE;
A=kkmo[oniAIlOWof_o`o?Geo_ohnOocmOSko_konOh9oo?goooQ]J;Tm_ko0O[k
n?kYoo7n8OoSoooMoonL353EooOjonceooomoOonm?oooOcjnOSgo?knogojm_;k
o?koooklnoool?odooKoi?o5>3^bn?Knmo;foOkfk>glomooTm_ojo_nloGom=_n
jOOon?Kon?C`k>WZkoGikOc/aNgdmNkWj^kblo;_kOCdmOCbkncZi^KYkoCcjnC]
kN_XiN;PgoGak>SXk?7el>cVhMoRi^WPnNGRocoN//OZi^7LfmcOhOg<Sf94<Rle
7bLeADi9>B`l=CDm?SHf?S@i?Cdi=cLj?SLkB4a3?3hm?U9D@TaE?dIJCCa:Som:
mOnakOcoojYGHUV5SHi5G7fARWj8WHEiPh9YKH5oOW20RW9/O7e]F6IHQFmcED]4
g__gn_okU5WanOoJoo3lmOGnooSioo?en?_no_oioPWoloOoon6eX^Cfo_l1n__h
o^WolOhQon?oomgooi`<D=Gomo[ok?Gooogmookdooomo?[in?Olo_koOo[fl__l
o_ooo_ckooo`ooCom_oTolDh>k;hm_kgl_Kmo_K/kOcogonCfoo[nokcmOodfokY
moohm_ohm?3/jN[_mOW]o>c5kOCek^OZk_;cl^o]m?Cem?;_k>[Vi^W_m??[i>g]
jnSUh^3OmO7/j>S/lOG`k>KQgn;VjN3iiN;o?mjban[VhMcKg=oQoLb?HT@b;cDO
9cE5CTTi;3`e=Cdn=SHn=3Tm?CTg=cXn=c]8C4<l?SdnDUA2C5DoAUY=?4Z?od[e
ok7]o?ooZUMRFHF=STELOI6:OXRMQGV3PVU]PGmnL82:LValOFeHIUR5Kg=EBdCN
noOjoo^DFO7iom[ol?cemOkon?WoloGhnoknooWn2OocmooohKFRi?Kno`7jnoSn
jOoaoR7ohooogOooW0a@eOogn_o/mOoooOgoo_Cooogln_Whmocno_mon_Kbnocn
ooono?_ooo3om?ofonCoaCPk/_Sfo_Obm_gnm^c]o?oOoi?Kon_ko_?eooCKo^Wg
ooSfooSdl>cYj^oenNglk<G]m?G^in[^l_?bkngdm?Gdl^o/j^KVjNodln_TkNg[
j>GRh=oelNcXj>camO3/i^7Oh^KYh?WUh_log[;7j^KQg=_Lgn7mc8mRA38_=AlW
=DE>BCT/?3De?Chf=Shd>Cdm>CLg>Shg>dQ<@c`n?CiBE49<ECm6FTdlBP?`Som=
jonSn?cooZ1KGF:8XZI@FV]hMWF9Xi=mP85YIWA`Og21Rg9[NWYcFVEGR7IjGEE7
g?S_kooohD6ZomWoi_gil_;ko?Gfo^W]l_Ojn_SgnOh<k?oolOkofH62hoooj?ko
nOkYoo7n4?oNn?ohomHB=iKoonKjoo_ho_l=o_oom?kmnoWfm?;ao?knogojm_;j
nogno_gkn_Gel_cbm__oooD[1o3o^]oonO?fo_ohl?kcon7ob:_ojo_nloGom=_l
j?GomoCnmo?`jnWZk_Chl_Kl`>[Wongcm?GdlN_UhOCdmOCbkncZl>k_loOglN_/
kNgYi>3PhO;`kN_[kO3blNgVhMoQiNSLkN7QnCoT`LO4d^GblN7;_85I>cH_8BHi
;S@m@3hj=C<m=C<j>C8b>cPk?Sm0@D94?SDgB558?3Lf=DQ;?DYD?SQ>@cI8Som=
jonSn?cooZ1KGF:8XZI@FV]hMWF9Xi=mP85YIWA`Og21Rg9[NWYcFVEGR7IjGEE7
g?S_kooohD6ZomWoi_gil_;ko?Gfo^W]l_Ojn_SgnOh<k?oolOkofH62hoooj?ko
nOkYoo7n4?oNn?ohomHB=iKoonKjoo_ho_l=o_oom?kmnoWfm?;ao?knogojm_;j
nogno_gkn_Gel_cbm__oooD[1o3o^]oonO?fo_ohl?kcon7ob:_ojo_nloGom=_l
j?GomoCnmo?`jnWZk_Chl_Kl`>[Wongcm?GdlN_UhOCdmOCbkncZl>k_loOglN_/
kNgYi>3PhO;`kN_[kO3blNgVhMoQiNSLkN7QnCoT`LO4d^GblN7;_85I>cH_8BHi
;S@m@3hj=C<m=C<j>C8b>cPk?Sm0@D94?SDgB558?3Lf=DQ;?DYD?SQ>@cI8Som=
jonSn?cooZ1KGF:8XZI@FV]hMWF9Xi=mP85YIWA`Og21Rg9[NWYcFVEGR7IjGEE7
g?S_kooohD6ZomWoi_gil_;ko?Gfo^W]l_Ojn_SgnOh<k?oolOkofH62hoooj?ko
nOkYoo7n4?oNn?ohomHB=iKoonKjoo_ho_l=o_oom?kmnoWfm?;ao?knogojm_;j
nogno_gkn_Gel_cbm__oooD[1o3o^]oonO?fo_ohl?kcon7ob:_ojo_nloGom=_l
j?GomoCnmo?`jnWZk_Chl_Kl`>[Wongcm?GdlN_UhOCdmOCbkncZl>k_loOglN_/
kNgYi>3PhO;`kN_[kO3blNgVhMoQiNSLkN7QnCoT`LO4d^GblN7;_85I>cH_8BHi
;S@m@3hj=C<m=C<j>C8b>cPk?Sm0@D94?SDgB558?3Lf=DQ;?DYD?SQ>@cI80nN?
odSYoj3mooolW6ALL8RZZ5UIHgAkNGn;QfU^O71bP7ilKGf6KVUjNgiNHU:7NhAY
HdSGn_Oaoo;UoeJ^ooOMooG^koOhl_;jl_KkoOohoPklooo]o?oo_Wfnm_onoooh
o^WolOh@ioo_i?o6;DC>looolooomOWno`gnookcooonnoWgmOClo_ko3?[fl_Wj
o?gmo?[ij?Onogodm_?oF3V_lOSjk_ojloGlooWaon?ojnWoLOo[nokcmOodfoWU
l_oclO_clNkYi^O/l_Kcloo2f^3ojo?dmOCajnGQm?Cem?;_k>[ilnc[ko?clN[^
kn_RgMoSjng`l_;`kN_`k>KQgn;Vj^W^i>3Zg/6eoOS/e;25GdPS6RI5CRlm=Clg
?D91>SDe>3hd<SLf<38k>CPi?414ATHl<SE5CTDi=CLb@D@jB58j?UA:?e:?odSY
oj3mooolW6ALL8RZZ5UIHgAkNGn;QfU^O71bP7ilKGf6KVUjNgiNHU:7NhAYHdSG
n_Oaoo;UoeJ^ooOMooG^koOhl_;jl_KkoOohoPklooo]o?oo_Wfnm_onoooho^Wo
lOh@ioo_i?o6;DC>looolooomOWno`gnookcooonnoWgmOClo_ko3?[fl_Wjo?gm
o?[ij?Onogodm_?oF3V_lOSjk_ojloGlooWaon?ojnWoLOo[nokcmOodfoWUl_oc
lO_clNkYi^O/l_Kcloo2f^3ojo?dmOCajnGQm?Cem?;_k>[ilnc[ko?clN[^kn_R
gMoSjng`l_;`kN_`k>KQgn;Vj^W^i>3Zg/6eoOS/e;25GdPS6RI5CRlm=Clg?D91
>SDe>3hd<SLf<38k>CPi?414ATHl<SE5CTDi=CLb@D@jB58j?UA:?e:?odSYoj3m
ooolW6ALL8RZZ5UIHgAkNGn;QfU^O71bP7ilKGf6KVUjNgiNHU:7NhAYHdSGn_Oa
oo;UoeJ^ooOMooG^koOhl_;jl_KkoOohoPklooo]o?oo_Wfnm_onoooho^WolOh@
ioo_i?o6;DC>looolooomOWno`gnookcooonnoWgmOClo_ko3?[fl_Wjo?gmo?[i
j?Onogodm_?oF3V_lOSjk_ojloGlooWaon?ojnWoLOo[nokcmOodfoWUl_oclO_c
lNkYi^O/l_Kcloo2f^3ojo?dmOCajnGQm?Cem?;_k>[ilnc[ko?clN[^kn_RgMoS
jng`l_;`kN_`k>KQgn;Vj^W^i>3Zg/6eoOS/e;25GdPS6RI5CRlm=Clg?D91>SDe
>3hd<SLf<38k>CPi?414ATHl<SE5CTDi=CLb@D@jB58j?UA:?e83l8ooCO7lZ__o
nonMKen0QZBBFEe_Qi23MgFDKFanM75kMh5`O89YIWUmQ65QDHV1S75XAM?oooco
l_ooaU_kkOoam^k_n?Wblo_fmoWko?ckn_Wn3oojkokono[ofk2bkooom?Wio^Wo
lOh0joko1lhe8/Soo_Sjo_l8loWoookloo_`oOl5o_ckn_cno_mon_Kbn?Wko?ck
nOSfnooCkOcooFh>UooTg?oRooW`lOWln?7ofoobb_mZin_ko_?eooCKmn?`oo;`
nO;akNWVin_amO7eolc0h?oZin[^l_?bkngdm?Gdl^o/j_O_i^?Vjng]j>kbk>7K
gnGXk?7emO7/j>cYhn3Pi>W]k>c]k_4ok]Jfj<ZIICXO5157=BDQ8RPhBbLc@DY8
@3Lc?S@`=SHa=D0f<S0c>T12@C/d=dE9@3Tk@CU3AC]:DSLnDTDfAHooCO7lZ__o
nonMKen0QZBBFEe_Qi23MgFDKFanM75kMh5`O89YIWUmQ65QDHV1S75XAM?oooco
l_ooaU_kkOoam^k_n?Wblo_fmoWko?ckn_Wn3oojkokono[ofk2bkooom?Wio^Wo
lOh0joko1lhe8/Soo_Sjo_l8loWoookloo_`oOl5o_ckn_cno_mon_Kbn?Wko?ck
nOSfnooCkOcooFh>UooTg?oRooW`lOWln?7ofoobb_mZin_ko_?eooCKmn?`oo;`
nO;akNWVin_amO7eolc0h?oZin[^l_?bkngdm?Gdl^o/j_O_i^?Vjng]j>kbk>7K
gnGXk?7emO7/j>cYhn3Pi>W]k>c]k_4ok]Jfj<ZIICXO5157=BDQ8RPhBbLc@DY8
@3Lc?S@`=SHa=D0f<S0c>T12@C/d=dE9@3Tk@CU3AC]:DSLnDTDfAHooCO7lZ__o
nonMKen0QZBBFEe_Qi23MgFDKFanM75kMh5`O89YIWUmQ65QDHV1S75XAM?oooco
l_ooaU_kkOoam^k_n?Wblo_fmoWko?ckn_Wn3oojkokono[ofk2bkooom?Wio^Wo
lOh0joko1lhe8/Soo_Sjo_l8loWoookloo_`oOl5o_ckn_cno_mon_Kbn?Wko?ck
nOSfnooCkOcooFh>UooTg?oRooW`lOWln?7ofoobb_mZin_ko_?eooCKmn?`oo;`
nO;akNWVin_amO7eolc0h?oZin[^l_?bkngdm?Gdl^o/j_O_i^?Vjng]j>kbk>7K
gnGXk?7emO7/j>cYhn3Pi>W]k>c]k_4ok]Jfj<ZIICXO5157=BDQ8RPhBbLc@DY8
@3Lc?S@`=SHa=D0f<S0c>T12@C/d=dE9@3Tk@CU3AC]:DSLnDTDfA@?cT?m>oOg^
^_Com?nFLV2BRj>1H6IgQhIjNH:VMFj1N6ibK95kPH9VHgUnPEmSF9>9SfmV@m?o
ooOon_oRon1Kn=Gono?doOkgn?oin?Kdlo?dmOWn3oo/j_ooj^goomV[]Mcfn_Ki
o^WolOhIomgokS/c`_GRk^[_ooomnoSooocioOS]n_[nnOkh0Ocno_mon_KbmoSj
no_jn?Ooo>jZhOoo^P]af_ooo>KLooO^k_Gim_3ojoOheonZaN_ko_?eooCKn^Kc
ooCbo?Gdl>cYj^oenNghm]ZUi?oYhnO/lOCdl_7dm?Gdl^o/j_?^jNW/kN[Wi^kc
kN3Jg^O]k^o`l>o^kNSUhMoQi^gaj^OalnLog;R0A3PW7Al_@e4_>d0i<c0V6RD]
>DA8@SL^?S<`=SLd>THj=2la>T51?cdj?dQ5?3e6BSi5A3Y8CC4_@S<R;Y3oC_gm
k[[dooCoUW9PTX^SPF1VMhN6NWV2YWE^PGQ^LVbANh62IV=iOX5OHeRCRHm_IT?C
ooogoo[oh_oPFoSEoo_cm?gnmoSonOSfm??cm?GioPook>[oon[]oooIZkGLm_[f
nOkYoo7n6OoMonhk<l;eh^kZkooooO_hooolnOghkO[jo_Wnn07lo_koOo[fl_Oh
n__kn_Sgooc^Z^7ookX;LM[ooocVg?ogk^kenOK`on_gn=OoZ/G[nokcmOodfo[V
loodl_cem?3/jN[_mOW]n?KJYNCojN?Wk?7dm?;am?Cem?;_k>[ck^WYk>gZinK^
lngPf]kWkNk_l?3_k^gXiN7OhNK]lN[WlO?W?mbhP4@h9adO;d=A;c]0>C<`9QXU
;CU4B48g;Shc<3Hg=3Y6>S@_<CY1@Clm>Sm8AC`mATXnAD@jB4da;d8c8Rj@odkm
oNjjm?odoiIbH9:;Xh5PIWN7QWYiPZIeKX5hKW9/TG^1PVISNGj1Gf=HThV?KfI3
dooomoojon;oh5_heOokloCmo_OhooWhm_CcloCenOh?oncZoooZkOoofJ^eg?Kj
m_WnjOoaoQWogOo^>c?2mN;^j^oooogkn?ooo?Wmn>gjn_kio_P1o?knogojm_;g
n?[kno[hmoolkZ[Qoonj2g7Joooli]comnk^mOWfl?o[moSGoj[5jo_nloGom=_j
i_?om?;lmOC`k>WZkoGikOSffZGTonWSincam?CblOCdmOCbkncZlnkYjNc]j^OV
k_?]h=[Ning^ko3`knk]j>GQgn7VkO7Zio7cicoL^814>2LM7bm3DBlk@3Tc<2HJ
9BdiA4Q2=bhn<c0f=c@jASXd;c4j@D4o?CXoB4Dl?DI:?TE4>TQ=<Bm2<b8^0nfA
odKnmooUa^ookoF9KEnNU:UoKFmdLVITOj2FIF9oOg^3P9n6QhAUHGMnNeeVGib?
SfYT@mCnmnOonncooofcBLWoooSioooloOgo0o_in_choP3jo?l9oOCoomMfON?o
n?WnjOoaoR7jooAa7jgojnKoooWoooSnm_oon_SkmN[/k>g]k^k_kocno_mon_Kb
moSjno_jn?Obooo9oonf6D7TonSimnKoooG/jo?gm>ojoo3om_7b/N_ko_?eooCK
oNWfooSeooSgm>o]k_;ho>Wkkn:Cj?oXjngalo;_jnWdm?Gdl^o/j_;al_GhmNcU
iNkdkMoIg^OdlNcYjNcam>GSh=oQj>odm>cbiKdoVUlA;3<nADDm<b//@TPi=dE4
<cPc<3<h>C@^?C<`=STg?TY2>S@f?dI7A3loAD]4>T5@C3i2@3A2ABPW>bdM:Y7o
A_kgonG6koo_mHU]GijDZGm]KgAbIVAoX9IUHWmoNh>0WhJ7Q6EQMgikGFIOW8n?
JVA3e?kgiookk?oooK=9bOoon?WooocmoOl3noWjo?Sn0?[lo`Wmm?ooegImhooh
nOkYoo7n8O[om74O[Oo[i_oonOoon?kfooojn?_ej^c/kNg^k^o_o?knogojm_;g
n?[kno[hmo;oolWookHI@NCoj?Wgi_oomNc[loOdko[ol?oflO:ajo_nloGom=_m
jOKon?Gon?Odkng^l_SljO__hY?XonS[kO7cl^o[jOCdmOCbkncZl_7bmOSek>GU
k_C]gmWNioCak>WYk?7diN?Pgn7XkoCdk?;U_CnJGa4/<ci5ACdc:ba2B3TgAD@c
>3<`<cPi=2hm<c0f>CLnBT8j=3HoATM4?cm5Bd@j@E1<?T90=495:2Lk;AdZTOm6
o_OoiLK_onoeRFeOWYBYOfe_M79VI7nPUVEROgmkPh2OQXN4IF5gOW]MIUnLShmZ
I4?Do_OWoo_/ooom/dW9ooohnOooo?gmo`?knO[ln?h0n_co2OgdoooGMWgSooSi
o^WolOhQn_odLAn]on_Voooioooho_Kooo[hnoGZk>c]kNk^knolo_koOo[fl_Oh
n__kn_Sgl_oobOoo]QU1i?oXnOOVoooek>_cmoC_n_o`ooKal[7[nokcmOodfogY
m_ohmOohmoC_kNkbn?cYnnoRTnSoj>_]lO?bkn_Ym?Cem?;_k>[blO;en?G/iNG^
m>gOfMkWm?7/jNW/lOCUhn3OhNS_m?C/l^Fm?iYO4B`c?TE5?C<[;498>CM5A3<h
<c0c>3Td;Sdc<3Hi=ci:@SXd=Sm6Ad@o?dE;A3Y1D4`n@T0d@TDX9c/]7BX3kI7o
>?Smoj[Mooono8mRBUb@SH]PK7jAVYN:Oi9^Ifm^Ohj2YW5VMVYQJfaaH7=UKhI[
Ke5UgOo[oooeo_go2Y^?nOoUoooLnooWjOh?m_oodIRIg_o]ookSooo_oOWonOk`
oa3dmooom?WoooIk<i_oooSloOgo4_glkO_ooogkk]jXoo7koLgfoo_no0GjmoCb
j?;nod?jooo]kooil=503N_do_oil_;eoOSemOOhm>omnoCdooW8T>oRo_o/n_o>
m_Khn_KbnOohlNWXkO?fmo7jlmgFi_CdmOkf0oGbl>knnFWgmO7]jnGTi>W_lNkY
j>kdln[PfMOelN[ThN7Si_SdkncZj>CQc[F1AbHU:b/b<cm<BShk@Shn>cLc=3Pm
?c/i>Si0?CTV?3<W>Cdd>c<i?chh>3i5=3Ll?d50?S`o>S<[9R<R8RT_=34ZTOlh
n?goZ]goooklSf9:G92=Rf1/OY6JUhYoTViWKfioSX:VLFIfJV5[K75PLfE_QV]_
DFGMon_oooGnoOl:VhoionGoomckonOYoPofoooAV9WNongoo^?oonomnOoio_3o
4?CgooodnOoomW/cVooon?cmoOlBoOc]nooooO_^gZSolO_mcOKonokl1O[gm?;X
l_ko@o[oong_ooW`dD0=joCnooWbl_Gmn?GemoSdkogkm?ConLR@kn;noncjolkf
m_Sjm_;iooSajNS]loKglO[cgMKVm?Ceo_H3mO;`k_kiJOOelNg[iNCTjNoak^WX
k_Ccj^3IeoGaj^CQhN?Vn?C_k>[Xi>7>]H579RD[:c8c?da:?S]2?Shk=c<d>3do
>cTj?T0m>BHl<bLi?C@k<cTo?SPh?TDd=c`o@D0n?3lj<b/V8b8R:Bld<BZAocSh
oOnZgOooo_b?HTYLT8f;H6anTIZGRWnBKVM_KWn>PZIaIWIZHF]/LF1cIFn6JfmA
IMgojooomOkmo`ZKSoWoiOoog?_oinWn3oKoom6HVMkokOonhoookogiooWnl?l@
m?OoooCiooofNc>Koooho?gmoa;mo>gkooomnnkNZ?oanog=m_oko_`5n_Odl^Sb
o_m3n_ookNoonO3A@0g[m?konO;bmOghmOGgn?C_oO_dm?oib93_h_kok?[oc_Kf
n?[fl_Won?7Yj>gcm_Oan_?Me^Kdm?GnmP?el_3^o_UYmoGakN_Ui>CYko7^jNS^
m??Zh=WGmO7Zi>7QhnKhm>o/j^SThLjePDLV9B/[<S<oC4Xn>d8n?S/g<c@h?Clk
>CXn@3di9S`c9cTm=3/c>Cln>3PnAC@g?3m1@3hl?cXc:bHS8R8Y;c@a:P?ZTOm7
n_co[=ooookoX7MPKYZ>QVmhQY>HTXImXh9nPW=dNVb@Hf1eKfn0Q8iaMVMkW7ml
CV3Hon_oooKoknClomZRV?SZe_Col]oojOh?m_oom]K0`L[ofOcojnCon_WonOka
oa7Xoo[IoooinOmi@YK]ooKao?gmo`;mo??lo`[hj[com_GX//_VnoklEO[gm?;o
oOcjm_;dn?_oaOo@1B]Qk_Kooo[em?Kln?Cen?Sdl?[jmOCno=V_g^gon>_kn]K^
l?Cjn_ShnoSajNS]loKglocehMWVloKdmOKfmO;`k_7bo_@Fl_3_noSfmo[im>kb
lNcSg=_Pi^CUinWmjdclh;VIPV]?>cdn=BLX>492@Cm5C4Df<cXo?S/h=CHi?3hj
=cPm?S/g8STa9cXo=cl_=cho?3/oADY:BDI1>S@`=C8]:BHV9bTY;S<b;Y7oAo[l
ojcOooonoj1gH6jJSXI_N8JCV9:6OJ>2OX9cM7Y/T6=PMFm_P8B>LGIWNiaoO4iP
f?o[ooofonoTo?oJXYShj]Kdoo;OonWn3oKoooKF`<7:omWlon_Too[iooWnlOlA
j?ojfOoonOWoND:FkOoflOcmoOl2oOcco?l:n>ZlooKej;;;i__no5GjmoCboogl
n_Kbm?SkolGod0D[HNkfooojmOCfo?SdmOShm?3jn_Gdo_cI[mk]ooS[no[Fk_3d
n_[hn?_hlNWXkO?fmo?lmN7Ii_?fm?Gfm_Gbl>kal_kd5_;`ko_hm_OjnOC^l_7/
hmcKh>KTiNOYoN]<o>2iVH9[Cc/m?SDW:3Q2@T4oADa5=S<j?chk>3Df>C`n>SLh
?Chk=b8i<BLj?cLo;cLn?c`k?dE:BTU6@CXd<3Db;BTV9RLY:Bhc<RjAodOjo?n/
goooo_nPMf1^VXj6KgR6TiRBQWfSPWj2LgAjK91SH7E_Kh24SW5fIg^LOga>H=So
jooom_o_i?cofZ:Hn>[Fm?obgooYoPofooofe/31b_oIo?o[i?ojnOoio_7o4NSo
n]WoooWiogU2U^gom_7loOgo0_glloco2_SZ_?ofmNRbbnKko_aEn_Odl_omo?[f
l_Chnoo5om05:f7^m_oon_Gdm_chm?Ghn?C`n_[em?klfJoNkOohjo_je^k`m?[j
n?Skn?7Yj>gcm_Oco?GQfNKcm_Cem_Kel_3^lO;nm1Kbl>okn?Kgn_Wdk_;ak>?L
fn3Vi>GWjOg[C?cP^IV2Jdlk?Che9bPh@T91?dE<ACHc>Sln>cPe=STl?SXg>3dn
>cLR>C4W>Slg?blg?Sll>cm5BTY9AT4j=30e<RdY9RHW:BT^<c8^0o>AodOln_n^
i?ooo_nSP6imYI:6I6aiPhJ4OWV<Lg^7MG1hL8IRIGUbMX^@RfIRCfbFN6e:F=3o
k?oon?obkOWoomn7UMc]iOoom?oYoP7mo?ko2NjkT/Goookdo?khooWnlOl0nOko
1oKloonE1C?To_l2nOcmoOlBoOceooono_onm;onnokbb]__noklOo[gm?;gm_Ki
o_oon_?Nol/c@:[MloWooochmoSkmoCdn?WelOSimoCinncG`OWoj>onl=g[kO;h
oOgglOSajNS]loKgm?cgiM[RkoKbloCem?;`k^_/ko7bl_7`i>;Rj>kak^[cl^kU
fmOIgN_^l_CckNORXh=MB4@l:1D@8cDn@4UCDDI:ADI9@CDe?d0o?3Xi>CXk>cLd
=SXl>CDX?SDY>Sdd>blf?D0n?3doBdU6@CTa:RHY:2LW:2X/;S0c<blXTOm7o?[o
[^CoookoXh1^OJFBQVA/NH>6Q7iiS7=kQgE`N726HVEiLWJ;T8]VHTm/UWQ]BUS@
oncoooSol^gioooOQiGLkNGoooCojOh1oOcno`W^^i;5ooonm?cnn?oio_7o0?Wn
o`Ofo?ooU@Dci?ko0_WloOgo4_glmOooo_koo_Boo__nl/[Kko_no7ojmoCbmoKf
nOkooo[cg_o;<d2ZgO?ioooln?OhnoOdm?SimO7hnOOdnO_/el7ionS_o_3Mjngb
n?gmmo7hlNWXkO?fmoClmnGJh^ofl_?dmOCbl>k[k>oal_;al>CRh^S^lNkZlo;^
iM_GfMg[k_;dlngWhZ>3GDQ4?2PE42<e?T19De56BTE6BD4e=Cm0?c`j>CTj>c/g
=3Hj?3Te:3he:CXm=3/_=Se0?S`m?d]9AT4i<BXV:BPW9bPZ;2h`<c<_:97oAocj
ojkTooonoj>0KWfUTXITK7V3QXAnNHacNhMeL7Q`QV9UNG9fRi2;IV9?K9IhKDYH
d?o/ooohoo;]nOooghNEg>gUooodonWn0Oglo_l9k[^BaOooo_Clo_SonOkao`3i
o_l7m_cooiD5<nCno`;io?gmoa;mo?Goooknookd_okko_;:fnoko_aon_Odl_Of
m_Wnooojlmkobc=0Z]gcnOooo?Sgn?_gm?ChnOGan?Wgm?Wkk=O1nOoXkok`gN_]
l_SmoOOan?7Yj>gcm_Odo?OUf^;_m_;cm?Gdl_3^jnc_lO;blO3Th^;Xk_7^j_?b
k^GKemWMjnkbm??]in:SPee8A3`X5A0S=Ci0BE=AATY5ATU1=CDo@3ll>STi>S/k
=c@f>S`i=BPn=BTj?C@k;cHm@3hl?Cm;BDI1>C4Z9RTX9bLX:R`^<3<c;bP3jY3o
A_So/^[oookjUgMZOJVISeEOKGUoPXF7QFejRgUaP8BAM7R1L723QHebLeadX89e
BE78oNoooo_on?ool?ooefn8looIoOoQjOh2oo_ho_l8fkMVkoo_ooo]n?oio_3o
2^;oomkoojDd@9ggo_l2o_cmoOl;oOc`nO[dmOknml;[o_l3lO_onokl6O[gm?;V
lO[koOolln?D_0XLi>G2n?_nooklo_Yom_?dn?Wfl_Sjn?;`l_?cYOcoi?Soimkb
mOGdn_oik?SajNS]loKgloSfimWIio?`lO?dlo;`kn_]k_3`knk/jNSXkOCflno<
fNWbl^_VhncPajJ0FS`[@CD[<D9?DDdkC5YLFeQ9=dM1@DE1>T1>@cll?3hn?3Xi
=S<d>3Xg<c8EAc//>CT]<SDi?Clm>CDc<C4`;R`Z9odV2BLY:R`];Bh_;Rf@odKh
ok;ZooonnYMgJWfYVHmEGfeiOh:5QhE]NX]iLH24TGAhPG1`PhF=LW=LM:22MDUA
b?g_oookooSooo3oomM_R??ofOgohNWn0_okn?ko2=^gI^ookoookOSonOk`o`[R
oooNoonU=42Mmoko0_kloOgo2ogll?Wjm?Gno_O2joko0o7koo_no1WjmoCbi_7j
nogoo??Se;`:7>CU`_Sko_ono?kjOoKcm?Sim_;hn_Sbl?;cljGlonChonONl_Ge
m?[onNchlNWXkO?fmo?hm^OIfNOcl?7cm??bl>o[kNk`l>o^k>WXj>gdm_?_c=WY
l_;[i^?/h<NVP5Xl:d4e:c52Ce5=>daJG5]HBCM7@D55@CY0CT<o?3`n?S`j>CHc
=3Pj=c<b5DLk;3Ti;C8e>Cdo?CTe<c4a<2h/:ROm9PTW:BX/;Bd^;bh]T?m6n?nb
j_ooo_ZGMfYmZIV?EEm]NGn2QHN5KGZ;NG60Q95dN85`L8>5SG9cG7BPPWE9DLSm
kooonoohooo`oooGKhScomWmon7YoP;onoSno`SK]fK_onooonghooWnl?l:h_oo
g_ooYCA0WOOno`;no?gmo`_mo?3in_Ceo_kg`^_no`?anooko_`In_Odl^Kan__m
oocchmBl2QcTiL;hnokoo_cnnWofloChnOKbn?[hl_3blo>Uo?oTn?oWg_;emOCj
ooW/n?7Yj>gcm_Ocn?KWfMWWlo3aloCcl_3_jng^l?3_k^cYj>S]m?KcklcIjO;b
jnKSk>37YX1J?2]1=B/a@TmACC]<FUaKF4TgAd51AD4j@4i3?c`l?Shl>STf<c@h
>SLc<QE7>b`i>Bdb=CTm?cdi=C<a<C0^;2XWoBH99bTZ;2d];Rl^;@?NT?m6m_fe
l?oooObGM6EhYibDGFUiPhR<TiVRP8BBNfenQiN3R8M/JWalKFIeFFJ=LVM<CL;n
loooo?g[oooQjOoo^5BIookXoooYo__o1o_g_GBhoooZmooio_3o4?gdioOo]b9Z
i?o`o?okmOcmoOlBoOcbnO[cmOoonmOQooohm?3cnokl4o[gm?;eooocjNodl?oP
01Cmo;b<o_]oo?kmnoWhmO;dn?[gm?cjn?7Yi^okW??ok?ooh]_fo__alogkkoSa
jNS]loKglOGejMO@gNo^ko7blo;`ko7bl_7_k>SVk>WXj^g]j>?oooOS`j67NS@d
=CPmADa@>3`o?c/g=cPjADY5ADY6>dU2@DE2?4ACAD0l?T=3?SPi=S<Y=3Pj=c<^
A3T/>cdb>3dl>cXg<R/U8R8S8bDV:2TZ:R/[:RXY:2@U9b`bT?m6m_fel?oooObG
M6EhYibDGFUiPhR<TiVRP8BBNfenQiN3R8M/JWalKFIeFFJ=LVM<CL;nloooo?g[
oooQjOoo^5BIookXoooYo__o1o_g_GBhoooZmooio_3o4?gdioOo]b9Zi?o`o?ok
mOcmoOlBoOcbnO[cmOoonmOQooohm?3cnokl4o[gm?;eooocjNodl?oP01Cmo;b<
o_]oo?kmnoWhmO;dn?[gm?cjn?7Yi^okW??ok?ooh]_fo__alogkkoSajNS]loKg
lOGejMO@gNo^ko7blo;`ko7bl_7_k>SVk>WXj^g]j>?oooOS`j67NS@d=CPmADa@
>3`o?c/g=cPjADY5ADY6>dU2@DE2?4ACAD0l?T=3?SPi=S<Y=3Pj=c<^A3T/>cdb
>3dl>cXg<R/U8R8S8bDV:2TZ:R/[:RXY:2@U9b`bT?m6m_fel?oooObGM6EhYibD
GFUiPhR<TiVRP8BBNfenQiN3R8M/JWalKFIeFFJ=LVM<CL;nloooo?g[oooQjOoo
^5BIookXoooYo__o1o_g_GBhoooZmooio_3o4?gdioOo]b9Zi?o`o?okmOcmoOlB
oOcbnO[cmOoonmOQooohm?3cnokl4o[gm?;eooocjNodl?oP01Cmo;b<o_]oo?km
noWhmO;dn?[gm?cjn?7Yi^okW??ok?ooh]_fo__alogkkoSajNS]loKglOGejMO@
gNo^ko7blo;`ko7bl_7_k>SVk>WXj^g]j>?oooOS`j67NS@d=CPmADa@>3`o?c/g
=cPjADY5ADY6>dU2@DE2?4ACAD0l?T=3?SPi=S<Y=3Pj=c<^A3T/>cdb>3dl>cXg
<R/U8R8S8bDV:2TZ:R/[:RXY:2@U9b`b0o2@odKcn[WfooomojAoK7bXVY5PKWj6
QHF:TIAZK8=dJ7V5RX6=R6Y[PH5MH7EDG8EZGE==`?ohookmonceooo_loKX[gFQ
ooo`onWn0?[no`7mn?ko1[6D`o;oooSiooWnlOlAgOo`oOnC6Gk?oooToooWnOcm
oOl6oOchoookoOko2>CCooo`oo;_nokl0o[gm?;no`7akokoAlX^:^;omMVnoOWf
n?cmnoOgm?7dnO_imOoimoCZhNWi[n?jmoonj=cUnOobk__ml_SajNS]loKgl_Gh
km[;f>o[kNoal_7`kokeJO?`k>SVjNSYk_Ghm_;QdK67FcXX8UA=@cXd<S<d@4YA
BSPY92LnA4<l?diDDE19AdU3>d1=B44m@4M8@3Lk=c@f>S`i=B@l=2XnA3a4@3Xc
<2h[9Al[:BPV9bPZ:bh_<30^:bPV;bXU92B@odKcn[WfooomojAoK7bXVY5PKWj6
QHF:TIAZK8=dJ7V5RX6=R6Y[PH5MH7EDG8EZGE==`?ohookmonceooo_loKX[gFQ
ooo`onWn0?[no`7mn?ko1[6D`o;oooSiooWnlOlAgOo`oOnC6Gk?oooToooWnOcm
oOl6oOchoookoOko2>CCooo`oo;_nokl0o[gm?;no`7akokoAlX^:^;omMVnoOWf
n?cmnoOgm?7dnO_imOoimoCZhNWi[n?jmoonj=cUnOobk__ml_SajNS]loKgl_Gh
km[;f>o[kNoal_7`kokeJO?`k>SVjNSYk_Ghm_;QdK67FcXX8UA=@cXd<S<d@4YA
BSPY92LnA4<l?diDDE19AdU3>d1=B44m@4M8@3Lk=c@f>S`i=B@l=2XnA3a4@3Xc
<2h[9Al[:BPV9bPZ:bh_<30^:bPV;bXU92B@odKcn[WfooomojAoK7bXVY5PKWj6
QHF:TIAZK8=dJ7V5RX6=R6Y[PH5MH7EDG8EZGE==`?ohookmonceooo_loKX[gFQ
ooo`onWn0?[no`7mn?ko1[6D`o;oooSiooWnlOlAgOo`oOnC6Gk?oooToooWnOcm
oOl6oOchoookoOko2>CCooo`oo;_nokl0o[gm?;no`7akokoAlX^:^;omMVnoOWf
n?cmnoOgm?7dnO_imOoimoCZhNWi[n?jmoonj=cUnOobk__ml_SajNS]loKgl_Gh
km[;f>o[kNoal_7`kokeJO?`k>SVjNSYk_Ghm_;QdK67FcXX8UA=@cXd<S<d@4YA
BSPY92LnA4<l?diDDE19AdU3>d1=B44m@4M8@3Lk=c@f>S`i=B@l=2XnA3a4@3Xc
<2h[9Al[:BPV9bPZ:bh_<30^:bPV;bXU92@3ii3o7O;h^o[oo_goXXAfQZjJSE=T
NH:0OXB;PE=IO7MZM?ik9Hb7JFj8RH=oRVIgZHahFTo0oocoo_kooo?mooo_m^Oo
agf^noojjOh0nogo2_gmoncocFjmooGgnOoio_7o4NO`kOoA;CWooo7Rl?oomOgl
oOgo0_gln?_o2O_Z`oook_oon__no7ojmoCbnOoonOoon<d_0=ooaOobb_ggl_?i
o?Wem_?aloWknOKom_GjlnKYmmCCjokfm?GU_^Oomo3jo?7hlNWXkO?fmoSjo_SP
c=WdjN_^l?7al?3cm?Gem?7^k?ojlN[SfLg3?S/d;2Xa@4dY:R/]<CDh>Se1ATE0
?3`mDEMEC41=F5]FBdI7CDQ0A519@Se2Bda1=Shj=cPm?S/g:T4h;3i2>40l<RLS
9RPV8bl^:bXZ;C0b;S0b<c<`;2Xb;BT/<Y3o7O;h^o[oo_goXXAfQZjJSE=TNH:0
OXB;PE=IO7MZM?ik9Hb7JFj8RH=oRVIgZHahFTo0oocoo_kooo?mooo_m^Ooagf^
noojjOh0nogo2_gmoncocFjmooGgnOoio_7o4NO`kOoA;CWooo7Rl?oomOgloOgo
0_gln?_o2O_Z`oook_oon__no7ojmoCbnOoonOoon<d_0=ooaOobb_ggl_?io?We
m_?aloWknOKom_GjlnKYmmCCjokfm?GU_^Oomo3jo?7hlNWXkO?fmoSjo_SPc=Wd
jN_^l?7al?3cm?Gem?7^k?ojlN[SfLg3?S/d;2Xa@4dY:R/]<CDh>Se1ATE0?3`m
DEMEC41=F5]FBdI7CDQ0A519@Se2Bda1=Shj=cPm?S/g:T4h;3i2>40l<RLS9RPV
8bl^:bXZ;C0b;S0b<c<`;2Xb;BT/<Y3o7O;h^o[oo_goXXAfQZjJSE=TNH:0OXB;
PE=IO7MZM?ik9Hb7JFj8RH=oRVIgZHahFTo0oocoo_kooo?mooo_m^Ooagf^nooj
jOh0nogo2_gmoncocFjmooGgnOoio_7o4NO`kOoA;CWooo7Rl?oomOgloOgo0_gl
n?_o2O_Z`oook_oon__no7ojmoCbnOoonOoon<d_0=ooaOobb_ggl_?io?Wem_?a
loWknOKom_GjlnKYmmCCjokfm?GU_^Oomo3jo?7hlNWXkO?fmoSjo_SPc=WdjN_^
l?7al?3cm?Gem?7^k?ojlN[SfLg3?S/d;2Xa@4dY:R/]<CDh>Se1ATE0?3`mDEME
C41=F5]FBdI7CDQ0A519@Se2Bda1=Shj=cPm?S/g:T4h;3i2>40l<RLS9RPV8bl^
:bXZ;C0b;S0b<c<`;2Xb;BT/<P?WT?lalONmoOomoNjCOWV=]9f<Bf5kR8Z;TY^Q
KG2CRG1YIWIjSXMVKHR9N6MT?eZFN5]ODL7noa7mo^oom^;ooo?omo3ogg6ToooY
oPgomnkao_oon?Oookic[OOonOk`oa32ej4JHOgoomofoo3doo;loOgo4_gllogo
o?cooO;g`_oih?oaio_no4CjmoCbk?KioOofXDHDooOLoooPZogeko3gnoScm_;`
loWln_Onm?Cnnnc[mo;:h?o[k?o^W]Gno??ko>ohlNWXkO?fmokno`WVcm_ijN[]
l?7ao_01lOCnmVKem>cI^YE^AR<>;c4c;bTV:B`Z;S<g>3Da;U17?CXl?CTd@Da@
BdaCDDLm>d9=CTU?G4Y2?D==CT8e?c/i>Si0?CTkCd4`>cT[<3HZ7Q/Q:2XY:2LV
9bX`=SX/;S8e=S@b;adP;4ART?lalONmoOomoNjCOWV=]9f<Bf5kR8Z;TY^QKG2C
RG1YIWIjSXMVKHR9N6MT?eZFN5]ODL7noa7mo^oom^;ooo?omo3ogg6ToooYoPgo
mnkao_oon?Oookic[OOonOk`oa32ej4JHOgoomofoo3doo;loOgo4_gllogoo?co
oO;g`_oih?oaio_no4CjmoCbk?KioOofXDHDooOLoooPZogeko3gnoScm_;`loWl
n_Onm?Cnnnc[mo;:h?o[k?o^W]Gno??ko>ohlNWXkO?fmokno`WVcm_ijN[]l?7a
o_01lOCnmVKem>cI^YE^AR<>;c4c;bTV:B`Z;S<g>3Da;U17?CXl?CTd@Da@BdaC
DDLm>d9=CTU?G4Y2?D==CT8e?c/i>Si0?CTkCd4`>cT[<3HZ7Q/Q:2XY:2LV9bX`
=SX/;S8e=S@b;adP;4ART?lalONmoOomoNjCOWV=]9f<Bf5kR8Z;TY^QKG2CRG1Y
IWIjSXMVKHR9N6MT?eZFN5]ODL7noa7mo^oom^;ooo?omo3ogg6ToooYoPgomnka
o_oon?Oookic[OOonOk`oa32ej4JHOgoomofoo3doo;loOgo4_gllogoo?cooO;g
`_oih?oaio_no4CjmoCbk?KioOofXDHDooOLoooPZogeko3gnoScm_;`loWln_On
m?Cnnnc[mo;:h?o[k?o^W]Gno??ko>ohlNWXkO?fmokno`WVcm_ijN[]l?7ao_01
lOCnmVKem>cI^YE^AR<>;c4c;bTV:B`Z;S<g>3Da;U17?CXl?CTd@Da@BdaCDDLm
>d9=CTU?G4Y2?D==CT8e?c/i>Si0?CTkCd4`>cT[<3HZ7Q/Q:2XY:2LV9bX`=SX/
;S8e=S@b;adP;4AR11N?ocG2m?3ooo[oR7R2R:f]YeUMS9Ek]efbXj9bYgjGWh^N
S8RBQg5iUGF0H4ehUGYIEDFgooWlm?[noa?no_glo?oToOo5EGkokOoeg?oogOSo
nOkho`kUm_oOS9keooCooocYnooaoQ7oloool?gok_o@EAeikOo`o?gmo`cmo?Ok
ooO6Xl?nl_Gjo_lKo_coZ_omm_;olOonooonjnkok?g^oOo:BAZlnOko<?Kjb_oi
lo?hnOC]oo_fmOOfl^gojOodk_CRoOCSc_[oi?Gk^^Kmkn[moo7TkOo?l>knoaoP
a[^ccNOPl>[UiN[_lO3om_Soomk@fV52;3E7C4M3:?hWF2P[;RlY<3Pm?T57C4Q:
BDDo?414BT]<CTm@DE96BTmCE55=BT]9DEaJC4E8?3/i>3Pi>c`U;cD^8Al[>SHg
=S@`:R@P<S8c<c@e=CHl=2/[>EA`PkJi`]3NSole`_C`ooojohQhPXR][JMIGHbE
NkMM/Z>RLZMnUin;WXb8TXMaNIEeP61=N9EjFEE5]ooio?Cjo_lCo_kmo?coi?go
aEEnongomMcoomghooWnn?l>iOKoghbNmOodoooljO_olOhAoo?ooo3monkod5DM
NNgol?cmoOl<oOcgnoogaZ?3o_;en_ko6okloj[ooOKboo7oo_ooo^_^oncmk_go
bTTJ_?Wnoc3fn/[onO?cn?WdkOokm_Ggm_;]onWom>kdh_gdhlkjonCenk[VoNoZ
oOoai>goco3^o_lOh<Jk/lgWh?3ZiNGZko7`ooKhoooNd=YQ@R`eAda7@bSn9ePX
:bh_:C0h?Ci1Ada8BTU5?ca0A4Y;C4i?D55BATY?DeAACDY;BE5LFTa5B3`k>CPh
>C/l9Ble;R4O:cXf=cHd<2XT838b<c<d=CDf?3@[:cUDL8>f^L;@gXoo=L;dl?oo
n_n8N8:8[JfWFEf<UG^gGK:SXW:WOYNORij<R9:7LGVEMH1PCGRENUUEAKOonOcd
n_ko4oknoOclonCmolEEO_o]ooGLoooMn?oio_So3^Gfomn<W_Gom?ooo>Wkoo7n
4Oocooo`oOo^om1E7GW]oo3loOgo3?glmo_omlJS`okbmO[noa_no?nZoogfl_oa
ookoook[k_o/oNkmolY96[cio_l`m_[:ooWcloSim>gonoKemoKbkOoYooC^m>;m
m>?>n_oTmO^ji_g_j_golNC]olo`k_ko7n36^k?=in3`j^GUj^oal?ofn?oog]3J
HD8/=DM<Ad<XoRMH:2/^;bT`>3dn@DM<B4Y9ACll@4A:Bda>Ce1ADTI:Ce=DDDe:
BdUAG5Y<ADPl>cTh>3Tk?2D_=BhQ7b/j=SLf=30Z920b<S<c=3De=S`d:b/iE723
][W2d=h42hoo=L7el_oonon2JgZ9/Z^LEbQWDjFoPj2?QVjKQHBQUHQiNhV3LGRA
MHM_GXJSS75SCkgon_kfo?ko5?knoOclonk`ooNfWkWoeooomOWolOWonOkgo`gm
ooo@ZjG^mOooo?ooiO7n4NWolo3oo=WoiUT;I<JlaooloOgoK?glmoKoongChood
mo_oookknOn`oocelOo_ooWmooohl?CoooKlde0[T/[oo_oom_Fomo?amOcmmo3o
n_KemoObk_cWo?3[l=kjlNbml?oWkl>0bOoom?_ml_Wlo^_on^K0WHQnIdec_^Kc
m?Smoa7ko^cUgk9W;amI@cHnAd0d;RCm8aHU9RL/<cXm>cXk?TA6Ad<n?D56Bd]<
COe>0e=BDE3mCaI0>Ca:DDa:D4=1?CXg=SLg;c4b;bTR7ohM6QlR:2lf>RXY:2PW
9RDUDfbC^M?LfM?5algHhXoo=L7el_oonon2JgZ9/Z^LEbQWDjFoPj2?QVjKQHBQ
UHQiNhV3LGRAMHM_GXJSS75SCkgon_kfo?ko5?knoOclonk`ooNfWkWoeooomOWo
lOWonOkgo`gmooo@ZjG^mOooo?ooiO7n4NWolo3oo=WoiUT;I<JlaooloOgoK?gl
moKoongChoodmo_oookknOn`oocelOo_ooWmooohl?CoooKlde0[T/[oo_oom_Fo
mo?amOcmmo3on_KemoObk_cWo?3[l=kjlNbml?oWkl>0bOoom?_ml_Wlo^_on^K0
WHQnIdec_^Kcm?Smoa7ko^cUgk9W;amI@cHnAd0d;RCm8aHU9RL/<cXm>cXk?TA6
Ad<n?D56Bd]<COe>0e=BDE3mCaI0>Ca:DDa:D4=1?CXg=SLg;c4b;bTR7ohM6QlR
:2lf>RXY:2PW9RDUDfbC^M?LfM?5algHhXoo=L7el_oonon2JgZ9/Z^LEbQWDjFo
Pj2?QVjKQHBQUHQiNhV3LGRAMHM_GXJSS75SCkgon_kfo?ko5?knoOclonk`ooNf
WkWoeooomOWolOWonOkgo`gmooo@ZjG^mOooo?ooiO7n4NWolo3oo=WoiUT;I<Jl
aooloOgoK?glmoKoongChoodmo_oookknOn`oocelOo_ooWmooohl?CoooKlde0[
T/[oo_oom_Fomo?amOcmmo3on_KemoObk_cWo?3[l=kjlNbml?oWkl>0bOoom?_m
l_Wlo^_on^K0WHQnIdec_^Kcm?Smoa7ko^cUgk9W;amI@cHnAd0d;RCm8aHU9RL/
<cXm>cXk?TA6Ad<n?D56Bd]<COe>0e=BDE3mCaI0>Ca:DDa:D4=1?CXg=SLg;c4b
;bTR7ohM6QlR:2lf>RXY:2PW9RDUDfbC^M?LfM?5algHhP@DT?leo;ohmOooo?mn
HW>9]JVDNV;BG9=0CGIkIf^6P5J<RG1VJWQdHfEfHGiaH8:NSGUbFL7oo?oioOlC
o_kmo?coo?;noooEYY7ooncoonghooWnm_l<oOooiJj?aooolOgoko7n4Oomoooe
nOoi@U^?f?G=booloOgoOoglo?Cloookn?ohn_goo__gm?nnn_gglOg`ooOgooom
k^Obi_oD22c<d]conooon?6ck^kbnOoonO;nnOGemoOcko[UnnkXkM_fk?f]i?oZ
khDdWO[on_Wlm^_jeM_o][1]bkJVP55SXlKFf^;[k^OHc;N3BbdO9DYd@3Lg@40`
1R8O<C4`;bon;U@_=Sho>S@a<Cm1@d4n?T=9BT]=CDa;BDMFDdi9B4U<CU92>T98
@ci0D4]3>BlW8R0Y8QdR;CLk>TQ0<B<I5AHG<3iIO:;6hNoHgNGYi]gBb/o?d]WP
T?leo;ohmOooo?mnHW>9]JVDNV;BG9=0CGIkIf^6P5J<RG1VJWQdHfEfHGiaH8:N
SGUbFL7oo?oioOlCo_kmo?coo?;noooEYY7ooncoonghooWnm_l<oOooiJj?aooo
lOgoko7n4OomoooenOoi@U^?f?G=booloOgoOoglo?Cloookn?ohn_goo__gm?nn
n_gglOg`ooOgooomk^Obi_oD22c<d]conooon?6ck^kbnOoonO;nnOGemoOcko[U
nnkXkM_fk?f]i?oZkhDdWO[on_Wlm^_jeM_o][1]bkJVP55SXlKFf^;[k^OHc;N3
BbdO9DYd@3Lg@40`1R8O<C4`;bon;U@_=Sho>S@a<Cm1@d4n?T=9BT]=CDa;BDMF
Ddi9B4U<CU92>T98@ci0D4]3>BlW8R0Y8QdR;CLk>TQ0<B<I5AHG<3iIO:;6hNoH
gNGYi]gBb/o?d]WPT?leo;ohmOooo?mnHW>9]JVDNV;BG9=0CGIkIf^6P5J<RG1V
JWQdHfEfHGiaH8:NSGUbFL7oo?oioOlCo_kmo?coo?;noooEYY7ooncoonghooWn
m_l<oOooiJj?aooolOgoko7n4OomoooenOoi@U^?f?G=booloOgoOoglo?Cloook
n?ohn_goo__gm?nnn_gglOg`ooOgooomk^Obi_oD22c<d]conooon?6ck^kbnOoo
nO;nnOGemoOcko[UnnkXkM_fk?f]i?oZkhDdWO[on_Wlm^_jeM_o][1]bkJVP55S
XlKFf^;[k^OHc;N3BbdO9DYd@3Lg@40`1R8O<C4`;bon;U@_=Sho>S@a<Cm1@d4n
?T=9BT]=CDa;BDMFDdi9B4U<CU92>T98@ci0D4]3>BlW8R0Y8QdR;CLk>TQ0<B<I
5AHG<3iIO:;6hNoHgNGYi]gBb/o?d]WP11f@ocGh_O_iooonoh1YMhJ_Z9Y:6GM9
jlkUi=:gb/o;PLK9`kbobL>bZk9DN71MNI64MWAH_Ookoogmo`Sno_glo?_ooo_n
o`S[ZHO9o^GoonCiooWnnOl?iooomOOooof9Sm3oonojoo7n4Oo`oooaon577[oo
ooKonnGloOgoOoglooWloooll_Gko?koo?SckooDk_okm_gdoocfn?_il^g?okP@
F;G9onKomO[oo_Bajo3go_ommNoln?Cen?Sdl?gWoO3Yk]_fjOnbf_o]ngHKQn[o
m_WnnNgog]_QLJnFe[RXTg1YKUm3L[KWi:YF6Tdh:2T]<dQP:2L_>CHW0B4VoSXP
>CPf=38a>412?3Da;cTl?chl?TA:B4Y<C4]7@d58B4M7oDHdFTPmA4U2>CLW9bT/
<CHk?T@e8Q@B6bL_1A4YBg>K_<oPg]WDc/W5`]oDa[^la]GPcLc=dmV@ocGh_O_i
ooonoh1YMhJ_Z9Y:6GM9jlkUi=:gb/o;PLK9`kbobL>bZk9DN71MNI64MWAH_Ook
oogmo`Sno_glo?_ooo_no`S[ZHO9o^GoonCiooWnnOl?iooomOOooof9Sm3oonoj
oo7n4Oo`oooaon577[ooooKonnGloOgoOoglooWloooll_Gko?koo?SckooDk_ok
m_gdoocfn?_il^g?okP@F;G9onKomO[oo_Bajo3go_ommNoln?Cen?Sdl?gWoO3Y
k]_fjOnbf_o]ngHKQn[om_WnnNgog]_QLJnFe[RXTg1YKUm3L[KWi:YF6Tdh:2T]
<dQP:2L_>CHW0B4VoSXP>CPf=38a>412?3Da;cTl?chl?TA:B4Y<C4]7@d58B4M7
oDHdFTPmA4U2>CLW9bT/<CHk?T@e8Q@B6bL_1A4YBg>K_<oPg]WDc/W5`]oDa[^l
a]GPcLc=dmV@ocGh_O_iooonoh1YMhJ_Z9Y:6GM9jlkUi=:gb/o;PLK9`kbobL>b
Zk9DN71MNI64MWAH_Ookoogmo`Sno_glo?_ooo_no`S[ZHO9o^GoonCiooWnnOl?
iooomOOooof9Sm3oonojoo7n4Oo`oooaon577[ooooKonnGloOgoOoglooWloool
l_Gko?koo?SckooDk_okm_gdoocfn?_il^g?okP@F;G9onKomO[oo_Bajo3go_om
mNoln?Cen?Sdl?gWoO3Yk]_fjOnbf_o]ngHKQn[om_WnnNgog]_QLJnFe[RXTg1Y
KUm3L[KWi:YF6Tdh:2T]<dQP:2L_>CHW0B4VoSXP>CPf=38a>412?3Da;cTl?chl
?TA:B4Y<C4]7@d58B4M7oDHdFTPmA4U2>CLW9bT/<CHk?T@e8Q@B6bL_1A4YBg>K
_<oPg]WDc/W5`]oDa[^la]GPcLc=dmT4293o0oBkoognoaKmQGR1PJFXYiYaSHko
ooCTookooobbo?_o3o_akeb1NF5hSH9gKDncno[ko`[no_glo?Wkooomm_ko1VEN
eo[oooGiooWnm_l8oO;aooogXXg:o_l0m?7n4N_olnSocSl9ao3]g?Oooo?loOgo
Oogloogooo_`koKko?knnoKakOo[hOoon_chooohloGlooko_adeo?ndh>Sol?Go
ooZgkoGmookgl>_kmo?dn?WelOo/ooC/lMghjoo:e?3coiU<X^chl__omN7ohMoB
CiNFP7=oQW9[HdM[FT<d<SU1ABX`@51??B/T;bda>38X=b/h<S<e=C<`;B/a>D53
?cXi>CHi?3`k?DA:A4I9BdU5?c`j?dQ>D4a6@DTk=d57@3Tj<BhZ9B4OoQhS9c4e
>TYTNKNj_/?7b/c<`L?7c=7Ff]bl`<O>eM[Lg/_:bm7JT?l3m;_ooOko5_f5N861
YJRWVW6=S_oom>Coo_ooo;;lnol?no7_G85iHGR=PWM]Ck?kn__o2_knoOclnO_o
oogfo_l6IEkGn_oomOWonOkfo`Sml_7oooNRSL[no`3dlOhAjoocj?o>?`W7l>gL
mooolocmoOmooOcooOoono3_m__lo_kkm_7]on_Qooojo?SoooScmOcoo_no7CGl
okCPj?o`mOoon[O_mOgoo_O`jo_gloChnOGaoncom>cagOS[ol[Dl??oVDbRk?Sb
nooehOoQgm9?UiJ0Lgn6LV]SAf]J@c@b>D55:S10D4lm:b@_;C4h<RPg:cPb<cDe
<c0]:c4i@D<o>STi=STl?3/mA4Y4ATU;BDDo?3XoB4i@C4I1BC/g@DM0>CXa;RXU
8Aon7R<W<CDjBVAi]kZn`lO:c<c1`lO<dMKJg;c0alkEf]cNbl[;dMZ@o`?d^oom
o_lFoHEhPH6UZ:NJLHf>ooodi?onoool/_cko`oklNmLPGUQN8f2Mfe?/o_jnol:
o_kmo?cinooooOKno`IUG]OjoooenOoio_Ko2?gblOoomj:=b_ko0?CaoQ7[oo?X
olho2LO`kMcgoooco?gmogomo?omoookl>ofnocno__flNgojn7ooo[ln?oon??e
o?onoklM=Oco]>3Xoo3eoooj]noeoOonmo3[noOcm?SimO7ok?odk?7Mn>_ob]C`
lonIC:;/n?;kooGQon7OdTnGUX1cOhIbJf=7JeY3=38i@DDZ<41@Ccd[92l]<CPb
:3L[>38c=CDc<2d[<CU1@clj>CTf>C`l>ce4BTA6BD]9ACll>Sm8CU1<AT59>cM1
Ad0i>S4^:RDQ7ohN8bLa=CY:I7Vg^[k3al[<c<73alcAe][L_<37c]GJg=k;b/_A
fP@GT?l1l;Slo`ciQWn5OYnX[FAiTk_eo_lOnOWjm]Ven?WdloGloocdkV>3M5Ya
R7eaIdV^n?_ooOgnoa?no_glo?odmOooo?Goo_naS]O/j_SonOkho`kekOooo_Gk
onNbV;;moo3aoQ7iooolS1`l^?ookMgfoo_oo?gmobgmo?Wnookgm?conO_loO[f
l>gooM7ooo_hn?kmnOOnooCO_aMMooC]olcWoo3do_mo`?;ioooil^k^n_Kcm?Sj
mo?okooekO7Mn?7oi/kMoOo:SLkoo??noo3Wn>C[jf9/H7YmThiUFFIR<C8e>d0o
=c0k;R0I7c59FTHm>S`g;cA0<cDi>cXg<c0d>Cho?C`n@SDh>cXi>T57?D56BDQ4
?SXh@4aDEDm4?D/o>CTb9R@]:bDT92DX:bla@V:;YkG3enSPh^CUhmkIe^CRgm[E
dLk<h>3Og=K=a;o@cloFh93o0O2ho?l<nHIoQGjOZ:eTNI>kmOko7oWin_KI]OSi
m??eo?olm>iSPgAJLHQmLFM9[_Skoogmo_lCo_kmo?com?Goooceooko/HkGk>[h
ooWnn?l>mNgoookenooW/YRboOo`lOhAnOooo8`L?;SoongMm_okoocmoOl]oOci
o_onmoClooWko?gjm_3]oogAoookn?SnoOWgo_odgklGGOodkOo<ioo`m?koOl3b
nOoonO;^k_[floChn_OconoomNgagOSaonK>gOgobXg>oocco_o`ioSTjn]RK61j
OI>>IEUVHS4b=C]0?cL`>bhP6AlaBEY6?CXl=bld@3<e>C/j=c<`=3Tn?cdl?T8e
>3/j>CY1Ace1ATU8A3hj>41<E5E?A3e;?cTi<RHT;B/U92@U:2/_<D9RRjNe`mOX
h>;TiN?NfMKTh]oJeM7>c>3PgmcFcLBod<o?e^2@o`7`^?co3?V6OhEnWjR]I7VC
^oGnoaoinO[ffKGhnOCcmOcoo?C^Hh=dFW68OG5WBJkhnoomoOko4oknoOclooCe
ooolmOonok6>encZn?oio_So3_G]ooonmO_oik:H/_gol?7n4OWooob<73bhooo]
gOKonooloOgo;OglnOkoo_Odo?oinocmn_K`kOomdOoonoSho_gimokom=no5ego
m>goc>Ool?Cnogo0l_WoooWbk^kjm_?dn?[gloo_ooG]lMghlOoVc]gmolZ=c_ol
lokol>Ohi>_[HVaPNWfCSVEIIV8a<SDk@3lg<3/^81TO<DUJASdj?3L_=40c=CTk
>SLc<3@i?Slm?3i2=CPk>STj@DLm@DI9B4@n>SQ0C5AECd@mBcli>C8V92d[9B@T
9BP[;c52HX^W]L?Gj>3Ri>GSg]WFi>;Of]GAc/cPh=oLe/g4_m3?cmKP11f@o`7]
]oko3OkonX9fOWjQYJEmKV6Qo_l;h?Oom_[6e?ooo_gmoOl@mVb5KeA`S89fJDZ`
o?oon?Cno`Ono_glo?ohm?ko2OO`mOooigb^on[iooWnn?l2k^Wmo_l8n_7oo/:9
ZnkolOhAon3]_BHWa?oMoooloOolo_cmoOl6oOchoOonoOkoOoKhnocjm_7^n?o0
ookgl?Cnn_GkooJdLAZPk?Sol=oojOoemOcmo/G`moglmO7cmoWel_Chn_Odongo
ln_^f_GjloW7dOodiiGGooogooodoo[jj^UaFf]hJVeO=blj<T4f:RL`@4eD>S`k
=S<a;RU1=S8i>SDg?cDh?T52?c/hE3Pj>cPe=Sa2=CPk>CLh?T<f>d97B4@n>Se1
AdY8@3LaAcdd;1lI:D0Q;49OP:2iamWUl_G/h=WGemGCd<g;b/[@clo>cLc;bm3<
a/?6c]WOe=;Ae]n@o`7]]oko3OkonX9fOWjQYJEmKV6Qo_l;h?Oom_[6e?ooo_gm
oOl@mVb5KeA`S89fJDZ`o?oon?Cno`Ono_glo?ohm?ko2OO`mOooigb^on[iooWn
n?l2k^Wmo_l8n_7oo/:9ZnkolOhAon3]_BHWa?oMoooloOolo_cmoOl6oOchoOon
oOkoOoKhnocjm_7^n?o0ookgl?Cnn_GkooJdLAZPk?Sol=oojOoemOcmo/G`mogl
mO7cmoWel_Chn_Odongoln_^f_GjloW7dOodiiGGooogooodoo[jj^UaFf]hJVeO
=blj<T4f:RL`@4eD>S`k=S<a;RU1=S8i>SDg?cDh?T52?c/hE3Pj>cPe=Sa2=CPk
>CLh?T<f>d97B4@n>Se1AdY8@3LaAcdd;1lI:D0Q;49OP:2iamWUl_G/h=WGemGC
d<g;b/[@clo>cLc;bm3<a/?6c]WOe=;Ae]n@o`7]]oko3OkonX9fOWjQYJEmKV6Q
o_l;h?Oom_[6e?ooo_gmoOl@mVb5KeA`S89fJDZ`o?oon?Cno`Ono_glo?ohm?ko
2OO`mOooigb^on[iooWnn?l2k^Wmo_l8n_7oo/:9ZnkolOhAon3]_BHWa?oMoool
oOolo_cmoOl6oOchoOonoOkoOoKhnocjm_7^n?o0ookgl?Cnn_GkooJdLAZPk?So
l=oojOoemOcmo/G`moglmO7cmoWel_Chn_Odongoln_^f_GjloW7dOodiiGGooog
ooodoo[jj^UaFf]hJVeO=blj<T4f:RL`@4eD>S`k=S<a;RU1=S8i>SDg?cDh?T52
?c/hE3Pj>cPe=Sa2=CPk>CLh?T<f>d97B4@n>Se1AdY8@3LaAcdd;1lI:D0Q;49O
P:2iamWUl_G/h=WGemGCd<g;b/[@clo>cLc;bm3<a/?6c]WOe=;Ae]l4897o0_k[
]_ko;?gooWeZMX2VXiYBMIfmongoooOol?Nagoomooonn_gom^V0U7YOP:6HRVi?
]Oko0OC/o_l9o_kmo?cgoooal?co1NOnoi]^i_WonOkio`onooogkoKoonSYooo3
W/colOhAomQ=4hoomL[onN3fooo]oocmoOmooOcmo_gnooolkoCfnO_jmo?`l_ne
oOWbj^oonO7lon1^0FGboo;jon?Bk?ojmoSgnlG]m?Whlo?iooSdl_Chn_Sdon[n
l>O[e_7og_o1booRkgK4ooohooomnlgCV8<U96m>9QTT;3`h5BX[;cQ0@Sdh>415
A4=4?SLX7Ql_>CQN=c`Y;C@i>SPd<C`l>C<^;cLn=STk>CHf>d4b>416B4@n>Slo
?CTc;BHR920N7Qd]Eh79b/gBfN3Wj^7Hclc@e]SGgm[Cc/kBf=c@clo>cLc;bm3C
f=[Idlc8dm3=dMRAo`;njkKnobcmooimJWJ0YZ>JDWFM_Oo]ooogoo3g/MoooOoo
o_[mooKYP9AjGh2QV8Y^CkGno`7dk?ko2OknoOclmooolO3lo`GWo_nKK^KiooWn
nOl?o_oomnofoooXjOoo`ik<oo7n4OoHCA>?ooG:ooWPm_ookOoloOgoOogloOkm
o_ooo>odm_Wkn_Ocl?;o]Ogil^[_ooWao?oPKP5Ul_obn_oSd^con_Ohmo_5kOCi
n??cnOohm?;dn?[hm?oZo_3WjmKaomko`L_oh^mfa?oon?oooO_=diR39BA_CRHI
92`l>1DZ:blh@48m>3Q0ADA3A3hg:1hO;cThGSLl:Bdd>CXh=34l?3Tc;Rlg?SHi
>cTf=S]1<SQ0ATQ4?SXo?cdi<bdV8R@P7QhM;EN1bL[=d]WPin[Qf<o<d=KHemoJ
dlk>d]SLd<o?c/g<bl_@dmSJfM?<b=?@cM7HTOl2o^^fo_l/oOonOFYfP:JSVU9e
WKgokOoomoo`mk7OoogoookjoOofjH2DNUn0XIR:KTneo_l1m>cno`Wno_glo?Oo
oo7`o?l5iokoVfkVnOoio_Wo3okoooO_m_ooj>Wool>Nc?oaoQ7of4dCSooeb_oi
h?Koongoo?gmogomo?gnoOkoooc_m?Kino[glo3bokGmnO;ZkooilOcoh6h1IO;o
l_[ohm;/oo[gn?OkaNgdnOScloWon?Cbm?Sjn?Coj_k`in_FlOoNol7;on;_M/Co
ooSooogkcM>HPbDTKdhV6B@/?3PE:R/_>412?CPh@4E4@d@n=bPN7bli>5hg?2T]
=3Tj>3@a?3`i<bh_=chf>C/i=SHk@C8h@4I8A3hj?clm>C<]9R8T81hN7BeGPLW:
cM;Ih>OZhMS?c=3Ff=OOf]?>c];Hg=3?clk=c<_;d=?Hf]WCc<SCd<gAf0?HT?l4
/M_Tom[no`Z9G71lWkBSQ9>5bOgo1o_kooBIl?gonOh?M9]QKY>AYX5JJ[CjooKm
oOSnoOl<o_WfnOooo?WSZFoLjOko1?[on?Sjo_l2oO?_nOhAookko?ooo_WSlOoo
mM6WS>ggnol?mOcil_[oooW7:`kIonCofOWn2_Wgmo_oookjn?[mo?l:o_ooo_ko
m^G_ojonogoUd?oTk?o@:BFjh^com?kne_3[on_mooGebNKcnoSio_cbooS[jo[o
lmgjnocjm>_Rg>SjoojPn_o7f>7_n>k:VGE==bPZ:2</?R/j?BhZ=C/e;B/Y;38g
>CU>B44l>d17C3`k>cXi>3Lg@dE7B4E0>SLf<SM3AC`j@3Xh=cPmAB5>E4XZ8CY;
@Ci9?2lM51LQ:c1JNJ?1c]ORk=kNgMcKfm[InMOYd@C>c<cBfi3o1;7Ki?oJo_l:
REa`O9ndXhBCQLWmo`OknoodVO3mooWn3gBKHFjCTJJ1FVZdn_ofoOgho_go3?ki
m_WooocihjU_g>Wno`CjooShn_ko0_gckoWn4Oonnocoookiho7oooGAYhc]mo_o
3oGlnO;joooiab/>fOoTomWioP[imoOkooonn_SjoOco2_koooknooKUkon_o_mo
iM3oi>cod2TU^^;/ooCno]K`joo[oOoemLWVlo_hnOkll_ohjn_joo?Mn__ln_C[
h]cXn_onX?[oamSQkoS^bYUeCCLX:RPS;3h[>Sd^:SDk=Bd[:B`b=cTiCTQ1?3]0
Ad`l>c/j>CPg=d=5AdQ5@3Xg=S8g@dDl>T0j>3Lh?DDQCUA::R4jBd4nBC`_7A@G
8B/`FWVS`LkGh^cNg]gLfm_JfOWGjM44c/c<d]^@o`BafnCof_ko2XULL7bO]:>4
ThG9oOl7no_om9W`oOoioPmdVf5^Ti6VPEYZ]?[om_gmn?kmo`cnnOKiooolnN>Y
KmcYo_l4n_ohn?[no`;mlnoioQ7oo__looonnN?aoooedJN<kOOko`oeo?Wbn_oo
nLL[3]Woi?oInOh:nOOgnoooo_[hn_glo`[nooono_ofiNoo[okoOnG@onC/om0Y
9K[Rk?odo_kFl>_ojogomOG9i_?kn?Wno?;on>_[n_ocgO[ko?[djn;Lj?[ooZ3j
olOHhNohk/ZIMDdg:2XX8b`n:cXm;RXe>cD]:bT/<SLi>Di8@C`k@4M<?3/k>STh
=cM3ADM8AD0j=cHb=d=5?3Y0>SPg>3e58DiDBRXQ>T]1?TTl;adD5b4[<5YiXl7>
en;/g]kMg=_Kf]WienWA1<k<c=;K0nB@o`35oOlImoooOgN3S[bi^7V8Nl7on_on
nocolZCdoOoioPmmWfYaUINVQF9`^?gon?kln?kmo`Gnn_O^n?kno`SacGCBm?3o
oo_no`Ggi_Cooo?ioPWoo__moooln>Oao_lJkmW;I<Oooo7jn^Col>?oooS1W0^I
monif?oOnOh:nOOgnoooo_Whn_glob[hoookoOoginkodnWSf_Oo`OooT1A8_??S
kOoco_kFl>WnjocoloC;encnoOmomOWcjnO[l>cUl_Ghn?C[hM[_mOSbUmSQZheZ
>aXE9Si>=B`]=SH`=dM2BdTj=C/k<R/Z:bhe>cm0A44m>ce2B4dm?3Xi>CXl?SPh
=cTmA4Y>?SDd?TA6D5i1?CHa;c4d=She?Dm58a@M5Q`^CWNN^/S=f>CVg]KDe]kN
gMcKfmX0fOWGnM;ad@C>c<cBfi3o0<GmoaWgoomoMh>>_;VhNHQk`Oojookko?ob
Y?CmooWn3gfOJW6EUjJ5HW2hoOoho_cho_go1Okjmnkho_ko2?7=M=;dl?oonoko
1OOVm?ooloWn2Oonnogooochio7noa[_fL]TaooolO[ji?o`hooon<6L2iWgokWH
omoioP[imoOkooonnOSjoOco:_Sooo_mooOWk_oCjN?Jmoo1oon@54Rlln?]oo?n
o]K`jOk[o?ocm<_Gk?kmogoenO?[in_`k>GbmOShm>_Qf^oen?:Gf>6[SFXk6QDV
?The;2df=S0gAd9;BCXe>c/b:bX[;SDk?d14@Cdk?D98CCdl>STi>S`n>3Pg>Ce4
BThn=C@nA4I@GT4m=S4_<C@f?SDmCdDS51dF72i>Mijjb<gHi>KNe]CFg]kMg=_K
fP3InMOid_7A1<k<c=;KT?l0aOgo6OOoogmgPhjl^KQiR7_1oo[oo__loo:Tm?go
nOh?OImZLIFGYXERL;SmooSno?SnoOl5o_[gk_Sno_l8lLedd_C`oooko_l5mnKd
ooocnOh9ookkoOooo?SWlOko6^oIbfC7oooan_[Too3Soooh`I`;VOOo^MSogoWn
2_Wgmo_oookin?[mo?lZn?oonogomnO^om?Yhm[gol7ooi0DB;cchngolokne_3Y
o^_loo?dbmO/o_goOoGiln_Wjo3/iO;en?Sdjn7JkoGhlYOHhJ^=JS/J5BHnCSD/
;CHf<3M7@T]9>SDk>c8[:R/^=C/o@4A1?C/m@TQ=?C`j>CTj?3hh>3Li?DA:CShe
=3i4AU1N@Cdf<Bla=3Hn=Ce?AB<D7AHL;TigW[[8cMSTi]kFe=KNg]gLfm_J0=Wi
eoWBlM44c/c<d]/3i97o7nJeooCNomKhog^KRhRmSj9fQGW0oo_ooo_monbfn_ko
nOh?Mi=XJi:NYXiWLk[ooocoo?SnoOl4o__jn?kloa3gofiZh?onooO`o?oooOGj
ooWn2_ono?gooo[el_Klo?lGVX:Pm?oojnOdknW_mm1S0;GnoooZoo;RnOh:n_Sg
nooooOSin_gnocOnoOCko?WkooOWo?SCc_ofomoobfTiKoKo]nK_oo?mo]KaiogZ
n_oam<gCiO?blOCajNk^l?;en_ko9_gel?7gooonj=2[?3/Z02X/<3Hg<2<H<SM4
Cd]2A4m;CDPo?D8m<_hc13@g>Si0oS]4?3m3AdXi=S8`<SLn@RLa?dY<ACTaDdM1
@d4j?4Hh=cHg>d57BbhV9b`X;eZ=`/C;enG]kN[gm>oWgm[Ge]kNgMcKfm[InMSi
do7A1<k<c=;KTOlOi[Gom=koe_SoNi^;R;f?XWJ5NL3onooonogok;Kjo_oioPmg
TfQ[TYjVSVMc^_ooo?oln?kmo`Cnno[ho_co4?OoKV[Pookomo3looommO[onOh:
ookloOoon_Gbm_cloaNJPZ3dooo[ioC_jNogd6<0]Okoon[ol^;ioP[jn?Okooom
n?WjoOko=okmm?_lnO_omnOln=?>ooKogoo;JCU_m_ngi^oologne_7WoN[joo7d
cM?Ulo;am?7Yk^k`l_Gjo_lVoOG`lOOoookXd:/l>bX0:R``=SL`8aPb=dA?Bd94
Cd]=B3lm@SdboS<4=3Lj?T3n>d@l?d=7BSTf<S0b=ci29c4oBTa5>C5CAd53@CXl
ASPg=SLk@DM;;RHW;2P_FXg2a<_GiNg]j_OdknOOf]OFg]kMg=_Kf]Wif?WClM44
c/c<d]^AoaoV]Oodg_oFn?mkVh^8_HnRMXEi`?okoookoOo/]_[nooWn3gNCJ6^B
WZJ>Ig>joooloocho_go1?kkn_Sno?l@mom^J^3oo_ogl?cooogen_oioP[oo_cm
ooojmO;fo?co5iZ2X?Coon_Wm>oYkoO@H`2eo_ooj_obh_Wn2_[hmo_oooghnO[m
o_lgo_gdnocinoogiochdlkom_oOol]Y>FofokOVkoocoOkFlNOmj_[olOC=dnGc
l_7dlNW^k_3bmO[nobKmmO3amoooo^S@Zc`k:P0Z;30f=c0S638gA4m;@TA?Bde8
?ce2?C;n<`@d=cXn@?hkA3`o@dM:>CHb<38g?T8W<Cm:C4Di<E=7@D=1>Sa6>3Lf
=c]1Ad/^9RL/:2mJSL;4bmOUkNgZmoC_imoJemKNg]gLfm_JfOWHnM?ad@C>c<cB
f`?QT?l2bO[no?l:LZ^8OKeiWX6@P/Smo`Olo_oPboonooWn2fYnHUj9Xj:FHfjd
noko0?ggo_ko0_kmo?ko5?_gmoWioonE@:_omoSol?KoonCVooWn3?omo?koooSa
o_kmoOkmoaJMI;7ooogoo^SajX@D<jGoonSfkonUooWnOocin?_ooocgnO[lo_km
o?[eo?chnOcbh_oilJWkgOonbRD/`oonn]gZlOocoOkGl^Gmk?[mkoKBk?SkknW`
n?SomoChmno[kN_joooSYfPo8APY=QHZ@C/b=C]2AD@o>ca6DU=9?Ca2?cdj>Sm2
?C@n?chk=cHi?CXk?3ho@452:C@`:bT/=3i4;S@l@TA0>SDi=C]7BT4oA4<o>30Y
9B<R@F2D_lW5d^W`k_k/2NOLdmkIeMGJgmongPCMg=_Kf_SInM?ad@C>c<cBfi3o
0/Wjo_co2W:[R7fmNIj1T8;8oOl7o?koh<_oo_oioP]ZOV9NRJ>RUV=^]?_no`3m
mokno`;noOcnoaCkmoOinOooUD2[ooOhoo3foooTi_oioPcooOcnooohlOknoOgn
oOlFWFBaooomookXlNZ453>UoooXm^ooYOoioWolnOSkooolmoWjo?knoOcjmOcl
n?Wll^;onO6Ynmgoo/XU;<?oo_[Mj_7ologneo;UoNcjoNofd^chnnoYl?ShooOd
n?O_jng[n_oohjMX?b4H:CHF:T4k<SDk@TE4?c/lAU9CBCdl@Slm>SXo@Sdd?Sln
>cLf>Cdj>c`n?d11@RTd<2/Y;3@nA2hd?494@3Xe>CDkAdY1?dA3?cP`:BDS8T5P
U;o9aM;Yl>knk0WWg=?NfMGEf]oOo]h4gMcKfm[hfOWClM44c/c<d]^@o`;9n_kl
o`YbZhQm_GVNPI22b?go1ocnon3;ookonOh;JWiRGXVSXYISK[Cko_l0oOOno_l2
o_glo_lDnoOgnOWooiE0Zoogn?o`m_ooi>KonOh<ooglo_oon?7no_gmo_go5YeT
/OoooOonj?7ZQ1@cYOooj?K_ojGonOioo?Whnoooo?Oin_cno_gln_Glo?Sio?;R
ooWaZO_Mook:9Bc3ookjgN[aoo?mo]ObiOg/n_g_m];/n?__jO3hn?ogm?Sgkn_]
jo[oon>WJ3lQ62Tf5RY1>c8e>d95A3lk?4IBDdTm?48o?CXj?d8m=3ho?S/g=STm
>S/l?Sm0@D8Y=30[:B`d?T@^=3a2A40j=CTe>dM:@Cm4@clh<2TU8b91H9BobLGB
jO3^o^`9imcCg]WEeM[OgokN1=gLfm_Jn=Wido7A1<k<c=;K0mFAo`Gjd^Cjok[n
o`YTWh60cIG1R9J8c?go1okooloLoogonOh;MWe]G8BWV9EKI:[eo_ofo_km1?ko
ooGinol;jOoo`TJ<oo?oonS^oOohoPKmo?oooOG]oOlKo__jn?godY:Fg?oohOo3
6Q6con_Nooohoon]ooWnOogjnOcooo_enO_loOgknOSjooohn?[^gOoMk:SonmA`
5R^looWHnoo^m?oco?gGlnKok__mkoWIcN;ak^[an?Wah=ogooodk]:ZKCDF5BLg
<BHd;R<K;c90>S4Z:cE3CCi6BT8h=3Df?S/j?T0k=S@i?D0m>CToAT91@3ln?3/j
?cPd<2hb>dA;Ac/[8RLjDF5CAd10>BdZ<@TI=EZ4Zl[JamOboooejNWDdLoCfMgL
f^;OgMoQh=[Dg]kMg=_Kf]Wif_WElM44c/c<d]^Ao`Gjd^Cjok[no`YTWh60cIG1
R9J8c?go1okooloLoogonOh;MWe]G8BWV9EKI:[eo_ofo_km1?koooGinol;jOoo
`TJ<oo?oonS^oOohoPKmo?oooOG]oOlKo__jn?godY:Fg?oohOo36Q6con_Noooh
oon]ooWnOogjnOcooo_enO_loOgknOSjooohn?[^gOoMk:SonmA`5R^looWHnoo^
m?oco?gGlnKok__mkoWIcN;ak^[an?Wah=ogooodk]:ZKCDF5BLg<BHd;R<K;c90
>S4Z:cE3CCi6BT8h=3Df?S/j?T0k=S@i?D0m>CToAT91@3ln?3/j?cPd<2hb>dA;
Ac/[8RLjDF5CAd10>BdZ<@TI=EZ4Zl[JamOboooejNWDdLoCfMgLf^;OgMoQh=[D
g]kMg=_Kf]Wif_WElM44c/c<d]^Ao`Gjd^Cjok[no`YTWh60cIG1R9J8c?go1oko
oloLoogonOh;MWe]G8BWV9EKI:[eo_ofo_km1?koooGinol;jOoo`TJ<oo?oonS^
oOohoPKmo?oooOG]oOlKo__jn?godY:Fg?oohOo36Q6con_Nooohoon]ooWnOogj
nOcooo_enO_loOgknOSjooohn?[^gOoMk:SonmA`5R^looWHnoo^m?oco?gGlnKo
k__mkoWIcN;ak^[an?Wah=ogooodk]:ZKCDF5BLg<BHd;R<K;c90>S4Z:cE3CCi6
BT8h=3Df?S/j?T0k=S@i?D0m>CToAT91@3ln?3/j?cPd<2hb>dA;Ac/[8RLjDF5C
Ad10>BdZ<@TI=EZ4Zl[JamOboooejNWDdLoCfMgLf^;OgMoQh=[Dg]kMg=_Kf]Wi
f_WElM44c/c<d]/3ii7o5l_<go?iDo7bo6^8NGbkVK=oSX34oo[oo?ko1;[Xooco
nOh;THb3HhJ]SY=LHjOco_l0noSn5oglnocnooodm?coookooo_ok_ooXFVn/oko
0o3oonkioPSmo?gooocbjOkloaWmn^coombUXlOS/CD?Q?_on?koooSeooFgn?Sn
2?cjo?oonOCjnokl;?[gm_[ooo[jo?7Qon?`Q]fZHP2B/o?onOooaO;goo;koMSe
j?ocook`o^:nh_co?O_omLjnXV/g7A0H9S<k?C/i<cM9<dHiDUL/>T]DD4@h<DA9
Ad12Bdi8BdU<CT@c;cD/=C`m>Se8DdY7@clloS/o@Cll?3m6CE9:Ad8n?3i1@dPh
;S<kAEY_c<oCfMoUjN_ommc:am7PjokfjnGThn3Mgn?WjNGOf=CNg]gLfm_JfOWK
nMGad@C>c<cBfi7o5l_<go?iDo7bo6^8NGbkVK=oSX34oo[oo?ko1;[XooconOh;
THb3HhJ]SY=LHjOco_l0noSn5oglnocnooodm?coookooo_ok_ooXFVn/oko0o3o
onkioPSmo?gooocbjOkloaWmn^coombUXlOS/CD?Q?_on?koooSeooFgn?Sn2?cj
o?oonOCjnokl;?[gm_[ooo[jo?7Qon?`Q]fZHP2B/o?onOooaO;goo;koMSej?oc
ook`o^:nh_co?O_omLjnXV/g7A0H9S<k?C/i<cM9<dHiDUL/>T]DD4@h<DA9Ad12
Bdi8BdU<CT@c;cD/=C`m>Se8DdY7@clloS/o@Cll?3m6CE9:Ad8n?3i1@dPh;S<k
AEY_c<oCfMoUjN_ommc:am7PjokfjnGThn3Mgn?WjNGOf=CNg]gLfm_JfOWKnMGa
d@C>c<cBfi7o5l_<go?iDo7bo6^8NGbkVK=oSX34oo[oo?ko1;[XooconOh;THb3
HhJ]SY=LHjOco_l0noSn5oglnocnooodm?coookooo_ok_ooXFVn/oko0o3oonki
oPSmo?gooocbjOkloaWmn^coombUXlOS/CD?Q?_on?koooSeooFgn?Sn2?cjo?oo
nOCjnokl;?[gm_[ooo[jo?7Qon?`Q]fZHP2B/o?onOooaO;goo;koMSej?ocook`
o^:nh_co?O_omLjnXV/g7A0H9S<k?C/i<cM9<dHiDUL/>T]DD4@h<DA9Ad12Bdi8
BdU<CT@c;cD/=C`m>Se8DdY7@clloS/o@Cll?3m6CE9:Ad8n?3i1@dPh;S<kAEY_
c<oCfMoUjN_ommc:am7PjokfjnGThn3Mgn?WjNGOf=CNg]gLfm_JfOWKnMGad@C>
c<cBf`?KTOl1f>Kno`2Mo_l<OWAkOZ:FSg61MKgonOgo1O^Xk_ojooWn2iN:Rf>6
]XfKIf^/m_ko0?ChoQkmno[ko_ooo_?dooodl?Kon_CgoooN>fG0oooenooenOh7
o?cmoooll>KhoaKaoOoOMEIo03Z^ooo^encol_[jkRmdooWn7ooln_coo_Wcn__l
o?_hm_Cdo?kko_okjooonRH667C:nomol][enOobn_cHmN[omooolooYfOGoo>KF
bl=49ad^=B@J8TA0>SHg?DA9<dAE9DHdC4U3@clf;Rlh@TM:AdEBI61?BTeGFDH^
;cl_>40n=cM2CTe8@Sdk?D54@D50@DA8Bdi3B4e@CdU2?C<eBG2G^Mgijn_/k>_Z
j>ODg^_dn?DIj^3Lf=KIh>GUi=3JhnCNf]gRg]kMg=_Kf]WifoWFlM44c/c<d]^A
o`7Hi_ko09gno`anM7]nXYJ?LH5e_OoioOl5njS^oo[onOh;UhZ;HhJfSI]WJjcf
o_l0m?Sn7_gkn__nooonloCoooC`m_ojm?OoomhkIL3oooGkooGioPOlo?goooc`
i_So5_7mommeEWl0>ZkoonkGk?obn_[^;gConOhOoocjo?onnO?jnoclnoSfm?Cl
o__noo_[oooj9PHHM<[kogobf_Gioo;jo=Sej_ogoooconWImOoli]K;`d@W7Bhe
91XRA40j=SLmA4TcA5DUASA<BD=3?cH^;cQ2AdY7AE9TH4m:CEMIARh_?blh@3hg
=d9>CDQ2?C/m@DA1@D11A4Q;CT=8CE1?BD8m<cE9L9NigOW[jnc/jn[XimCNjoCh
mAWZh=cHe]WPiNGTd=[Si=kJgN;Ng]gLfm_JfOWKnMKad@C>c<cBfi7o0MSVo_l0
WOko37idNgjRUXmaPGFmooWmo`GkZ>kon_oioP^GRX]SQ[J=VfM[[?Kno`3dn?hN
oO_jnokoookcm?oom?3foo[dmooogS]U`?oomO_omOWn1ocloOooo?3Vn?lFlOgo
ggEFO`0j[_ook]O/oo;jn^h_M?oioQooo?[lookilo[ko?ckn?Kdm?cnnokonn_o
ooXV1QQdb__oOo;JmOWol_[lf?GZooOooo?ojMWeoocVe/_3A2LM;SDT6R94@3Xf
=ce4BC=4EBE6=4a9@d<o=Rh_>497BTM5DVAPCdY=EeU6;Rlo;cQ0?SLg@Ti=B48m
>ce1A451@454B4]>@dQ=D4m9@Sdc=DU`UkWMnN_[k>c[j^SWe=k[m?Se6N[Pg=SF
fN3UiNC@f^?Tg][Mh]kNgMcKfm[InM_ie_7A1<k<c=;K0o>Ao`CKeoGon_ko3OF4
J8VF[kFIJG]a_?ono_l6o_NMl?oiooWn3hMiPU^3_9>VLgFcn_oooNohoP[mn_Wk
o_ooo>c/o_go3nooonkgoo_Z^W1R]OgonOoioPOlo?gooo__iOgo6okmo?ccn_oj
/DlJ5h;Doo_[oookoo;ono8ER_OioQ?ooO_lookhlo[ko?cjn?GckOKknokoOoGh
^XT0C;SWomc/kOGooo3am_[ol_[lf?K/oo[oooCokJR^WW11:1lL?BDO;c4V<Da4
?cL`;2`_<A`jD1Q:@5eF@4YDE4]1?Cdl?c/kCV1D>C]3E5Y5;3=;?TE9@C8/<ci<
Ad0k?458CSXj?3i0@D93C3/W7RiBOIW:cMken^kU:>KWinSYj>KTh]kTi=[DemcO
i>;QhnKTg]SLi^gVf=?Ki]kNgMcKfm[InMcieo7A1<k<c=;KTOl4fmOeoo[no`ge
Q6R9UZneVFUkLKcoo_ko1_kgWO3onOoioPn7NH9KPkbCYW=e/o[ooog_n?h:oO[i
nokoooc/k?kmo`o_ooo^mookj[Y`H[GmooWonOh7o?cmoookknGmoa_noOcllo[o
n[5?6QN2e?okjooonooboo_b5H[gnOhCoogko?onn??jnocln_Selngfno_nogoe
n;Z904bhiooLk>geooo`lOKjoo;jo=Sfk?ojooodonfX[Yi`@BPO73dU7bla9S5<
A3lg<2`/;c4L>U0HBT1MET1:E5A;@Cdm?3lk>diPE3Tk@eAJAB`cBci5BD4b;3<n
C4M0>ca1B4hj>S`n@452@d`k9ah^DWfIb/gNmO[^iBSVinOXjNSVi>;Ni>CJe=OL
gnCRhN?Vi=kHg>K]i]SCfnKNg]gLfm_JfOWLnMOad@C>c<cBfi7o1=_GmOojo_l=
mHAXRIJ_]IUYNg6lookno`Knmig`ooWonOh?QgV2Fh>lTjIcMK?jooomkoSn2_gj
nO_nooolk>cnoOl?koook_OonnZjL6:eoOoiooWn1ocloOoonnoUoOlKo_glo??j
ooZaCaXGP]Conn_ooo_ol_oklQF:moWn4oomnocoo_Scn__lo?[hmO?]m__ko_mo
mORjR@1<^>Oog>c]mOool?7fn_obn_cHm^con_oom?o]Z:jNL44X7a`m9Al_<BHa
C4@o=c0/;2la73Y@64Y0GEI0BUADBd4m?C`o>c]>H5@i>d=DFTD/<d/nADU1<R`c
?Ta7@3/l@DQ>>SXl?T11@T=<>bLN;U9mVL[=g_Gjk^DXi^OWj>WXi^CRg^CTf]CG
g=oTh^7Si^CNf=cVkNKHdm_Vg]kMg=_Kf]Wig?WGlM44c/c<d]/48:WonOkdo`Kn
oOfinOodo_lDn?UdOGBJY;:MP4mY`OOoooSkooQko_l0nOWn5[M]R6jDXkRgFgF>
ooWho_[on_Ooookko_l=o_cloOkol_Gio?glnOOioPoon<ImIY[Ron[ooo_looo/
o?l5l_ColOgfo_momo;k_60S=8CJof=gWN7oonkooog`oon6o?o^m?[moOcmo_oi
moook>Ogo^_UloW`jo7al??koo[XfHTe5cWLn_objOGknO_oooSjn_Whm_CblNoo
onoP_g8T8R0O8b/`;be1>3Hl>S0^=DY7@CXd<2h];cPn>BdY<CaID4M5B4TfA3e:
@SXlA4Y:Ab`h@d8j=ci8=SXn@D4n>CHeA59BB453BEE?@RlP7bXf=6>F]<SMkoKa
kncXi_kUnNT7iN;Nf]WKg^3ihOSL1]_Kf]WHemOig0oEe]OIfMOFeMGDd]3>bl[9
nLl4b/S9cmVYooWnm?l6o_gm^OWom?ko5?SiM7edVZBbWH1?JL7gooohnoohNoko
0?WioQJgKHQ^U:>h]e]eS_oin?kjoo[gooonnoko3Oklo?gnoo;enOcmo?WgnOh?
ooS6OFJJh_oZoooko?ook?co1O;doo7mm_koOoObnkaP8cB4f_mSMigQooo^ooom
l?ooQ_cok_CjoOgloOkonOOooncWmok[iO?il>_alO3cnoojj=V9=ALig?[ol^We
noWkooohn_[in?Kdl_7_ooo_h;mb928P7b<[<2l]@CPf?3X`;SE:Ad4j=30^;Blh
?ST]:C4lFE17ADQ9=T@mBT8j?4A:BTL/>4=2>SLnB3Hj?T51?STf=DABDTQ1@dUE
Cd8_81lZ=SASU[C8gNoflNo/j>KniOWY1nGRg][IfmkPnN7hg0KKfm[If=OGnM`?
eMKGfMWGe]GEe=;@c/_:bOW?1<[8bLoIZOoio_Co1_kmoKWiooCnoaChnGAmM9ZT
/Yf0CfW1mooon?_on7_no`3inOhF]ff8KYBS^;MKMHkonOSnn_ojmoooo__no`gn
o?cmo_obmOWloOcimoWn3oohaWeVV^;oj_oonocoonclo`Gbm?oaoOKnogogl_^l
H2<dQ=[oHgNMhOook_oooO3oohKlonkdn_gmo?gnooWgooo/ioOnjnGcnO3[lO7`
lo_on^SIRCDG>Mcjoo;YmO_inooon?[jnOSfm?;akoookn2oLR@R81lS:c0_;D4h
=S`j<2heBTM1>S@`;Rd_>3hi;BTa?5U@AdE8BCI4?DY2>Sa4BTY7;3Q3@SXg?TPf
>Si1@Chi=SE4DU98@D=9EDm2;b0O:SHdHiJdb=g_m_7_k>SVo^Gij@OUh]kJfM_N
h?WQn=`6fm_JfMSGeoWL3mGFemWIemKEeMCBd<k;b/Wic`C:b<W?f@?oZOoio_Co
1_kookCfooOno`cjo7ElLIFP[iYcFhWMnol1jIWmooWn8/MbPfZFXjRHFW:;ooSh
o__on?GnoocioOkmno[ko?kon?_noOl0oOWn2_GoomZZSW=Hh^C_o?l6l_3hooob
m?go2_GHWfaU01]=R<Wjo_l3Y3E3^_co1NgjgW[Zjoko2?chmoWkk^k_m?ko6OOo
n?;moocjoogcm_oodVTD>fS1jOOHg]odo_P4oOgWc?Kmof[^eLE[I4LW9SL_4b@R
8bP_<c4]<B/^>Chj?4I;Ad8m>3Dc<b/hADHm=c]1Ad8n@DU?CT]9A414Bdm=BD=<
DT/m=3HmF5E>Acli=C==CT/o=CQ9FATT=T]UQZ[2d^[lo?Slo__akn_Xi^GUi_WX
1nCShMoNg]oOnN3gg0GKf]WHf=Oif@oEe]OHf=OFeMCCd]3>c<[9nLl4c<[:d=VY
ooWnm?l6o_oo]?Komoko3?[lMGaaUJ2_VW=KRMgko`7YVOgonOhRag:3JYJSZ9QJ
LX_on?SnnoohmOkoo?Wmo_gkn__lo_ohnokmo`3mnOh:mOoofZZ>LeSRi>olo`Kb
l?Sooo;doOl:mMROK6D06df8bO[no`>T=D>jo?l5kO[NN^[[o_l8o?SgnO_^k^od
o_lImoohl_goo?[ooO?foooBJA@kJ<7YmmSNgoCnn0CmoNO<m_goJ^kEaF]TAbLV
=blC928S:2lc<Bda:bhi?SXlAT]7@Sdh=C<c:cQ5ASdg>d57@Si1BDm>BdU4@4A;
Cde9@daBBcdd=SeHEDi7?cTe<de>Bcle>4UI6B@fBfF6Z/;Bj_cln?cnno7_jnSV
iNGVnNP7i>?QgmkNgmoih?OL1M_JfMSHeoWI3mGFemSHemKEe=?Bd<k<b/Wic`C<
b/[@fJWonOkdo`Knoondm_ogo_l<n_aeO76EX:nJLe^9gO_o0NVIoOoioR;7LX=Z
UZ>XV5YbRoohn?kkooSeo_olnOgnoO_jnocnooSko_go0?gioP[eoooJZXicF>;T
koco1_;`n?ool_Cmo`[ef9m/I@0KCHS9n_ko0j@e@k[lo`G]n]ijj^_no`Sln?Oi
nnk^koCnoaWgooSboOoln_omloKoom9Y53]X`NWgf=kOm?kh1?gmilcfoOmZk]G5
JfA79bHg;a<T8R<X;c<a;C4[;STn>Sa6BdM2?CPe<c<[>4E6?CLk@DM2?T59Cdi;
BDA0A4]?CDU3C59;?C@f?EQECTLo>CDcCDi;?cDhBETI93I;IHJZ`];Zo?cho?kk
lNo[j>KUiNKij0OThn7Og]kOgoWPmm`5fm[If=SGnMT?eMKGf=SGe]GDdm;@c/c:
bOW?1<c:b]3I10RYooWnmol2o_gno_lE[_?onoooo?koMg]]T9ZZUVM[/?goo?go
1M35ooogooWn8]ilP6BCWYQlFFn6ooOioo_om_?loo[gnoShmoOio?kon__noOoh
oP3QoOlNnN?9@2a=V/6kd?oooOkomNGQijf/McHM:F>_ooomnOko2OWgkK1iOj39
m_?no`7]]Oko1O[cko3eoOgo6^kdonk2jnS`ooonm?;^ooJE8@AD/_Smooo1f_ko
0_kal?koK>GdkmnoSE8K02DZ7PdC:c4U92@V;C@f<B`a;30mA496D4U6@Shk>STi
9cI8D4a7AdUNEdi9Ad@o>U]GDTm;@cP_8B`g>cTj@TXj>3Hf>dA=DQHK82<Y>UEY
al[?d]KOjoG`m_;Vh^SWgo3^jnSniP3WnND7hnCTiNCRh=k`g@KLg=_JfMSHn=Kk
e`SFdm?Ad<k<bl[ic`C@c/gAfJWonOkgo`;noOknoaF^lookooolo_mgNff@VZZF
If^`oOoloOl5d<GoooOonOhRgWb0I9>NV7aIKhKomoWonooflocon_Okn?SgmoWl
o_ojnokmooSn0>7moakihlU0;4fJ`K_@ooomo_oeiN7W[Jag=QdYHjoooogio_l9
nOO]/7UoX<Wfloko0Nfeo_l5n_?_l?GmoOlJk_Cok/;[j?3oookdl^komYDQ15Bb
n?gool7Jo_l2o_7`o_m/iOC_gkn=DQ/09BXN3A<[<BDT92H]=3Ha;34/<3e4@TI@
BDI2?S/j>CTW=TQ@C4M7BEiGCTU7A3ljFeMBCd]3>2lQ;3Lk>CY2BSXh=SHkA4eB
5Q/P8bTjEFW7b/oBe]o[mO3fl^KRj>OOl>k[j?kV0>Oii@OSi>CUi>;Pg_3M1]cL
fm[If=She__G2=KCdm7@c/c;b_W?1=3>cM7IZOoio_Oo0_kmo_ko5Jkcoo_ooocn
ogMkKI2JZYIWJk3moocmo`G@aOoomooioR;NO81TTijHO5U_Q_ognOokooKco?oj
mo_hn?OgnOcnoo[ko_gon?h0hOgo7_WSbD0/CI[1^m3ooognooGUhNN][7Lf7BUS
[ooooOWno`Wimnf`NGnPbOKco_l1kKGno`Gjlno`mOgmoa[^m?o^`^_Xl?ooo_Cb
k_ofUB44E;;hoOoo`M[no`;nlO3nofcUm>oO_heB6`0U:Qh=4b/a9B@T9Rdd=S4/
<B``?DA2AU19AT8n>cXi>BLfB51<AdM9GUM>BDM4?cYKEe9?Bd<h;b4/=c/i>T9:
>SPf=S]4CE8F6b0S:CYEJLO:cm;Fgn_el?Kbi^;Ximo`k^_Xo^H0ioWU1n?Ti>GT
h^3Nl=d6g=cKf]WHf?SFnmL8e]?CdM3>c<_:nLl4d<k=dMT4:JWonOkho`?nn_[m
o_lE/?;oo_oon_ooNGY[S9JUTVUh`ooon_ko1_bek?ool?oioQO`RXIPRIBDOUY^
P_cfn_okooCan_khmOWnm0Sen?_oooGfmoWmn_Wn1?oon^caoOljg<?4VTXX>f9J
D4Lm=CDh67?6loo[hO[cm>oYlOoonNWok]7Jbh]Ha??jn=gHooommo7_l_OjnnGf
o_cnogS_n_[lo_OXfM6`HQ`^R^?onogPe>bYn?oPgnonoo72MCDM7R8V:Rha<QHZ
>3Db<bTI92@W;S@e;bTo>3U3A3i0B4A2?c`k>S/l:3A3Bd]:C4m8A3lk>CLe=414
BU1BCTM2H69PED@f<C1HDdTm=2dY:86D[lKEhN_bo_dDn_Kbl?3Qh]gIi?GgkNk]
j^SVi^OXnN<7h^CWjNSUh=gig?SN1]gMg=_JfMWie`oHemKEeMKGf=;AdLo>cLc<
nLl4dm3?dmVYooWnn?l3o_[joOko5K3bookooo[oogUjJhbFYI9YN<?ooo[no`Kl
]Ncooo3onOhGl8Z6H8VDU7iJKX;lm_[onoodlO[nn?Gio_@8mOSkoooem_OioO[i
oPCooo[/lOgo>]c3a9Y::3]RFU17?CDe>1Qca_?ojn7jloC_jO7oooWYonkAf/^;
F<Ccn_SMf?oooOOako;gn__Um_klo_mhko[jo?kgj=WA/68L;X[Soo_mh=C/ZOSo
h=o_o_oa`WDe7AhR9RX^<C8F:SPe<S<Y6B@T9bhd=BlY?cPi@d@n@4Q4@Sll>cXk
?2Pd@d];BTa?B4@o>cTg=CA0A4Y@DTi7@V1RH5E4=S4`F5=9?C@]:BR1U:o6eN7[
l_km5?[fl_3`hN;MfNCemng^kN[Xi^KWj?WS1n;TinWXiN3MnMchgPKMgMcKf]WI
nML?f=OFeMGFemSBdM7?c/g<c?W?1=?@cm?IZOoio_So0okjn_gnoaF`l_onoooj
oomiNV^<UZFBJGS3ooojo_l6o;G/ooo`ooWn5o2:QV29U9AnFVj2o?Kjoo_om?7j
o_SenOkd2?GhnooomOKgnOgjnOh4ooojk?7moc[L`lBJBRPkHUY@Acde=CPHLlKc
on_Qn_?dknWaoooijOo^dM[;ReS4lo[hgMSooogglNobmo[kiOKno?koN>ojn_cn
mnSIdK1R72j:hookoN3Dk:Whon3OkokolL9e=AdN8RHZ;S4b5RXh=C8c:ATT92L^
=3D_:Clh>D=4?T18A48o?3/j>c`X=4=;BdY<CdQ4?c/i=cDd@4A:D59>Ad9PHV1E
A3Ha<5QCBCdd;BTXPIB_a]GQjo;noACjm_;`l>7RgMWTmOO]k^gZj>KVinSih`OR
i>OYj>GPgOWLn=h6gMgLfm[IfOWG3mSGe]GEe]OHd]7Aclk=c<cic`CCd<oCf@@A
ZOoio_So0_ghnOko5_blmOonoooioomjO6f=UZB?LX34ooolo_l1mZ?no`7cooWn
5oZESen0SYfEH720noKloo[om?7jo_SenOkd1?GhnooooOL3n?[ko?Wno_lKm_Gi
lnWoo_WllMW>dnGMd<O:f>G/VlgYl_[bm_[o4Oc_oooNd?oo]EhTO;_Mcngog?_o
0O_doOl@oMgGi__oonbkNSP>BFRLdOOmogWioOnOc=:[_iiS:10K;SDl=2LM6QdU
:RL_;R<K7b@T9bHW;38c;RTl=CDl?3De?3lm>cTg>3Tj<3Dk?d54BDe1A4Q=DUYR
IdiAE516>2/S8BDY:RPV9bQOK8:M]lkNi/oNm?oooO?]d]GKhnW/jnW/k>OVl_ol
kNg[jOkW0NSYnN<7h^CWjNSUh=gig?SO1]kNgMcKf][if`OJf=GDe=GHf_k@1<o>
c/g=nLl4e=7@e=ZYooWnn?l2oOSio_lFo;ceookoooWoogYlKHfFY8mbP<Cooocn
o`7fXoko0O?onOhGnYF?Gh2>WIEPL83km_con_odlO[nn?Gio_@4mOSkooomm`?h
n__lnOknoa_fmOWcjOonnOcafLkCiMg@al[HiNbKcNWbn_;fn_lAo>ooomk@oone
GRAl^mg?kOoLnol1noCmoa3mgMOVnoook;]j>0i9J9cAmogoNOWmoio<dZ^oWV<X
41/^=C`d9adJ7BDZ9bl^8a/O92@W9RL/<S<^:C`e=C`l=CDl?cdk>CLh>CX`=C/o
@DA9CD54B4eBFV9WCU5DD4Hh:b<Q9BTZ:2HW:5m/PYfgc]kVcmkdooomlngBeM_S
jNc[jNc/inKbooc]kN_Yo^L1j>Wih`ORi>OYj>GPgOWLn=l6g]kMg=_Jf_WK1m[H
eMCDeMSJo]04clk>cLgic`CDdM3DfZWonOkho`;mn?WnoaKl_?Goo_oonOooNWa]
SIJTSg:0a?ooo?ko0OJSo_l1looioQOjUHmOP8jMUF1`P?_fo?ojooCan_khmOWn
m0Cen?_ooogg0oSjnocio_ko6oKenO?Yookio?7Ic]?UgM37b]SUk9_=jO;jl_Kj
oa7lkooog]3ookEN97bkgLo]omcko`7km?go4?gMenKkooo/^gXh3TUXW=7goOmi
nOgoWlcBZknNHbP@6bhe?3@W7AXM9BXW;bhS6alT92LV9b`b<bhY?3De?3`e=C`o
?C/i=cPi>S0e>cm1A4U=@DA8CE9JHVM>DEA@ASP[8b4U:BXX9RLXGfb2WKO>g^K?
g_CooogckM;Efn?Yk>_Yk>cWi_;oo>g]jnWni`7XjOWS1n;TinWXiN3MnMchg`KN
g]gLfm[JnM/7f]SEe=CEf=[nd0C?c/k=cOW?1=CAd=CJ116YooWnn?lVo?Sloooj
lM;loocooo[oogUoLY>JY8edPl?ko_goo_ocX?oon?olnOhToIVBHH6BYZ=ZMX;k
n?konOoflocon_Okn?SgmoWlo_onoOcko?konOh1n?_ko`CSl?Kfo_co1_3Qi__o
oo[mo`omkooflnCFg?Sooo3oon3]o_moemZTIRn@h?O]jNWboOojlOW_l>JaL69m
WWTm3QYS_?C^mOgnl]c3/[JHOE`:6S4X1aLR8R@[:R8m>cTg>3/n@2d_<2h^=3a2
<2`Y;34d<Rl[9BLb=S4d?Clm>SLf=SLg?Shm?3e0@dENGEU@AChm@3U2C55>BDI5
Df1fTZo8fnH0oOco8O[fnO_lo?Sbk>Sflo;clnoVgmkQh=kWl^cMk>[XinOXj^_i
i@OSi>CUi>;Pg_WMn>06gmoNgMcKfoWL1m_HeM;BeMSKnll1c/kic`CCd=3Dg:Wo
nOkhobKln?cooo[ad_coo?oon_ooNGmbTiZTSGB3`o_noOonoo>PooohoocioRCm
VI9QPI:VXfYfP__ho_oiooKco?ojmo_hn?OgnOcnookmo?_lo_oioP7hno_o1>?`
m_Kno?l6l>7Vnooon_go3og_ooKci=KLn?ool?ooh>gnogoGfZAV;i3PmngYjO;m
oo[anNo`i[5`HWfNNCd>6V>lm>keoOkbg<>b]YQmG0XJ<BP75b8R92/Z8Sdk>CLh
>ci0;Bl`;Rhd?48`;2T/<C@b;b/U9c8f<C@m?cdj=cHf=cLn?Sdl?D13AEiMFE15
?Se0>D9<DDi9ATECH7JB[lSKiP3mo?lQn_Kinocln?;/j?Kcl_?cknKOg^7Pg^Ob
k=g/j^SWinSZjoWU1n?Ti>GTh^3NnMghh0KOgmkMg=_KnM`7fmSEd];Ef=_kc`7>
c_W?1=?@d=CLZOoio_So9_cho?oon_7Bo?olooojoomiOg:CVZB=M8?3nokmooko
lj3oooSoo?Wn9?fITV61TZJSJWJ2noSnooWom_?loo[gnoShmoOio?koo_glnocn
ooWn0OSknol4ho3fm_klo`K`hNKkooojoOl?oNoom_?Te]chooo`oooPkOkoOmOJ
Y6H_T>3gkNWYl_gon_7iko3V/G1ROIii?@hJHkcdk_Gmo_;L`k:fV7eL2QXa:0LG
8R8T:bXR?C/i=cPk?T0];c0^;S@l@S0/:B`a=38_:bDW<SHa=3do?CXg=SHg=chn
?C`m@4=5GUeID4Dn?D0i@TaACTU6AE=PMY:_b=_V0?glob7jm_Wko?chl^cXm_?b
lo?_i]oNhN3Nio;/gNcZj>OWj>[[nND7hnCTiNCRh=kigOSP1]oOg]gLfm_ig0OK
f=GBd]GHfo_?0Lk>nLl4dm3@e=`44JWonOkho`7mn_ko5oCVjOoon?ooo?okMh9i
VinWSFZ5c_omn_ko1_FZoooaooOhoRJDS6B?X:RGM7f6oO[oooOon?GnoocioOkm
no[ko?koookkn__noooioPOoo?OcknkcnOgo4_Kaj^?ooo3Mg^kbj>cmm>gln?Cj
ogobh_ooi=goook[mooofVQ^=a2=QX><WJRVX6IaNgAJA4MFBUaVHF5]M74`=Ca0
?34R5bdH8R@i;3@]?C`b:2dh=b`o?CPd<2d[:ahO9S4h>CPh?CH_;S<h>SX[9BTf
?3TmAd=1?SXh=cLhCDa;BTU4?SY5AdDm<B/]<SI;JXVT_37BhL_>eMoYlOCeh>;U
jNg_l?7Qg]_Kg^7Shn;Ph>O`lnkXj>g/ingjno?ZjNSWinSZk?WX1nCShMoNg]oO
nN3hh@KPgmoNgMcLnMX7g=WDdM7DfMcnc_C?1=7?cmGMZOoio_So0Ogjo_lGm>KY
ooohoooloo]gPWVKWjN=JXG>oogjo_l6mJ[ooo7omoSn9YB<I8nPZ9MdOHKmn_oo
moohmOkoo?Wmo_gkn__lo_ooo__jnokoooWn1oolmo?_k_?ioOlBm_7Zhoool=gN
k_;Xk?gdkOchm?[oOo;RoooTgOooo^_goooJJ6hg48f6PhbMZ:JPIW5kM5Y4AeI:
G6IQHFedLC0e?40l<B8G;APR93T/=2dm?38X;CPg;3lm>3@`;B/[7QlV<CPi>3Pm
=Rl^<cPj>R/U:CHl>Ce7@d4n>SPg=cQ=C4]:BD@n>TE7ACda:bdb=T]ZRJBl<M;Q
blkEgnWam?GPh^GYkNo`lN7Nfm_NhN?Sh^3Pio3ck^SXkNcWkO[kln[Yj>OWj>[/
nNP7i>?QgmkNgmoih?SQ1^3OgmkMg=cifPOLfMCAdMCIg?k>m<l4dLo?eMfYooWn
n?l1oO[noaOdi^WoooSooocongN2NI^OYheZQLkooO[no`KeZ_oolOogn?hVU8aT
Sj2XUgAmQ_gjooogooSeo_olnOgnoO_jnocnooonno[ko_oonOh7oocglno^loWm
oa;flN[Sooo`gMk^l^S/oOC]o?Sdn_mol^;oonCMooonjoOoomYXKSL@SHJ3S9fX
YZ1VLG]dFTA7ETYLIV5QKGAa<3Dl@3`a8QL]628T>B`d;Cdl<RP]>3L/?cdh=30]
:b/N7bHa>3Th>3df;bhc>3Xj:bDY=S`i?DM3@Chj>3Lg>4e<BdY9A3hjADM5?C4[
;C8fBfZ9Y;`ad^7;c]GOjO7dmN3RiNW]ko3ahMkKfmkQhn?Rh>3Wl??^j>S]k>O]
n__cj^WXinOXj^cij0OThn7Og]kOgoWPn>46h=oOg]gLg?WJ1mcIe=7Ae=WLo/kd
c`CAcloEg@@GZOoio_So0Oglo_lGlMohoogfooomooQfQ7jPXjR=GHKJooogo_l6
n;?lonoomOWn5_n?QFJL[:F4NX68oo_oooKon_Ooookko_l=o_cloOkon_Sem?Gh
o?oho_go0?gno`ofmoooo?gooOoikoSooo_koOl7o?7ol?WkloCnofCamN7Lkm^Z
U7^JY9I3LTm3CC`Z92P[9AdQ?TD]8c4d9a//;QlH92`X8Q`G6R<]<S@_9CDJ?Plc
FC8]9BPlBS`T?cT`:bdf@TY;>2LT:cE2C4Ln=34f?D53>cDh@dM3AU18AT8n>ohi
@EMHFEYFBcdb<dAMMhn[b=cXlO_mn?Kio_;`l?;dm?3/o?Sck^g_loK`l?;fnOSd
koG_j^__knOOlOG^gmcUj^OZjOkW0^W[k?WY1nGRg][IfmkPkn45h=oNgMcLnML7
gMWDd=3DfMgnc_k?0M3@n<l3cLkDgZWonOkho`7mo?ko5o7On?omm_oooOohMXAn
X:>XSEf6f_oomoko1_Rco?o_ooGioQKoShEVW:bUQ7Z1R?okooofoo[gooonnoko
3Oklo?gnoo[hmOCen?con?kmo`3mo_l?m_OooocmoogonNohoooknogo1ocaoo3i
no?do_mTlOGQg>oKZYAkVZBF@g9?@ddl:R@X:bDM8Ci5;B<a=2LK;2hO62@/:28L
5aXS;C8d;bDe6Sh?<eTb;BDX?4Xl93li<2/]=T9:BcPW92/e@Ta7?S@a=Se1@c/e
>4=7@dI@B4I2?S_n>D5GF5UJET/m<S=4GGN?ZlSLj?7koOSfnOkbl?3bm?C`k?ch
lnk]ko?fl?3bm_Whm>oekn[[knoWgo7ek]oLiN[Wj^Wni`;Yjncij@OUh]kJfM_N
h>oQ1N3Og]gLg?WG1mgIe=3@e=WMo/knc`7@d?S?0lg>e=jYooWnn?l1oOcnoaOa
goSooOKooogon7J4OZ2SZ8eMQ][oooOno`Kh/ocokooenOhFohn5IYb/YHAjPHSo
nooom_ojmoooo__no`gno?cmo_ojn?GdmOSlooSnoOl0oOko3oKgoooloOomooW_
n?oono_mo`OllOo`nO_cm?koI?7ehMc_fjZDNiZTUT=bCd==?2XT:2/U7B4nABdS
<C@W6b`^7aPT;2PR71LJ8bdb=2lU=AXn3c=I<RdU:3a:?2@o>C0[;CI2BT/h9b@[
=D9<Achd<CHm@D<k=CQ3Ad=6D4Q6@ShkoSU1EeQIFUI;?C8cA5egSj_8g>Sanogh
m_Wnl_3`l_Cdl>cln??^kNocm_3`l_Kin?C_mNoZjno_imoamNkOg>GZin[Yo^L2
jN_/nNT7iN;Nf]WKg^3_h@GPgmkMg=cie`OMfMC@d=CIgOk>o/l1d=3hc`?=c]CN
0mRIo`Ojoo?on?Go/_So2hZ7N;:fXWmiP=[nnOko1oKYb_OomoWonOh?oj]jGWn_
Y[MZJ9?on?odooWk2?[mo__gmocomO[o0O[nm_mPmoSlo_[loocdo?oonNoBoog]
c=76albK[ho3XFmiFS8b9C8S7QXL8bX^;R`V;3Xj;c=3?Shm?C`k>STU:Bh_;B`]
;S8^:b/^;RTT9bHW;30`:R@Q<bdV<BPN;bPX:BTZ:_h[<eU[B2@V=S/iA3LI5Rde
9cDl?3Hd=B/K:2`c>CTa9Aa:AD=0=2dmEDU2>S4Z?G6Uf]oWlO[noaoal?3_k^g/
k>OWj>WZj^_[knk]k>_Yj>S_knk/jn[Yj?WV5nCTiNKWj>SYjNSXinKUi>C]j>CS
iNCOf^WO1mkNgMcKfm[InML?e]GCd];CeMKAdM3?c/g=c?W?1<_:bm;LVOl7n_oc
ooSeok;ho`^:QgRb]Z9oNH3Jo_Wno`OfjL[gooOiooWn3on[NUio[jJgJVRCooSo
m?oin`SjoOkkmoOlooGjo`7jo_KoH?Oho?kjo?olm?coooW_d_omkLcAa/O<Vjn?
`j5_NEXb<RDb8ahJ72<Z;Rh/9R`j>Rlc@chn?Cdl>cXi9BT^;bd/;Bhb;R/[;RhY
92LV9b``<2XT8C<]9S4X7RlX:2TY:R[n:c=IJdPT9SHk>D@g6AH]=BLe?3`f=3D[
6bP/<cTi<BDLBTE3@3@]?EE9@SXa:SeaYM[Oio7jo_lOlO3`knk]k>cWinSYj^[[
jno^kNc[jNSXkno^k>_ZjNSiiQOTi>GVinSXjNWXj>OViNCTkNSThnGTgm[Yg`ON
g]gLfm_JfOWG3mKEdm;BdmGFdM7@clk=cLcic`C;b/_Bg9Wo1o[oloohmOnbn?l;
RXMh/[JROgV0f_kio_l7m^W:moognOoioPooZgYNOjnV]fYXToohooConO/8n_gn
noOgo?oen_l1n_kfof3gn?cnn_coo?Cloooikm;ooNg<dLK7c9^_Sl>QKgUJ<S8U
<R<N6Q`S:Rh^;2H/>SX_<d<n?Sdm?3/j>BDY;Rl];2d^<Rh[:bh^:B@W9RL/<30Z
924c;BHa:1h_:2PY:BXZoR/cFF]892Hf>cU4=aTF;CDW=C`l=S@e:a/X;3<i>C4U
74Y5@d0d;CeEBD8j<BXmLJGJgnOan_ko7o7`l>o^kNc/inOXjN[Zjn__k^g/jnWX
j>o_k^c[j^WXnNHGi>CUi^OXj>WYj>SWi^GTi>gXi>?Ui=oJjMl7g]kMg=_Kf]Wi
e`oFeM?Bd]?Ee]7Ad<o>cLg<nLl4bl[;d]`3o9Wo1o_omOoimongnOlGni6EPK:e
[YR3RN3omooeooK>e?Kon_;onOh?njAdFWZXWJecIhWlnoocoOWk1_[mo__gmocm
oaO_hnG^m_[kn_?]kOGmmOCakN[^moolmocnobkfmO;G^7N:BRdC:B8Z?21=?WQ`
@eQ=>da6E4e:AdYAEUIEGE1=E5A<CEQ7AD=0?_hm12X]<34`oRlG;2`^<cLd:R8R
8B<Y;c4]:B4d;BHa:B0aoRmL<34a<S99J6e69R/k@30g;1TQ?dPj:B/U72<f@T5B
ASXh@4Y?Cc0b>Shb8R@b6C]e[<_Jl?onoO_hlngXiO7`l>o^kNc/inOXjN[[jncd
lo;al>o^k^o^kNc[j^WYnNLGi>CUi^OXj>WYj>SWi^GTi>_Vh^;UiN7MjMl7g]kM
g=_Kf]Wie`oFeM?Bd]?Ee];AdM3?c/g=nLl4d]7BfN>Io`OkooGonOOo]oWo5o^A
UH6b]JjHPhWPooOomOofc]Cfoo[booWn3o^TM5YjZ9f]LfN9o?_ologin`KjoOkk
moOloOlGkn?Uk_Kjno[ckNgeoOGdlNgZk_Ooo?Olo_l^m_GbekQgRTX]4bTR:S`P
CCihL4=HCC]<AUA=BTM:DEIFEEe@CEADC4eHAdE3@3kn?@@Z;C0a<?h_5b`/;S<g
=2XR8R4S:Bla;BTQ=2dV<BTP<Oh_G30a<C8bBFQ]ARH[>d0`=b`I8Cm8>RT[9A`S
=T91DTHj>41:Cdl`<SXn<R8T<QTkMJc;f_3oo_gkn??]j>Gal?3_k^g/k>OWj>WZ
jn_/m??blO3_k^k_k^g/jn[YjOWW5nCTiNKWj>SYjNSXinKUi>C[i^;RiNGQgNWO
1mkNgMcKfm[InML?e]GCd];CeMKBdM7@clk=cOW?1=;Ad]WSVOl7nooeooWgokOi
oaOkTIF1/[F^V8>9h?ogooGom/kDm_ojl_oioPokY7AJNZRM[G=WROckoo?mnO/6
n_gnnoOgo?go5noSiNkfn__jlng]mOgem?7]j^kgoocgo?ko;_Kel]NhMhY:;A<Y
8RXl84dnN713F4dkC4IDCDY7BU5FEUEMD4eDE4a=F4M5@d0noSd4:Rd`<C3n;aL/
;2hc=c@Z8R8Q8bT_<BdY8C@]9S4Y837n;e``<C4b<TUXKDHV:c]0<3L/6B4oB3XY
:bDL8cI2@E96>SQ0BTm?<38j?S8R938I>gF/bm[`ookmnoSckNSUlO3`knk]k>cW
inSYj^_[k?Ccl_7`knk^knk]k>_ZjNWiiaOTi>GVinSXjNWXj>OViNCTjnKRh^GU
hMgYg`ONg]gLfm_JfOWG3mKEdm;BdmGFd]7Ad<o>cLgic`CBdM;Ih`?TVOl7nooh
oo[iol3ioaOdTI^3ZjjbZ8B:hOogo_;ooK7]o_7olOoioPooZgiVQ[6S/7aXPoWo
oo;dnO/9n_gnnoOgo?o`m__o0?gno`3mn?mon^ooongH^i1YEB4/=2=>@4eJD4M<
GDMlKjE_?e=?AEQ<DTI4A4Q>Cda8IeM=DUUFE5ICCdU3?cho@38c=CHf=38`:2Xa
>Slj;bDN7AlU;C4_:b<e;RHb:R8d<c@e=SLh>CUNJf4k9Bhl?TA1;Q`V?CdY=dE>
BTE1<b8[;34mAdPA?cAGA34W9cUSRlOAj_oonoOlo_TJmoC`k>[al?3_k^g/k>SX
jN[[k>c]l_;al?3_o^h3kNg/jokZnNPGi>CUi^OXj>WYj>SWi^GTi>SThN;VinCP
jMl7g]kMg=_Kf]Wie`oFeM?Bd]?Ee];BdM3?clk=nLl4dm7BfN>Io`OkooSon_Wo
`?Wo5oBAVh>[[[:XQ8[QooOnl_om/NgnlOoaooWn3on[OVJ6/J>`O6R3nOool_Ci
n`WjoOkkmoOloo3fnol0oOko0?ghogojkoookMRkT6UE8B`d8di0CEY@AdaMAga_
YFloDdm5F4aBATA4B4i?C4QWEdeBFEIDEU=?BD<o?Sm0<S<e=SHd<S0X:S4j?cX_
9AhM7bD]<Bl[8cD^9S8Z8S@c=3Df=cPi>Ei[HC/U;S`nA44^72Hm?BTgADi:AD4c
8R//<Ce7B14o=5M4<BLW>F>;am7ZoookmocnnA[gm?3/j_7`l>o^kNc/j>SYj^_/
k>gbl_7`l>onkP?]kNc[o^[ij1OTi>GVinSXjNWXj>OViNCTj>CQh^KWi>3Yg`ON
g]gLfm_JfOWG3mKEdm;BdmGFd];Ad<o?c/gic`CCdM;IhiWo1o_on?ojnOo0nOlG
m96KPj^^/ZR4R^7omokboofakOkaoo7onOh?oj]nIXJaXk1lJ8?iooobm?Wk2O[m
o__gmocol?Kko`3mo_l0oOSoOo[_ooo]f;^@JEDQ;3@SCT1=FU17C5e7O6nUKcmC
CdEHC596A4A8CTm<B6MGCE9IEUAFDdm9@cln?d0b<cDf=S@b<2PZ<CXo>RlU7QdO
9Bda;b/S=BhV<RXR=3<d=CHg>3TiGV]Q>bD^?3i4@BhL9Sdm:CM5CTY5@C<R:b`a
?DM84CldEd@a9bLiHh_7dN[ooo_go?ki6_Odl>cZlO3`knk]k>cXj>WZjnc/kO;b
lO3`kok^0ng]k>_nj_WX5nCTiNKWj>SYjNSXinKUi>CXi>7Ri^OTh>WO1mkNgMcK
fm[InML?e]GCd];CeMKBd]7@clo>cOW?1=?Ad]WS0nBIo`OloogooOccc?Wo5o:<
TGRQYJZON83LooWon?ooX_oojOogooWn2_n_Q6f<]ZFaOVj<o_l1l_Sin`ojoOkk
moOlookel_WlmNo_oOmoo_Wbk?W`i^3LdKn`>2XT;ca6E6A;FeQ9EdDmBV9JFVE=
OF:8QU5PFU1NBDMHEUMKGeiGDDXn>45@Dda4FEA<A3lm?Slk>SPi>cTe<2`]<CPm
?3D^8R0O92X];2PU=bhV<R`V>C0a<S@e=cPiDUE7;bD`>CM@A2hP;3df8Cho<b8A
8SM;DT9AHFEH@B/O4biUXloXoOlMoOWfko;kjNc`m?Oin_[al?3_k^g/k>WYj^_/
k>g^o^[ljOg/oN_ij1OTi>GVinSXjNWXj>OViNCTiN;OhNKXi^;Yg`ONg]gLfm_J
fOWG3mKEdm;BdmGFdm?BdM3?clkic`C:b<W@fYWo1ocooOomo??<nOlGlXbAN:6U
ZYmhP=conOohoonRoooYooOonOh:ojn4KHbfYK5nKXcno`7bn?Wk3o[mo__gmoco
o_GbnOceknomogonnO;/nO3Vh=cA_k0h:R@_?4IDI4]KF4UGACe:HUYJIDemHXR6
DF1JD5i9AeQFEe]OGUMABShh@E1CC4AIE4a4?cdn?c/j>3Tk>CD`;2da>3dl=BhR
81lT:Rd/:2Dg;RHb;2Hi<34b=3Dg>3UBEDL_9C0i=e14;R0/?CHQ?Slc8Q4R=d]B
@U5QIEQ1:alC;VFScnSmoagmnOK_l__Yk?3dmoWjn_7`l>o^kNc/jNWZjnc/kNkn
j_cYoNcmjoWX5nCTiNKWj>SYjNSXinKUi>CUh]oQi^SVh^WO1mkNgMcKfm[InML?
e]GCd];CeMKCdm;Ad<o?c_W?1<[8bM3JVOl7o?omooglllcioaObS95hXJFZWgR0
g?oiooSooj;oonWomooioP[o[hA]S;JU/Gi^S?ko0O;hnO/?n_gnnoOgo?onmO;i
o?G_kogoOokil^cil>KPg=6o/3PZ92llAUATBe]HBEM5?DYRFUYUCGeRR8IAH5Y@
GTU7F5IGFemNEe5:?SQ1D5=<A5UDC4@o?Cho>cXh>C/i=C0/;C4h?C`e;R8P7b@Z
;B`X9CL^9S8/9ST`<C8d=CLh>E9EAblU<3TgD4@^82`m=R4n?c<R4B8gBe92DF5U
F44[7a<^IJ??j?go7Ogim^obnnW/l?CgnO[jlO3`knk]k>cYjN[[k>c]k_kZo>Wm
k?g[nNPGi>CUi^OXj>WYj>SWi^GTi>GRgn7Vj>KRjMl7g]kMg=_Kf]Wie`oFeM?B
d]?Ee]?Cd]7@clo>nLl4b/S9d=X3i9Wo1ogoooSoon;InOlGo8f:LZ:WY91dO]_o
n_ohooRSoooWooSonOh?njIkHh:[VZEiLi[ooOocooWk3?[mo__gmocoooSVk__m
ogokhMCBbk^[ME`k9RD]=CQ^JFEPDT]LM4MLEVAhNV=/JVQ^OFZKLhYnBUeKEVQF
EEaJFUaNG5A=@ChmAUAHBSQHE4e5@3dl?4<o>c`o?CH_=S8^<3Dj>SP/:2@T:2XW
92Lh;bLc;bXn:BX[;Blb<c@j>SD^<3Pj=D@g:2HiC4Tj@CI;Bcdc=CHb;RD@000`
P;oGhocoooWTg^_SiOCmn?CfmoShmoCak^_al?3_k^g/k>[Zjnc]k^k_o>SnjOg[
oNcijQOTi>GVinSXjNWXj>OViNCTiN;OhNKXi^;Yg`ONg]gLfm_JfOWG3]KEdm;B
dmGFe=CCd]7Ad?S?1<K5a/gGVOl7oOoon?ooh]WioaOlSHYbXZNTT7AnfoojooSo
n:?oonOon?oioPokYW]SPZ^JYGUcV_omoo?onO/<n_gnnoOgo?oon>K^nogoOo_Q
e=;;^j]eG3/V9Bde>6iYIF1BBeadAeaFI7QjHfaZJ6imJY]cRWi:GE]FJ5IEG5YJ
G5iLE4e1?Se6E5Q:>5QDCDE0?C`l@clk?3lm=Rlf<Rh`=CXj>2`X92@X:RLT9cP_
9c<_:ShY:R/];c8c=3Xj=Bh`>3XeA3LX9SU<BCY1=T];?C<e=S8^9A000320_mOS
o?oonNCNjn?Um?ghm?Kgn?Sgm?7^jo7`l>o^kNc/j^[[k>g^k^olj?kYoN_mk?WZ
5nCTiNKWj>SYjNSXinKUi>CUh]oQi^SVh^WO1mkNgMcKfm[InML>e]GCd];CeMKD
e=?BdM7@n<l4a/G6cMNIo`OmooohoooRfOWo5ob=RW:RYjB@M7kKoo[on?ohXooo
ioohooWn3o^VNf>2ZiZUNG>Joogolooin`cjoOkkmoOlooohi^kkoOmonn7Dd/^k
ZgEL>bHU;CDhKVUUH59;G7A7G5ITN7YSK6YXKWeZVg>:OTYMFeIXEUELFUYLGUaD
CD4n?DIDF4XhF5A=AD0m?3a3?c/l?cdf;cHb;S0e>SXh;2PT92PZ9b@W>2lW<blZ
?RTZ:bd_<S<d>SXe;S0h>SE4=bPV>Da9>T4fBd/m<cDf<RhU4000<82oen?loooi
i=k[hnGdoOSdm_Ohn?OdlNk[lO3`knk]k>cZj^_/kNk^kocXo^Wmjog/nNXGi>CU
i^OXj>WYj>SWi^GTi>GRgn7Vj>KRjMl7g]kMg=_Kf]Wie`kFeM?Bd]?Ee]CDdm;A
dM3hc`C6aLK=e`?oVOl7oOool_oodnGhoaJDTW^//:RAN87NooWolOcN/oookOoe
ooWn3onYNf:0ZYZWLg:Loo_om?oin`WjoOkkmoOlooSco_mojM3=NUdk;38n@T1T
HV1RIfUWI4ECIfeMCUM^J7MJJfa`@TEHF5aYF8UFGge;GeU=Ge5FBdM3@T=0>C=:
CTe<DE=4<EECCd]5@3`jBD8k?44o=B/l=Bd[<3Hi>C@^:2HY:RLT:CT_9c@a;T<V
9bT[;S4b=38c=3Ll?S/fBcha<3a2AD8i9SHl<BPZ;BXHFJgWn?OhoOodinO[lOoo
n>g/m?G/i^WgmoSgmO7^k?7`l>o^kNc/jn_/kNk^ko3[jnc]kNk_kokZ1>_/kNg^
nNXGi>CUi^OXj>WYj>SWi^GTi>SThN;VinCPjMl7g]kMg=_Kf]Wie`oFeM?Bd]?E
e]GEe=?BdM7@nLl4c<_<dmfIo`OmoooboooCiOSo5YBBNjb`Z95hPMkonOoao=jc
ooo]ooGonOh?ojUkHX2ZVZMcLYconoodooWk2O[mo__gmocon??nogoYd<ejGC//
<Si2@6ARH69WJFMTAE=WKEe>EfiXMeY[K712AEQHG6UHREIOOD]OFDeODEI;Ad=2
@d0i<dY>CDaADd@aEE=?BdE0?3Y9@S/l@Cle:c`e;B/`=STi=2hX9RTZ9b@Y>BlW
=34^@bHW:B/^<C8d<S<d=c`n>cI;?S4`?495@STV=S`a:2X]:QQI[NOhmoSmooCW
in_aooohkNcdmNcVjOOgn?OelNk/lO3`knk]k>c[jnc]k^k_l>_[k>g]k^o_o^X4
jnc]kNkijQOTi>GVinSXjNWXj>OViNCTj>CQh^KWi>3Yg`ONg]gLfm_JfOWG3mKE
dm;BdmGFeMGDdm;AdM3ic`C<blcCgIWo1ogooo;oom?Un?lFU99k[;2XTGR1g_oi
oo7lg[?oongomOoioPooZG]RP:ZJYg=bW?okooConO/9n_gnnoOgo?ohlokoOnW@
cGYM>b`b?T90I69PHVMYIfA5DfM]GDiGKVQgFV]/L495F5QLJER9EUmmBemICEmA
ET]7@d93@3TcBTi=C55CA35EDdm;AD0l>TU2>ca1?cD[?3D]:c0f>CTd;RPV:BXW
92Ti;bLd<Bi39RLY:bha<S@b<c@g?3hk=T/n<C0l@TE2>BHf?34X:RdZ65V]ioSg
n?gom>OWjo7oooS]k?Cek>KYmoOhmoGak^cal?3_k^g/k>_[k>g^k^o`jn_/kNg^
knonjPC[k>g]k_WZ5nCTiNKWj>SYjNSXinKUi>CXi>7Ri^OTh>WO1mkNgMcKfm[I
nML?e]GCd];CeMKEeMCCd]7Ad?W?1<c;c=?M10:Io`Ono_o]ooo7koWo5o^GX8Va
/JjOLWgKoo_olok7d_GoooWhooWn3on_OV5oZij]LFV>oo[olooin`SjoOkkmoOl
ooKnognnG2DQEU19AT]IJWI;FVehMfaQFF=[NX1aG5]WC652H61mFfmeLVmfIY]V
JHIGJUa7EDeIIUmHE5=BCDU=E554@TU7>e9DEEA?B44lC4<j>d4o=2Pj=2l^<C@c
<3D_:BP[;Rh/:c/`9c@b<4HZ;2ha=3Li>S`j>S`j=34aAc/`;4//:BHU:2HH2R1Q
Z]Oko?W_iNKcoo7]l_cghm??m>[Vk>k_noo/k_7emoSgmo7`l>o^kNc/jnc/kNk_
l?3Yj^_/kNk_knWYj^_/kNk_nN/Gi>CUi^OXj>WYj>SWi^GTi>_Vh^;UiN7MjMl7
g]kMg=_Kf]Wie`KFeM?Bd]?Eo]H5eMCCd];AnLl4dM3Af>:Io`Ono_o]ooo7koWo
5o^GX8Va/JjOLWgKoo_olok7d_GoooWhooWn3on_OV5oZij]LFV>oo[olooin`Sj
oOkkmoOlooKnognnG2DQEU19AT]IJWI;FVehMfaQFF=[NX1aG5]WC652H61mFfme
LVmfIY]VJHIGJUa7EDeIIUmHE5=BCDU=E554@TU7>e9DEEA?B44lC4<j>d4o=2Pj
=2l^<C@c<3D_:BP[;Rh/:c/`9c@b<4HZ;2ha=3Li>S`j>S`j=34aAc/`;4//:BHU
:2HH2R1QZ]Oko?W_iNKcoo7]l_cghm??m>[Vk>k_noo/k_7emoSgmo7`l>o^kNc/
jnc/kNk_l?3Yj^_/kNk_knWYj^_/kNk_nN/Gi>CUi^OXj>WYj>SWi^GTi>_Vh^;U
iN7MjMl7g]kMg=_Kf]Wie`KFeM?Bd]?Eo]H5eMCCd];AnLl4dM3Af>:Io`Ono_o]
ooo7koWo5o^GX8Va/JjOLWgKoo_olok7d_GoooWhooWn3on_OV5oZij]LFV>oo[o
looin`SjoOkkmoOlooKnognnG2DQEU19AT]IJWI;FVehMfaQFF=[NX1aG5]WC652
H61mFfmeLVmfIY]VJHIGJUa7EDeIIUmHE5=BCDU=E554@TU7>e9DEEA?B44lC4<j
>d4o=2Pj=2l^<C@c<3D_:BP[;Rh/:c/`9c@b<4HZ;2ha=3Li>S`j>S`j=34aAc/`
;4//:BHU:2HH2R1QZ]Oko?W_iNKcoo7]l_cghm??m>[Vk>k_noo/k_7emoSgmo7`
l>o^kNc/jnc/kNk_l?3Yj^_/kNk_knWYj^_/kNk_nN/Gi>CUi^OXj>WYj>SWi^GT
i>_Vh^;UiN7MjMl7g]kMg=_Kf]Wie`KFeM?Bd]?Eo]H5eMCCd];AnLl4dM3Af>83
o9Wo1oknon[ool7dnOlGjI>XT:nZ[jYTLMCooOomokk]l?oom_oonOh?ojIbE7:O
U:EbH7kenoobmoWkOo[mo__gmoconOoog88d=F=3FFmbI5]QK8ElJU=4BEe`He]J
GeeFFfIIL4QQDG=HNEYFDeaFV6aaO5=[H4aOHGE^IE]EE5=@CDiGDT0lCEQFDUEJ
FeM?ACm>@cXk@Clb9C@b<C<f=2dV<bdX:2hc=3</>c0W=C<bB34b=3Pk?T1254M2
?ST`9B<W8AXH6Q`L8BR5[mgeo_ko5ocimo[no??[ooCXj^oboOo/ko_oo>SPi?gg
2OGak^cal?3_k^gmk1G]k^o`l?7ShnCUinSYj^SYj^_/k^o_nN`Gi>CUi^OXj>WY
j>SWi^GTi>gXi>?Ui=oJjMl7g]kMg=_Kf]Wie`KFeM?Bd]?Eo]H5eMCCdm;BnLl4
d<o@en6Io`Ono_oZooo1m?Wo5nVCZ92_ZZnZI77DoogooOnnkO3oooKoooWn3onV
LUAbWiBULV1nmO_ol_OingojoOkkmoOlooWoomb2=3ES@eU_LVAKHFb5O6YCA4UM
L6=KFUmMEU]VFG18HE5cF7UJEU=LEYQ/LGaCJf1<Gf5eKVEKEEACD4e>Ee90?4eH
EU9EFU]GCdDoCT<j>d4o<RDd<S4c=S@]9S<]:2P^<c@c;3/`9cDc<TPa<S@h>ci0
@QA7@Shi<2DS9b4J61XL724XQJoMmOknoaOlnOOjo_ccjoodj>[_l_gok>okoocX
h>Cmm`WelNk/lO3`knk]oN`EkNk_l?3ahn?TiNOXjN[XjN[[k>k_koW/5nCTiNKW
j>SYjNSXinKUi>C]j>CSiNCOf^WO1mkNgMcKfm[InML6e]GCd];CeOkF1MGDdm?B
d_W?1=3?d=OQVOl7o_koj_oo`OCioaOYTjR@[jZ_ZVAae?omoogo_^g`ooofoooi
oPooYW9DLYnDYG9PO_Gkoo;gnO]on_gnnoOgo?oioooLPS@eHd=IKg9TFf5/QGaZ
DdA9GG1SFeYOGEIKIUU`B65ALeQiFUICG5JHK75lDf]PC5mQMFiUFeEDDe1=CUMB
@3a=F5IBEEYKEdm5?di3>S]1?c8U=38a<cHd;BHc;BPX;S<d<b`k<2Le<c98<C8d
>3/n@48DAd8n>C0U8bLQ6QPJ71`Q:8F_gOGno_lGo?Wgn_klln_om>SZko;monc_
noolj>3ToOL9mO7^k?7`l>o^kOg/5Ng^ko3`lN?Si>GWj>WZj>WZjnc^knoik1OT
i>GVinSXjNWXj>OViNCTkNSThnGTgm[Yg`ONg]gLfm_JfOWG1]KEdm;BdmGnePGE
e=?Cd];ic`C@cm3Gh@?cVOl6nOojoOooY_So5oBIYhb/ZkJdFY;Kooolo_n[l?on
oooiooWn3oRcE6Id/j^bJg]ln_oon?oioP3ko_moo?[mooobl_m1ADeGAVAREeUG
MFQjMFEDDf1TGX9gK6Q[JV=KIW=bMg]PDVi`NG9TLHV0H7mSCD]?CD]=KW5bL6a[
L7EGHEA@Hee;DU=2LFa@DCD^=49>Bc`c=Sla=3a7C4Tm<ah[=S@Z:3=1;C0d=c]5
E5mGBchj?Chh<QhY<B`K7aPM9B4fG8bjfNOZo?[flo3_ko3blO3`l_CgnOWa;nS_
moWel>k^m?Knoo?TjOSal_?cl_3]k>OXj^_[j^SWiNKXj^g_lO;WjN_]k^k]k?WV
1nGVinWZjng]nNKai?WO3mk2jn[KjM[Lgn7QgMWJgnGieacFeM?Bd]?Ee/k>cm7B
dmCEdM7@clk=cLc@c/oEgYWo1_Won_goojKhoaOdVJN<[:^f]5ZBfoooo?koZo3o
o_oonOoioPoh/eAVM;>[/V]kO?[oooSonOh0nokoOocjoOool_;o@DE=EdITHUMI
EgEXNWEUE5=PI5j2MfaXJfYSFfIcLWMkH59^L7UbI769P61oHde;Cde;CFiaLW1/
Jg1eEf5DD6=MBe9C@W5/D54e;SA2CT/l<cHo<C@lAda9?C<N:cHd:RPc@Bd`=3Lk
AEAOEd/n>Sdn>38N:C4/6alH7BDQ=Ub<^]WWj_cjm_?`kno`l_7`l?;dmoWilBoX
koOimO3^k_Cfo_oci>WhlO;clo;`kNcWj>[[jn[XinGVj>[]ko7binW[kNk^kNci
iPOUi^OYj^_]kOWVlNCig`oN`^_ZfnWJg=oQhMgIf]oUnMLLe]GCd];CeMK>c/oA
d]?DeM7Ad<o>cLg<d<k?eMjIo`Kioo[moonVn?lGm9VWS:b[][AJT]_ooocnoj_`
ookoooWonOh?n;=DIWBcZk9[NgcjooohooWn0?_nogoln_gooo;bod55CEM6I69G
FEMeJ7YeIEACH6ANPWM/J6]ZHe]VLg9gNf1BKW1iLVAaRH1POf==Bdm=Bde^LG9`
K6]`MEMQE51SGD]BDd9aK51A=Bhd@Ti;?3<f?c4d?4M<BCdc7R/f=2XX<d4]<3@g
>dEDGeM;?SXm?SPb7RTa;1/O61dU8CILS;[Iin[ln_Kcl>o_l?;al?3bm?OinO4_
j>ognOG`k^kdm_kolnCYn?7blo?bl>g/inSZjn_Zj>OUi^SZkNoal^OYjng^k^g/
nNH7iNKWjN[[kNgii_7TnMl?g/;[j]_Yf]cOhN7MfM[OiOWG7=KEdm;BdmGFc/k?
dM;Ce=GAdM3?c/g=c=3>cmGN0nZIo`Kjoo[moon^n?l:iHJDOJ>UZZ5UTmSlo`Nb
l_omoooiooWn3oo7J7AgZ9:BLWmln?oomooioP3ko_moo?[moooko]h^?dAREV5R
I5iKJEemOWM]KWMdJFMUI6I[KVaZJF]KF6=GEGETMGUdPYVCNWeTDE=JFEUMLWAb
K6=NGf9cO6YMIUY8DTXgEdPoG5=GA4U?D4U0=c8k>SXn@D0i<cdm?3Pc;bh_=3@a
:B4N8BHg<2PS81dH52dW7Q/7;UnPc^3Ukocno`Cgn?Kcl?g]1oCcl_;cm_SjnO@N
j>ognOC`k^kViNcfm>gao_7bloCdl_3_j>[[kNg[j_kX3NW[k>k_l>KWj^g_knk]
mnH5inOXj>WYnNKii?WRnMl?kL[Tg]GUen7Fg>;Rg][Kg?WG7=KEdm;BdmGFc/o@
dM;Ce=CAdM3?c/g=c=3>c]CMVOl6n_ojoOoo[_So2^F6U7fSYJZQII?Ho?l7/_;o
oOoonOoioPooafQdMjRBTW9oO?SoooOonOh0nokoOocjoOoonokN;Sm4HUIQHVAN
FfUMOGigKFigM6UWIFAVJfi/JVU[FeQSEeEeI7EiM8:ITgYmI55CFUUIGG9dLVaS
GUmRLgaZGFIJB59:=eM8?eaCEdA9Ce19@3Lb>cXj?T50>C<m?C`h<bl^;c@d<BTQ
7R4V=c0X8b0M61@]9ahK1biOX<kPiNolo_l4moSflo3mk@Odlo;bloKhn_Wd7^S_
moWdl>k^i^G/m_C]lOkal_?dm?;`knSZjng]jn[nj0gYjnc^ko3Vin[]kno^kOOV
1NOWj>SYjOWVnNCih_WO3ng:i=kEiMOQe]cRh]kJfmcieacFeM?Bd]?Ee/k?d=7B
dmCDdM7@clk=cLc@c/kDgIWo1_[on_goojkho`[UQYAmXjFZXFFCf?co1k;boogo
ooWonOh?olMXM7NXTY9bOgchooogooWn0?_nogoln_gooo_ngRhoA69FHF9TGU]Y
GGenMfe^MgAYIfETIV]^K6YYJe]HHeMEMFAeNGB2VI=jOFAADeYIFEebM79/HeiO
HW=lJUeVFTQBBSMGB3mLDeM4BDm@BD0g<S/j>Si1@3Tc?Cdl>3<_;Rld=34Y8AhQ
9SL`:2<P7APD;BLN6`L^Gj3>h>G_o?ko1?Ohm_?`oNd7m??bl_?fn?[im1kXkoOi
m?3^k^KUk?KdkO7nlO;cm?Cbl>oXj^_]kN_Zo^P=jN_/k^o`i^OZkNo_k^ggiPGW
inSXjNWii_WTnN;ig`o]b^CNeNGGhMKLh^;Nf]_LnMLLe]GCd];CeMK>cm3Ad]?D
e=7Ad<o>cLg<d<k>e=d3gYWo1__on_gonkgho`[SOh]k[;2]W7FBdogo2>bnmOok
ooohooWn3oVnJGf4]Z2PO8Inm?onm_oioP3ko_moo?[moocooXDH?3ASGe9MMVQb
LfmUKFm^LWUaHVmcMWA]IV9QKf]BBEE:@EHhB4Ti<cHY4EI2=CY2@dE:Ce1?BCli
>3XR=2l/?S/fBT/i@1L=:18A=C@g?T=0<bPn>38a<c@a;S/d;B`^;BHO6AlV:B/_
=S`S:2`]:bT[;GZJanPKm_Gbl?ooo__hl>CJmOCak^c[k>ggm_Gem_Sjo?Wg7^W`
m_Ocknk`ooC`moS`jno`l_Cem_Gdln_/k^o_k^cljog/1>?VjNg_o_3iiPCWinKU
iOkTnNKii?7O3oCChm[EdZbdc]OQi>3IeMCie`cFeM?Bd]?Ee/o@d=7Bo]<<dM7@
clk=cLc?cLkDgIWo1__on_gonkgho`[SOh]k[;2]W7FBdogo2>bnmOokooohooWn
3oVnJGf4]Z2PO8Inm?onm_oioP3ko_moo?[moocooXDH?3ASGe9MMVQbLfmUKFm^
LWUaHVmcMWA]IV9QKf]BBEE:@EHhB4Ti<cHY4EI2=CY2@dE:Ce1?BCli>3XR=2l/
?S/fBT/i@1L=:18A=C@g?T=0<bPn>38a<c@a;S/d;B`^;BHO6AlV:B/_=S`S:2`]
:bT[;GZJanPKm_Gbl?ooo__hl>CJmOCak^c[k>ggm_Gem_Sjo?Wg7^W`m_Ocknk`
ooC`moS`jno`l_Cem_Gdln_/k^o_k^cljog/1>?VjNg_o_3iiPCWinKUiOkTnNKi
i?7O3oCChm[EdZbdc]OQi>3IeMCie`cFeM?Bd]?Ee/o@d=7Bo]<<dM7@clk=cLc?
cLkDgIWo1__on_gonkgho`[SOh]k[;2]W7FBdogo2>bnmOokooohooWn3oVnJGf4
]Z2PO8Inm?onm_oioP3ko_moo?[moocooXDH?3ASGe9MMVQbLfmUKFm^LWUaHVmc
MWA]IV9QKf]BBEE:@EHhB4Ti<cHY4EI2=CY2@dE:Ce1?BCli>3XR=2l/?S/fBT/i
@1L=:18A=C@g?T=0<bPn>38a<c@a;S/d;B`^;BHO6AlV:B/_=S`S:2`]:bT[;GZJ
anPKm_Gbl?ooo__hl>CJmOCak^c[k>ggm_Gem_Sjo?Wg7^W`m_Ocknk`ooC`moS`
jno`l_Cem_Gdln_/k^o_k^cljog/1>?VjNg_o_3iiPCWinKUiOkTnNKii?7O3oCC
hm[EdZbdc]OQi>3IeMCie`cFeM?Bd]?Ee/o@d=7Bo]<<dM7@clk=cLc?cLkDg@?]
VOl7o_okoOo[cokioaOSNhEk];^bV8>AdOoloooEcoWonOoomooioPo[/fAmR<2b
^8B;Oo;nnoKonOh0nokoEOcjoOojo>8j5TDXDVY7G7iELfM]OhN9Qh^BRW]gP8J1
LVEQHU5GB4MKDCY0<dA;@d16AC`c8a/R:2HW;TI:CDY4@453B5eGCeI8>dTc=dH[
?E`nA2h]oR`S:RDR:bHQ8B@U8QhK6adR:2d_;bT[:b@H3PX:?eMlWkkLn_ohoOlJ
o?Kdl>cYjo7dl^ofmO;`k^o_l?[in?OgnO_lnOD_jo3fm_;^ko7ol^O_m_3Wi?3b
m?Kgm_Gdk>k_lO7_k^c]kNc/jn_Zj^?UjNc_l?7`nNH7inOVi>?Qh>3ii_WTnMci
g`oZe^STh/5gNlkEgMoKe]CDnML7e]GCd];CeMKmdOgB3=7Ad<o>cLg<c/c=dmbI
o`Onoo_mon_?o_Wo5n=kQG^d^k:HPi7AoocoomG?nOoiooogooWn3n^cI7f8`;:h
Q8]ol_kkm_oioP3ko_mEo?[moo[lhSXFABQBJTMLOUEcIfeoQhV7Ri::NgN0QX5b
IF5RDEM8Ae]A>T0cA4]3@4I5?3<S6b8X9RL^ATY=BTA0@D=8GEM?ETPkBC<gAR/m
G3i4;Rgn;2<Z9B8[9R4Q92DR7Q/K7B8X;Bl_:B/[91P>2PXoEgbO_]cjooSmoa[l
m_C`k>W[lOCbkoKel_3^kno`n_WhmoOinocimBo[l?Kfl^k_lOobinofl>OTl?;d
m_OfmOC/k^oalNo^k>g]k>c[jn[ZhnGYk>o`lO3iiPOWinKThn7Ph?WVnNCig?WO
3n[Fj>CR`GMkc]GMgm_Fe=Cie`OFeM?Bd]?Ee_gAoM8<dM7@clk=cLc>c<gCg9Wo
1okonogojlonnOlGhg^5NkBk/YR3TM7oo?ooeLoiooWoooOonOh?jk=TOHS0/[R4
Rgobo__fooWn0?_noeGln_gon_cR>QI5:59ZAeanEG=WKGn7RHN;TXYkMh26PG9U
HF9AEdQ7Fe4j@3=4Bd=0ATDl<b<K8RPV9bi6BTe:A411@dQMEdmFB3]9<cM6:ceL
?T@^;Oh/8bXU8R/V8B4T9B8N6a/M8RP];blY:b/T60h:2SmGO9nng?[on?go6_cf
m?3/jN_am?;_m_Gbl>k_ko3jnOSgmoWko?We;n_`m_Kbk^oaoo;WkoK`inC`l_Cf
moKem>c^ko7aknk/kNg/k>_[j^[SiNW/ko3al?WV1nOWi^CShN3PnNKii?WLnMl?
j]KXi>;1Mg_>eMgOfmKDe?WG1mKEdm;BdmGFoM7mdPcAdM3?c/g=c<k<cM?L0m^G
o`GkoOoIi?cioaOLLW]b[[N/T8Z<d_ofooo0h?knmooom_oioPom`FUfMJNJXhR>
P?;mnoOonOh0nokoLOcjoOoomZlP;UX^@6m8KXXgKEMUIFILCda?B3/T<3`m=S0a
=1dZ824n@C8g>d=3>S@g>CLo<bhd=Bl^=3XoA4<m>CTj8cTg=D8e9C0R;3HR@5<`
CSe1@CL[:CA05QHH7R<S7AHA7R`a<CI4DGf=YKkEk?_o2_gako7om^KIf>Ono_lE
n_Wlooomn_Sfm??dmOKlnoWgmoSin_Wb;ncamOC`k_3cimC<gO7fm??`l_Cem_Gc
l^c^ko7aknk/kNg/k>_[j^[Ti^W]ko3_koWV1nOWi^CShN3PnNKii?WKnMl?h=OW
i_78NI3DemWFd]7Ff_WG1mKEdm;BdmGFoM;kd@[@clk=cLc=blcBfiOo1O_momWT
o?Wo5mabNg:^]jb@RXcBooKool3Po_kgooofooWn3og1JGIeYiZSR8j0l_gkmooi
oP3ko_mao?[mooof[b0^FRi0KdQ^RSM]EfEUIUa?C4m8>b@`?3df<34d7BXP8Ci1
<SLk@d<j=3Li=clc;S@e;bhd>Sm4@cdi>CXS>CLe@SDU<28/=R90Dc1>?D51=b/Y
=40F5QPN8b<M5Q4N;34a=TAAOHfU_]G/nol:oO7_lOofi]WHioknoaGjnOcooogj
n?KdloCem_cknOOgn?WjnO8_k?7em?3^l??We<cMlOKdlo3bm?GfmO?bk>k_lO7_
k^c]kNc/jn_Zj^CVjNg_l>o_nNH7inOVi>?Qh>3ii_WTnM_ig`oPenOVlLQiT=CG
fMKBdMKJnML7e]GCd];CeMKmd__A2]3?c/g=c<g;c=;KUol5nogofNClnOlGg79k
LZjg[92:S=;om_oo`>3no_OoooKonOh?oL5YMWFWVZ>8SX3boO_gooWn0?_nog7l
n_goooJ_82iJ;T1_B6j:=feGIFEVG4m<CdPk930l?CH`<C@M:R0Q?T4b=c]3@cXd
=cTg?c<^=3D_;S@j?dA3?CTi>R<i=cE2=BD`8R`f8T1C<4hm@D4g:bTd@1HF61hS
8adF4Ah/<C4fA55mSJFneNcko`[mlNoaooKVfMSWo_ko5O[io?oooO[hm_Ccm?Gf
o?_imoOhnO[ilRo/lOGdl>k`lnODc=gam_Ccl?;dmOKelo;/k^oalNo^k>g]k>c[
jn[Zi>KYkNo`knoiiPOWinKThn7Ph?WVnNCifoWO3n3GinKab7V@e=OIe];Ae][i
e`OFeM?Bd]?Ee_gBnm4:d<o>cLg<cL_<d]/3hISo1_kkoOk9mo_ioaOSNH1e[kR`
V8N6f?oboon_lOojmOoom_oioPol`FM_JIR;UXN>PO?oo?SonOh0nokoJ_cjoOoo
k6ddAV0n>e16UkM8YiB[RHAbFe9BBclf>cln>C<a<EYRAc0oAd=?CTe:AdE3@3e>
AD=9Ac`j@3Tn@T0h<2d]<Sle=D]7>457AC`R>Rl:CQHS;c0^>E=ZbL[>eM_Ke<k;
fnWYhN7`o?l>oOKfn>CYl?Cfmo_ohncjo_lIm^oonO3/k>g[j?_imoKfmoWjo?[h
m_Gem_Oil1k^l_Cckng`m?WVgNWhnoWjlO;clo;`kNc[k>k_knk/o>_mk0OXjN_]
k^k/joWV1>OWi^GUo^Cii_WTnMcig`oNfmkGl=2Ed=SIf=C@dMSNnML7e]GCd];C
eMKnda7BdM3@cm7Ad<o>cLg<c<[;dMZHo`KnnognbOOknOlGhgV0MJnh/9R7Q]So
l_oo[o7on_GoooKonOh?o<5WKfVHRiJ7SX7coochooWn0?_nof[ln_goona]=4IP
?S]@AYNgB:NDZhV4LU]BDT/o=S/o?STc<C5JHTL`?dM3Cdi=BTM5@d0mCTE3BDLl
>T0i?T90>30];C8o=CE;AcQ1AdDl8SX_2ThF8bl`;SUCJ/W:c]GKfmC>bm_YjN7Q
l?co3_gfm_STjO3dm_Okon?/n_ko6OK_ooW`k>c]jnSknOOfm_Oin_cjn?KemOKg
nO0Nk_;dlno]l?Cii]gYn?_in_7blo?bl>g/jnc^kno^k?c[oN`7j>W[kNk^k>_i
iPCWinKUiOkTnNKii?WLnMl?g]_Neo3@UM3HfMSDd=7Hg_WG1mKEdm;BdmGFo]<A
d]7@d<oAdM3?c/g=c<c:bm7JV?l6o__mo/WgnoWo5n=iP7F_^;2HQhKHoo;oojoa
oo[eooofooWn3oc1IfmYV8^FQhj1looln?oioP3ko_mZo?[mooo/KCA6H3hkD4JG
]dRWU:^9Q79KDU9;?cHk?chi<c4aFV97<3m7@dm>CDY7AD=0?Di5@dU7?3Y0>Ci2
@3P`;Bdb?cDeBdLh@DM5?28j;`Y>5R<_<2hiDf[9b/kEfm_Dc/_KjNWQhO3lo`km
m_Khi>W`m?KgnooSk?[noaWfkooil>c/kN_XnoWgm_KgnO[ln_SfmOGfmoW`7^kb
m??_kO3dnNKMjOSknO[al_?cl_3]k>_/k^o_k^cljog/1nSYjng^k^c[nNH4inOV
iNGni?WVnNCig?WO3mkKg]O`d9G@f=WHe=3Af=kie`OFeM?Bd]?Ee_kC4M;Ad=3?
dM7@clk=cLc<b/_AfP?`V?l6o?cmo[gonOWo5nZ2RGV^][BRP83NonkoojCmooKc
oooeooWn3o6lJgUeXYBNPhb1m_oonOoioP3ko_mIo?[moogI9U14AdDk:d[>lfk_
g_Kooo_[ingYgM7;a;nk]JjXHVi?:BLW8BdT92e0D59:@S`g>D0m<BlfB4iDE4i7
A4=@B2HG;2`L8QPJ7b=69@9[^LCCgnWfo_l2noWko_l1no[noc?no?oonO[jmO3a
m_coooWfmOCakOokl>OShnCUn_G`lOKjn_ShmoGdm?KhnO[hm_?bl_?dnO<Nko;d
l^g]lOGoooGhn_?`lo;cl_7^j^OTj>[[kNg[j_kX3NW[k>k_l>c]k^k]jnWWmnH5
inOXj>WYnNKii?WNnMl?g^7KbMfbNLWDfMcKemGGfoWG7=KEdm;BdmGFe=CCd]7@
clkAdM3?c/g=c<_9b]3IV?l6o?cmo[gonOWo5nZ2RGV^][BRP83NonkoojCmooKc
oooeooWn3o6lJgUeXYBNPhb1m_oonOoioP3ko_mIo?[moogI9U14AdDk:d[>lfk_
g_Kooo_[ingYgM7;a;nk]JjXHVi?:BLW8BdT92e0D59:@S`g>D0m<BlfB4iDE4i7
A4=@B2HG;2`L8QPJ7b=69@9[^LCCgnWfo_l2noWko_l1no[noc?no?oonO[jmO3a
m_coooWfmOCakOokl>OShnCUn_G`lOKjn_ShmoGdm?KhnO[hm_?bl_?dnO<Nko;d
l^g]lOGoooGhn_?`lo;cl_7^j^OTj>[[kNg[j_kX3NW[k>k_l>c]k^k]jnWWmnH5
inOXj>WYnNKii?WNnMl?g^7KbMfbNLWDfMcKemGGfoWG7=KEdm;BdmGFe=CCd]7@
clkAdM3?c/g=c<_9b]3IV?l6o?cmo[gonOWo5nZ2RGV^][BRP83NonkoojCmooKc
oooeooWn3o6lJgUeXYBNPhb1m_oonOoioP3ko_mIo?[moogI9U14AdDk:d[>lfk_
g_Kooo_[ingYgM7;a;nk]JjXHVi?:BLW8BdT92e0D59:@S`g>D0m<BlfB4iDE4i7
A4=@B2HG;2`L8QPJ7b=69@9[^LCCgnWfo_l2noWko_l1no[noc?no?oonO[jmO3a
m_coooWfmOCakOokl>OShnCUn_G`lOKjn_ShmoGdm?KhnO[hm_?bl_?dnO<Nko;d
l^g]lOGoooGhn_?`lo;cl_7^j^OTj>[[kNg[j_kX3NW[k>k_l>c]k^k]jnWWmnH5
inOXj>WYnNKii?WNnMl?g^7KbMfbNLWDfMcKemGGfoWG7=KEdm;BdmGFe=CCd]7@
clkAdM3?c/g=c<_9b]3I0o2Ho`Kjo?gm]_oinOlGhGZ2KYjVZ9]jO>?okOooWooo
m?;oooConOh?oln2T8J[U9V0RX;hooojooWn0?_nogoln_gok/H0Gc@W@CXRFoSo
MooSm>odl^ogoookoogem_koo_Sjooobl^oUk=_>a<2aSF539R<X<BhS8BTE7BP/
:bTY:TU2:SMfX;77fn3]nOo1Po7in?[noo_`i_ohk^W/l?;bnoKbl_Kfl^goookg
l_CkooW_i^O_mO?_k^k_la_hn?GbmO7^l?Kkn_Sdlo;al_?emoWgm?;`l?7bnOHW
l?;dlNg/lOKlk^KZkNW[m??cl^o[in;OinSZjn_Zj>OUi^SZkNoal_g_0ngZi^Ci
iPOUi^OYj^_]kOWVnNCag`oIi^35bXDjRLoGh>?OfMKEnMLLe]GCd];CeMKEe=?B
dLo>c]7Ad<o>cLg<blW:d=VHo`Kjo?gm]_oinOlGhGZ2KYjVZ9]jO>?okOooWooo
m?;oooConOh?oln2T8J[U9V0RX;hooojooWn0?_nogoln_gok/H0Gc@W@CXRFoSo
MooSm>odl^ogoookoogem_koo_Sjooobl^oUk=_>a<2aSF539R<X<BhS8BTE7BP/
:bTY:TU2:SMfX;77fn3]nOo1Po7in?[noo_`i_ohk^W/l?;bnoKbl_Kfl^goookg
l_CkooW_i^O_mO?_k^k_la_hn?GbmO7^l?Kkn_Sdlo;al_?emoWgm?;`l?7bnOHW
l?;dlNg/lOKlk^KZkNW[m??cl^o[in;OinSZjn_Zj>OUi^SZkNoal_g_0ngZi^Ci
iPOUi^OYj^_]kOWVnNCag`oIi^35bXDjRLoGh>?OfMKEnMLLe]GCd];CeMKEe=?B
dLo>c]7Ad<o>cLg<blW:d=VHo`Kjo?gm]_oinOlGhGZ2KYjVZ9]jO>?okOooWooo
m?;oooConOh?oln2T8J[U9V0RX;hooojooWn0?_nogoln_gok/H0Gc@W@CXRFoSo
MooSm>odl^ogoookoogem_koo_Sjooobl^oUk=_>a<2aSF539R<X<BhS8BTE7BP/
:bTY:TU2:SMfX;77fn3]nOo1Po7in?[noo_`i_ohk^W/l?;bnoKbl_Kfl^goookg
l_CkooW_i^O_mO?_k^k_la_hn?GbmO7^l?Kkn_Sdlo;al_?emoWgm?;`l?7bnOHW
l?;dlNg/lOKlk^KZkNW[m??cl^o[in;OinSZjn_Zj>OUi^SZkNoal_g_0ngZi^Ci
iPOUi^OYj^_]kOWVnNCag`oIi^35bXDjRLoGh>?OfMKEnMLLe]GCd];CeMKEe=?B
dLo>c]7Ad<o>cLg<blW:d=T3]?SnnooXoPGmnoSgnOk7o`OknOoom9cjo?Wo3o9m
V9Ba[kJPT6WfomgoiJgho_go4_kknOo1DhB3T9NTM6^9l?o_ooKioQofooKgooO^
ool>CcETGA9Z8[oo[^Kol?Wko?knoO_hm_Wcn?kmod;nnoWdhm7>en3Qg>WKg>oo
oogdolaMjoomooonooolooC5T_Goj=gol<g_n_Oemo[im>k`m_[gl>gbn?kkm_?a
l_GgnOHGl_7_kN[Xi^G^j>gek=[Kjng^lO?dlo;bnOH7no[hmoOhn__il`o^ko3c
mOOin^galo3[jN__nNkak0Kein;Yk>OUn>T7g^;Xk>gZi^?ihOWOo]/1g=cngAOJ
emJa_<>=T9Vab]KJgMWBdmCEe]OIf][ie1C=c]7Ce=?Bd<Jogm?:ckgGe=7Af>?h
o__oj?h5oO_hmoWnaol7noWoooBLn_cio`obOIRD/JnfX91Ym_oMonF]n?kmoa;n
noWo`E>4Pi2GY7A[RO3okoofnOhOm_ofmoogk_oo3TleI5dBJR:oojkVoo3inocn
o_gkn?KiloSnoOm2o__im>?Ac]OPhMcYfmc_ooomm?o<GN_ooOooo_ooo?odaI;e
onSMoo3=ko[gmOOjnOC^l?Kjmo3]l_SnnoKclO;emoWf5o;akngZj>KUk^S]mNcJ
fn_]k_7cm??bl_Wf1o_jn?Ogn?[knO<?k^o`loGgnO[]lO?`jnW[koW^lN`6mNOR
jNcWiOSY1mkRj>c]j^KSnN7igokK0McLo]dGf]OF/Kc3SI2I/L[Ff]gId]?DeMKG
fM[JnM@DcLkAdmCCd]36_moCb/nmemCAdMSSn?kkonSn1Ogkn?Oio/Oo1o_ioood
W?[lnOl?lWfHU;6_]Z2@JOKogOoU[OSnoOlBo__iol5CQ8>@UjAdJhW`onoom_Wn
7oKom_Oomnkoo`i?=FAM4VXR_on^i_o`nO_lo_kmnoSfnO?ho_go@_kknOCSdLkG
h>7LjM_LkooooOCoc5g[oogoookooocom<FBmOoXgOo`cNojmoGgn_Wdk_3fn_O`
kO;ho__flo7bmOOimQOblNo]j^SViNkXkOG/f]_[kNkaloCcl_;imPOkn_SgmoSj
noWc3nk_l??emoWjkO7cl>_Yjnoik_7/1_GWh^W/inGhj@ONh^S/kN[VhoWQnMon
f`7Lg?kM5m[Ge[6l`hf@VK7:e][MfM;Ce=GFemWJf_WD5<g>dM?Ddm;@a[oOdl[?
_MODdM7Hh`>gnOkno07knokljOk1o`Onn?oom:_noOWo3nihT8^XZ;:MRG?bon[o
fkkho_go4_kknOo<FWUcR8nBMVb8koo_ooOioQofo_WhooWfolHF=C`e@ca1BmOo
_nWom__moOkmoOclnoWfn?kmod;nnoWonng[m?_im?S^nOc`oOooljOIjOoogOoh
o?[iooo/bj;RoooLkOobn_Oemo[im>k^m?Sekngam_gjm_?bloGgnOHBl>o^kN_Z
jNSakO7il^?TlN_]kokb4O7`l?7cmOOinocem?;alO;dmOWf3ng]ko7cmOOhko;d
l^gZk?3ijo7/1_GWh^W/inGhj@ONh^O[k>[VhoWRnMl1fm_lg1SMi]gPa/g5SIVo
`lcFfMOFfMCDeMKGf=WJnMCndA7@d<o>cOC?eLWBh/KAaLC6d=gio_kl0O_ko_cY
o/7o1okhooodZokmnOl?kWR@RjRX/Yf9Lo;oj_oK__SnoOlBo__iolaJNG>8Si9f
K8S_onoomoWn7oKnnOSonOKoaQHe?3E3?45;eonojOofnogmo_gmo?cknOKho_go
@_kknOokkN_dnoWdn>kio?3mooocYmWYoooMooSln_Woonc;X^;oomc]oo;jmoGg
n_Wdk^kdn?G_kO7foO[flo;cmOOimQ;`knk]jn[Yj?7]lOWbhnCajng_o_8AlO3`
lO?emoWko?Gdl_7al_CenOH?kNg_lO?emoS_l_CbkN[/l?W[lN`6mNORjNcWiOSY
1mkRin_/j^KSnN;ig`7KfocL6=gVgN36cLF=VKo3c=KIemKIe=CEe]OHfM[ie?kA
4M3@clk=m<oEbM;Ra]75a<K@gOWno_`1no_no>Wn`Ol7o_SoooB[o_gio`o^N92;
Z:RbWHUcl_oZom^nn?kmoa;nnoWoc5YiLhR?TWI/R>ookoognOhOm_kin?oim_o6
5SDl=D<l@D_GokoYooKkoOgnoOglo?_im_SnoOm2o__ioo_]joCknOChk_Wll?go
oo>WfNWoomgon?cjnOook<^Rh_oog>gol_[gmOOjnOC^k_ChmNo]lOKmn_Kcl_?e
moWf4_3_k^g[j^WXlNganO;Si?7[kNonlQ7al?3aloGgnO_lmOCblO7bm?GimPo]
kNoaloGgn>obm?;]j^c`nN_ak0Kein;Yk>OUn>T7g^;WjncZi^?ih_WO0M_Ko=`H
gNKMh<K=aHfI_l?<e]WGe]WDe=GFemSIf_WDo]4Ad=3?c/gdcmG9d^;6dLG4a]3M
0k7ioPOoooklo?koonWnn_l0o<So1?Sooo74mol?l7R=QjBW/j61QNoko?o9e_Sn
oOlBo__iomQTKfJ>VHijK8G[oo3on?Wn7?Klo?[koOooIRH[Eb4lDan=n>?Jk_on
o_ooo_gmo_oin_SnoOm2o__iooofmokoo_Son?ooi_oonY6BonSoo_7on?[glo[o
oob@ZOoof^cok_[gmOOjnOC^k?3cl^k/ko?jnOKdloCem_We0>kmkOk/7o?amO_g
kNkgj^_^l?7`knk/k_3dn?coooCclO3`lO?dnOP?jnc]ko7bloC`m?Kck^c^l_WZ
lN`6mNORjNcWiOSY1n3Rin[[j^OTnN;ih?[L4=_We^3Dekb2W;^b^mGPeM;Ko]D4
e]OHf=Wie1CFe=7>cLc=cLBjdkJIW:;JbLW=e^3ioPOoooklo?koonWnn_l0o<So
1?Sooo74mol?l7R=QjBW/j61QNoko?o9e_SnoOlBo__iomQTKfJ>VHijK8G[oo3o
n?Wn7?Klo?[koOooIRH[Eb4lDan=n>?Jk_ono_ooo_gmo_oin_SnoOm2o__iooof
mokoo_Son?ooi_oonY6BonSoo_7on?[glo[ooob@ZOoof^cok_[gmOOjnOC^k?3c
l^k/ko?jnOKdloCem_We0>kmkOk/7o?amO_gkNkgj^_^l?7`knk/k_3dn?coooCc
lO3`lO?dnOP?jnc]ko7bloC`m?Kck^c^l_WZlN`6mNORjNcWiOSY1n3Rin[[j^OT
nN;ih?[L4=_We^3Dekb2W;^b^mGPeM;Ko]D4e]OHf=Wie1CFe=7>cLc=cLBjdkJI
W:;JbLW=e^3ioPOoooklo?koonWnn_l0o<So1?Sooo74mol?l7R=QjBW/j61QNok
o?o9e_SnoOlBo__iomQTKfJ>VHijK8G[oo3on?Wn7?Klo?[koOooIRH[Eb4lDan=
n>?Jk_ono_ooo_gmo_oin_SnoOm2o__iooofmokoo_Son?ooi_oonY6BonSoo_7o
n?[glo[ooob@ZOoof^cok_[gmOOjnOC^k?3cl^k/ko?jnOKdloCem_We0>kmkOk/
7o?amO_gkNkgj^_^l?7`knk/k_3dn?coooCclO3`lO?dnOP?jnc]ko7bloC`m?Kc
k^c^l_WZlN`6mNORjNcWiOSY1n3Rin[[j^OTnN;ih?[L4=_We^3Dekb2W;^b^mGP
eM;Ko]D4e]OHf=Wie1CFe=7>cLc=cLBjdkJIW:;JbLW=e^03U_WnnOoYoP;gnOc3
o`Cho_gYgoOo3oIlT8VWZkZZP9S^m?oo]>Who_go4_kknOKPKV]SWJnKOVf2iooa
ooWioQCgnOolm_oojB@k?V]1Dc8kc_o0l_Glo`;noOknooWmn?kmocCnnoWln?Gh
oOkhl_oaooo^ooo<IM?ho_oPoo3no_[bl?GlomfH/_ool_C]n_Oemo[im>k[kOg^
1>oan?Ofo_D1m_Kim03/o^d0k_k_7o;bmOWhm?CgjN[]ko3`knk^ko;en?_mo_Wh
m_Gem_SinOH5jn_/kNo`o_46m?Odkng_l^W/1_GWh^W/inGhj@OQhnKYj^WWi_WS
nN4Gg]gMg=cKf][Mb=SFeJeeW9R@YM?Vf=3JoMKmeoWD5=OEd]3?dM?Eg=;X_XI`
LJk?dMCIg_WnnOoYoP;gnOc3o`Cho_gYgoOo3oIlT8VWZkZZP9S^m?oo]>Who_go
4_kknOKPKV]SWJnKOVf2iooaooWioQCgnOolm_oojB@k?V]1Dc8kc_o0l_Glo`;n
oOknooWmn?kmocCnnoWln?GhoOkhl_oaooo^ooo<IM?ho_oPoo3no_[bl?GlomfH
/_ool_C]n_Oemo[im>k[kOg^1>oan?Ofo_D1m_Kim03/o^d0k_k_7o;bmOWhm?Cg
jN[]ko3`knk^ko;en?_mo_Whm_Gem_SinOH5jn_/kNo`o_46m?Odkng_l^W/1_GW
h^W/inGhj@OQhnKYj^WWi_WSnN4Gg]gMg=cKf][Mb=SFeJeeW9R@YM?Vf=3JoMKm
eoWD5=OEd]3?dM?Eg=;X_XI`LJk?dMCIg_WnnOoYoP;gnOc3o`Cho_gYgoOo3oIl
T8VWZkZZP9S^m?oo]>Who_go4_kknOKPKV]SWJnKOVf2iooaooWioQCgnOolm_oo
jB@k?V]1Dc8kc_o0l_Glo`;noOknooWmn?kmocCnnoWln?GhoOkhl_oaooo^ooo<
IM?ho_oPoo3no_[bl?GlomfH/_ool_C]n_Oemo[im>k[kOg^1>oan?Ofo_D1m_Ki
m03/o^d0k_k_7o;bmOWhm?CgjN[]ko3`knk^ko;en?_mo_Whm_Gem_SinOH5jn_/
kNo`o_46m?Odkng_l^W/1_GWh^W/inGhj@OQhnKYj^WWi_WSnN4Gg]gMg=cKf][M
b=SFeJeeW9R@YM?Vf=3JoMKmeoWD5=OEd]3?dM?Eg=;X_XI`LJk?dMCIgP>FnOh7
nO_mo_kmnoWYoPCmo?_loLGo1?[on]_dmol?m7Z>QjJ[^jZ4XNkbooJTmOSnoOlB
o__im>EdJf2N/IZ4KWkSoo;on_Wn5?[dooocooZj84iBEEiR1YSiokOno>kon?km
o`GnnoWmo?gmo`?joo3io_l9h8^coo_ok_cogOko7o_ckO3hol^?_Ooog?WjmoGg
n_Wdk^c[jng_lO7`mOGfo_L1m_Kil`3]o^h0kok`5Noalo?dmoC`j^c^l?7al>od
mOGfm_Onn0KgmOCdmOOhnO4>k>c]k^k_ko3`loKck^c^n?7ak0Kein;Yk>OUn>T3
hnCViokX0>Oii?WR5moOg]gKf]WIgL_Lem2XMZFWXK3@g]KDgogGoMKge1;Ce=GH
f]_Z]KVocm6[^LK;d=GHnOh7nO_mo_kmnoWYoPCmo?_loLGo1?[on]_dmol?m7Z>
QjJ[^jZ4XNkbooJTmOSnoOlBo__im>EdJf2N/IZ4KWkSoo;on_Wn5?[dooocooZj
84iBEEiR1YSiokOno>kon?kmo`GnnoWmo?gmo`?joo3io_l9h8^coo_ok_cogOko
7o_ckO3hol^?_Ooog?WjmoGgn_Wdk^c[jng_lO7`mOGfo_L1m_Kil`3]o^h0kok`
5Noalo?dmoC`j^c^l?7al>odmOGfm_Onn0KgmOCdmOOhnO4>k>c]k^k_ko3`loKc
k^c^n?7ak0Kein;Yk>OUn>T3hnCViokX0>Oii?WR5moOg]gKf]WIgL_Lem2XMZFW
XK3@g]KDgogGoMKge1;Ce=GHf]_Z]KVocm6[^LK;d=GHnOh7nO_mo_kmnoWYoPCm
o?_loLGo1?[on]_dmol?m7Z>QjJ[^jZ4XNkbooJTmOSnoOlBo__im>EdJf2N/IZ4
KWkSoo;on_Wn5?[dooocooZj84iBEEiR1YSiokOno>kon?kmo`GnnoWmo?gmo`?j
oo3io_l9h8^coo_ok_cogOko7o_ckO3hol^?_Ooog?WjmoGgn_Wdk^c[jng_lO7`
mOGfo_L1m_Kil`3]o^h0kok`5Noalo?dmoC`j^c^l?7al>odmOGfm_Onn0KgmOCd
mOOhnO4>k>c]k^k_ko3`loKck^c^n?7ak0Kein;Yk>OUn>T3hnCViokX0>Oii?WR
5moOg]gKf]WIgL_Lem2XMZFWXK3@g]KDgogGoMKge1;Ce=GHf]_Z]KVocm6[^LK;
d=GH0e[io_WojOk0o`GlooS:ooWho`kYLHR3XZJdXXNIjoOojj?go_go4_kknOWV
Mg1NSYj<R6mkg_ocoo_hoQ;_oooconQk?UAA<UMA7o7olL[kmol1o?[iooSnoOl5
o__inocnn_l?mOgok:]lmooomm;oi_GooOko8_Ofo_;o`9cYonoon_Oemo[im>k^
jn[]l_KdlO;cm_Sin?OfnO80lOg`oNl?lo;]lOScing^lO?dlo;amo[f1o7`k^g]
k_3am^oll0O]lO?ajnW[koWclN`6mNORjNcWiOSY1nCTiNKWj>WYnNGihacPh=kM
fmWHenGLj<o0XWVVe=GEdLkAf^;If=SGe_kEnM@DdM?Ef=WHemJXNY2Z`l:HYlK=
e]_MnOkionWn`?l5o?ohb_oin?l>jG68Pj:V]::7VN_gon^Smokmoa;nnoWiiWM`
GXjNS8Q_Nmkolookn?hBkooolooXNciDDC9GDAoaoo7:noOo0OcjnOoho_go1Okk
nO_lo_[o3oGmonb[O?OoooOBonKeoognob;gm_kbol2LjOo_oo[gmOOjnOC^k^_Z
kO;fm?7bloKhnOSgm_Wb0?7ml?g_3o?bkO7hlnO]k_7cm??blOOjmPOal>k]kNk`
lOK_o?07kO7clN_Yjnoilo7/1_GWh^W/inGhj@OTi>GVinSYjOWUnN<Lh>3NgM_I
f=OUg>S?`:9iY]CEeM7>dM[RfMSHemKneOWD5=7CeMSIf=OFZ7Z@Z/?2V:O6cMKK
gOWnnOoYo/3o1Ocon<[onOSo3^UaR8>RY[BRQiW[moo[XoOnoOlBo__inNIgL5j>
WXb8Kg_Noo?onoSn4^oooo?oj7/nE54bEe4OlOoab__go`7ln_Won?kmo`GnnoWk
o?kjo`oeoOo/Zgcgooogd_oVmOomo_lRmoKnl_o0W>WokoojmoGgn_Wdk^k[j^gb
m_Cal_?fn?WhmoKilP3aoO3mk`ocl^gan??WkNkaloCcl_7gn_H7lO3^kNg^l?7f
koc`1ngalo7[jN__nO?ak0Kein;Yk>OUn>T7i>CUi^OXjNWiiOWS7>3Pg]gKfMSG
iMcXcl2RNJKDeMGAc]7Jh]WHf=OFo]Gie1CAdmGHfMSGeZQjT:[3`YRWa/gFfmd3
a_Wn1ooomo3`mooojOh2gNGco_l1o?S8o`GnooNjoo7ho`oTKXR6YJNcWXB4i?go
hjgon?kmoa;nnoWkhGIkIXVGSha_N=_om?olnOhHon_oooGoe3m:CD`kB3B6ooo=
jO7ooocoo?go0_cdk_Won?kmo`CnnoWhnOgk5?konoolm_o:V<3nhooYi_o[oooi
n_ko8Ocoi_obbMCkookjmoGgn_Wdk_7/j^kfn_Scl?;fnO[imoKilBKdm??al>k]
k?;hm>c`n_?Rl?7dm_OgmOGbloCemoSin_7_k^c/k^ohl@7clocb2?7Zk_3]j>KX
joWalN`6mNORjNcWiOSY1nGUi>GVinWZnNKihagQhMoMfmWGe^7Rhk2GQfB:_McY
el_Fg]SJfMSGe]Gge1C?dmOIem39`hAXS9N:KDQYcMCJfMCioPOoooO`l?OoonWn
0]gUloko0Ochb?l5o_og^_oan?l?i6j8QZFW/ij4Q>Cmon>]ooSnoOlBo__inn5f
NfJ9Uhn<KgSKooCoo?Wn6?o[oooeom@oBTe<>dPdQ_oocNWaoooloocmo`;lm>ki
ooSnoOl4o__in?WmnaCnoo_oo?KobYS0o^?ojNKojooonO[nob7lonKol/WDnoon
n_Oemo[im>kak>[^m_[hlo3bm_WjnOOfnO4Vm?CclO3^kNcbn?C/l?[ch_3am?Kg
moGel_?dmOOhnO[aknk/k>k_n?41lo?llPSaj^k`kNSVj>_ilO7/1_GWh^W/inGh
j@OUiNCUi^OYj_WVnN<MhN7OgM_IemKQh^>`UhMTR[gLjMO;e]kHf]WHemKEmm@D
cm?GfMO@bL>4J8bGRVe8JLgDf]WDnOh7ooogl?3goooYoP;MiO?no`7ln<So1Oko
mk[olOSo3nA^R8JUYk>NQ8CToOoS[Ooho_go4_kknO_QMW]VRIN?S6mhfoodooci
oQSojooomOoD?dY=C3]8=8KoolgYlOooo?oloOl2o?C^nOoho_go1?kknOSioO/D
o_okoocfolZH`?kSonWVon_oooWjo_lQo?oVoo;9e?_oo_[gmOOjnOC^lNcZk_Kj
n??`l_Kin_Wgm_Wa9_Cdlo7`k^g/l_Sdk?3jln;`lOCfmoOemO;cm?Ggn?WjlNo^
k>c^koSa0O?co?88lN[^l>gXi^S[nO7ak0Kein;Yk>OUn>T7iNGTiNKWjN[ii_WS
7N7QgmgKfMOFhN;S/9N7I8Zmg>WGbmKNf=[If=OFeOOD5<oCemWGd<W3Q6R<UhY]
B6W=e=[Ie0?3nOh7nNcIc<cIk?WYoPN^`MghooommLWo1_coooNaon_ho`oVLXj>
[JjgXWmdgooihKSon?kmoa;nnoWifgB6M96PXHi`MmWom?olnOhHonWoooOoaQY1
A4iPB2?XmOVconSoooOon_go0_[^i_3noOl2o__inOl6i?ool_nfX?ko;Okoolco
noogloooo?Soom_hon?/on[jmoGgn_Wdk_?^j^ohoO[ek_7fnO_jmoKilBOgm_Cb
l>g/joOln>gbo?CPl_?fn?Win?O]k_7dn?_nooKelo;bloGfnO@1mOGnm?kc1nS[
k^_Vi>KYnNkak0Kein;Yk>OUn>T7i^GTi>GWjN_ii_WT7n;QgmgKf=OFd]WCSFeU
AFEf^NGLdn;Oam[JfMOFeMCCnM@DcmCHfMC8^k=66T9o^<VX_LW=c/FfnOh7nNcI
c<cIk?WYoPN^`MghooommLWo1_coooNaon_ho`oVLXj>[JjgXWmdgooihKSon?km
oa;nnoWifgB6M96PXHi`MmWom?olnOhHonWoooOoaQY1A4iPB2?XmOVconSoooOo
n_go0_[^i_3noOl2o__inOl6i?ool_nfX?ko;Okoolconoogloooo?Soom_hon?/
on[jmoGgn_Wdk_?^j^ohoO[ek_7fnO_jmoKilBOgm_Cbl>g/joOln>gbo?CPl_?f
n?Win?O]k_7dn?_nooKelo;bloGfnO@1mOGnm?kc1nS[k^_Vi>KYnNkak0Kein;Y
k>OUn>T7i^GTi>GWjN_ii_WT7n;QgmgKf=OFd]WCSFeUAFEf^NGLdn;Oam[JfMOF
eMCCnM@DcmCHfMC8^k=66T9o^<VX_LW=c/FfnOh7nNcIc<cIk?WYoPN^`Mghooom
mLWo1_coooNaon_ho`oVLXj>[JjgXWmdgooihKSon?kmoa;nnoWifgB6M96PXHi`
MmWom?olnOhHonWoooOoaQY1A4iPB2?XmOVconSoooOon_go0_[^i_3noOl2o__i
nOl6i?ool_nfX?ko;Okoolconoogloooo?Soom_hon?/on[jmoGgn_Wdk_?^j^oh
oO[ek_7fnO_jmoKilBOgm_Cbl>g/joOln>gbo?CPl_?fn?Win?O]k_7dn?_nooKe
lo;bloGfnO@1mOGnm?kc1nS[k^_Vi>KYnNkak0Kein;Yk>OUn>T7i^GTi>GWjN_i
i_WT7n;QgmgKf=OFd]WCSFeUAFEf^NGLdn;Oam[JfMOFeMCCnM@DcmCHfMC8^k=6
6T9o^<VX_LW=c/Ff19`>om?doocmlooN`IE^X/[0o_l>l=[Zm??onoook/c2foS`
o_l=nogkm:7?nookmOGdoOkno`;nnoWao`7ho_ko2_gin?cooo[noooel?l5noWf
`?ogn?l?nFb@X[Zg`Im`T]gon;?onO7n3o;HNI9oTifNNgQleOolookmoa_mo?_j
kOgoi_oo734/CdQ?@6ooo>cRiOOooOSlhOh1o?gmo`Smo??ol?od>_onn@Gjnocm
oOkin@ofnOgoo_[elOWnoo_ak>odo_P1nOWnnRoUkoWkm>k^lOGem_Kgn?Sik^g[
j^[[kNkelNg]l?3/ioGfn?Whm_Cbl?Ghn?Gdn?cnmocf3ok[i>gaj^gjj_;jnoKa
lO?ilAWSi^cam?Ccl_o`j_?O^;G@h^K[j^SWjo3WiokX0^GSh_WV3m[RjN_YjNkb
jNSXinKUi>CihD_IinOHe=oTgLkbgmOLS62YY=3Ej=k6fL[Jf=WMgm[Bc<cGf<k<
e=OAgMWCdmW>XgIB@k:b^KoE_M;1fMN^om?doocmlooN`IE^X/[0o_l>l=[Zm??o
noook/c2foS`o_l=nogkm:7?nookmOGdoOkno`;nnoWao`7ho_ko2_gin?cooo[n
oooel?l5noWf`?ogn?l?nFb@X[Zg`Im`T]gon;?onO7n3o;HNI9oTifNNgQleOol
ookmoa_mo?_jkOgoi_oo734/CdQ?@6ooo>cRiOOooOSlhOh1o?gmo`Smo??ol?od
>_onn@GjnocmoOkin@ofnOgoo_[elOWnoo_ak>odo_P1nOWnnRoUkoWkm>k^lOGe
m_Kgn?Sik^g[j^[[kNkelNg]l?3/ioGfn?Whm_Cbl?Ghn?Gdn?cnmocf3ok[i>ga
j^gjj_;jnoKalO?ilAWSi^cam?Ccl_o`j_?O^;G@h^K[j^SWjo3WiokX0^GSh_WV
3m[RjN_YjNkbjNSXinKUi>CihD_IinOHe=oTgLkbgmOLS62YY=3Ej=k6fL[Jf=WM
gm[Bc<cGf<k<e=OAgMWCdmW>XgIB@k:b^KoE_M;1fMN^om?doocmlooN`IE^X/[0
o_l>l=[Zm??onoook/c2foS`o_l=nogkm:7?nookmOGdoOkno`;nnoWao`7ho_ko
2_gin?cooo[noooel?l5noWf`?ogn?l?nFb@X[Zg`Im`T]gon;?onO7n3o;HNI9o
TifNNgQleOolookmoa_mo?_jkOgoi_oo734/CdQ?@6ooo>cRiOOooOSlhOh1o?gm
o`Smo??ol?od>_onn@GjnocmoOkin@ofnOgoo_[elOWnoo_ak>odo_P1nOWnnRoU
koWkm>k^lOGem_Kgn?Sik^g[j^[[kNkelNg]l?3/ioGfn?Whm_Cbl?Ghn?Gdn?cn
mocf3ok[i>gaj^gjj_;jnoKalO?ilAWSi^cam?Ccl_o`j_?O^;G@h^K[j^SWjo3W
iokX0^GSh_WV3m[RjN_YjNkbjNSXinKUi>CihCcIinOHe=oTgLkbgmOLS62YY=3E
j=k6fL[Jf=WMgm[Bc<cGf<k<e=OAgMWCdmW>XgIB@k:b^KoE_M;1fMN^17/Ol[;@
k_Wol?_cfKN=[lk:onC_e;oIk^WZn_c^bJBN^m_mo`3ko_l4e_?ooo_no`;loOkW
o`[nooo_noomo_oonO3o1Ocil<Kom_So3n5/Ph>[[:fDMHk/ooNLooWaoPoogFQn
NifWX7]hN]3omooio_lLo_kmoOc]noo^oml^CSUY>f8Eb^3oc^7gooomoOoQoP7l
oOgo4Oglnoo]oi6anoWin_[ko?gno_Wi4?Ofm?;alO;blOKhm>gYk?3co?@QmOGX
lO[km_3`l^o_k^c[j^WXk^g[j^[[kNkcknc]l?7^j_kao_8>lo?bm_Whm??fn_?c
m?CeoOH>lo_ooo3`o>3TjN_/jn_/nO0Hi^S]l?;bl>oYgn?`jMCBhN?XkNg[j^kb
j?kY0nSWiNCiiPoWj^g^kNc]k^WXj>OViNCTnN5LgNKUf]WQgm?Hj/6SX6MM^<kN
a]CIe?;UcMGGd<gBe]GHf][Ge]OEd];Ff=OA^89@4SgIdkVYcm_?a]gK]_:bd>ki
oo3klmVgSJo>b_oTkmBofNkYj_[lk/VTW[_KoOl0noko1=Kcoooko_l2o?gniol:
o_ooko_ooOkoooW`o`GlnO36ooKho`oQK8>3Zjb]U7F>k?ogW?oilOh?omeXOW^M
Yj1kN7[@ooOonOko7?knoOglkO_ok_oO;ThiJC]R5L[PolkQmooooOgohOh1o?gm
oa7mo?_okOnA/O_inO[jnocmo_kinA3gm_CblO7bl_7fn?C]jNc`locd8OGej?7j
noK`l?;_knk/jn[Yj>k]jn[Zjng^lno/kO3ak^[nlOkb3_?cl_Kin?Ccm_[cloCd
mOgf3_?kooo`l?cPi>W[k>_[k?W`6>KXkO3bl_3_jMoSl>WDd^7Sj>g]jn[^l^Sn
j@?XinGTnNH?in[]k^g/kNkYj>SWi^GTi?WQG=gViM[IhMoCf>[1Xj1WGKS>g/KD
fMCbiLgEem3=d]KEf=[JemKGeM;Be]SGdKR2D18mfM>iZLoKclKMfkKb/]3^nOo`
no?I]hf_c/[oi>oD_mW^jN[jo>k9Y9jkfogo0?_no`CFlooonoko0_cmo^Oo2_ko
onokoognoooil?l5o?W`a_ofn?l?hFb3Pj^/[IAeS^comiconO7n3ooMJ7ikWJNP
NgQjd?ogooWnoacno_gmo>gkonkogbi>>FTkHQG:h?o>hOOooogmon7n0OcmoOlA
oOckongoTK7knOWjn__loOknnOT@moKdl_7al_;am_SdkNW/l??lm27emNSan__f
l?3bkno^k>_ZjNS^kN_Zj^_]k_?_k>g`lNkZo_7nlPkclo;fnOSdloKjlo?dm?Gm
mPkcnoool?3lh>CYjnc[jncil1SVj>g`l_;`knWOho3Ye=;QhnS]kN_Zk_;Xo^T3
j>OUi?WV3nOZkNk]k>g^jNSXinKUi>CihCcMi^GJfN7OdmSZ`J>PIefhc]k6e=WD
l^G=eMO@cM;FeMSJf]OFemGBd]KHem6hPU0B?MWC^JW?flo6gM^f184`ojnhfOCo
g]CZdKZ:RiZNj?oohKC;k_CenoWW`IbCZL?ao_olm_Sgl:[>lOglo?Wcooknj_l<
o_gnoooNlooooOooo_3o1Ogji]3omOSo3mf<SgBa]j^MOhOlooR9nO_aoQCoeF9g
LI:NVh1kN/golOkdo?gmo_knoaCbmockohi5JTmcADLYomSo]>Kooocnon7n0Ocm
oOlAoOconOkaI?ojm_[jnocmo_oonOX@o?SbkNc_m?O^l_Cckng`lo3jkdO/l_Si
mO7`lNk/j^OTh]oNk^g[j^[[kNk`k>[/lO?`kNk/j^W[ko?fm?Sjn?Cbm?S_ko3b
loCem]cUmOkei>7ZjNSWjo7dm?;il1OZk>k_knk]jnOZk^kXg]KBh^S^kng]ko?n
j`CZjNSWi_WU3o3/j^[[jnSUjNSXinKUi>CihFgRi>7MhN?Fa;cD`JbGB29JH7Ig
[M7?g;k@h>3=a]GPg][De=_NfMGFc=GHdlZeRfA23R`075jad<[5c[R;ojnhfOCo
g]CZdKZ:RiZNj?oohKC;k_CenoWW`IbCZL?ao_olm_Sgl:[>lOglo?Wcooknj_l<
o_gnoooNlooooOooo_3o1Ogji]3omOSo3mf<SgBa]j^MOhOlooR9nO_aoQCoeF9g
LI:NVh1kN/golOkdo?gmo_knoaCbmockohi5JTmcADLYomSo]>Kooocnon7n0Ocm
oOlAoOconOkaI?ojm_[jnocmo_oonOX@o?SbkNc_m?O^l_Cckng`lo3jkdO/l_Si
mO7`lNk/j^OTh]oNk^g[j^[[kNk`k>[/lO?`kNk/j^W[ko?fm?Sjn?Cbm?S_ko3b
loCem]cUmOkei>7ZjNSWjo7dm?;il1OZk>k_knk]jnOZk^kXg]KBh^S^kng]ko?n
j`CZjNSWi_WU3o3/j^[[jnSUjNSXinKUi>CihFgRi>7MhN?Fa;cD`JbGB29JH7Ig
[M7?g;k@h>3=a]GPg][De=_NfMGFc=GHdlZeRfA23R`075jad<[5c[R;ojnhfOCo
g]CZdKZ:RiZNj?oohKC;k_CenoWW`IbCZL?ao_olm_Sgl:[>lOglo?Wcooknj_l<
o_gnoooNlooooOooo_3o1Ogji]3omOSo3mf<SgBa]j^MOhOlooR9nO_aoQCoeF9g
LI:NVh1kN/golOkdo?gmo_knoaCbmockohi5JTmcADLYomSo]>Kooocnon7n0Ocm
oOlAoOconOkaI?ojm_[jnocmo_oonOX@o?SbkNc_m?O^l_Cckng`lo3jkdO/l_Si
mO7`lNk/j^OTh]oNk^g[j^[[kNk`k>[/lO?`kNk/j^W[ko?fm?Sjn?Cbm?S_ko3b
loCem]cUmOkei>7ZjNSWjo7dm?;il1OZk>k_knk]jnOZk^kXg]KBh^S^kng]ko?n
j`CZjNSWi_WU3o3/j^[[jnSUjNSXinKUi>CihCcRi>7MhN?Fa;cD`JbGB29JH7Ig
[M7?g;k@h>3=a]GPg][De=_NfMGFc=GHdlZeRfA23R`075jad<[5c[R;17h[ojjQ
`>_oh<gK_;9oHFAb_?ok]Fmk[M?]l>oTb:ZNZ[[>j?oooO;MbIJhg??no`3ho_l1
o_kZo`Snn_;/d^goooc^o`Kno__Hg_odn?l>j:nULk_3[:J>P?oioIChl?hCkm9c
SGnHXj>=QGo?o^onm?[ko?gmoaOnlo?ond]EJUeTEa>Aoooa^_7oooKooocQoP7l
oOgo3_gloo?oUjgoooSknocmo_konO/9oogim_Gfn?[bm?kf2?Oino7`l>o^k_k]
A_3cm?;_kNc`kng[jNOViNk]jn[Zjng^kN[Xjo7dl^o^jnOVj>kfn_GinoWdlOCg
k>g^l?7cm?GbloOmooglo_C_k>ken?OcnNomkQO/jnWXk?GahMSIe<WLhn_]k>_]
knk/jnWnj03YnN@?kNORh^OXiN7Yj>SWi^GTi?WQJ>ORgN3Vh/fgan3WjmMo>3hf
F76njMkR`m;Nfl_:f]kCeLk?fMgHe]W@e]G=blVkZ997ARJ6cnOBdm_OcKGo[Z70
jooPcM^l/WmQI7:loo^eKg^]dng`knC8ZYjZ^/kXoooml]g9U[SLloko0?Sno`7n
o^[o2?kjl^cBkOooo>ko1_knnmSNooCho`kX[jEc^l>/YXj0ooWmU?S`oQ?_dW>=
OiRSXhf5Olonkokdn__loOgo5okclookBeEZGFAG4i7ooo6jlOoom_ooo>7n0Ocm
oOl>oOcolonG[Ooon?_ko?gno_oin`WooOWfmOKhn_;do_H8moWklO3`knk^o^e6
l??dl^o]k?3_kN_YinKUk^g[j^[[kNk]j^S[lOCbknk[inKXk_KjmOWknOCam?O/
kNk`lO?dmO;cmogooOcnm>o/k_Ghmo?ikog^5nc[jNS/mO7Qf=WDbMcSjng/jng_
k^c[jOkX0>Wii0o]in;RinSUhNWXj>OViNCTnN5Xin;Mh>KRcKO7h>O[eglh?SIH
LKkYg^;3d]kKbl[Jg]?Ec/oIgMSFfM3FeLg;bK^XTTM69XK?im;Cfmo=]On^XL3[
on3=fkbbOf5TL[conkE_NjgCkO3_i<RZWZZjc^SooogbgLVF^=cco_l0n?ko0Okn
j_l8o_[bk=;]ooolk_l6o_kkf=kom?So3^R_YG>k`jbVSX3onOfDn?3n4noBLheo
V:>SSHEocok_o_CjnocmoOlGo_?coo];EFYMI5LCTOoolK[aooofooolhOh1o?gm
o`kmo?ocoiN]ooohno_loOknooWk2OomnOKem_Sjl_CnmPSgnO_al?3_k^knkDK`
loCbkng/l>o]jnWWi^G^kN_Zj^_]k^gZj>_am?;_k^_Wi^S^m_[enO_im?7dmnc]
k_3aloCel_?goOomo?kdknc^mOSgloW_oNhGk>_Yj>celN7HfMC9g>?[kNc[kNo^
k>_Yo^P0jOWT3ngWh^;Wj>GQjNSXinKUi>CihCcWh]gPi^;=]lOPin_GOcPn=UQa
_^WNh/?Bg]_;b][NdmG>cmWMf=KId=KEcL_9^jRBAdHVQ/oWd]?Kglfe16TQohih
V=7ok^KJ[Zn8GfF3bn3IVEQLQkgbiMg</j2Q/lG6hogo1noL_L70`m[lnoomo^co
1oCOc];]ooolk_l6o?olbNgol_So3nRaYW6c]j2KUh3ilORioooaoQ?ofFjGY/g:
]j2DR]Gol_ohn__loOco5_3_on0/FUAGGD8Wj?3o_McnooCbooodhOh1o?gmo`gm
o?_od7;ojokoo?cmo_gonO`<n?[loOcimO?cl_?en?kj3oGem??blO3_knk]kNk/
jNOnk?c]=nk]jn[Zjng^kN[Xjo7dl^o_k>WWj_3go?Cgn_Sdl_GikNk_l?7bloCi
i]?DjOcmlng[j^[/k>[WnNhOl>o]jnWXj>OQj^G@aLgHfM?KiNWXinSZk^cYi^GV
j>Wih`oZi^;Si^W[jnWXj>OViNCTnN5Nj=oKh^SMa[?>bL?=c9iaJHFLW/gIa=_G
a<C3a]7Id/CEfM[Dd=;De=3Gem3>c;bX?UFPR<?DdLWEg/jbZ?n>N9SAonkVfZj_
R5mUPl_PfIUHG8Nml^GMc;>PXK?5a^?mo`O_g;g1`<?Jo?_ooOk/o`OdglkBkOoo
o>ko1_coo<W]oo;ho`oX/JIa/kNPViN0nO7h^OoolOhComU^UjK=b[NPU8[Eoo;o
n?[ko?gloaK`kooP;5YDEee29nS`okgLo_odl_oom>7n0OcmoOl=oOckom1bon_n
oocloOkmooWl3?Sjo?glnOGclo;cmOSnnPoemOCcl_7`kno^kNg^k>WWo^clkCO^
kN_Zj^_]k^gZj>_am?;_kncYin[`mocdmo[hm?;enNg^ko3al_?dnNKCe>WloO?]
jn[Zk>cZioW^7o3_kN_Yj>SWhN[Ud<G=f=WCfnGYj>OXj^k/jNKUi^SYnN<?j^KR
hnKYjn_Yj>SWi^GTi?WQG^SOfn;XgLJcc/W3cLbNLFV5W9k=fLCKelC4`lKAfM;4
eMWJe=3Be=C@emO@c/blZ3iEX8S3e=79eMk>/ZSoSWRHdOo^i]Z^[hQOIH?;h=VI
F5b7_O;UgLbcX:6caLKSoOl7kmbm`L33f_ckoognk?l7m=o>d^goooc^o`Klooc9
kOobn?l?j;6VLK>gX9^GP?Wan;Wooo7n4ooIKYNVcLZgX9B:eOobooSjnocmo?lF
l>ooh2aJE5MM@ROXl?nmg?kom?;oooCQoP7loOgo3Oglnoo@L_o[o_olo?gnoOoi
o0chn_cmo?Welo?bloGho_X?mOGdlo;al>o_k^g]k^cYiok/o>dgk^g[j^[[kNk]
j^S[lOCbkno/jNOZl?Olm?Ojn?CbmOW]k^o`lO;cm?WVdmCYo?gckN_Zj^c/j^Oi
kQo`kng[jNSXin7ZiM35cMSIdm_UjNSWj>[^k>WViNKXjOWS3n[Vh^?VjN_[jNSX
inKUi>CihCcXgm_Rj=g6/lk9`lg<WW5YQIbNcMW4fmO4a<?6dMWBa=GIf]C@d]CD
d=OGd<k<_:PnEJ28`mCAbMGNc[:X19<Tn8E/OjWKen34QI1nG7BQi?_Z]H^7SJgU
mN71Y9ZZb>3?hoCgo?ko2=oLe]O[ooojo_go0_gknO7o0Ogmo_l:l]Fng_?ooogo
ookao`Kjoojln_o`n?l?jYjSOjj/XIRDR_C`gn3ooo7n5?o8BhFhl^Bk/::Cf_od
oo_loOgno_go5_3dojPZFT=<GB:Dm_kj]?coo>keooobhOh1o?gmo`cmo>goS:Ko
jNcooOgno?oioDO_loOjnOG^j_3]jnkcm_Can_Whm_Gcl_7dl>c[kNgZiNKWj>WZ
jnc/k^g[j^[[kNk`k>[/lO?`kNk]j^[[ko?fl?Chn?Gdn?cnlocb3oKL_kcImO3K
i>_blnkZjN_ikAo`k^_YinOXjNo`j=2e[KoDcMKQinOUiNK]j^KRhN?Vj?WR3nS[
jnSUinkfjNSXinKUi>CihF7Vg=_Ti=C1^<Rf/kjiWG]TVK6be<VQ^/75][[@f<_3
bLCQhl:damC>bmGKelbaPUPhML^Ob/k@hlO<YH:;n8E/OjWKen34QI1nG7BQi?_Z
]H^7SJgUmN71Y9ZZb>3?hoCgo?ko2=oLe]O[ooojo_go0_gknO7o0Ogmo_l:l]Fn
g_?ooogoookao`Kjoojln_o`n?l?jYjSOjj/XIRDR_C`gn3ooo7n5?o8BhFhl^Bk
/::Cf_odoo_loOgno_go5_3dojPZFT=<GB:Dm_kj]?coo>keooobhOh1o?gmo`cm
o>goS:KojNcooOgno?oioDO_loOjnOG^j_3]jnkcm_Can_Whm_Gcl_7dl>c[kNgZ
iNKWj>WZjnc/k^g[j^[[kNk`k>[/lO?`kNk]j^[[ko?fl?Chn?Gdn?cnlocb3oKL
_kcImO3Ki>_blnkZjN_ikAo`k^_YinOXjNo`j=2e[KoDcMKQinOUiNK]j^KRhN?V
j?WR3nS[jnSUinkfjNSXinKUi>CihF7Vg=_Ti=C1^<Rf/kjiWG]TVK6be<VQ^/75
][[@f<_3bLCQhl:damC>bmGKelbaPUPhML^Ob/k@hlO<YH:;n8E/OjWKen34QI1n
G7BQi?_Z]H^7SJgUmN71Y9ZZb>3?hoCgo?ko2=oLe]O[ooojo_go0_gknO7o0Ogm
o_l:l]Fng_?ooogoookao`Kjoojln_o`n?l?jYjSOjj/XIRDR_C`gn3ooo7n5?o8
BhFhl^Bk/::Cf_odoo_loOgno_go5_3dojPZFT=<GB:Dm_kj]?coo>keooobhOh1
o?gmo`cmo>goS:KojNcooOgno?oioDO_loOjnOG^j_3]jnkcm_Can_Whm_Gcl_7d
l>c[kNgZiNKWj>WZjnc/k^g[j^[[kNk`k>[/lO?`kNk]j^[[ko?fl?Chn?Gdn?cn
locb3oKL_kcImO3Ki>_blnkZjN_ikAo`k^_YinOXjNo`j=2e[KoDcMKQinOUiNK]
j^KRhN?Vj?WR3nS[jnSUinkfjNSXinKUi>CihCcVg=_Ti=C1^<Rf/kjiWG]TVK6b
e<VQ^/75][[@f<_3bLCQhl:damC>bmGKelbaPUPhML^Ob/k@hlO<YH:;19<ZoiR5
R9Vn`mZmJGAaFh6fl?W:THB=NXFlonkB^k>mdN3Mk?C`l?WmnOKioOko1?_GkO;j
o_l1oOWao`omn__oooGKaNokoognoooilOl6nOon/OookoSo3nb1WYJ`ZK2PQ9_g
m[Wfn_oaoPo3YEJH]]oI`[ZZV=colooko_lLo_kmoOcol?omHC=KAU53>__^ol[E
ooogm_coo_WQoP7loOgo2oglm?R:i_ofnOono__onOh0m?ke<_CblO3ck^_]m?Oc
k__jn?Kdl_7`oOK_k_;ck^WZj^WYj>SWink]jn[Zjng^lno/kO3ak__Z8^_[k>ca
m_Oem__onOWgm_CblO3oongYoOongm3Smo[ajNgenN`Ok^cYi^KWj^_im_?P/i:S
c<cFh^WYinKWjnORg]gOhnKhhPk[knKHeN?bjNSXinKUi>CihFOSfmcUglZo`M[E
j_OK]I5_VZbZc/>J]/?B^;_D`I:D_H_6d9b;^m_@cM?Dc/2KFAl>F[ZVilf6IKg2
Tgb[oiR5R9Vn`mZmJGAaFh6fl?W:THB=NXFlonkB^k>mdN3Mk?C`l?WmnOKioOko
1?_GkO;jo_l1oOWao`omn__oooGKaNokoognoooilOl6nOon/OookoSo3nb1WYJ`
ZK2PQ9_gm[Wfn_oaoPo3YEJH]]oI`[ZZV=colooko_lLo_kmoOcol?omHC=KAU53
>__^ol[Eooogm_coo_WQoP7loOgo2oglm?R:i_ofnOono__onOh0m?ke<_CblO3c
k^_]m?Ock__jn?Kdl_7`oOK_k_;ck^WZj^WYj>SWink]jn[Zjng^lno/kO3ak__Z
8^_[k>cam_Oem__onOWgm_CblO3oongYoOongm3Smo[ajNgenN`Ok^cYi^KWj^_i
m_?P/i:Sc<cFh^WYinKWjnORg]gOhnKhhPk[knKHeN?bjNSXinKUi>CihFOSfmcU
glZo`M[Ej_OK]I5_VZbZc/>J]/?B^;_D`I:D_H_6d9b;^m_@cM?Dc/2KFAl>F[ZV
ilf6IKg2Tgb[oiR5R9Vn`mZmJGAaFh6fl?W:THB=NXFlonkB^k>mdN3Mk?C`l?Wm
nOKioOko1?_GkO;jo_l1oOWao`omn__oooGKaNokoognoooilOl6nOon/OookoSo
3nb1WYJ`ZK2PQ9_gm[Wfn_oaoPo3YEJH]]oI`[ZZV=colooko_lLo_kmoOcol?om
HC=KAU53>__^ol[Eooogm_coo_WQoP7loOgo2oglm?R:i_ofnOono__onOh0m?ke
<_CblO3ck^_]m?Ock__jn?Kdl_7`oOK_k_;ck^WZj^WYj>SWink]jn[Zjng^lno/
kO3ak__Z8^_[k>cam_Oem__onOWgm_CblO3oongYoOongm3Smo[ajNgenN`Ok^cY
i^KWj^_im_?P/i:Sc<cFh^WYinKWjnORg]gOhnKhhPk[knKHeN?bjNSXinKUi>Ci
hCcSfmcUglZo`M[Ej_OK]I5_VZbZc/>J]/?B^;_D`I:D_H_6d9b;^m_@cM?Dc/2K
FAl>F[ZVilf6IKg2Tgb[190PmIjIWZK7eOSMNGn2L9cBonVOGVfBRIWIl^_Qe/k7
`[o^o_l>o?KZgMcB`l3@f/JWgnSeoOl0o?3o3_Wgo?ojiM;looojo_oomO7o1_So
ojcoonoho`oRHI2MZJ2dWgNYoObKo?3olOh?IiJ@e;Znb]Rn[IWKoo7on_go6ogl
no[dl?oc;cYMDV0ML_odok3goo[hooojn_oQoP7loOgo2_gloknfoOofon_nn_oi
oUoooOSdloGio?celO?jo?Oan_WgmO?`knkono?bmoSckO?bl>k[j>KUk^g[j^[[
kNkelNg]l?3/inGWj>WXinCSjNkdm_Kho_onoO_hmO;`knS_k^_almVe//kZlNCL
ho3ik1G]jnOUiNO[kN;Qk>ZnTjWQc]SUk>cZo^T6iN3Kf]gQiOWQ3mWUjmk7`M7U
jNSXinKUi>ChhEcIgNGKa;k7`/7Lh[VNUhF]WG1kLF2K_]Fc/l>CBE>HCIjbMfbc
i=SFdLRn]IMK8bEhdZkT^fU:/jUL;4geWYVNY/OEn=eiOh9`W=;ojImNKI:9VMWb
jn7Fc/O2_nkno`klm^[Mg=;3`=3JaZOOj?Gmo`3ll?l>nOOloo[Ud_cooo[noooe
lOl6n?oo[?ookoSo3n9QT9fYX;BOMjWmo9_ll?oaoPmWUY3D^[k:f;j]VM_olOoj
oOlKoOckn_C`oo<_>UeBH1ebooCo/?Oon_Sooo[jon7n0OcmoOl:oOco_kKmooKo
jokjooWnGoomn?CcmOWlo?Galo[lmo7jnOOelo3_k_oklo;gn??]lo;`k^_Xi^G^
kN_Zj^_]k_GakNg`l>cWiNOXjNSWi>?Yk_Cfm_SnookmnoSel_3_j>o^jo7cfKFb
c^[ai=cSl?W/5Ng[inGUin_]h^7/j[jCZN7>f>G/k>[nj@KUh=_JgN7UnN4?fNG[
g/O1dNGYj>SWi^GTi?SQG=WMiM_4_/O2`McR^IjGQJfML7]aH9^neK>c`i=9DiQ=
W[9gK;?Tf=KAb;jeUe/S9GSB[^BkJDZcZE`/COFNVIjVamGhgGUoPW2Ld_oYWei]
TXVIfO;[hMK>al:ok_ko3_cfj]gLd/?0d=[6YmoXmOgo0?c`o`kimocon^GBo?oo
n_koooGao`Khoon/ooo_n?l?hV6@WJVP]9mgZOglVoc`oo7n3fNFT=Bj_/[H_ZfI
fooaoo[moa_mo?_jm?3olbljGE9P7G;om?n`moojn?oon_[ohOh1o?gmo`[mo?no
]_gom_o[o_[onOiOooghm??enOclmO7cn_cglO[imoGcl>o^oo_cl_Ohlngcl_3^
jnSViNk]jn[Zjng^mO7]kO3`k>OUinSYj>OThnW^m?Kfn?koo_gkn?Gbl>oXknk[
lO?I]K;>j_7Tg>?`nN`EkN_WiNGWjngRhNcZ_Y>YhLkHiNc/j_kY1^GPfm[MhNGi
h@oIiN_Nal7AiNWXj>OViNCTn>4kfMgUflBnal;1g>:iWYN5[Ie`Ng5PVkkE/k?3
TdUCV4fN/WM//nCHe]78_[FGFb<UN=:^i;]YB[>YG2a=1F8`oiakY;Bee?>nRWMm
MXFY^Kb4S/?2YJ6Ue:>:R_Gloo[olOKoo?[S]JcoonGZgKVgoOko1?ggoooZoOl1
lo?ko`7moOko3?;jonc4ao;ol_CoonO`o`_lomJWon[noOWin_knoaGnfX>HR/34
/HZ@MNgoWoGooo_knOSnoOlfm_ookOolRH5ji9biglOQb<Jme_oom?Woo_[oooWj
oog]okl]Kee?GC[RoOCo/O[oo?gooo_io?Wnmol2n?;gn_l3n_Kgn_koOokinOOd
og7UooKogoojo?koooklnoSkoOgknogoo__inO_mo?[oj_oei_oilOghmOGgn?C_
onWlk^giiO[Zjnc^ko3bl^KXj^g_l_CenNgVj_7cloCZkn_Qh^g`j_?fm>g`m^kN
ko;emO;`lO?]ojcYiOnLdNOYjO[am?oSm^3_OmWEk>7fn?3Fo>Wnk?ooiN[KY[CY
kM;>^N;@j=gheo;Rf^7ZfnC`aooP^>WXilOKe_NYGKg`g^KOf]oJg??LbmKRf>7_
iNG1cMkCfKAG`MWYblVQ[Tk1^YjhZgf=T:Bf_9YM<C=:EV5fU;?9e=Jnb]7=`9mP
9bIY`N[2MTY7WGmI<T91oiakY;Bee?>nRWMmMXFY^Kb4S/?2YJ6Ue:>:R_Gloo[o
lOKoo?[S]JcoonGZgKVgoOko1?ggoooZoOl1lo?ko`7moOko3?;jonc4ao;ol_Co
onO`o`_lomJWon[noOWin_knoaGnfX>HR/34/HZ@MNgoWoGooo_knOSnoOlfm_oo
kOolRH5ji9biglOQb<Jme_oom?Woo_[oooWjoog]okl]Kee?GC[RoOCo/O[oo?go
oo_io?Wnmol2n?;gn_l3n_Kgn_koOokinOOdog7UooKogoojo?koooklnoSkoOgk
nogoo__inO_mo?[oj_oei_oilOghmOGgn?C_onWlk^giiO[Zjnc^ko3bl^KXj^g_
l_CenNgVj_7cloCZkn_Qh^g`j_?fm>g`m^kNko;emO;`lO?]ojcYiOnLdNOYjO[a
m?oSm^3_OmWEk>7fn?3Fo>Wnk?ooiN[KY[CYkM;>^N;@j=gheo;Rf^7ZfnC`aooP
^>WXilOKe_NYGKg`g^KOf]oJg??LbmKRf>7_iNG1cMkCfKAG`MWYblVQ[Tk1^Yjh
Zgf=T:Bf_9YM<C=:EV5fU;?9e=Jnb]7=`9mP9bIY`N[2MTY7WGmI<T91oiakY;Be
e?>nRWMmMXFY^Kb4S/?2YJ6Ue:>:R_Gloo[olOKoo?[S]JcoonGZgKVgoOko1?gg
oooZoOl1lo?ko`7moOko3?;jonc4ao;ol_CoonO`o`_lomJWon[noOWin_knoaGn
fX>HR/34/HZ@MNgoWoGooo_knOSnoOlfm_ookOolRH5ji9biglOQb<Jme_oom?Wo
o_[oooWjoog]okl]Kee?GC[RoOCo/O[oo?gooo_io?Wnmol2n?;gn_l3n_Kgn_ko
OokinOOdog7UooKogoojo?koooklnoSkoOgknogoo__inO_mo?[oj_oei_oilOgh
mOGgn?C_onWlk^giiO[Zjnc^ko3bl^KXj^g_l_CenNgVj_7cloCZkn_Qh^g`j_?f
m>g`m^kNko;emO;`lO?]ojcYiOnLdNOYjO[am?oSm^3_OmWEk>7fn?3Fo>Wnk?oo
iN[KY[CYkM;>^N;@j=gheo;Rf^7ZfnC`aooP^>WXilOKe_NYGKg`g^KOf]oJg??L
bmKRf>7_iNG1cMkCfKAG`MWYblVQ[Tk1^YjhZgf=T:Bf_9YM<C=:EV5fU;?9e=Jn
b]7=`9mP9bIY`N[2MTY7WGmI0D911ChcnjEkSZBlcLN[MV=UEVVYf;jce?S^gM:m
Pj[Rg_oPl_ojmOoonOoohm3ooo7nl<k>Vjo?k_go0nKSk?_no`Wdo?cnoochn_kI
o_l5lLJdbMWko_l1koW`o`KYomfmhkKIn_lAo__KPYB5^l6aS7ibhOjln_o/oOl0
oOko7O_omOSokXb1S97UOiWFc]OBcK_9lochooG/kO[oo_ko4N[oMCI@K5m3Oo?o
oloIk_gloOconOh3noWhno[o0_gko_[o0?gno`kio?oonoooe9ojooGok__go`?m
nOSjn_lOo?KboN_on>oomo3ln?Cen?Sdl?o/oo3_oNSjkNg^k^onl7ocl_;`k^cZ
jO7al_;_kO;ijO7^h=cWloKcn?K`lo_hkOCem??alO?fcO:cgNOdYmOXgMoflngi
j^K>moGUl^7TeO;^o];`i>[ai?3N/<Gaj^_N^]gBm>;^gngNfN_[g^OSe_:RM/SM
c^O@g?n[AgBel<:d^k_AjN7Of^W[gNOZc73Qd^_/b=SY`:o4f/cPb^:9^Ymo[:IV
IfV2S8igCcDjBdE<Fg67UY^J]Lg4RUE1>RhI@G^LR5De<69@?3DlnjEkSZBlcLN[
MV=UEVVYf;jce?S^gM:mPj[Rg_oPl_ojmOoonOoohm3ooo7nl<k>Vjo?k_go0nKS
k?_no`Wdo?cnoochn_kIo_l5lLJdbMWko_l1koW`o`KYomfmhkKIn_lAo__KPYB5
^l6aS7ibhOjln_o/oOl0oOko7O_omOSokXb1S97UOiWFc]OBcK_9lochooG/kO[o
o_ko4N[oMCI@K5m3Oo?ooloIk_gloOconOh3noWhno[o0_gko_[o0?gno`kio?oo
noooe9ojooGok__go`?mnOSjn_lOo?KboN_on>oomo3ln?Cen?Sdl?o/oo3_oNSj
kNg^k^onl7ocl_;`k^cZjO7al_;_kO;ijO7^h=cWloKcn?K`lo_hkOCem??alO?f
cO:cgNOdYmOXgMoflngij^K>moGUl^7TeO;^o];`i>[ai?3N/<Gaj^_N^]gBm>;^
gngNfN_[g^OSe_:RM/SMc^O@g?n[AgBel<:d^k_AjN7Of^W[gNOZc73Qd^_/b=SY
`:o4f/cPb^:9^Ymo[:IVIfV2S8igCcDjBdE<Fg67UY^J]Lg4RUE1>RhI@G^LR5De
<69@?3DlnjEkSZBlcLN[MV=UEVVYf;jce?S^gM:mPj[Rg_oPl_ojmOoonOoohm3o
oo7nl<k>Vjo?k_go0nKSk?_no`Wdo?cnoochn_kIo_l5lLJdbMWko_l1koW`o`KY
omfmhkKIn_lAo__KPYB5^l6aS7ibhOjln_o/oOl0oOko7O_omOSokXb1S97UOiWF
c]OBcK_9lochooG/kO[oo_ko4N[oMCI@K5m3Oo?ooloIk_gloOconOh3noWhno[o
0_gko_[o0?gno`kio?oonoooe9ojooGok__go`?mnOSjn_lOo?KboN_on>oomo3l
n?Cen?Sdl?o/oo3_oNSjkNg^k^onl7ocl_;`k^cZjO7al_;_kO;ijO7^h=cWloKc
n?K`lo_hkOCem??alO?fcO:cgNOdYmOXgMoflngij^K>moGUl^7TeO;^o];`i>[a
i?3N/<Gaj^_N^]gBm>;^gngNfN_[g^OSe_:RM/SMc^O@g?n[AgBel<:d^k_AjN7O
f^W[gNOZc3cQd^_/b=SY`:o4f/cPb^:9^Ymo[:IVIfV2S8igCcDjBdE<Fg67UY^J
]Lg4RUE1>RhI@G^LR5De<69@?3Dl1Ddank1nO9>h^iEfI8RaWY:lik6de_?jonbi
SZWDdooL`:C2goookoooi:3Blooog9nAm?gmo`[km>G<ioomoooRo_go4_koooCo
oo_/fL6`j[bdeoCol/k_o`FM^L_0`OWloa?nnoWLP8mn];faT8R3a;;1mOogo?ko
=O[gn_okooGkojENSIFOdeU^]lC0bMCEiooolOobjN_iooklooocmS9C>VM@:<kf
o_FTooclo__onOh3oocin_go0?cmo`?mo_olnOl>n?Sooo3boj_Moooiooo[molZ
oO[io?oomOWnooojlnohkOoemoodl__gm?ChnOGaoo3olO3ok?_alO3`kok^OoKe
mO;_j^KTj_GmnNo[l?OXlNoQfnOen^gemNg_nOghn_OdlO;enO_lomONooo>gOo]
e]3ChOOoaZGYonWfkn[CjnWjd_SH/>7Rm>S2bN?Na[1nWjoai^CZj^3FlN3IiN7a
j6m9__[^nk;BkJIDF;3M`l:/M7g2jmWEi^cMg]JdK/ZOYKJbcM6Fg>;Xdn2mbFUj
DbmZN4YJIjjXUgiVF5EF>3Y2CUUMFUEmbNFMABHY:A<L<DE5<R<P;RTW;SWk/7il
TkRkUGITR;6NT[cW/KCFlo[ok;V>ZMCComc0Y<;Oooo_oooTX=;coooLWi7doOgo
2__diLcWoogoon;noOlBo_oom?oonncI`K3Z_;CGm?obc^oo1Ifibl31nOco4okk
nMb0Sgjd_K6@R8?4//7eooOlo_len_Ojoo_omO_oYEj=UIoCFFjga<39e=GWoooa
oo;YjoWoo_cooo?f<U<jIe0Xc_KnmJCoo?cnnooioP?oo?WjoOl0o?go0ognooci
o`khn?ool?;oZmgoooWoon_gob[mn_WloooenOkooo[ckoS]ooGgooCbnoOdm?Si
mO7ol?oal?o/no7al?3_o^iom_Gel^oZi^CZmOgikn_`mnSakn7KioGjkOGekNoi
oOSjmoCal_GinocoemkoolkMongFd=?Qmoo6YNWojOK_j]?[jO[Bn=R`hN;dj<;9
hmk6/7jO[o7Vi>[Zh=Kah=WUhO7XKdVnn^kk/];]YUAH/=g3`ZadOL;[fMGVk=gN
e[A^bYnU][;=dIKLh^SCh;g9JGYC;fYhBUYW[ZRGOVIHEEHh>T9>FEeJEGg9iIe5
9RTY4a`aADDb8b0^:BL^>O^`OWbC^;^EMVB8/IjB_>Na]=Kcn_o/^HjYe=?og<2T
`]ooonooonBPd_?oombOTOCmoOl:noCUc>OooOooh_kmoa;nooodoookk=W1/>Zl
]=Odoo;>kol5WKW;`<7io?lCo__ig82?O[Bm/I28PlBb`OGomocnocGjmo[onooe
nonUGXfEWm=IK[O4`<WDeNOooo7ol^W[nOono?ooloHbDcYWD2S>m_keY?olo?kk
ooWn0oolnO[mo`3loOl3oOkoo?Wo3_Shooo`l_n[gOoonOoojoOo:_gjnOcoooGi
o_oon_?_n>gomOOom?;kmoCdn?WelOo`oo7`oncklO7`l>onkWofmOGbkn[Vi>[e
oOW_jo3gj?7_hM_WmO[]mOG]koWmn?[gm?7bmOWko?oGg_ooc]gokMK@dn7golJU
jOoYm^oZdn_Yn];hf;3Qh_CX`/WSg/J`OYn_lNKTj^[Pe_7PfNGQlNQ_BKkjk_^b
d^fVE5R`gL?2[7Am`^_IeNK/gMkF]3c:WjFf//gAU]cRj=?P_LUYNU<_JWQ:FVN^
Z9MnIUQEESPj@TiIGEYEOLWUWDDV:BTC7355AC8S82hY9bhi1FE0oZajO8JGUGY]
ATmZGV^dm9f8W/[Qj]JWc[BQS^KH[Ff8`ooolOWb`hRdkOof[W]h/<o]mo;/iMk`
d?_ojO?oe_Cno`3mo?l;mnCGg]FdmNCooo7akOl4Qm_Fj]Gkookn4]ioRgR^^k:C
LH:RM;cMooWgmokkoc?`ooJ6K9jQTHVV@5=oVIk9f=[Tm^WMloobl?gooOKfno?5
8GIKHDA;ooomb[Coookooogmo_oioP?ooo[jo_l>o?ojm_koooknnOgooocloOl6
o?gooo3J[Ogo3OGok_oooO_koOooo?cmo_m?o_WYk_?fmOCemo[coNCeonojn_Kc
m?Sim_;om?o^kOo`noCdlo7`k^g]k_3al_3]j>K[m__elO7_jNK/jnCWl?3Wgnca
j^SbnOWlmo?cmo_noGoN_9oZfLo5enOdg>[ohM^MMLWhiOKnoo_A^o?Soke^l;^B
NEaQXNB^TdmRP^O[h^k/k=Ccd]OVfnbm@1j8g^g8K8f4D3<VNL[Q_hIRAgCMi/7>
kn;7_[K@XJoDf^?2K<;5d<WQ_/IU`9mQIe/iDURZUgMICT]1<cTi>d13@3L_?`fT
fj=C=S0T71XK7R0P8OhU@bL_=_j/NWb6UiEjKDI?JUi[]?BMR9k:hN[FYljdXHkV
f:e]R<?ooo7il/>8]>gomZikN;3?kOObk>GNl=3konWcomKdo_l0oOco2oOTemkE
]?GToooalNgo18OKe^[EnoonoQ;NOh]h[[^bTg62XWBlgOoimoOnnolcl?ofQVbN
XI69YT1COiVNbMSJi?KYgO?ol_3moogfm__caB5fFf54BooooLZdooonooomoOko
nOh3ooojn_ko3_con_Knooono_Wmooolo?go1_cmooo`fZgmo`geonkooogknogo
oocloOkoCokijNkcm_GdmOOjlogTmOo_n_[floChnOKbooCok^gol?_dm??al>k]
kNk`lO;`kNSVjoKkmO7aknWVk>_Tio3`imo/lN[Xl_Wio?OcloOko_eog[bOj]W?
aMOWm=cZon7KWGG9n>Gfo_okdK_chonmK_2kTWULHJ7T[Y=?HX;Wjn;^k>cDlm;G
i]_/_D0NR=k]b6b=Q50c9WW:hKn6HTMdgNK1c^oRakjfd:6_e=[S`Vc2aM39hKk6
IL2OHFMK>E9HZYMgFDi;@C<i>C]0@d0g;cl=Y=^SDcH`91`J6ahP827n9D<W;cKn
[7YlQYNENVe6CfYNJkCdWHRNb^7ZeZO>]:6>i]R]KHS3oooanO;3R;C]ooJ^NgR`
cnggl^cUg_3@nooYlooFm?ko0?glo`_gi=ONeKCei?oolO7]o`B7fmKZeO_oo_hB
gWn;N:jk/Y=aPZ9d_=gonOOgo__o<o3omXI/WZ6ARJI0DgnIW/WHf^CfjMgcoo;`
oOomm_KkllDQMU]QA4_ooog:]?ooo_oooOgnooWn0ooon_[no`kloo[fo_ooo_ki
oOooo?cmo`KloOool=Z]oOl=mOo^ooomno_mooolo?gnodonnNW^loKem?Ggn_?m
i?Goko[jm_?dn?Wfl_odonk]oo3km?CclO3^kNg^l?7bl>gXi^_fnoGalNoYi^c[
i>O`l>OOk?7Zj?;inOcglo?gnokmOmjlWn[IclGGioCLj_oQfieebOSUm_konm6k
ln?o_Fk`^i9iG66Qi:jCCf:2in_Rk^c/e??BenKKk;e07XSNkLQ/SHA@<bIib^6o
QV97M=gV`Lk_h/Nn]]2Q[mCJhl9/`/G@bN6naVG0Wf5WFcUBF:ZGMeU>Bd4c>CTk
@4=0=blo3JCKXe<f<2@L6Q/N820QoRD29blf1G`aniMZOGMSIfj8HfV2Ohflfk6P
c?okf]SOc/nmOJfZ]J5n]?Woo?ofaHRH_lVDGf>1Mk_mob3nl?k8h?gRlONdfoCo
noGkoo_Sjooi`l?QgM3;mOc2_o;`o`W]hggMW[2[oOOno_l@o_oogWn:MZfk]9Mk
YKJAfn3io`7ioOko6;AGQL2COEe_>Te5HGO7bkZd`[g4j?;ThoCmo`SblWP`NhUM
CFkno`^[l?7oo_oomOCnooOioQ3ml^W/nOooo?o^h?3oookknoko5Ogko_ofookc
oooj/mCok_oogOonooknoOko0^7Wm?koOoOYlOGflno_m_gon^k:j_oVooSel_Ch
n_OdooGoi>?olO_emOCblNo^k^oal_7]in3Kl_?]io3jk=CPh^7Ul??M`<_Rl^kY
koOhnOGcm__kmNk@^kMiZ9G:f;SLgXn^nmkOMUfin??aj_ooYHo]d/n?DZ=fLYZ<
C5Z^aK5ODVOMOnkUiN_hb_KDj^o]kJ98;EjeimnK/XIGG4=V]]ie@Y5X?kWlZJ[W
f9fF/gYcZm:cXY9M`<;Ad^Ni^ENPZGYSBSYJD91mFcloBT@`?C/l?Slj<2P_JGY8
7B8]9BD[;28I6bH_:bTY;2kkUfYmMf=WKXQSJH9oSKcK/J3<oo_Jf=o>6<nmOJfZ
]J5n]?Woo?ofaHRH_lVDGf>1Mk_mob3nl?k8h?gRlONdfoConoGkoo_Sjooi`l?Q
gM3;mOc2_o;`o`W]hggMW[2[oOOno_l@o_oogWn:MZfk]9MkYKJAfn3io`7ioOko
6;AGQL2COEe_>Te5HGO7bkZd`[g4j?;ThoCmo`SblWP`NhUMCFkno`^[l?7oo_oo
mOCnooOioQ3ml^W/nOooo?o^h?3oookknoko5Ogko_ofookcoooj/mCok_oogOon
ooknoOko0^7Wm?koOoOYlOGflno_m_gon^k:j_oVooSel_Chn_OdooGoi>?olO_e
mOCblNo^k^oal_7]in3Kl_?]io3jk=CPh^7Ul??M`<_Rl^kYkoOhnOGcm__kmNk@
^kMiZ9G:f;SLgXn^nmkOMUfin??aj_ooYHo]d/n?DZ=fLYZ<C5Z^aK5ODVOMOnkU
iN_hb_KDj^o]kJ98;EjeimnK/XIGG4=V]]ie@Y5X?kWlZJ[Wf9fF/gYcZm:cXY9M
`<;Ad^Ni^ENPZGYSBSYJD91mFcloBT@`?C/l?Slj<2P_JGY87B8]9BD[;28I6bH_
:bTY;2kkUfYmMf=WKXQSJH9oSKcK/J3<oo_Jf=o>6<nmOJfZ]J5n]?Woo?ofaHRH
_lVDGf>1Mk_mob3nl?k8h?gRlONdfoConoGkoo_Sjooi`l?QgM3;mOc2_o;`o`W]
hggMW[2[oOOno_l@o_oogWn:MZfk]9MkYKJAfn3io`7ioOko6;AGQL2COEe_>Te5
HGO7bkZd`[g4j?;ThoCmo`SblWP`NhUMCFkno`^[l?7oo_oomOCnooOioQ3ml^W/
nOooo?o^h?3oookknoko5Ogko_ofookcoooj/mCok_oogOonooknoOko0^7Wm?ko
OoOYlOGflno_m_gon^k:j_oVooSel_Chn_OdooGoi>?olO_emOCblNo^k^oal_7]
in3Kl_?]io3jk=CPh^7Ul??M`<_Rl^kYkoOhnOGcm__kmNk@^kMiZ9G:f;SLgXn^
nmkOMUfin??aj_ooYHo]d/n?DZ=fLYZ<C5Z^aK5ODVOMI^kUiN_hb_KDj^o]kJ98
;EjeimnK/XIGG4=V]]ie@Y5X?kWlZJ[Wf9fF/gYcZm:cXY9M`<;Ad^Ni^ENPZGYS
BSYJD91mFcloBT@`?C/l?Slj<2P_JGY87B8]9BD[;28I6bH_:bTY;2h5OdCdR5]c
ITM>IC`jGH20OW=CCEbYfYiMMJbjd<EdT8VGPhjMb^geoo_BMWNO/H=SK7:0^N_a
iN;NeNn[Xl_WoM^5c?3oookno`oD`>ool>[eengDdm[?e^ccl?lMlhkcaMW0g_3j
ooomnooogGn;N;2n]iRM]9>0Yk?ho?lQil[>ioSo_fNH^XUYHCi=?U@X@eN9W::a
a[V^a=31`=Sbo_ko5_e6BF:2?d=5T=giYooXl?Goo>[YnOc`nOhEi=S@fNknoogl
g]?[ooohnOSmooono_go2o[Ynoo?O?Koj?cVaO[o;okjn;g8g_Ooon_Gn_ooo?;^
m?coo^6dgo[Fo_OdlOCinoWeo_Cle=?il?Wdm??cl_kaOoWimo7Wf/k6l^oQenKg
i/C?eMWMi=jmVJ[?koG_l_Oim?;cn?W^f<J^_=F0IDRMb8:XZdUjfkC<Gf6dl_oI
[M_ON7SJTgaVEda7Ll_AJ468X:UR@4C3inGLiO>/m>3igK2dK4a:CY_LPf]lHCi2
<25W[EDaU60__]mmLk:RGeZ0Oi=fX=?@eM6PgMcYiNjc/ED^F5EPDd9KCJJJN59:
EU0k>3Lh?3hj<BTfAD0U628V72@g?bhL72L_:2HT92GdR5]cITM>IC`jGH20OW=C
CEbYfYiMMJbjd<EdT8VGPhjMb^geoo_BMWNO/H=SK7:0^N_aiN;NeNn[Xl_WoM^5
c?3o0Oono_l?e<3_oo3ZmMO]e=?JcmK/lo3o7O>>llGI`=k`n_oooO_oomeoRgR`
_[NHWKBCP:Ncn?co8NO:c^OhokmWV;Z9JF4nCCiD:4=GRIbR/LJi[/C@`L3Hl_kn
oaKmATURPSm3AI3MnJOoj?3eoocZjOWll?Wn5NCHd=W^o_omo=kCjooon?WhoOoo
o_kmo`_jjO_ocgcfonSli/Gjobonn_Rmb=kgooo[eo[ooocbk_ClookQ]=oje_kg
m?7dnO_imOkdo=CCnO3im?Cclo;nlGoinOOaim[>a_;_hMOVmnK4cmGIgNCN_IVZ
cnoeko;gnOCbloSik]S6[[cEP6E8WLR2Z:]9N]^dc5mQ]?;ofJgKggQhfY=lIUM<
Ag?;dFQ1R:2YHT14`nOUg>Gc[?CPnMf`]6a<BTjKg8=[O64n@S0QIjeE<IAP;kkO
OG>bXUmJP7nCMZ3Cd=GAX=gLjNG^/k5E;UQEH5=2FdfVVWQBBUI@>cPg>3`n>S4Y
=TE09APR9Q`T=cl^71`W;bPV92@Um8QKLfI7CVDl>Uf0P7icDdeLZMZNGGF/^]35
M929Uh>>WL[]mOokdWIgWk63HfabP;W[lNGRg]G_Zj?;iogKQLc`o`7oo_ko3mC0
koo`j_GGkMCCf/oFk??`oagcS_?5fL3Nl?[ooogkoooMOh]h/;jgV9fdTh2W/oSl
ob7Wb/kWn?noIiRjRFUQ?TdnE2Q3EhVLX[76^Jk4d<70f?;no_lFoDI9HX8o@dF@
gOVWonS`mOolj^Wio?3ioQGTf=3Ik_kooOcNdn_oooSin?goooknoOl;n^Wkolml
m_oXo>K5n_l_o_[h_LSNmooojmOjoooll^kdo?onhKCOn]KnmoCam?WknOGnm?cD
doW`nOCdlo?bo_5onOWglNOJc/Kbkn7Gi_OVa<oEfMgTg[fIZ/o_mNobmoWdl_?h
nNkHaZjleH1UB9g8PZR[BG[K]<aOHKCbomV]fmmhN=ZCO6IGC4Mcbm5X@HRPZF90
A<?WiMcUljcdh?WM/;A/C4Y>Vmb3JgaQ?T8`8FN]EC6DH2nnggec/Z9OFX0lTgJP
dm3EdJ3Mg>WUk[>aEBiHEF1C@U]=YYYhDTYFD3/h=cPl?SXa:CI5@2DH8RHL93Lo
;Q`L9blX9R@T9@F9@ONDGVAPFEeLM6]XG5n@[YIQKJ:lSgNNb:bl/GB_/YiQWh>L
eoGliK^1Ki[<c<VaMHfkhnoloook^Y^D^>?V/7:giOco4?_XW/7ooo_//JC;djim
HXoOlOmOnKA@]KO>WgK`nooon??iomb0SWfe`[VIRXeDNG^Ae^kio_oWZhN]k_7C
O76kYeYCB3e;@ET_BdE4GG6B^KBV]lB_YKG<e]SKj]4/HV9X=T=7?;gI^^goi^Cd
lMkPmok`nOhEiMO<e>[koOOHc=Ofoo7/n>CZlOGgn_ko3OW/lO?K[8Ghm__d][?l
o?mon^kSg9fX_]gclmo;hO3oooWbloSgo=RXg?;4l?KclO?inoWfoO7da<?akOSa
l_;cloCdmOOgmNoSe<Flj>cOcMGXg/6ib]G?`[:JPWZ[g_3^ko?dlO7dmo7F[Xmf
QiiS<AmEIR5FVG>X_dIKFV^H`NBXJL:kFEb]FEaTEE];<T5ZE3E>]6RHJch]ZmWN
h]kJNMkKhi@iFalT>RQNS5]FE6aIAEU1=VeKC5l]<:ZDC4A_ID0lB9ABGY^jem>I
^kkEg>o3fI9ZLg:NRTA0?I>CMDHa=c@R<S8d>Cdj<RXg>T54?c8W8B4g?c0R9B[n
:D@X9B;gU5iTH5UMG7A[J5aOT:jFHFfR_8mgW/R/_;5d[k:NHIn3W=Oeo>FkPFnJ
c<c9/GF=^n?_o?oonkZKU;SSi[1b]nGloa3kj9k1oookk;6Tbm>^OF:?go7oGoVd
D;FgcYmfl?_oooScnOoLP8im]L:iVHZ=E7UkTMK^nOkoij^7[Nkadgaa^jMJDdPm
Bd5I;d]5A5eaT[VdY[O4[jFec=KHfn[A;69RJ3I3AcbmfK[]onKTm?7Nh?Onl?Wn
5NGGc=CZnoggf<cGm_oak?STj_7emo[no`gik?7cfjb5n?Kkm;Jco?coOo[^hmbM
Z;kMlo?Obn7`oooil_?hmocHZ=cba?3flo7cnO_im_gam<C3lNghlO;blo?dm?Gg
moG_hmC5_>S/glgEj=k1^L[Ecl:bVX9jZmk`k^ocm?7am?OaeZj?MXNNHc4OEFHQ
EYUcZ;m6FeY[V<7TZ6W2^eUL[EULI5EKBc91JU@eC[AXV6/n;J_Ig^;NfWWNfn>D
>E/O93XXGXaKEUA/FDEI@CI]FdaO;C2ZU4a4KfE0?4RDDUjK^]OCVK^neMc_`mVB
JW=bWXY4@3fCTgE6<CLd8S8b=3Tm>S8Z=cY1A3lb9b4Q=cl`8RDZoRU4:2DRmiAN
I61IGEadJfQLGi2^UV5]X[b?Mik8[;baM:nbWV6OPicGmOcU^h5_V/c<bK5eSK_S
kocooo^jViBhhnJ`L[OUo?l@nnRN`OoonnbaY<_C[WeRSmoaoeoi]52e]ljOM_3k
ooohloWog82>OKG2^IV:SEAiNi7Fk_WnonN[Qjg^lM=lLK^WFU=8?D]1FBm;ADAM
LI:i]:Jga:nU]LcFf=_ZdBaRHVPf@dLl_MVjkOoVi?Cag^3go_3ioQGUelcDj__m
mmS<eoKolNchi>[amOOjo_l=nNcalm^/QOSfnoBf/oclogojk^?LWJRngO?cgl_Q
l?oonO;cn?Olf:SLl/C`m_?aloWknOKmlOC4`o7]n?7bl_?cm?CemoOekn?DaKcX
k=o=eNSN`KW:eLo2/YZ2NZ_Nl>k_loCalOCglMJ^SgJ7WV<a7eEV8EJILjRoAU]J
JiS1i:QY`[]IG:eIG6AEFd/b@FYD=DjdJ9Q[?Rf[fMkRg]Yig]_SU3UK7b@j:5j<
FeIDK5U5FD4fKE]<Gbd`ZYA<A6mU@3a8U59NVk[GdiVk_]GLkl?ITVYcLYj:A40m
Ti=eAS4g=28b<S@i?CXb:SLj@D@o<RLQ8CLo<28U:_hY0RPU8PFEEonZJUaSNgYI
BU]XFEnO_ieZDU1GHi:k^X^caY_Sl^V`[gjBh?oociQnAE6;]^36J4Z7b>oomKMb
QJ:caMNkRgZFb_;akOOdi=F?_Ok?[kfXl_>oVj6=Q[O`oekT[?_^m^:llogoooC]
l_[KP921^LFjVXjRS_oemookmoooi95//OohIf2bVfIQFC];Ed1K@Eln=c<Q<6F9
Zm[B]9fOZJRSXHaj4W1nJEMWWUCGdm:bomWGjNSFfoSoloWnOo[Xf=_/n?K^^L7Q
oooShOS=eMkUjo;loooMgOoog<OIk>WokXnZn?_loOkikM_:_h^CYlKPi]O6^];`
oogfmOS^nMBUg^jghoKbl??io?[go>o^^[W[joO`l?7cm?Kgmn_]k^_Re/W0gncS
bLOIf<>Xa=C3Y8j2NU6;b^GWj>[[Oo3`m?KY`hmXH5URGE9QJ4MOEF`mKWTHKee]
LX:fNd?3]D/mPD=`N4EFJdloEU5S[7FlWF<iYm7Fk]c3C/G:_THcKc@hCbi9Ee51
8UY96e=9Fci1DclU=e]N>3U>CDe<>IehV<Bmb]o9f]GNe=JP^7UoG5BWXT8mEWB0
Kd@`?D<iM34a<cTm>c<[>C4e?C@S:3`R=3T]9bl_9C<d<bdUojYZG6=kNUU:FfQI
GinoWFYBD5MST[^jRk?6Vn?bjK2_OY;Pooo?V7i5DH^fh<IXBXO8kooe]g:5X[?5
ek^;NYK:l_7]moCTeHnmo/n__JSblknKXHf6]o3oG^B/nnkfh[ccoOoom>gbn]^0
T86iaKZJSZ:>ooGgoo_goooTTFbaooQWH;:KIV5I>d]G@5]1Gchg<b4`IHV[f]:d
WInYZ:>QS7XBL7iYEfNNE=OCd[;ofMOYj=KKn?ocnOion^SHfnchm^ji`N7oon?Q
n<gEg^G[l_coomgMoooLamW/jOo^Sj[hnocmo_W]flZoRi>Wa^3VelJjd_3ooOKe
n>kie:GNk[OSm_;`loWln_Olknjj^N_[mo3`lO?dm_Ogjng^jn;FbL3Ok>?9amWH
`jS4e<>TSX9jDH_:iNOXj^]ol?3dm^W3SfQPFF9MDV5XAemEK3e^NAQ_GFebP[Ik
@l>eBcf1@g1hAEI[CcmFDF>/MKbMHcVWdMK^g<=>aLZnAS=_=3Q?;TUGDD4RFTTK
DdUK?T5C?bDgFehh>Di=CD`iWGRHa;g:glWJeMkDeZ2hNGmLE:NR@SeFM81_A30m
@cUd<C4c>Cdk<b/i<CDm=2<X?28d>BdW;blU<c@c;BGoZVYLHg]jFDYKJ5UOWknM
JU9@Ef>B^kZ;/lJKho;Y/:mnT^3oolnHOTEARkKPaVQ:QlS_ooFgLXFR/lGG^h]j
U/[blNggm>CESkgncjnmZ?;c_i^QSHJgl?mNi:ckk_KR_??mooodkO;jfh2@PKW5
^YZ>XXkomOOonoOoonBAK;7on6MP/Y]VHETkBeM0Fd5O?SLc8C1URJ_Jd[BMWjVX
Xj6<NQ9`OVUGIiiDem?B/_oIenWXe]_hoo?ioWojj=SKk?Sfk[W1hOoohn7hcMGN
iN_bo?oogMgoomc7fNcYonj?Z_Sko?gnnNgKb[n;TjO6h>KGa[[Bl?omm_Ghk_WD
YMk^]n?fl_3cnOcjmoc_k[Zijn_gl?3aloCfmoO[kNk[h]K9`=o/hlW7fMS3Z<CD
`jB>PWYARl[UinSZjgo`l?CfjL>?J61IHUeBHFQ7GeE/?Fii66mMKG:2]W]3`kE;
?H53L7Q5EV]??eIAHjae_9eS>JOAe^kL`dk5b[i6<fld>4l^BEMA@B9JBA]CBE/n
@E<o9CMKGSPiCTe=C3VMN9S4_L[ObM[Eg]CFX;QiOeaDYj92?EIdP6m4<3e3>A`a
<C<i?C/c:cTa=Cdd8bPl8S@i;BL_;bDc=3<]9@GAOonLOVYKH4iJEeePG5A@E5YE
FUeTOjBk_hj@T;cool:HNf^9_mo]f:J[S6FG]IB4Gf]FMLO_bI1gQXc7dNR^]kRK
NZKenM;6bX=nT<WoooO;n^VcN7>?QEg:ooo`o_oolOocooomoogom97VonO8SN3i
ooojlO3[hk:PSI2^`k>D1kN^XlKoooGno_mo`8F2Z<QmV:6<NW5K?Sm4BTa;CE=H
Le]>CSl/?62I[k^i_<FnZkMD@4U[;digR7gBok^We]KLi>SQe]OUmN?Qi>kfkMG0
b<33g?_ok]G8W;;bon_E`9^HWK;?h=kFomb>l_nP_JfngNW1RXG2oooEcMg9/JVN
_J^NYK6d[JO8[<1ooooOa]O`n;29/jVQi?oR^kGHoOgWe^KAXZ7GoooWlOC_l?Ke
joc>e_OWb<;1bmW;Yijb/IZV/I^7TI28UFNId=o8]lSUknoZiKiZ@f1PCD]YAcaa
FdI:DU]PFdi3FeE<BDeJJGAmGdiKIf1FEFIRG5QHG61TLeBU[caE^ZY[j;5oEiBK
Cddb>C<S9CQ2?3Xk?T11@D0o?CPe=CPh=C0i=Se:C48n@dhjL9VFb=AlS6^hkieO
GdIh>dAO?357@HZ@EDa88Rdf<d8X83h]63P^:CQ:4TDO:ab8Q30V=bPQ:bXW9BCo
W7iZFf1>FUMMH5aDD5AJEEYMI7nT^kn>T92loomY`YQkJhVogngHYZ^<IINeU8AO
JeIeano9T7N6S<OAj:jg^9]jY_Gid/K:Pgj@bOooml_jjK=hLhn5GL[ooo3noooa
oo?ooogooOodTNKoilR=h?Wooo[al>_S/Z2=T:k3/iBg[Z?6oooeo_koOl25PZS8
OIRQS7YaFchoA4Y<BdeCF7=KCTho;3aPVJnk^Kc5_Z^gE419Jbm>MhQmd_nkYmKF
g>CXhMKGiOGShNC^m^gE`<S0`mckonkEb9bbl_o[eL2KV9fbcn3Ne_oLS_;oX;f]
_]gY`HZ5`_ooeLgMbK6YW[f[WZFa]:fWb:c0OoooglKGl?R`RK>YXNCoh[^ef?gm
imKVdJ:Qeoooio7dko3fmN_lc]KgilS2`L_IbjNN/[6JY[6KQi6@R9EWVM3Ob;O8
iNo_j^FnJT=PH4e;JDLlLE]6BU9KH5]>@e]EC4U=FVUdOEm>FfMPEUEVHUaHF5aP
I7=DYJllEKZZJnRaOeNDVdm=<STc8bDh@S`j>ci0@D50?cdh=CDh>3D`>CHmBTa2
?T=>>W2IU/SDO8a[^>nMGem6N3]4Gc`aAd6:T5E<B28]=S=2:20n;APh;RThBQ95
7b/LR8@`9SLX8B/Z9bDToianJU]PCUYGGF1LE51DFUEJGFAoY;^oSY2@_?ooJL:H
Nf^9_mo]f:J[S6FG]IB4Gf]FMLO_bI1gQXc7dNR^]kRKNZKenM;6bX=nT<WoooO;
n^VcN7>?QEg:ooo`o_oolOocooomoogom97VonO8SN3iooojlO3[hk:PSI2^`k>D
]jjSa_oomOknogo0QH:Xb7fHXHajLE/n?dA:C4]=DeQcFdi>?b`lH9V_^kVlaKj[
]eA0BF/_CWN8OM;o^jOFe]cTj>7FenGehn7Tk_K]eL38`<?Lnoo^eLRL/_;ojmG0
ViRM//oPg]Kog8kboj2m[KkMjL6:QL;oomG=gLVaZIjmZijU/KB]YlR/`7ooomo6
eo3h/8VcZJ7Ton:k]MSmoNOFi]6RXMOoonOam>o`m_G[o<kFmnO8`/7;fL^WW[:a
VZJaVhNAT8REIiW@glRgb>G_kn[U_VY3H61=BfU7?75KATYBFf1KCT=KEDa9CEYY
M7eOCU]WH5IEIV9LF5QLH6AcE:F_?5FjZV_X/F5GU9]?CC8i<b<U>48l>S/n@451
@3lm>3De>3Pe<3Tf?DY<@Si3CSY`VIK8e7b<JkS_WEmOAWPkA5ll<DM1RY1EC4PR
;CHc@RPP?RdH>2hY>4XBAAl[78R4<2Hg:24[:RLU90G@G_jEMf=DFDMDEE]PGUQD
EU]IHFETJg=/GVEYIXJl/6m8QH2I]/WWil2GPej0RVIXEfB1]MW3S75hPfj;S;69
V9N3M8fWVYR_^H]iNJ;OooONooo5LeV1YjgEo_gnoo;eo_l0nOko3?khokWloMFj
PKo`m?WnogoM/9n@PHRZa;RLR8AdPjbkan[Tk^K8[Z>KT7B@Vga?>Sm9@dM;BDI5
B4aDA4UPI59=FTYOMXNJ//C</UUDDf<bDemnK[ceb;cJc=CGe/o6a<gGh=SCe]cH
bKZSWZG2ioS]fiicQKc7^;2UWI2;XL?Db[WI`hCLj8fJNjVg^Z62PWnYdK>:SZZX
Y:bY_[J^ZjZXZJ^TVkgdl[f[aNWa]IFi[J;Ni<BOW<Gco>g3c;bJUl7/oO3hn?7a
n_[cllSAl^?8a<?7hMnlZK>`Vi^ST8BCSh27B6F:UWm]Qk7Oh?Ok_6U<FdUJDe`n
;EQ<ATM;DEA@ACa:BTU:CUAJGEM9B5IOGGmQK7=ZGE5<CUAI<QUGLCUP/:A6ZhY4
IVTi?SY2?c8`>CT`>3Pi>S/l?Cdl>CHg?3dj=cXlAU5>@T9;FSaRRHo1aFa=@9G<
OdM?@fYLTkZ7FEQBVH`o>DPb?ClmC3`Y<SD[;2dX@e/[DB8R>jBH=b<c;2``;R/X
9ojEMf=DFDMDEEEKH5iHE5IKFF5UI6]cK5iUJFJ6_;1_B8F0VKK9inO0Uh=NP8YV
J5MTPKGI`haaN8=^RhbaRIRGPgB=YiZH[kV;NGVRgoogg_ooaG=IPJN]eOkmo_ob
mOko0?Wno`cnn?nio?gE^X6ol?Cio_mogK2OT868Z/BhW8R4M8>/^lOZi>kVb:jS
Vi1dT9]lCcXoBD=7BdU6ADQ<E4A9H6ABCEY:GgJ7V[;4c;9IE5=S<U=OOVjlmLRl
f/cDemK?a/C=en3HdmKLf<VjXijU`^OhkM^NLhFlakR`YIf@Rj73e<ZifL>4g>R=
VW^Y]kZQPX9oZM6cRXjZZ:B/ZKjf[Z^ZZ:V[Y9^mm?:mZlGYlKFE^JfRg^C4Wic5
loc]`lblVYO1k?g`n?SalO[jlo?8dO;Sb<C3an7O_:Vc/9^KXi24Thn0QdQURYIo
KHNagn3gnkaYC5]9FU=L?ReHC4I7Be5DD4DlBTY9BTiDFUeGBDQFGeeoHFacJUeA
C4iDFC8IEg4iH;2TAZ^:A6IY>Chj@Slb<3Ti<3Ph>CXk?3dm?3Tf=c`m>SLj?4IA
CT92BeXlHXV?`LE/CD2Ec7m7Cd=ZG9>jQeUHDYV<?cU8<Sdo?D`l:C8e:b`]:4=K
:e4R8S^TV3LS<b`/<2h[:2OnUGMSE5U7E5EEFf1NF5AFFeUQIFA[LfaNIFUVQ[b`
KdR5P9VfbNOW`9N3GX2:IVQGI86efL><LGR3KX^</HVHUh=dSJNJV:niRgUiX]oo
mmkoolEcFH6W[MGnoOkol_Gno`3io_l<o_So^OcmeKZ1_o3dnOkoOmf`Wi21R:[4
^9b8Q7B3[;_7j^C^i/R^Xi^@M92KO4lj?dU3Ad]9ATE8C5A4BF1TDTeJBUmfQiZb
a<bbFEACHc9CGgi^_?G8_=[<e=OFclK4cMOPf=?Fg=S9^Z>NYL;Wn>gKWW>5_<Nh
/:FMT8^Q`mC:^MW3Q=cXSIYkZKNjXH:2OjWA/hZ>ZZRT[:Vn]Zj[ZZRYZjBK_OCb
_J_5jO6eUKV]X]kTa9nLaO?lkL?<_9ZG`Ncml?ShlO7jn_?cb=7bhlS4`lOQgkbY
/k2KVj>@Q9>?P8M8IHZFOff7/MoPmo^lJDaKBEYCG3h]F4a6Ad]AE515?4Y:BDY>
E5YMEdU8EUmMMV5/LfYMDDa>E5Tb6EMa>F2`Y4J[RTAVJCTn>T8o<S0i>C0h>3Tj
>c`m?C`i=SLl?CXg>Sa6DDi2@T]J?6:9Sl75K4e0ULaoAdm3JUbC^XMIF5:IS3li
B38m?ce<?2Tb=B//;BQ3Fb]A8R8kY9Pg8c</;30^:bPW1M5IoIAgI5EJBEE:DEMI
EE9BDeANI6EZKfEDNGifSKk1W8bATiZ=RK2oVXN4IWYbDFY/H92oa:NCWK:6HW9g
ZHF8NWZ3UHMXO:J]He9AMk?Oimc]ooF[L7:=Vjg^o_monnojook5lOoeon_DULB]
PWY@Lm3Qlo_ihJioVhj1RJ[4^Z2<U8N4VJG0l_ccek2HUifOUY65JdD^>E=8BT]7
@3`m?c/]=5=TFDa<>45AHFUeT:^DEVeMECa/FG9QXN3@c]c5dLg7`;Zh^K_Kd<C1
aLO2^kR_[KcBg=72[H:8YieoRhV5XHb0TK;0/9V^Z7B_^X2;IYRET8Z8SIRPWgUm
UYFHYZFb][BZWYZMXI2I`nWDW9>b`lfUTZnRV<S7Z8J5[]k[gkbk/J:L/]oomoci
k^khnoKO^lSXflS:b[cUl<^/ZjVIV9b;Rj>JP81^KWb4KUUk/kB`jOn^JEmGAGmY
Dd1o:d=3BdQ7B4]9@ce9CUAJG5YGE4m=D5A>AdmMIV=METm:AdEI?dE7<SiC@c]b
KDI7AcXo=Ce0>SPj=B/h=S<b<cHj?Cdi=cTn@3di>T5@FDm1AEE68cECHHb8>4]?
Wl^8FfYYG66BY6HlFX3@ZT@eBSTm=496BCHU>D0T=BM7GC]YE2HP>jbU@B<Z8B@d
<Bh[:?fDMfAEFTUEBU5GFEEBDU=DGVAUJVmUE7UnMXfn`Ib<TI>JSHV`_iZ7Q6Ij
LU5ZK62@_lBWTifbQV9bMjV5R7YjPiF7J7bV[F=BDGNcgnOLkOoeZg1bSI^]k_ko
Oo__n_onaO7omOo[e9G4[H9jD7?@hO?knN6^Oi^>PHVZa;ZPS9B7Q9VU`?;llmN`
V9NMWiJAQF]5;SUCB4Y;Ad0l?Clk;CACI5U<C3Q1DF5YMI2[U5I]GEDlK5UbHJ7P
d<kLaM7=al2j^;Vkfm34`LG7`[^h[jfld]cA`Zf2R:NMOh^9QJ6<P96b`;2I[ZQd
[kZ0RfJHUI2:R8fHX9miOIJEV:JU/[JdZYjJWJ6@VL?Ye9bC//?=YI:_XYS8ajR6
QJkNjmnl^k6RW;;OooOlnNk^n?_fgk_8j=_8b/ZliO3;[:^YVIRLRh^SVX20KVil
Q6iINk>d/>Wo[VUOEdEoJE=0Ob]3@d]8AdQ;BD<mBDiDFUaJEeA?CE1DCTM?GFIS
GEI?BTM5FCm5Ac8nDd<kLVe6AdLj?cDm@3Xh>SD[>3Hc<S<f>Sdm>CLi?T0m>CY1
D5U?@DEEAR<eDf6<R3Q;Cio;R5]ZJEaQTZAV?5Z0d:Y4=DXi?CA2ATTf9CU093DW
AedkJE@V83^/YD4S:R4T=34^:bSmU7MTEEY9EDYAEeUEDU9CE5iTIFY_IEAiOWJ=
_/6LS96CVXf9/;nJQhAVNW9AJVaPT;o4Yi>M/XIRLWNYQHQjNX>EQfQlYZeSDU5g
/moWg>gomJ]`LXfK[Nknogokko[oo/GaooGojmBEa:f2NU1cd>7cnoWQ[WnKSX69
Z/BjX8bDQhBIYL3bo??G/9RGWInFTHE[ABhiDdQ:BdM0?3do>bddDfAIC4`h@E5Q
JGF@ZiAFKEeE?6aILV6Qh=3>g<GAcLO0^[Ri^m_@a<75al:k^:n]_=;LdL:]PXRW
WGn;RHFQS82A//2`VJjXM:njP8]VV9F@RXR=V:2ONGfFUIRVYK:f]:ZNVYfQT9W3
jMBLTk;3cJFB[j:Hb<NXQXF^g^_O_;^aXYbbgoogo?W^k_Skm]nkb>SKb<[:_>G`
bjb[ZIVHW8^;XiZ0P6i^O8A^FG^c];3YojiYGeM5OfUC@7l[@d=;B4M8BdU3?DU>
E5YLFUMDCde@E4i7CeeVHeeFCdY7AEToADLb?U=3>g9]ATM7>Sle?D0j>3Xe:cPf
<c8c=SXm?CTg>Ci0?CTj@E1ICd55EDHS=E=QS8PhBdnObhQKJVULHI:TISaJP=2Z
A3E:>Cdd@TI9=RDi@2@e9dMM>`mD9R0k[:E18bXQ93@a;R/X1M=ooif0KEmUE65>
DeUMGU]IF5IKG5eZOXAnLW=SKYf`[KN6R85QFXbML7InIgYbFGUmAU9DE6bBXi]i
I8ZMcIN2HWf6XZ1oP9JFOGMoX<cUh=6Qf?31PFQ]LfG9oo?goo3Vn>Z9c_o`ooo>
/=BfUJVIY;?No^o3WHIkYY^=TJg3^J1oVjjWWj^__^KoomFEIFJB^kN4FeIFAd17
B4]<Aclk>ci5=2llADA7D59BFEe>@E9aJ51oG4I9T7I^IIK9bLgGb=;;`kjm_;Ve
d/W0_/;6a/?BaKVh_[jcZ<BPYKFNR8Z7YYN<TjBZWXjJVF^3TX>KP9:;QhjJWYR?
/8j>Vi:FYJ5oW:BWX9ZGTHVFXL3F_I>@ZjZdX9Z/WYJh^9n2PJC9cKbfZjNWWZ38
nOSlmn_ZloKaaZVkfm;8dM>chNo6WibOUj6QTijk[H^7Of]YLEa5I9f5L;OOU6]b
E5JOLTU<?TU9CdY4A4Q;BTQ=DUUNGU]EDE9ADDi5?Sm5B51JH5a@@CMoAT4a<TM?
BD]=CeMA?cm6@B`a=3Hh>STf>SLb;c0e>clo>cLh>S/g<cE1DeY<?4AGEca2Deai
M3i4BGfDI4MCE4Q>IfD`5U2KfK56<T@a=Be7;dA99Be0940UBeM4CbXR=k:fES4^
7Qhb<2`X9_nMP6eOIEAQCU=IGEiKFEQFFeaoGFYnQ7ibLf=^WK2]]hJ8PF5JS9e`
MWiWNW9INGe6DUADK9:SVgUTRYg=Uh9ROHJRX7n0UYImMgnPc>GPdJ7Hl<61J6ec
ILWoloOol>KhjXW>oo3oolj`e;JEZIVT/mknkl>MQW^VVhfA[L>iX9^^Yin[[kkV
oooEUFEVT[^gQ5]oEUI7@4M8Bda7?c/k?TDd;ca5A4M@DU9IGDi1DW5XD7mLATV@
MViUU/W9cMO8d/_3_[fl^KGBbL2n`/K6`m;5^KRn_[>Xa:2U]Ij8RXNVUhbCY:ZN
SYZIJh>BPi^0TX^7SYZNV8n`SXjKTYJUXIbTYj2JUi69UZ70e[fCT:^Z]:1oVZbN
U[RhWh:1Y<W=_;J[YjNNX<Sin?cgjn[cm_76ZK_Kd/SAdk?QklJOW9nGXJ6CW[^]
RhMoJfUaG4ETWHE`]mnDJg9DEYmbBD`nBDU?BTA4B4]:B4eBFEiNFeEADU5ACTDn
?dE8D5YPG511=dI1<C97CdU;CDmGDCloAT4/<CAo=SPj>CHj=c8_<3Dk?clk=cPj
>cLc=D5CFT`lA5MG?49CG7Ud?TA9OIATAe=DB4iWIC0FD9_I/DHbA34e;DL_A4TU
;D0T@2E;EdA?:R8g/[IF<BhN7S8`;2PVoif0KEmUE65>DeUMGU]IF5IKG5eZOXAn
LW=SKYf`[KN6R85QFXaoWG1fOVMjLUUiODIBE5A/TZ>KNFB:WLfGPV9mQZ:POh2F
UWegOj3<iN3AXMS``H5XKG=UbOocmoo`i_SZRLkol?ooc[3D]YFYVJBcg_k_`if6
NjJKSI6]`kVPVjjWWj^__^KoomFEIFJB^kN4FeIFAd17B4]<Aclk>ci5=2llADAo
Ae1BDUUMCT5BLFQ@Oea6BI1fKVFFbLW=elSBbl>n_Kbi]M;9`;k2a/K3d/Fi^;jn
/jS4X:FeWXR:QjJGS9>TZYj>VYU[Pi:3Vh2BRhN>VYjHSk2>SY^BUZFQW:BWX9ZG
THVFXL3F_I>@ZjZdX9Z/WYJh^9n2PJC9cKbfZjNWWZ1ob?Who?O[j_?flLJY^m_B
b=7C/n7_aYnLWiNQXI>N^jf;Qgm[JG5LAFBMQG2ggiA[LUAFWg99C3i9BDm:A4A8
BdY8CE9IGUiKEE5BDE5>AChoADQ@FV1LD44gAT4a<TM?BD]=CeMA?cm6@B`a=3Hh
>STf>SLb;c0e>clo>cLh>S]6=c<e@E=JC3a4EeLl@U=LNG@nA4UmU6A7DeA8CVMU
<1I@VmVaAS94<CD]Abm4BBD]@2A09D]GA4lZ8SNb]UHa;QhN<S0/:2H5dgooX8=a
I6YJIeiPHfMZJVMTG5mKEUe[KFEOHe9DM7adOW9aK5YUXK5mI71LLG1JKfF;P6]X
Tl:kU69OV:k@SWEGNVN2X8]aLFmSH69`OWi]Fg>GY8ASIh6CFHSFfN_he?clffNX
gmComH9nUg]QP8ElXLk`hKJDQ7nTVhnCZl6hXWn8UhUoTifV`?cR]hMVIXBRTf=1
ADe1=cY5BDY7@Sm0A4Y5@D0m?DaN@4YIGE15DFQ@G8]DA5>RUGAkWKVh_<cBc<K1
`<71_[Zn_Kg1a/W8a[^cZjZ_/[6][IFU^ZRKXIbZZ:BPViNEU8f@MGZ5S9f9QXN;
UIfMUHbKPXJBRYFXXgn<U9JGX:JDNHnBWjbTUI^]_/6k^;NUWk>XVHN:Z<6iXZBG
Uj2GS:SEmokll^oeln^`W;7>a/GDe[KMh[JCV:6KZ:BHZ<FaSXj4KfQ/G4IIPW9>
Q:mmKWUADXaD<d]>FEA:@c`l@DQ;BdU:C4e=C4]:B4M4A4U=BD9<D5EHE4a1>gl_
?S0`D5=:G5Th?T/k?DDb>3@c=SPi?D8l>3<`<CHl@44k=S@e<bdX<Ce?ETPh?e=A
B4Y<BeIF@4Q6EEY7?dE3?E9/MEH`BXf[TcX]?B/j?U@/AV4i8c4Y?BEVM6]H;QeK
clUO=C<X:b`Z9b@Qoj23LFAZFVMNH6=WJVYWI5aOFgmFGF]]IEmSDUAdO7AnLW5/
FVFQ/GeTL5aaL5Y_IH^0JfRC`[^DHUnH[]2>MEMjIh:PRg5aKf=PHW1nOVeKLiNT
Q6=WPI=IR=KIjoSDo?cKIjSOe?oePWjGNf60QGbQc_3Q]YB4OjBKSi>[`KRRR9N9
Oi>MY/3lh[N7IVJ4XY=S@Gm5CD4g>TE9BTM2?d14BTE1@3dmC5i0BUUMD4EAJ51L
ReA4Dj:EM7^M^KRlc=;<a/70`L6n^[jm_L76bLS6^k>[ZZnb/Jf]UJFjZ9^QW:ZX
Y:2KUiFDSI1eNXF<WHV6Qh^EWIfES9^2QY::UJRSS9BFUj2VU7V?TYn/Y9FK[Kk1
^gnh]jFO/jRIQhZX`KVRY9NGX9N<Z=Ggo_cbkoGcjk2L/Lk6aMCF]]gR]Y>HXI^X
Y9RXaK6>SXA_J6aLAUV2LTj4[ge^NE5BS5@cBdiIE4Y3?3a1B4];BDY<CDe<BdY8
AdA4BDe9@Ta@EEQDC44k;ch`<51CBUaI>3i;>ce5<SPd<glf>3Tm@S`h<c0a=Sa0
@C/f=3Dc;BPa?DmFB3PoDe58BTa;EUI0B4IEFTLoAD<mDVaeES1:SJ^C>Rdm:cXn
E2a6HCTS<BTm9FIdJeP^7E_?bEle<bP[;2XW927oX8=aI6YJIeiPHfMZJVMTG5mK
EUe[KFEOHe9DM7adOW9aK5YUXGnaOFA`G75`FVmURh1[J9?2^iARGiR^d8ieEgYW
PZ2;LG5_Hf1RL7inKE]cUjB4HfN1TeV8e]W[n=Clo=]WZ=oDooF2OYMkHH25O:7>
l>6fU8AoY9^?Tj_1^::8UhUoTifV`?cR]hMVIXBRTf=1ADe1=cY5BDY7@Sm0A4Y5
@D0m?Gm<GT1:FEe@AE5XD5b;E4ACXYEdNifi^;c<d/c6`L31`Kjj_[fm`LK9b<Jk
/j^Z[k:a[JfEYKZXVj6LZZRTX9^GUIB=T7EjQHbMRHJ7RiFMWIF<Vh:6TXZEZ:><
U9JGX:JDNHnBWjbTUI^]_/6k^;NUWk>XVHN:Z<6iXZBGUj2GS7nXeOOno?;_mO?[
/9bac/K5e=JfgN:fTiRQVjRTV:S5/Hj>Q6mXK5a6FH9bCXB_OFiiDE:<E3=;CUUD
BT<l?458Bd]9BTa=CDa;BTQ7A4A9CDU2C51EF5A<@C/_?S0`D5=:G5Th?T/k?DDb
>3@c=SPi?D8l>3<`<CHl@44k=S@e<dH]:34mCeI8>3mCDDQ:C4]FET18AUEJAcm5
@ceBK7EF<4Z=Zi<j;Cd[>SiD;4IQ>B<a:CdUIWA[F2hMFlo9GcDc:2//:RLT8@GC
OonJOFaOIUISGEUGFEeOGUY>F5eMHVIKBV5aKgVERfiZNFm]Ig:PZ7QYMV1bLEYU
CEURIFQjRWQHJ6>AV;9gM6Z0Ef64NF=QGgMbKFmdMgEaIWEgIei/P8Z;E8bif<>N
onnjFhF[W<>_UYn]UGV<VX29W[>j]jR8JIF?QhfV_KVVOhnFO6b8XJo6olZ0Jh2G
WIaHEEA=>bdeAd95B4I2@4=6;CU6BD<oAU0]AEQGDeUPHUQhRdQLIYRHOIBY/K2b
`MJm_Kjm_;^k_:nc^Ko2`l70_KVd/K2a];F^VjZl[::SUjV_[j>CRXjFOH>5Qhb<
Q7EhOhR?THj9QIB2RHj1S9fDOhZBTI2Q/J1oMgIjPX^EXZc8`L:nZIJFWi><QHj[
_k>IW9BHXj2EX[_bo_onn_W_h:VJ[lBi^lg=_=G?YI6QZIjSWI2P^9n1S8j3O7Q]
HVQgLU9/R75/Ke4lFBdV?4EMCT8k<c8g?D11CTe;BT]=Ce1FEU18BTe4=6UPDdM1
@DE8OdECAcXl;R4_FSXiAdA8Ac1:@C`n?3Hh@3Pf=38c=c/m?STd<S8`:bH`>4M?
ASPlBc`o?3Le<S0aEUUCBTmHFUU=GV9VFcI3R:nQCci3;3i8FdmUNV12?cld:Y2U
XFXf6WWK_THM92</9RDS8B3oVWe/GfIFHeeIEeUMGeiJCUQMOeeRIU]:HG5_NIF;
KVYiKfeWLZ2XN6UfH79aFVE=FF9UJ7Z:N5QXHi6H/WMdJX1GHHAiHf5OMg9]KgAg
MG5VMGMWGVb0RX]DS;WH`ikokkYKQJ^L`jnFWjfENHbJP8VN/kZgZ8QYUHn7SJJm
^JJ?UWa/R:6_a_o:P6^0UifLF5EDOddk;CE7@TE8AT90@dH]>DI9@cm6D2e5F5MC
FF1RF7R;B5aVV9QmU:Va/;;1e[fm_[fl^k^l[k>i_l;3`L2m^KBa/;6d]JjKZ[b/
XZ>GZJn_Xi>:SYImPhF7S8b4MGQoR8nASXV5U8:9SX6<WIB:TY6@XK6POgMfNX:;
UJ:/b<72OkjYUYJOThb5SZ^o/iVLU9RSX9FR^o;nookjnNoPZIZ_a;VkcLfleLnU
TJ6YWZ>MT:2hWh6<SX=lN6eRJ7MbDVb8LFa_DCaI;BHlAEe>@S/c<SLm@45>CD]:
Bde?D5IFD4Q:CD@dJF1CAd51ADQ5DdLj?2hQ;eXj>DM4B4L`BT4lOchl=SQ0>3Hd
<S<g>cdn>C@b<S0[9S0hAdm6>3a;?3ll=cDb<35FFE=:CeQJFDeNHVIK=T>8[j5?
?T</?TQKCfEjH48o?c@ZT:FQJSHJNM^nAQdT8b`V9B<Q8?nJOFaOIUISGEUGFEeO
GUY>F5eMHVIKBV5aKgVERfiZNFm]Ig:POjQhJGIPLW5JIDeIHVEXNXYhF6QSTIRb
MgAZP5MQQ7USHEmgLVe_M7MeLFIeMfMNK82:ReB<^MS3W_o_^U^5Zic3[iJO[IEi
S9Z0RIjc^[NXR6VEShN=Y[fiYXnFO6b8XJo6olZ0Jh2GWIaHEEA=>bdeAd95B4I2
@4=6;CU6BD<oOdI@;DEHEe=IH69HN8]8G6JHV7fDZK6`//7F_Kfn_Kbk^kb_/kVo
`/?1`;fi];6`/KBe[Y^Z_:bRXiNY[jnSThZ>UWf3QHN<S8AeN7n8Si6>RHFDPXV>
PHbMU8ZBTI2Q/J1oMgIjPX^EXZc8`L:nZIJFWi><QHj[_k>IW9BHXj2EOj:kl_ko
o_[ikn2YVZo4^K_=cKcEcjFAXJVNXif@X;ROPHb>PgahKF9XMg9BK8QaK6mA?5T]
9Sa5GDi2>c<b=ce0@Di=BdY;CDm@EUI@B4Y=A3AYH5=7@D55B4ECAcXl;R4_FSXi
AdA8Ac1:@C`n?3Hh@3Pf=38c=c/m?STd<S8`AR/V<3Q7CdHh?4/l?c`g=C8`<EII
DdY?F5YICEiRIU/f@hR_XDln@b`nB5]?IGYP@Slo=2Z@YJ5Z=QYifki67B@S;2HU
8b4P1M1ooIEiJ5]RDV1KDTY8CE9BCdMAF5aWM75UGfi^O9bCLfaoKg1_IgZ1IFb0
KGM`FVUDDf9dPHR7OgEkIX5lUf]jOH1YKGI[L7EREUIGFEiWL7IOJW5`LG=^IJEJ
PY>g]GSEcY=ZQYf:P7jJZK6XRhnQPGb5RhfDUH9ZUi:;SZBj]ZA;V:RDP9BW[koo
/fe_V:bMR4AGGdhj>498@4=5@cdk?D0V<Si4ADA0>d5QJE9=H618J8]i>hZ8R8^4
Xjn`^;Rkck>j`;fe/KBj];Nj_?jkOkc<blJm]:j^/<6X[[RXXIn<YJFQUXV2Q8Qh
MHF9RXQgNGf1QX^=RhN4VXfEU827ThB<Ui>4SJFTSgElOgj3TYnTYiZRXhMlR8j:
QGn7XKJ[U9>EW:R^[J^/h?;ooocdh<Z_X[Bo[Jfm^[K3]9BBZZ^BW9F7Tj:6LHQf
NW5PFV5OB5EOFV9_KFEQGSm1;clc;4lhASlf<S@f=SA>Ce1ADeAEEEaXIeE8ASlc
IV1FCDM7BT`]=3/m>3Hj?DU6@dA=DDTo@CLh@Clb;cOn<Glb<c@e=STe<C8e=S<_
=CI0BdPm?4IFFTe9DdXmACU@Ac@mB4I:D5Ln<CHS@Yo>^Em7B2dmATV1UX^ATWmb
?3FZ]k=Z@B]R`ZHg62<M7b@S8R4RoIEiJ5]RDV1KDTY8CE9BCdMAF5aWM75UGfi^
O9bCLfaoKg1_IgZ1IFb0KGM`FWmYE5=RM868QgmeNfJ1O9M[NWf0JFefJg1eHUIF
EeUNIg1fGfYaL75cKVFUFX:C]kEheLjCJXJMRX1nVZVaZ8^?XH5lQH^=U9F2JYNB
RhjT^[JTV:RDP9BW[koo/fe_V:bMR4AGGdhj>498@4=5@cdk?D0V<Si4ADA0>d5Q
JE9=H1ePB6R;NC^:R8R;Q:>_/;Rh^lnc^/2m]K6d^[Bg^[cn^gnlc<_6_KB^[[31
Z:jhZ:6OS:FUXIJ9PXB8N7F5RHZ8MgUmPHJ;SH^7Q9Z=UIB0Qi>4S9NCQ8fUY8me
O7mnPi:OY:NJXZ>7O8R>RXEoQj6fZiBCUIbX[Zf[[>3booolm>3:[j:d_jf]_KZf
`kBDTZZ[TYbEQi>RQW68MWYaH5YQGdQEGeYRKfeUHEho@Blo<ba?>4Ho=S8d=SHd
CTm@DE=DEEELJ6MEB4Ho<fIPETe7AdY<;C@k?CPf>Se9AT=4CE59?d4g>44o<Rlg
oS5o<S<d=CHi=C4b=CHc;cDf@4]8?Ca6EUY=BE=:?DDiD4Ld?DQ6BU1G?S4f8d:O
c[UOAdP]?DI9PIJ;TI9oLS`eZ[NcJT4[H/:V=aPS7AlT8b8Q8_fENFQKHU9PFe9:
B4eBDTm7DEQLIgAaIEm^KWbLTg=/Ofm`KfMjPFE/P6egL5YoJEACHWB1R8MoMG]V
PGbGJgYmP6U]MV]`MF9FEUMIGVM`MUmZLG1aLfiUYEZ2TkNeN=G>TfZ6WHZ0OYZY
/JR;Sj61O8F;SIBEPVZGTX^>Y;ZfY9RXU82DYjnook=]KiR/WHQ4Eem>>SQ2B413
AD<m>ce09S8nA4E4@3]1HFUBCF0MH4QXRgTkRXR8RhBS[k2h^;_?/k[0_KFa];Zd
]kZlo[]o_<c;a[fd[Zj``JR^^:RQWhbUYJ6FRH:4R7QeQHV:R7MiOH66Rhf;QhBJ
SIFDP8NCQ8bGThB=YJB?MGaoOX>BWjBWVZ:SQgb8SXZ5OhNQ]Z^DTiFLZ:j]ZjcP
l_ooo?CPbZnR];n][Kfj]/>dU9:ZZi:LUHNCXXIaR7IjLF1JHEm8EEmJHVm]IF5N
?d4_?c</CcQ6?cHb=3Hf=4i?D55CE5EEG6QWEDQ6?c=VH5I=AdM:C2dd>cdh=SXm
BDI3A4eABCm1=cQ1?c8_=ohaDC8c=3Df>CDa<SDf<ble=T1;B3dlAUIJCDUCBSe5
>E17=3e8ATY@Echa=R=2WljiGdM8;Ce6BH6FRi6BOg8l=JZg/fY1:f;2YSLH8adO
92<R8B85dgonUWYYG6ADHF]ODTiCFE]IF5QABeM`OG^3QG5aSXacLViOJg5QJG]e
G7UZL6ABKF9PEeMULgIdLg]MKfR:I7EfLW^7MVR3REm^MG]lN7=aLUiOGUmYMgim
TgjXMIW>KgRhPX^X^jYmQh6DWZJ>S:>3R9NGOVU^Pi6XXiVGYkNaWgmhVYN3RHQn
Q:N:PZ2fW6Q3Be99>3i@B2do@T<o>C@f>4M4?d19CdPjEGUfCTQWHca^Sf@b/JN1
PHNX[k75`kW5/kk7`K>[/K[2`/6l^;Rk_kRk^kF]ZJb`[iFHYInUZYNRVHj6PWmk
Mge/Ngb0QWnGSX^;SiFFT8Z4OXb?P8ZHRWn:VY=gM8nPVXRHWY::TIZLPgF5SGEd
SIB>QW]mU:RPRWn8TYf[/ZVIcN?fn_KYc[FhZkVnYJ:`ZZZ_WXJA[JB1VY:3RiEh
JHUnRWmTHGEbFSmFFf1[GeQ]F4]=ISHI@2=ABCli>3Hb;Si2B4e?CT]9@5e[Fd]>
EEE8CeYQHEU>AWm3>TI;>CTo<B]5@cU7BT139B0Y?Cl_:BlZ;2ha<S4`;c@a<3<j
?S`i>CHmBTa2?T=CDS`kDdTb>3MPG412AT59=dXh<T0_C[;0YDHb?Ri2BRfQ^I:d
fl:SCSj[Z:AMBT@mZ:58=CdW6b@T8b@VoYIjJEaTE65[Ge9>DeUKFEQHDGm;Eg1m
Nh>5LG6>S7=bKUm[LF5YNgELNFY`I59]HV1GEfEcMWAcNee_J8YTMGIbNhMfJ8>9
GfieNgahLg5bGUmNGfUgOWfCOZQeVLi_N;R2RjRkZWf7PIBNYXj<Xh>8UiMnJFj3
TJRSVINW]k6ON9ZGPhV8OXBWRX:P]YaX@d]BBGlh?U18;Cm2@cli=3HhAd@o@4U?
B3YENGI>B6MS?6j?I3:aYh61QjR_/LG3^LFc_/O1/j^a^/;2`Kbh^;^o^;^k]JfY
[;2_UIRUWjFZUj:ISXJ2Og]gOFakO826OiN>Rh^?UIJ@RXAnS8n0RYR:RYZCMgB?
X9Z8V9jBRY6JW8=eQGn=MGB=U8j6NgfDZ:2:OhRBWJ^bZIW=hoKjm^W>]KR[^KjU
X[2ZZZnNQY6]Y86JTX>;UGQYRGj:OfAQMG9J?eIKH6]OF6eHBdeV=QU08e59?cTh
=S8^?T98CDm>BdU0GF]KBdiEEDQ?FV5QFDi6@cY6BcTi?c4[AD<iAdY0@bDP:Glm
?blY;bX/;S4b<C0_=34`<cXn?3Ti=Se:C48n@e=B?3]CBC8h=f1L@496@DTgBSPb
@2m>//2UAS8n;T9:;J6iT[CK`Z=>?Z^XY5e:A3fXXDPe?BLK92@S92KnUWYYG6AD
HF]ODTiCFE]IF5QABeM`OG^3QG5aSXacLViOJg5QJGmkMEaiJW1TDVeRH5MGIG=f
M7=kGFmXRVAeMW9kQgIXPhUOKWEkO7QcLG9NGeiOJGMnOI=nZ7FIcVmh^8:;Z;^Z
OHN1U9jVSXbSPhRGUgiYKX>AZ:>IUjNg/ImhVYN3RHQnQ:N:PZ2fW6Q3Be99>3i@
B2do@T<o>C@f>4M4?d19Cgm8>UEiMTi8If<lKXmT<[6WPH67Z:naaL>iaK>nal6c
Zk6j`/;1_;Rh^knh^k^e[JV//:nEV:FOYJZGXYV>QX9oNgMmK7]lP8IoUhj;RhnE
UY2:Q7j<Sh2:V8Z:VY=gM8nPVXRHWY::TIZLPgF5SGEdSIB>QW]mU:RPRWn8TYf[
/WnYVLgSm_[fjLje^:^i_ZFR/:ZZ[ij6TJfTPIZBPh^EN6V9OXYoI65eLUXoEU]P
JemHKEQ;CFHf6D0SDDTo>CPf<Rhn@TQ=Cdi;BD1MJe];CUEEB4mJHF5ICTI3>TI;
>CTo<B]5@cU7BT139B0Y?Cl_:BlZ;2ha<S4`;c@a<3<j?THl>CTf?DY<@Si3De8l
>e=9<SPgH5a0@TI1BCM:>390;djb`:E6<Sh^@TX]XKVB]=_2XdhnZjRTGDY4?JRQ
B3Dm9a/T92<T9PG@OonGQFm=HFQ^FEIACTmDFUi/I5eNI6QTGfQ]Lg=aKg9ePW=/
LWI`KG1aJfabKEeDEU]SKWEhNWj2PG9`Q9>?P7QQHFA/M7A[HVI_JeYIJgIcL5mD
GG=mLV9eO79fRH>0Vh]jMhF=RXfIKG]jQ9J5LhB;S8^2MVeYJI^[V8jcakFVOgf0
WgJ1WWbXRUEg/IQeIDM9BDDo?45;E3Pn?3<b>c`f>3i1>S8eAUHnBU]UHf5[NUf1
;efhWIbPU9JX`<>e/[g2^;c2[I6K_JZgaL[6`/G:aKjnaL6bZjnfXYFDT8^I/9^c
Uj5`Ui2VR7agQ9JFOfN;S8j@TI>DU7NARgj;SHNBOiR;PX9oNWn:V8YeKGf@S7^T
TWigOhbEV9b1UKFWU9NFQY6YVJF^U;W=i_Sim^c?[iZX]kbdZ:6OZZFOVYRJWZ2D
VIVCSHV0MVQ]L6]QFeeRHVIPEembLF5FBdM8@C@_=5Df:Ca9@3Y2?blX?EaUCc@a
FVmLBde9>EA<Be5@ATE<JCU1AdDl=3@gD5UPFTe8CUPm?3L_:bli@R4]>S`g<cDj
=cPj>c/j>3Lf@4]<AChl?TI5@Sln?SloC5A>?cm?E4e<Bd]<CU9EEhY_C3@_=d15
@JJBH:SH/9LoF9o2RTa1Ac`n@40k=2/V:2Sn9gooUhE_CF5XKUUFDDi?E5YNK6AM
GVAXI5mXKG=cLFmbMH9cK79fL6e`LF]/LVeME5IKHfieN7YnPX5bL8BCSh1hHF5T
K7AdJf9VKf]JFF]fLg1OE5ecOG9RMGabMXV3P9^;NWN5SHZ=VFekNXBFQG>4Rhb;
PWI]JFVKZiR>/lNeYWmmP9mfPIilZ8YEMk6HMFE7BDU5?ca1Be@h?S`c<S/l=SPn
@CXb=DIF?TYKIF=QJgYMPBmM^9fLX9BFZ<33]K:m`[Rl`ZfAVkfZ]lG:a/;5b/Fn
_/G1/Z^_]Z:EU92;VK2K/iNQL9N@YXQlMhBFUWmWRhb>T96CU9AgTH]nRhf7TWnH
Rh:2OgYoRYR:MFemT8akY99nMgn<UIRLPIFeYiBGUXJAZIVU[YBicNKhnOK/cjnJ
Z;Nl]:RQWjZUWiZHVYjPU9VIThf9P7IXKG1[HE]MHV9VH5MOLW5QET]7B44d;cAE
=RTlBD0j@Sl_:3eLIDld<EY_G4]=BCUDC4]AD4I5C6Ti@DM5?3@d=e1IH5Y=B4iH
?C`g;b/_>D8Q;CXl=c<e>SLh>S/k>SPg=T1;C4Dn?3i6AD8o?Sho?daDCSloCeA=
C4];C4iBEEN:Kd`d;cM0AD6VTV2Xf;2G?eRO`XY<@DLl?T10>c@[9RPXoRMooiN5
KdeQJ6iIEU5>CeAJGVaTGEiTJ6AOJ6ecLg5_LWF2LfabMW1]L75[K79]GEAFFf=^
MGQjOX:1LW24Thn0N65QI6adM6]RIVm[FUU[MW=`GeAMLgebHWElLWJ9Ph2KRgYg
QHf:SIU]NgZ4UXEcQ8^<Rh9fKFUYVj^HS[?7]JIoOH2OMX6NO:R:EGNaV7EUAdU9
ACll@D]D>3hl<c8k?3Hh?T4j<SE6ESi:FfESHF]jGH4_GKRMW:2DUZS0`kFb_L:h
_<:]TI^mZ[O5b/K2aL[5_[k5`K:[[kJRUIB@RiV`Vk>GXG2GT:J8O7N4UYIoIh^<
SY2ATiBDMi6;OX^=Qi9oV8^2PWmjOhZHRWE]OI2<NjBBOWMoS9FHW86E]JNDUiJ6
TJVIYJjD^LgVn?Wfk<n_VZRg_;BXXInZYInJV9ZNX9BIVI>=RH1fJ6e`Jf5KGF9R
IV1GGg9aHEI;AdQ1=2ldECHY?4U0>T8o;bPmG6E?=35JKea;CDTiE4a;DE16ADaY
>D57AC`d=3M@FF1JCDQ>F3dl=bl[;cU28Bdj?3Lc=CXg>3Xk>cXh=cI0Bda5?S`n
ATE2?chn?cm<E4ho?dmDCDa;Bda>DUEGRVm<=2lg@4E1YY9PZ=R`UcmHWl::C457
?3i0@3/d:bHX:?hW1Leoni27NEEKDDi[If9NGV5WJW5ZI6AYK6UUIF]bM79`LG=e
JfU`L6QVK7EZI6IRF5QQI6]cMgIeN7^>OGF1RX9eL65RHEmMHV]cHFa[H5iWJF9Y
GeURLWU`I6ebIV]oMVb1MF]`QYJIWj^7THbBX8ajRXN6PW]dLWQmU:FCR[37]JM:
ShnROhbOKXAbMIjSLVAS?TU:BTI3ADeD@DQ6?3a5AT0i@4<l<c<nBcE1E69SFeIG
Lg9?O[^WVZ6DUZFh^Jf/]ZnY/KjbWjg>XJN_o[<U];Jo]kJk]jZUZjRQYK2/WIVQ
TJRCWgJDQ8j6OWb7UIN9NIBBT8gmS7m`RXAgQ8N0S7abL7UoPHbJS8f3MGF1QX:J
V9JETHUlLhM]P9j?OH1nR9:ZUj:ZSk?<dM3;c<NXQIRQZjbWXJ2QYj>OW9^OXjNR
XIbBRXJ1O75cLfaSGV9WCE=@BDmKEdM=@d15@CLe?3dd<ce2@4=:Cd0g@eURET@k
FVICAdi:>SQCBTU=BShk@B`d>c`g<cDhBE5FD4<l@DTb<c<_;2dd>clo?STc<C@h
=3Dg>CXi>3Lg?40n>3Hi?dCn@gm5B4]=@TY8?3]5AS`n?3/i>CXl?Dm1;bLY<3Dg
<X9]BY30Yj0k<U9W@AlS:RT/<38a;BLT;Bd_<C?kT8MiEE]ACV]WHUiNHFMZLFYT
I6U/JFEUJg9dLW1aLgE[JG1`J6I/MFYTIV9HF65TJg=gMWEhNhimMH6:PWE`HF9Q
GeeRJgmcHFa[H5iWJF9YGeURLWU`I6ebIV]oMVb1MF]`QYJIWj^7THbBX8ajRXN6
PW]dLWQmU:FCR[37]JN?Sj9oS9m^Q79eWZ=bI6<nBDY:AT=5CEA1B4Hl?4E6@3U0
@c`c<ci;=D5DHV=KEUMcLTmn^jNJXIBFYKRi[Jbf[jVa_[:O[@?>XJN_o[<U];Jo
]kJk]jZUZjRQYK2/WIVQTJRCWgJDQ8j6OWb7UIN9NIBBT8gmS7m`RXAgQ8N0S7ab
L7UoPHbJS8f3MGF1QX:JV9JETHUlLhM]P9j?OH1nR9:ZUj:ZSk?<dM3;c<NXQIRQ
ZjbWXJ2QYj>OW9^OXjNRXIbBRXJ1O75cLfaSGV9WCE=@BDmKEdM=@d15@CLe?3dd
<ce2@4=:Cd0g@eURET@kFVICAdi:>SQCBTU=BShk@B`d>c`g<cDhBE5FD4<l@DTb
<c<_;2dd>clo?STc<C@h=3Dg>CXi>3Lg?40n>3Hi?dCn@gm5B4]=@TY8?3]5AS`n
?3/i>CXl?Dm1;bLY<3Dg<X9]BY30Yj0k<U9W@AlS:RT/<38a;BLT;Bd_<C?kT8Mi
EE]ACV]WHUiNHFMZLFYTI6U/JFEUJg9dLW1aLgE[JG1`J6I/MFYTIV9HF65TJg=g
MWEhNhimMH6:PWE`HF9QGeeRJgmcHFa[H5iWJF9YGeURLWU`I6ebIV]oMVb1MF]`
QYJIWj^7THbBX8ajRXN6PW]dLWQmU:FCR[37]JN?Sj9oS9m^Q79eWZ=bI6<nBDY:
AT=5CEA1B4Hl?4E6@3U0@c`c<ci;=D5DHV=KEUMcLTmn^jNJXIBFYKRi[Jbf[jVa
_[:O[@?>XJN_o[<U];Jo]kJk]jZUZjRQYK2/WIVQTJRCWgJDQ8j6OWb7UIN9NIBB
T8gmS7m`RXAgQ8N0S7abL7UoPHbJS8f3MGF1QX:JV9JETHUlLhM]P9j?OH1nR9:Z
Uj:ZSk?<dM3;c<NXQIRQZjbWXJ2QYj>OW9^OXjNRXIbBRXJ1O75cLfaSGV9WCE=@
BDmKEdM=@d15@CLe?3dd<ce2@4=:Cd0g@eURET@kFVICAdi:>SQCBTU=BShk@B`d
>c`g<cDhBE5FD4<l@DTb<c<_;2dd>clo?STc<C@h=3Dg>CXi>3Lg?40n>3Hi?dCn
@cQ5B4]=@TY8?3]5AS`n?3/i>CXl?Dm1;bLY<3Dg<X9]BY30Yj0k<U9W@AlS:RT/
<38a;BLT;Bd_<C<5dGooU8Z1GfAIF7McK6MUIf]^M6mZJFa]K6UOJ75eLg1_L79^
LGQeJV]dNf]OGUaIHg5]LWMgLW1aLi1oMganLVITHFY`KVMXMH5VKg9^K6eVFf5P
HVU`LViXLgIYLHQkJGIdKWB5TI2@ThRARHfKRW^=Ph1kM71fPXb:W8b5[LJeZ7n@
TYR0TiYVJ6fP_hU4BeD]@DE8AdA3Ad`k@T0g>453?3i4BD@k=ce4<T1EJG=]G4b1
D7>S/j^@VibMYk:bZjbf^KBi_k6MY/2l^[Vm`lK5`kne/KBaYZF]XZ:/^KNWVYR=
Wi>MQ9J1O8N5QXbDUiB?THn;R8N9S8mgTHYmRXb6TGmnLfmeMgElR8>BUH5aMX>;
T9ROWI1nKVJOR9ZeYYVNVHVCZYNQZ8b`[ZFIVJN^VWjMXZJVY:BX[:2MVYRIWJ6T
[:FKTHV2P85gMW9ZI6=YKe9FE4m@EDm2@c/i@40i>d<]?4@n>T14@dm5?3e6C4Y5
AEEGBT]JFdeCBdU>BC/f>`8a=ckn@Qe6BDmEF596@4A:?3m1?SXj?T=DBC/c<cLk
?C8c=SWn>Wli@D4o>SHh@4Pl?3i1AT]@DdM@Ddi;C4Dj@d4n>SPg=cP`;Rhb=cXg
<b]I@RiXRGn<B2DW=24G81lM8BHZ;2/X9R//;c<goiB:PEmTFEQgLfaWIFM[KWA_
JVU/KFaYGfQaMG=`Kg1bKW5hMFY[M7][GeiLFF=aKG9gMg9`LG>@OgmgO7ibIVAQ
JW1^IfQePFI_LVi/KFIKHF1RJG1bKVQcMVUaR7]YMWA^M8FAT92CR969SI^:Nhf3
P7]dL7J2S8ZLS8F]a[FXT9:HP9>JIVQ]X;n9A4]E;D55B4M4@dM<>d90=cQ1@c`n
A4U4>cLmA390EFUcKEa<PE1cXk>[T9^LWGnW/[:[[;Ji];Vo/IfV`;bj^Kg3a/G3
_kFa];6VYJfRXZbi]jNJV8fOTif4UX5lQhF6S9BGU8nASh^8QhV<SgNARWf:S8JA
OW=_MGMeO8R3TYF1LGJ3Ri2HWif@OViVWhRJ]JJIWYV9TjZGXJR</:jUVIVW[YYn
WJ:VYZBTZ:bPWDRJV9VMXJB/YI^ARH:0PGMfLVYTHfU_DUIDCe1ECd93>cU0@3Tk
@bdlA3hj@4A3CdDl?DI<BTE5EEM:BeYKCE=;BDi9>cHk<CLnoT8MATU?EEQBAT14
BS`o@Chj>Si3E4Tk<c<g>cdb<cHioSYo>D51?cXf>418?3`n@DI;D5=7D5=>Bda5
>T=1?SXh=cLh<2h^<SLj=c<[FD8^J8UoS4PU9c@Q5b0O7B4V:R`[:2H[;2lc=onD
RX5OI5UHMg=/IfEWJfidKfYYK6e/JEmXLGEcL6m`LViaN7EZJgAkJemNG5USLFeb
MgMbL75cT7moMganLVITHFY`KVMXMH5VKg9^K6eVFf5PHVU`LViXLgIYLHQkJGId
KWB5TI2@ThRARHfKRW^=Ph1kM71fPXb:W8b5[LJeZ92BV82CVVIXKJ2oRDA;EBe1
ADQ7A4=7C3]2@3Lh@D<l?TA9A3/g?D@b@5EYLfeLC85@Lj>cZi2KW9eoYk:bZjbf
^KBi_k6MY/2l^[Vm`lK5`kne/KBaYZF]XZ:/^KNWVYR=Wi>MQ9J1O8N5QXbDUiB?
THn;R8N9S8mgTHYmRXb6TGicKgEgMGb8Pi:EPG5fPh^@V9nMT7i^IYn8V[FVVIjI
RI>ZUj6XS;2^YIVIYjjJOYfRYZJTY:R/X9e8VYRIWJ6T[:FKTHV2P85gMW9ZI6=Y
Ke9FE4m@EDm2@c/i@40i>d<]?4@n>T14@dm5?3e6C4Y5AEEGBT]JFdeCBdU>BC/f
>c4g?_i27DI9CeEHDTI0A4Xl?d4n>SXn@eA9>c<c=c/m<S<f>OhjACU1@Clj=SQ0
B3`l?T56Be1CAe1CCT]<ACY3@Chj>3Lg>30^;S8g>SLc:eU2;VR9Oha89BLd8ALP
7adQ9RX/:bPV:b`_<cL5cQ;oT7]cFFQ/N7A_If5NGV5TKfaXoVHCIFEKI6mdLfm^
KWQgOHAoLgAoN6WmGgmYN6ibMG=_K6iaOWIgP7i_I6=HI7AnOWUcL6AWJV]]Jf=J
FV5YKVi]K6afNFmjThE^MfUYL7f5PgeiOHEmPYF;PYV2P7adKg5iPHBGQh:/aKJY
OH^8NXb>L729/:aT;SY29C<i@48n?3`n=chm=3Do@C/mA4];AD52A30lCV=hOgm]
EGLYR;ZRXhFAY:N]/K2_/kZo^kjo/InS]JnWXJF_]K>^aKVc]K:Z[;FYYZJZZjFN
Vi6JUYNBVhf0SY6CTi:DVIf6Q8>3QhfEVGRBRWb8RH6<PgMbM79[KWR0TIJ4LgJ0
QXfBThYnMgZ1QG>7WiB?Ui68TjZIY:bA]J2HShnIWGnCQINJWZ6SYJNYW9ZFU9:C
UIJPV9>BS81lOg=`JFARIfmeIF=MEE9BD4e1=cDk>cHi@c=7BcXg@cl/B4I3@3dl
?T1=CdY5DVQ/HU19BU1=@3/o>Si2ADM:CDm;Ce9>AdA7Bdm?Bd<m?498CT4d<CU1
@T0d=STl?Chm?Clm>SPg>QE0A3Df=cXoADY=CUELG5Q@A3U9AdA1oSlh@3Hi?D93
?cPc=4</8dA<AEU?;c90=2h`92<V:Rd_;bd/8R@W:RkoT7]cFFQ/N7A_If5NGV5T
KfaXoVHCIFEKI6mdLfm^KWQgOHAoLgAoN6WmGgmYN6ibMG=_K6iaOWIgP7i_I6=H
I7AnOWUcL6AWJV]]Jf=JFV5YKVi]K6afNFmjThE^MfUYL7f5PgeiOHEmPYF;PYV2
P7adKg5iPHBGQh:/aKJYOH^8NXb>L729/:aT;SY29C<i@48n?3`n=chm=3Do@C/m
A4];AD52A30lCV=hOgm]EGLYR;ZRXhFAY:N]/K2_/kZo^kjo/InS]JnWXJF_]K>^
aKVc]K:Z[;FYYZJZZjFNVi6JUYNBVhf0SY6CTi:DVIf6Q8>3QhfEVGRBRWb8RH6<
PgMbM79[KWR0TIJ4LgJ0QXfBThYnMgZ1QG>7WiB?Ui68TjZIY:bA]J2HShnIWGnC
QINJWZ6SYJNYW9ZFU9:CUIJPV9>BS81lOg=`JFARIfmeIF=MEE9BD4e1=cDk>cHi
@c=7BcXg@cl/B4I3@3dl?T1=CdY5DVQ/HU19BU1=@3/o>Si2ADM:CDm;Ce9>AdA7
Bdm?Bd<m?498CT4d<CU1@T0d=STl?Chm?Clm>SPg>QE0A3Df=cXoADY=CUELG5Q@
A3U9AdA1oSlh@3Hi?D93?cPc=4</8dA<AEU?;c90=2h`92<V:Rd_;bd/8R@W:Rko
T7]cFFQ/N7A_If5NGV5TKfaXoVHCIFEKI6mdLfm^KWQgOHAoLgAoN6WmGgmYN6ib
MG=_K6iaOWIgP7i_I6=HI7AnOWUcL6AWJV]]Jf=JFV5YKVi]K6afNFmjThE^MfUY
L7f5PgeiOHEmPYF;PYV2P7adKg5iPHBGQh:/aKJYOH^8NXb>L729/:aT;SY29C<i
@48n?3`n=chm=3Do@C/mA4];AD52A30lCV=hOgm]EGLYR;ZRXhFAY:N]/K2_/kZo
^kjo/InS]JnWXJF_]K>^aKVc]K:Z[;FYYZJZZjFNVi6JUYNBVhf0SY6CTi:DVIf6
Q8>3QhfEVGRBRWb8RH6<PgMbM79[KWR0TIJ4LgJ0QXfBThYnMgZ1QG>7WiB?Ui68
TjZIY:bA]J2HShnIWGnCQINJWZ6SYJNYW9ZFU9:CUIJPV9>BS81lOg=`JFARIfme
IF=MEE9BD4e1=cDk>cHi@c=7BcXg@cl/B4I3@3dl?T1=CdY5DVQ/HU19BU1=@3/o
>Si2ADM:CDm;Ce9>AdA7Bdm?Bd<m?498CT4d<CU1@T0d=STl?Chm?Clm>SPg>QE0
A3Df=cXoADY=CUELG5Q@A3U9AdA1oSlU@3Hi?D93?cPc=4</8dA<AEU?;c90=2h`
92<V:Rd_;bd/8R@W:Rh5cGooP6YXDUiQL6aWGeQDE5MIIFERGU]IFeaIHVa`Kfe^
KgE`LgYgKFeeIUaHGUmLHFaVJVe]JVY^Lf]_OXn=OWAgFUQLJWQiJEUOFEQOIFEP
GEYRJVe[JVa`JW1[N922KGQCFfIdPXV5OH:8O7nCS8RRQXJ4Ng1XIVR7VHV3[<Fe
Z5MfUHEjQ864SJ6GJclg?SXe;cLo@Chj>CXnAD@l?DQ:A38i@4A4@T51=Ca1Bf9e
Je=Q79C6UIR8SIjUZZVY[kJi[Jnf^kJ`]L6[XifQ[;>a[<>h/[FcZjffoZ]o[;2_
YIVDU9F8TYJIS9NJViNATINNQXF4QHR=TiI]QWe/MWE/MW=ZJG5cL7AoNH61MW9g
Mg6?TY::P7j7TFaOM8Z3R9B<QY6ZVZNaUkb^[:VSUHInOHV=UIfRXYjJXInJUI6=
RhZ8PXNCT7ieNFYTGU]OIfmdJV1DBT=0ADa4>CAD=cH`<cdi@clc?4e194E<DDi6
?d13E4i4@DiOHUU5@4A>CD8n@S`k>S/n@450>C/n?S`k?T5FD4Dg;B`e?D8j=3Ln
@C/c>CXm?d51@3lc<S<e>3Th=odjOce0@dI:CE=GDTDi<cdl>STh>S/m=cTl>cPe
<c91?C0_>2lX=D8]=Sl]:S4V;Rh_;bh]:bXQ8R<U9on0JVQBGV5`K6MOF5ADEeUU
IF9NFeUKG5URK71_KFi_MG1cNWM]KGEVG5QNGeaQK6IZKFeZJVicJfmnShenM7MJ
F5aZN7UYOeUOFEQOIFEPGEYRJVe[JVa`JW1[N922KGQCFfIdPXV5OH:8O7nCS8RR
QXJ4Ng1XIVR7VHV3[<FeZ7JEQGZ4PHB=XIM[?cLn>SD_=cm1?SXi>Si5A3`mB4Y4
<SU0A4A2@D4e?45;HWE[Df4LU<JEV8R=WZFZZJV_][V][kJk][2e4<6[XifQ[;>a
[<>h/[FcZjffoZ]o[;2_YIVDU9F8TYJIS9NJViNATINNQXF4QHR=TiI]QWe/MWE/
MW=ZJG5cL7AoNH61MW9gMg6?TY::P7j7TFaOM8Z3R9B<QY6ZVZNaUkb^[:VSUHIn
OHV=UIfRXYjJXInJUI6=RhZ8PXNCT7ieNFYTGU]OIfmdJV1DBT=0ADa4>CAD=cH`
<cdi@clc?4e194E<DDi6?d13E4i4@DiOHUU5@4A>CD8n@S`k>S/n@450>C/n?S`k
?T5FD4Dg;B`e?D8j=3Ln@C/c>CXm?d51@3lc<S<e>3Th=odjOce0@dI:CE=GDTDi
<cdl>STh>S/m=cTl>cPe<c91?C0_>2lX=D8]=Sl]:S4V;Rh_;bh]:bXQ8R<U9on0
JVQBGV5`K6MOF5ADEeUUIF9NFeUKG5URK71_KFi_MG1cNWM]KGEVG5QNGeaQK6IZ
KFeZJVicJfmnShenM7MJF5aZN7UYOeUOFEQOIFEPGEYRJVe[JVa`JW1[N922KGQC
FfIdPXV5OH:8O7nCS8RRQXJ4Ng1XIVR7VHV3[<FeZ7JEQGZ4PHB=XIM[?cLn>SD_
=cm1?SXi>Si5A3`mB4Y4<SU0A4A2@D4e?45;HWE[Df4LU<JEV8R=WZFZZJV_][V]
[kJk][2e4<6[XifQ[;>a[<>h/[FcZjffoZ]o[;2_YIVDU9F8TYJIS9NJViNATINN
QXF4QHR=TiI]QWe/MWE/MW=ZJG5cL7AoNH61MW9gMg6?TY::P7j7TFaOM8Z3R9B<
QY6ZVZNaUkb^[:VSUHInOHV=UIfRXYjJXInJUI6=RhZ8PXNCT7ieNFYTGU]OIfmd
JV1DBT=0ADa4>CAD=cH`<cdi@clc?4e194E<DDi6?d13E4i4@DiOHUU5@4A>CD8n
@S`k>S/n@450>C/n?S`k?T5FD4Dg;B`e?D8j=3Ln@C/c>CXm?d51@3lc<S<e>3Th
=odj>3e0@dI:CE=GDTDi<cdl>STh>S/m=cTl>cPe<c91?C0_>2lX=D8]=Sl]:S4V
;Rh_;bh]:bXQ8R<U9`GAOommL7YTH5=IJFALEE9CEUQPHF1KEE9DF5YPIfYZJfmc
KV1IGf5KF5aCCDiGF55BFUmSIFESIVabJG>8ViR:QXmjIE9FJWQcIfaPGV]eLVa[
Gf=WJ6QZKW=WM7=lSWm_PVI^M7MnPga]QHIdLX5jMi:=SX^0LFAMG96RTHV`a[FW
Oh:YR7n4NiJNUG4e9dQ:?4Xf?DA6@Slo@CHn?CHh@TDo:2`b=cXj>CQ;CdQ0D6UW
DT/fWLZBRiJ=RIJNWJ2[/k>f^[fl]Zn_/Zn][[>k_l2n^k:_/k6YZK6X/KVoaL:/
TY>@VGZ=QYZ@VIZJUi:AU9RAT8n=RhV7QW>;P6acKfA/OgQ_K71^IVI^KFm/Ifif
KUj<Ti^MUX^3OgQ_Q9JAWJ^PQY6ZVJJ_UKZPXZRWUX>1S9:EVjF/[:BMYJ>NV9:;
QhAiLWbAT7U]LfIPFEQNI6MXJemDCD8j@4i6>C8c<B/^>CHb;2m2DDPe>458Acli
>SeHCdE1ATU5?cdi?da=@Si25dM1?3`o@T4n>CXj>c`l?CiHDdPj;b`c>_hlOcln
>2dU?3do@40n?3/l>SXoA4I3?d=2@D11@TA6D4]=Ddm1>CXk>SPg>3Tk?3Dg>CHc
=3Xo@SXj?CTc<S@m:Rh/5aha;30_;B/X9RDT:2PY:bcoOG1jI61CFFUTG5EBDeIH
H65PFeEBE5QJH6MZJV]_LfiPFEmQFeQLDde>EeQAOe9JGf=UIF=VK79YLhRKV8Z6
SgYUDUIZN7=WK61NJgEbK6]OHfMXJ6Y^LfMdLgb>Ofn2IVidMgj3O6f5QWAbPGYg
TXf>Rh1aI5eLTJ:ARK36]JN2ZHQoQ7^FWYEa=BM8BSa:=Se4AT8o?d4f?Sdf>495
?bP/<SLj>SThBdm8@51YOfMBBcJMbY:;UXf9UYjMX:^c/kJj_Kbf[jnb[jf^/k^o
`;jk/Znc/JVY/JRa^Ko5`ZbBTi2INXf6VY2IVYZGTY6DV96@Shf;RHN6Lh^0K7=_
I6ahKfa`KVIVKVe_K6M^MViNS9>KWIJ;PgmhKhBFTIf[X8JAZYVV[iFjX::XYiJ3
JH6<TYFKYJb/Y9fUXijHTX^7Q7UbO96@NFecIV1IF5iTIfQ[GeA=@SY0CTHi<S<a
:bhi=S8/;d9AB3Dh@DQ7?cTj?EQ?AD56BDDo?CToC4e2?T97@C`l?d91?STj>S/l
?3dnF5=8>Rl/<c[n?7lo?SP]9C`m?d10?S`k?3Xj?dA6@cm3@T50@D94AU1;CE=?
@CTj>cXh=cPi>c`e=cTf<c@j?d8j>Sdi<c8d?BX^;1LN<B``;bd[:2HU92PX:B//
oge`NVAPDeUYI5aEDU=FF61QH5]EDUAHFV1WJVY[Kg=^H5UOHE]HG5==CUMHDGmB
FUmSIFESIVabJG>8ViR:QXmjIE9FJWQcIfaPGV]eLVa[Gf=WJ6QZKW=WM7=lSWm_
PVI^M7MnPga]QHIdLX5jMi:=SX^0LFAMG96RTHV`a[FWPZV8OhAkUYjELCDWB4Xl
BSHmA4I2?cm1=Shm=SQ2AClX;38g>SXi>4]?B41@JGmWDT/fWLZBRiJ=RIJNWJ2[
/k>f^[fl]Zn_/Zn][[>k_l2n^k:_/k6YZK6X/KVoaL:/TY>@VGZ=QYZ@VIZJUi:A
U9RAT8n=RhV7QW>;P6acKfA/N6m/L6iVIVi]KfaWKWI^GXbCVifFRh=oN6n4UY6M
Zj26TJZIYZnE^Z2RZ:NFPfV1S9:EVjF/[:BMYJ>NV9:;QhAiLWbAT7U]LfIPFEQN
I6MXJemDCD8j@4i6>C8c<B/^>CHb;2m2DDPe>458Acli>SeHCdE1ATU5?cdi?da=
@Si2Ad4l?3m2@Chi>SXk?3`m?UQCB3X_;3<joSaA?chh;BDl?Cm0@3hl>c`j>Sm4
AT<o@d91@452A4I@BdeCCd4i>S/j>3Lh>C/l=CLi=S<d>Sm2>SXm>C<b=3dZ;R`G
7S4/<2l]:bPV9B@X:2T[;0GAOomlKWeYI5IMIF5JE55CEUUSIVIPEe=GG5aPHfAT
J71gN5i<DE]IDe5CBd]CE4e?F5eOHEmLGfI/LGR8TX]oQIF8MF9OJgMjMWIXJWj8
OFiYJ6AQHFE/LGAVNGYmQ75XPgf4PGIdMVUEO7aWHg=^KXbDTXaoLVUWJIj^Vi2d
b;BUOh>ZNG^:Oj2KLVLc94]9=4Lj?dA4@Cm1AB`c<b`^>C`g;bl`<cHg=C=?Eddk
AF5VE3QOW/>>N9n5N8^HUif^][;7b/Ro/jZRWHfEWZFWZJb_^K:b^KR]Zk6a^;Zi
`LJcVINFZWjANiN=Ti:BTiJFUIBCU9JFTX^4Oh2GRWAgLFA[OgY`JfaVFUILIfe^
K79jLf>0QY2HV8]hJG5ZOHZ3TIn@RI>YUInUR:bARhjHUhjCXYjKVZ2XZjNRVIRE
T8^5P7emL7J;RG5XLfeVGUaOH5aGIemMGE4o?de3=Rh`;RT^>SDZ:3E1@dA9<3<e
<c0a=SaACDY;BT@n>dM4BUIFBD9684e5?Sm4B4M4AD90?Shl>SM;CDa5?3He=c@j
@44k=2l]>ohl@3Xg=396?cTj@TU:B491@3m0@TE6EDU5BdLk>T=5@d0m>c/l?3Hj
?CXe=C]3>S<j>Rhg@SPm:R/Y6RLf:2l^:bTWoREo:b`_<SKoO6imJFAFGFEQFUAA
DeIIHfIVH5MCEeaLH6=TI6Q`MgQNC55KFE=ADd];DeA=CeQMGf5OG5mVK75hR9:;
OhFER7ERGf]gNWIfJ6YnR7e^JFQTHF5UK75dIWUjOHAaJ8=mQ85fM7IYEGalIf=c
KVj<U9:<Og9YIfVN[Y]oT;C8]:F3ZWUkRWnPVg9W<bA;BCA7>Sm4A44o@DD/<c</
;STl=bl_<3<f=cDcCeM=>dEQIU@hGik3SWROQGR;V9NM[[Jbal[8_k>ZXYf=UIjU
YjV/[kVb/[Vh[J^a/KRj^L76/iVGUZYnTG^GSI>BTY>FUYFDTiBFUY:;Q7n0UhYo
M7MaI6]jL6]/IUYFG6M]KVabNW=SP8J@V9R;N6UaJWf:Pi6OT8VCZIFOYHR/TH^>
V9N>Tj:NViZPZ:^WXYVHUI2;QH1mOG1fRhUaJ7=]IUiLGf1LEfMOGEeA?cm=@cH^
<2hY;SXe:RPe@D=4BC0c=C<`<CHlDDe:BdY4?S]7A4XUEUI9@TI=AChoA4Q7A4E2
@3hn?3XgBde<AC`f=CLd>T11>c@_;C_n?40j=c@bASli>T99BTQ2@D0o@495AUE9
AD]7>cY3AD=0?C/k?3`f>Sdj=CDk@cXc>SX^=d8h?BX[:AXW=RP_;R/Y9ohUOb//
;c8foga^OFUTEUeUHEYDDE=FFF=VIV1GDeMLG61SI6AXL7MhGTaAFeUCDE=;Be=D
CDmHGEmQGeaOIVaaN8RBRgn5UHQeHUm[MgYfMVQZOXQmKVUXI65QIFaaM6IiNWf4
LFR3OHB1MWAfJEElO6MSLfi^S9BBS7mbJFMYWZjKOi2db;BUPjYiNhYoX9]bIc<T
BdTdAcXoA4A1?d55;3<c;2hi?3L_;c0c=SLe<dmGCC]5HFID>5nN`hihWhEhRiRG
WJjf//O:b;ncZZ:MSIFNYJNY[:ni/[:i^:f[/K6h^[W1a[>IUiJZOY5kUhfCTY:C
UYJEU9>DUYJBRhAoP9N:OgAgLFA[NW1[K6IJEUaWKFi/LWYcHh26T9RHRgQYLFYm
RX>AWi29TjVEWjF8[96;SYRGSY>RWY^JX:R[Yj:IV9F@RhF0OGe`MX^9LFQcKFIN
G5mPG5MWGeeMDCloCD<f;S0^:Bhj=BXX=D53A4T`<cDc<34f?55=BT]:A3hkAdA:
9EIFBD96CDDn?dA8AdA5@T0n?S`j=d]=C4Dl=SDg=3Y0@C/d;bdkoSa0>SLd<THo
>CY2BDY8@T50?d12ADIEBDE;Ac/j@dE3@3dk>c`l=SXm>SDe>d<j<cXj;SM2>3dZ
:bTJ9cHX;bh[:BOn9@@[;2lb=PG>Ooi]E65BFEY]H5aED4i@E5MYKFeVG5QLHUiP
HEmPIW5jS6]AEF=UGEMNE51EEE5EH5iPGeaHFEmVMWV0PGE[N8mbKfe/KFe/JVUM
Hg^4LEU?KVELG6A^LgAHKW1]K5IALVegMF]]MViKNWYXIW]jOinHThUlLFmfOJNf
XIBgbKBTOgFIHG6?QZFAF7==:d@o9CDg>chm>SXm@S8i>C8e@4<n?S/h>3Xj>3Hf
A3h/=5ANCbYkVKR7IYmjLXVIVZ>f_[Rh_l6l]kF`ZYBQ/KVg]kc2_KRj`l:f/KK1
_JfOZ;^iYinR_X^KNYN;S8Z:T9RKUi::SiFIV9::QGjDQFi`J5UPOeiGFF=VHF=/
JGImNW^1OWAeM7InQH9cIX5kRiB:V:FDS9BXTINKO9jVT8J?Thf>V9F<Q8F>UYJD
R8N6Ph1kMWB8MGF6PfYUMWI^I65QGE=:F5EKHeHl=T4n<RX];BXa?C/];chl;cQA
>cPc;c0h@d]7B4mGEdm;C5QEFVARDd]=7d4i<S<k@D4m@chi=C8_:BD_=d53?3</
:BXd?Sli=ca2oST<=c@`;2Xl;b8P:SDl?OdhOc/n@D=9>C4f<bT]>dI3?cTe<c4a
<SLk=bdX:c0d;CD^7C14=3<R:S8/=C@D<2l]:bX[;2dW:Rhd>_i]E65BFEY]H5aE
D4i@E5MYKFeVG5QLHUiPHEmPIW5jS6]AEF=UGEMNE51EEE5EH5iPGeaHFEmVMWV0
PGE[N8mbKfe/KFe/OfYYGF=kQ75ICfiUG5aTKW=dF6i`KFaFDG9]MgE[KGI^FgYj
J6IkNWnOV9>9O75_MWfW]Z6D]lVdY7FIHG6?QZFAF7==:d@o9CDg>chm>SXm@S8i
>C8e@4<n?S/h>3Xj>3HfA3h/=5ANCbYkVKR7IYmjLXVIVZ>f_[Rh_l6l]kF`OjZD
XK6i]kNl`[fh^/?2][6f`Kf]WjRk^JNOX[j;VgZGRhb:RY2HViNBRXnEVIRBRXEn
U8E^L6QIH5iGFF=VHF=/JGImNW^1OWAeM7InQH9cIX5kRiB:V:FDS9BXTINKO9jV
T8J?Thf>V9F<Q8F>UYJDR8N6Ph1kMWB8MGF6PfYUF7IfKVAQHEeCBUQEFf=F?3I1
?S8Z;BdZ<Cdk;Bln?2lhDC/h<bl`>4=;AdQ?EeM?BdaHEEYTHU=;CD4i<S<k@D4m
@chi=C8_:BD_=d53?3</:BXd?Sli=ca2oST<=c@`;2Xl;b8P:SDl?OdhOc/n@D=9
>C4f<bT]>dI3?cTe<c4a<SLk=bdX:c0d;CD^7C14=3<R:S8/=C@D<2l]:bX[;2dW
:Rhd>_i]E65BFEY]H5aED4i@E5MYKFeVG5QLHUiPHEmPIW5jS6]AEF=UGEMNE51E
EE5EH5iPGeaHFEmVMWV0PGE[N8mbKfe/KFe/OfYYGF=kQ75ICfiUG5aTKW=dF6i`
KFaFDG9]MgE[KGI^FgYjJ6IkNWnOV9>9O75_MWfW]Z6D]lVdY7FIHG6?QZFAF7==
:d@o9CDg>chm>SXm@S8i>C8e@4<n?S/h>3Xj>3HfA3h/=5ANCbYkVKR7IYmjLXVI
VZ>f_[Rh_l6l]kF`OjZDXK6i]kNl`[fh^/?2][6f`Kf]WjRk^JNOX[j;VgZGRhb:
RY2HViNBRXnEVIRBRXEnU8E^L6QIH5iGFF=VHF=/JGImNW^1OWAeM7InQH9cIX5k
RiB:V:FDS9BXTINKO9jVT8J?Thf>V9F<Q8F>UYJDR8N6Ph1kMWB8MGF6PfYUF7If
KVAQHEeCBUQEFf=F?3I1?S8Z;BdZ<Cdk;Bln?2lhDC/h<bl`>4=;AdQ?EeM?BdaH
EEYTHU=;CD4i<S<k@D4m@chi=C8_:BD_=d53?3</:BXd?Sli=ca2oST<=c@`;2Xl
;b8P:SDl?Odh>3/n@D=9>C4f<bT]>dI3?cTe<c4a<SLk=bdX:c0d;CD^7C14=3<R
:S8/=C@D<2l]:bX[;2dW:Rhd>PFi=OmiHW=VJ5iXD5aYKFUUIFQ^IE]JH6AQGEE@
DEEBDF1eIVMXK6i/If9SF5AIF5=FH61TK7=hN_eiDHBCT7a]JfQZKW5bLW1_IFAT
IFQ[Kg5LIW9gM71^KhN0MFaZLGj7JVI[M7=[K7ImNW^3SHj4NY5lI61bP7EQVK:T
UkW=]j>7UH=RKINHM4Q8BDWmBT/n?Sdk?459CcHk=RhgBDPh@SHc@eAGCDDj@dI7
F6i/FVAWWkB7Qj2>M86CXZV^/[Fg_lBn/Zjg`Zff/ZBV]kjg`KRmc<^j];bn_;Vf
oKAoXjRZY9^HWZF<SYBOYjJLTi2OUiNWUGEbQ7YfNWQ`LW]`G5a`L5aLKf5gMf9Q
N81dQ8R:QWihNGaePi>HUI>HWZ^HTYjSUi6EWijJUI:DVj6CR9::N;f3UI:HTXF7
U962Pf]RKVaNIh:6N6QPHF9PG455BD]9@c`h=D4o<310BDA?C4Q1?3/m@DA0?CU2
FFUH?E9:ATU6@diOGEICFV9MBSMDBSlj?454A490?C/m@TM;>4A7?CTo@Si3@3`i
>Ce2ASDe<C=0BS`T>cXg=C@e=SOn>b`n@d]BETE8Aclh>45;Ad8l?3i0?CX[9b<R
9Bhg?C`o@D=2?c`i=SHd<S0_;Bcm:_dY>RL/<S<aogURLfIXGVQ@G6U]JFEUJ6iU
FeYPI65MEE1AEE9AH7EVIfQ/KVaWHV=HE5UHDeIPH6A/LgQjoGUAQ9>@O6e[J6Y^
LG9bL6mUI6AUJ6]_LEaVLWMdL6i_Qh1eK6YaOXMZIV]dLf]/MWejNh>=SXAjTGaT
H7:0MF6I/ZBG^LfgXhNEPf9]UiQdB4Q9BOe:Bchn?C/l@DU?=S/f;SM9B3Q2=S=3
E5M=ACY3ATMHKVaJI6NO]8N7X8idPI>RZJjb]KNoa;jb[[O2[KJbY:Jg_[O1^;g<
bkZd_;jl^KKm]7nSZ:ZTViRNYHb>U9nWYYbCT9nGUjNEMG:4NWIjN71bNg1LG71`
G5a_HGMgHV5hP7B4R8Z6OWQiO7F3TiRETiRNZiRBWZ>GTIFOWYZETYBKXI>8TXYh
_H>ETYRBQHNDTH:3Jf9^K5iWPXIhJ61QHV1L@DE9BdU3?3Pe@Cl`<419A4m<B44l
>ce1A40m>D9IJEPmDTY6BDI3CUmMEU=JHUe:=eA:?cXl@DA4@T0m>ce2Ad/hA4Lm
>Cm2?T=0?3Ti?D96=CDa<d1:?2@k>SLe=3Df=ohk;3i3Be9FADQ7?cPh@D]7@S`l
?T0m>R/W8b8U;SLm?3m1@d8o?3Tf=S@b<2l];?dZoBTj9b`b<c7oNF9cIVQNJ51L
JFeYIFEXKVEKFV1THEeED55EDU5PMFIWJ6a^K6MRHeQDFEQCEV1PI6acN7[mNE64
Ti1lKF]XJViaLW9`KfETI6EXJfmaG6IbMgA`KVn7P7E/JW5nQfYVJgAcJfafOGYk
Phf>Q7ZAO6APLX1eHIVbY9NicKNSQiF3HVfGV7A8B4U9oDY;?Shm>ca1BDlf>cH^
=dU8>48f<d=DEde5>T=6AeQ^K5YTIindQhNPSWB1Tj:Y[[:e]ko4_[:^]l:]][:T
Y[Nn]l6h_Lc;^[Bl_[bi]_fdOj>XZZBKV9jUS8jDWjNVW9>@WiNGYiEeLXAjMWYh
L79kL5aLL71LG6mQMgMRHGR0M8B8RXInN7UlMH>CV9FCV9j[V9:NXiNAUInNVYFB
U9^QThRBRWRmPiFBV9:5QiBAPX=[HVi/GVN2QWQXH65RH5a1ADU;BD<l>3E1?c0`
@4U4Cda8@C`k?D54@3di@UUYF3eBBTI9AT=>GeeFDeYRGDXgE4Xo>Sa1A4A2@3dk
?D97BcQ4Acdi?d8n@d0l>CTm@THe=C4c@4Xl93/j=cDd=CHgoS//?T=;DUI5B4Lo
>3Q1BdM2?3`n@3dj:bLS8RD^=cdl?d53@Sll>CHf=38`;bd/oB[m:@@W;38c<@GA
OomjIWIZKVE_EeeQH5]JGfEXH5MEFEaJEe5=D5MFDemaL6IOHfe]H5=HCdiFFEMM
J5ULH6EYJfa/NgAdOGacLGQgL6INGF5YKVIVIfQZKFmaJFa`Lg5ZH5U]K6QRG5YL
GUmKH6]]IfYdPH:6S92>QWn3NVeVJW=gMI^XTHF^aJfG2YJSZjNHOeXk@T93oTAo
@d<kAe1;?cU0BTeABSm1BT<b=S@f?40n>c]3CUIJIg5UCUmOS9imPYb?KGbAXjng
_/?1alW1/jfc_;S0_[>d`LBl^[>ha/Rn_<Bi^;Nh^Kbn`:nWWYVHUI2;Sh^6QHV?
TiJ;VI6AXYEjNX1iNX5nLVeaKUaMKfmNGg5RMGQ[L8IoR7MOIF]_Kfe[JWEhOhN=
SXZ6Y9B>VInHUYbKViZIVYnVZhn6RHIb[WR6PXR4Ngj8PgF3KVQ`J5IMMWQ/GeQI
FeUFFeYHDd]1>C=4BdHe<C/o>D8n>38_<3<f?S/d=DIFCce6?cm3@Si7EeYFEEUM
EdPk@TI7@cm0BE91?3D`<3Eo?D8o@C`g?DM3=C/l?Cho?Sdl<CTk=SLm>2`e=CLh
>C/k?3Dd=3Hj@4E9=cTh<B/[<c]5@3/j?Chl>3dh<2XX:c0d<S@g>3H`:BDY:B/]
;c4b<bDV9bTZ;2d^7B8Y;c?oNVIfJViUKeMMHF1KFUmUJ61GEEULFUMACE1GEU=O
LG1YIUmSKFePDeQ?CUIIEeeXFEaPIFU[K6akM7AmO7=aN7M`IUiMHFU^IVIWJ6Y]
Kg5YK71cLFYPFFe/J69LFUaNGe]PJfeWJWB1PXJ<T8j6Oh=jKFIZLgMeVjRAQJk5
[INFXj^WV7mJ>d92@oi4Od=3>dM@Bcli@4Y=DDXo@DY3<SHd=Sa0?S/k@diFFVMa
IDiOGhbNOH:LSfelTJ>_]kk3`LO9`K>]/kbh`;jc]<74_;Zc^<K8_[c4^KRg^;Vl
_/2_YijIV9F@Rhn;QXF9Si>FRiVATJ:ENWZ0NGZ1OW9]LFiLGFm_GUmaHWEhJg26
OhQgGfE[Kfm]JfYeN7n7SHj:QZBDSYVOV9JLVi^JVIZOYZ^?QXV6LZihQX:8Q7]n
R8=ePfiXL6QFGGIhK5mHFE]IEU]JF5=;@CTcA4]6=C4k?cU2?SPb;c0c=Shk=3E6
ETlmASlo@d8nAeMJEUEIGEM8>d96Ad<o@4UB@C`e<30eOce2?d4l=ce7@cDk?3dn
?chm?34i>cHg?CP/=CDg>3Tk>c`e=3@f>T15BCLi>34[:c<kAD0k>Sdn?3Pm>30Z
:2/`=38d=cPf<2TU:BT[;Bla<S<U9RLY:R`];QdR:BlcogYVMVY^IFmGGF5PFeYO
IFQPEeEIG5YGDDe@EeICGg5`JFIOHfe]H5=HCdiFFEMMJ5ULH6EYJfa/NgAdOGac
LGQgL6INGF5YKVIVIfQZKFmaJFa`Lg5ZH5U]K6QRG5YLGUmKH6]]IfYdPH:6S92>
QWn3NVeVJW=gMI^XTHF^aJfGUZ>[YiQoFS]2@T?nA7m3@c]7D4/o>D1:CE5:?d5:
@c8f=3Hl@3hk>d=>EUYWLFE>Gen<WWf2W8m]O96S[kNn`l77bL6c[K>l^<2n/kC1
a;bj/kS6b;jla;Vh]kRi_;k0[jNNVIRET8^?RhJ5RHnCUX^ITI6RUGYjP7UjPGib
KG5^G5e_KeiOLF9eN6]`QWn8MemUJfm_KF]ZMGQoQhf>RXJTU8jIWiRFW9^KVYVJ
WjJ[ShJ9QW:^N8J2R8AkOXR3MH=^J71XEUefN6aOF5UKFEIKFUQCBd4i<dA;ASDa
>cli@Shh<Rl`<cHn>c@eAUI??DHo?d=2?TMGFUIEFEeGB3]2ATM3?d19DT4l=C0`
=Ehm@Sm1?3LmAd<e>c`m?Sln?C`a>C/f=cdh;3De=cPi>c/l=C@d=SY0ADTg>CPa
:b/c>dE0>cXm?S`h?CP`:RP[<3@b=3Lh=S0Y9BTY:bd_<C8c9BHW:BX/;BhM8RT_
<`G>;omhIgAWKFE/HF5NFEIHH6MYHUYGF5YJF5ABF69TGfIdMfIHGF]]FdMHCdiE
F5IKI_iMOeiPHfIXN79eP85hMgedL6UTHfQ^LVUYJVa^L75bH6=XKg=`IemRJW9c
K6=NG6QRIG9gLgJ0O8B=THn9QH>1PWidJfeoT:BSPg^[`jN<Oh^Z_Z1O<ba1@T=4
A4=1@3]>GUM1<cQ3?40m=C@f;1hj@4E1>SPk@4aHIG1kNVA;F5MfOhIeOI6:M8:G
ZKBl`lS9cLc2/jb_]Kk5a/2oa<:j];2c_/?0`l^n_K^j^kfo`<6`WijWZIb=ZJRV
XIjQZ:jAWiJDYYb7SGmkOhN2LFMXJeeNKVmRHg9GIF]YMXR0JF=UJW9gMg5[P7]k
QY>FS82TUi6GWIjRZJ:QWinQY:NXWIN@OIJ1/86;PHJ5PXJ;Q7MWG5eUGTmGKVaU
G5QIFeYHDE5@Cdi<BdY8BT@h=3/l=TE1?3Pe=SPj?Shg;cI5BD4m>Ca4@cm6EEAD
EEAABd@o>dUEDD<mAe=2?3@^;S8i?d@n=390CT<^=3Pn@D4m>3@a?d8g;c8e<bd`
=S/n?cdl=?hc<cDh?3hn?cdh<c<i?d0l>3Tl?CXf@chg<2h_<cHi?D52?SH/9RDV
:2T[;Bl`8R<U:2/^<37n9C4V:OmhIgAWKFE/HF5NFEIHH6MYHUYGF5YJF5ABF69T
GfIdMfIHGF]]FdMHCdiEF5IKI_iMOeiPHfIXN79eP85hMgedL6UTHfQ^LVUYJVa^
L75bH6=XKg=`IemRJW9cK6=NG6QRIG9gLgJ0O8B=THn9QH>1PWidJfeoT:BSPg^[
`jN<Oh^Z_Z1O<ba1@T=4A4=1@3]>GUM1<cQ3?40m=C@f;1hj@4E1>SPk@4aHIG1k
NVA;F5MfOhIeOI6:M8:GZKBl`lS9cLc2/jb_]Kk5a/2oa<:j];2c_/?0`l^n_K^j
^kfo`<6`WijWZIb=ZJRVXIjQZ:jAWiJDYYb7SGmkOhN2LFMXJeeNKVmRHg9GIF]Y
MXR0JF=UJW9gMg5[P7]kQY>FS82TUi6GWIjRZJ:QWinQY:NXWIN@OIJ1/86;PHJ5
PXJ;Q7MWG5eUGTmGKVaUG5QIFeYHDE5@Cdi<BdY8BT@h=3/l=TE1?3Pe=SPj?Shg
;cI5BD4m>Ca4@cm6EEADEEAABd@o>dUEDD<mAe=2?3@^;S8i?d@n=390CT<^=3Pn
@D4m>3@a?d8g;c8e<bd`=S/n?cdl=?hc<cDh?3hn?cdh<c<i?d0l>3Tl?CXf@chg
<2h_<cHi?D52?SH/9RDV:2T[;Bl`8R<U:2/^<37n9C4V:OmhIgAWKFE/HF5NFEIH
H6MYHUYGF5YJF5ABF69TGfIdMfIHGF]]FdMHCdiEF5IKI_iMOeiPHfIXN79eP85h
MgedL6UTHfQ^LVUYJVa^L75bH6=XKg=`IemRJW9cK6=NG6QRIG9gLgJ0O8B=THn9
QH>1PWidJfeoT:BSPg^[`jN<Oh^Z_Z1O<ba1@T=4A4=1@3]>GUM1<cQ3?40m=C@f
;1hj@4E1>SPk@4aHIG1kNVA;F5MfOhIeOI6:M8:GZKBl`lS9cLc2/jb_]Kk5a/2o
a<:j];2c_/?0`l^n_K^j^kfo`<6`WijWZIb=ZJRVXIjQZ:jAWiJDYYb7SGmkOhN2
LFMXJeeNKVmRHg9GIF]YMXR0JF=UJW9gMg5[P7]kQY>FS82TUi6GWIjRZJ:QWinQ
Y:NXWIN@OIJ1/86;PHJ5PXJ;Q7MWG5eUGTmGKVaUG5QIFeYHDE5@Cdi<BdY8BT@h
=3/l=TE1?3Pe=SPj?Shg;cI5BD4m>Ca4@cm6EEADEEAABd@o>dUEDD<mAe=2?3@^
;S8i?d@n=390CT<^=3Pn@D4m>3@a?d8g;c8e<bd`=S/n?cdl=?hc<cDh?3hn?cdh
<c<i?d0l>3Tl?CXf@chg<2h_<cHi?D52?SH/9RDV:2T[;Bl`8R<U:2/^<37n9@4V
:@G2BoYhJ6mLHUUMHV5PGUmSJVm^JVAPGf1QHUmMI79fL79jLVIMGfMXGE5TFEAH
ETmBFfeZIfEVJFe`J6]jS8ekK6UHGfUbMgIbKVa^L7;mLgmRK7IhLfe/KV9`OhF1
NWQiM6YZMG]hNX5^O8bAS8J6R8AoNG5VI7F;[:F4PkK8XhIkQiVHLdLjATE7BT]:
B4A2@TeECcle=cdg?453ADDo=ci3@cdl@dM6Ff9^O8EoJ59AF6ekNGf3P8REY[>i
_<32b<W7_[>][[:j_l;1_kbf[gZd/[>h_;k3b<O5`;^g]KBd_k:VYk:g[Z>@VZFX
XIRCTIBRUi6PUhRBQGmoQGm^IFMXGf1/KVIWLUURIfenRGUMPgmlOX62O7IlO82:
UINARZVQVYVLXJV`[JVUXj:PViNNWhfRSJn=TH:4QhZ?ShMmLV]YJUi=CUeYIfCl
HcU8AdM8BTiADchl>3Dh?Chk@T0o?Ci1A4HnAD<h=T57AC`j@4Y;AD]HCDm?Bd<n
?Cm6DUeIC40o@T0ooSeA?d53@Clh=3i:@c8g>C/m?3Xf=3]2?c<_=CLa:Bhe>cdk
=c@j>CTh>3Ti>TQ7AD8o@495>cPf>3`m>C@e<c0`<SPn@Se1Ad]8@3L`<2l^;2XX
9ohVERLY:R`];BhZ92@WnWQXKeaRFEeRHF1NGf=ZKfiZI61OH65RGeeTLWI`LWYb
IUeOIfQMDFAIE5QFCe9KKFYWIFIYKG1XJgZ<SG]/JEQOJG9gMW9^K6i`L_ecOf9/
MWQcKFa^HW1oQH5jN7UdJVYeNgQjPFilS96<QXJ8Q7miLFITMH^/YHB3]/RSQW^7
VIQcAcY6ADM:BdY8A492CEE??cDg?CLl@D=5AClg?T=3?Ca3AdIKHVilQGmXDU5H
KG]iOH>0R9FV/kVl`<;8bLNn/jf^/[Zo`/6o_;J_N[Bb/kRl_/?8alG0^kNe];Bo
/ZJW/[N^Xi2JYJRQV9>AU::GTJ2GR9:5Ogn5OfiUIfQOH6a^IVMbFF9WKGj9NEf3
OganPH9lMWalP8ZEUi6:ZJ6JVIbQZK2]ZJFSXZ2KUijOSJ:=[hfAPXB7RXn?Qgeb
JfUZGTe>GFUWI?aS>DQ7AdQ:CU5C?S`h=CPm?S]2@3lm?T54ASi5@cPf@DM5?3Y0
BT]5BeQ=Cdm;@chm?dIBGEU<@3m2@3on?E4o@D=1?cPd?TY3<SLi>cdl>SHd>d8o
<ble=c4Y;SDk?C/g=3Xi>CPh>CTjB4M5@Sm0@TDk>3Hh?3di=3Dc<30b>3i2?D57
BdQ0=c0`;bh/:RPWoRIF9bTZ;2d];RXT92OjN6Q_G69IGF9QH5iOHfY_KVYTH5mP
HF9OGFAbMW1bNW9VGEmWJ5eAI5UDF5I?DU]]JVMUIVU]L6Q[NXb=NfaYF5mYLWMf
LVi/KW1boG=oHVafN7=]K6iRL7n5PGYhNGAZJWEkN7Z1KWb<THb6QXR4OgUaIVAe
RjbUQ8>fb:>6NhNIV7=7>TI5AdY;BTQ4@T9=EDlo=CLm=ca1@dE5?cLn@d<m?4=7
AU]RKWb5OfQBDEQ]NgUmPh28UJJc^Kc0`/S9akjc[Jjb^[o2`Knl]Zmj];:c^;bn
`lS7aL2k]kFd];nbYZNb]jjST9ZUZ:6HTi6DXYNAX9N8TXEoOhEoKVEWJ5mPK6iV
Ig9IHVM]OXUiGH=oO7j1PWafO7b0RYFGTHZYXIZIW:6Y/:fYYJ>RX9^GWYn=XXf_
SI62Q8N:Shn7OG9[JFYNCDiMJFMTo6<iB4M7B4Y>DE<n?3Pe>3dn>d90?cdn@DA6
?TE3>3I1AdDl>T1:BdE;F4e?Cd]3?SdoAU9MFDa0?d90?ohmDCm1@d4o>3@nBT<b
=cTk?C`j=S@k@Slc;cDg<BT^=C/m>cLd>STi>3Pi>CY8AdE2?d12AC/h=SPl?CTd
=C<`<38h?T8m@DM;B40g<30_;R`Z:2On9PXW:BX/;Bd^:R@T9`G;Ooj3Lg5HGE9A
EUMKHFQ]Kg1^K6UUHVAWJfMRJ7MlMW=hIFMXIV9PHfIWG5MJF55BG7IdL6i^L7Ag
JFUdPh5^H5iGGFI^Lg=`KG1bMGQhMgEdM8B?QFmRJWQPKG]nMg9eNgIXHVY`KF]`
IWN:Ti6<SI27LVASHE]PKZVURXjj`9V2G9j/X797?4A:A4M:C4]6@Ci;AChk>c`k
>RL[=3do>cTj=cL`;3aCEDQiMGInPGAOD4YPLWn8PGQkUZ:b_L31`lG0`;ji/k6b
]KVj_/:o]Zj[]kVg]KJj_Kc2`;bg]?jb>[F`ZZRZZjVVUIfUZJBLU92AX9B;UHYm
RXj3OGigJVM]JFAUJfaXJFm_LGEmRXikI8EnMW9cMWQhIg>0oXQoRhnTXibETiZR
YZNSWj2RWiF=QHa_UXBIQHAmNgn8SHZ3OYnCQWYWDTQ9IFMZJVUXIfQKF59<AdA2
@S`d<3@j>cTg<c@f>Ce2ATPhADY1?454@C`j@4Y;AD]HBd]7?cLe>Ci<CeAHETi2
>CLl@dU<BTI3>T=5?3Y2@ce0?CTf=CHA>3Y7@cPa>4<l:b``=CTh=2l[oS/7>STh
=SDo?C[m>@Ph>3Hf>Shn>CCn:gl]<CLm@B/_=S/l>38]<S8`;R`[:BP];B`Z:BLV
9RTT7b<]oX=cLEQMDU5FEe]QJ6e_L6i/JFERI6M[If9XMgafLgQUIfQVHV1SIVML
EeYHDE9LMWA`KVi`M7MYJGB3PFiPGUMMIVicLg1]L79eN7QgMGAdQ8n5Kf9ZN61]
NgigLWieNgIXHVY`KF]`IWN:Ti6<SI27LVASHE]PKZVURXjj`9V2WZbPLTLlA4Y4
AdY<BdI1?T]5?S/k?3/j9b/d?Clk>CXg=c0/?5=EB7UeMWj1M5m@BV1bOhR1N7^F
X[:m`<73aL30_[Vc/K:e^KZn`[nf[Z^g^KNe][Zm_<;0_;Ndo[8j]K2ZZ:Z[ZJJE
WJFYY9bDT96PU8^ERWf:SX=mOWMZIfeYI6E[K6QYKfmaMGf:SW]TQGifLW=fN7QW
Lh3nR7n;SjBSW9FCVZ:VYj>OX::OUHf5S6nFQ9V5Q7ekOhR=RX=nWi>6NVMBB4UU
IfYZJFQWJ5]HDTa7A492?3@`=3Xk>CLc=3Hi?D96B3Q5BT4l@DA1?3Y0BT]5BeQ;
BdLo=cDi?Ta?E5QFCT8i=ca3BDa:AT<j@dDl>T93?D0m>CHe=Q4h>TM3>34h@c`[
;30e>CPd;b_n>`Lj>CPf=Clm>_di23Ph=SHj?Shi=?h[Obda=ce1:blf>c`h<Rdb
<S0^;2/Y:2d];2XY9bHV:B@O8bgnPg=aF5eBDEIGFf5XKFm`KVaYIF9TIf]WHVQg
O7IcN6EWJ6IRH6=VIeaGFUQADUafM71^KW1dMfUYM8>1KV1NEeeVKW=cL6e`LWEh
N7MeM7B4ShE_HVYhH6ekOWMbOWEkMVQRJW1]Jg1VMhZCTHb=T8MbI6=QFf1^ZJF:
S[[0VH:N[:1bAca4BTA7BTa;AT4nBdDn>c/l>cXW:c@m?c/i>SLg<2`lDeE8NGEf
OX5dGe1:H79oR85hNiJR/[g0`L?5`<2n^K>a/[Fi^[k2_kJ^ZkNi]kFf^[fl`/2l
]kCn/SZe/:ZXZZ^YYYFMYJVTW9B@TJ2DRiF:OHZ>PgenMfYWKFUTIF]/J6U_Kg5e
OHZ>NfB5OWIbLgIhN6McP?j8Oh^?Y:>LUI>JXZJWXinPXYnESHF<KiJ4VHF4OG]o
R8f:PgjOThIjIe98BFEWJVYYJ6MXFeQBC4M4@T8l=30d>S/i=c<d=STm@TI8>4E:
@Ca1A44l>T1:BdE;F4];Aclg=CTnC4mDF5I>@STg?4=9C4Y6@cY3AC`j@T<m@3di
=SDf4CPjAd<h<CQ3?2//<3Di>3@_:ohk1cXi>3He?cdjoCT8>3Pf=SXn?STdoR/Q
;C4g?D4[;cHk?3Pb;C8b<2h/:bTX;Bd/:RTW9RHY91lS;@G>OonBPg]LHUE@Bda@
FVI]KVaWJ6QUHVA[LFUQHg1fKfY]GfM]J5iKI6mRF5ILGEUNJ75`Kfi^L79cRGee
MgA]L7Z6OgA/K7=mQ7AgNgemNgMeJWV4OFi^PIEWM7ijJf9UKGm]HfYaKV]^JGJ7
TiNDT8jFMfA]LVMRJ9fQSXn[YXZ4EiJNRELh?4A0?D15AdE0>CA>@3<b>T4n>2`/
<S/h;Rhg?3dc<4Y^Lf6BQ7]mN6A>@d9YNH:CQGJ6VjRha<W:cLnm_;Zh]kRi^[jj
_LK3]k2b]kfl];>h]k3m/gnf^Kbn`Kbe[j^WY:6h/:NTYj^/ZYZ[XYRPThJET8=k
NgEZJG5[JVY[JVUYJW5`LWQoOg=VLgAbKVY/MWiXMhR=R8J<U9FKVHf8TIRIUI:C
W:FUVi1jR62FQHb5OXIoPHjET8^=UHEcJVQREdmKHVQZIV9RHeUHEU=@CDY9ACL`
>7ln>C8`=3Lk@4E:CDlf@TLo?D=3?Cdi?4A3?dIEDT]0=c@g>ci0@TQBFeU=@S<i
@DQ:Ad4l>TQ<@Sa1ATA6@CXe<cDj?DY4>CE2CT8/<C<f=cHb;R/h>3Tj>3Hc<Cdi
=SLj>SHb=cHh?D91>cDb<2l^;Bl`<B@W;30b<Bl^:BX[;Gl_<C8c<C0^:bPU8b8_
9QhO9_nBPg]LHUE@Bda@FVI]KVaWJ6QUHVA[LFUQHg1fKfY]GfM]J5iKI6mRF5IL
GEUNJ75`Kfi^L79cRGeeMgA]L7Z6OgA/K7=mQ7AgNgemNgMeJWV4OFi^PIEWM7ij
Jf9UKGm]HfYaKV]^JGJ7TiNDT6R>UWMTKG9WHVRMXHj?ZjJ:Q9JNRELh?4A0?D15
AdE0>CA>@3<b>T4n>2`/<S/h;Rhg?3dc<4Y^Lf6BQ7]mN6A>@d9YNH:CQGJ6VjRh
a<W:cLnm_;Zh]kRi^[jj_LK3]k2b]kfl];>h]k3m/gnf^Kbn`Kbe[j^WY:6h/:NT
Yj^/ZYZ[XYRPThJET8=kNgEZJG5[JVY[JVUYJW5`LWQoOg=VLgAbKVY/MWiXMhR=
R8J<U9FKVHf8TIRIUI:CW:FUVi1jR62FQHb5OXIoPHjET8^=UHEcJVQREdmKHVQZ
IV9RHeUHEU=@CDY9ACL`>7ln>C8`=3Lk@4E:CDlf@TLo?D=3?Cdi?4A3?dIEDT]0
=c@g>ci0@TQBFeU=@S<i@DQ:Ad4l>TQ<@Sa1ATA6@CXe<cDj?DY4>CE2CT8/<C<f
=cHb;R/h>3Tj>3Hc<Cdi=SLj>SHb=cHh?D91>cDb<2l^;Bl`<B@W;30b<Bl^:BX[
;Gl_<C8c<C0^:bPU8b8_9QhO9_nBPg]LHUE@Bda@FVI]KVaWJ6QUHVA[LFUQHg1f
KfY]GfM]J5iKI6mRF5ILGEUNJ75`Kfi^L79cRGeeMgA]L7Z6OgA/K7=mQ7AgNgem
NgMeJWV4OFi^PIEWM7ijJf9UKGm]HfYaKV]^JGJ7TiNDT6R>UWMTKG9WHVRMXHj?
ZjJ:Q9JNRELh?4A0?D15AdE0>CA>@3<b>T4n>2`/<S/h;Rhg?3dc<4Y^Lf6BQ7]m
N6A>@d9YNH:CQGJ6VjRha<W:cLnm_;Zh]kRi^[jj_LK3]k2b]kfl];>h]k3m/gnf
^Kbn`Kbe[j^WY:6h/:NTYj^/ZYZ[XYRPThJET8=kNgEZJG5[JVY[JVUYJW5`LWQo
Og=VLgAbKVY/MWiXMhR=R8J<U9FKVHf8TIRIUI:CW:FUVi1jR62FQHb5OXIoPHjE
T8^=UHEcJVQREdmKHVQZIV9RHeUHEU=@CDY9ACL`>7ln>C8`=3Lk@4E:CDlf@TLo
?D=3?Cdi?4A3?dIEDT]0=c@g>ci0@TQBFeU=@S<i@DQ:Ad4l>TQ<@Sa1ATA6@CXe
<cDj?DY4>CE2CT8/<C<f=cHb;R/h>3Tj>3Hc<Cdi=SLj>SHb=cHh?D91>cDb<2l^
;Bl`<B@W;30b<Bl^:BX[;A0_<C8c<C0^:bPU8b8_9QhO9PG;<onERGeMIEUBEE1=
Df1[KfmUJFaZIf]dOG1THFabJfEWIVMVHEaKGfAWGEYPHEaQJfIXJfgnKWm]SWic
LW5_N8NGS7aaKgN5SWMjOX61OWUfKVaYIf]gR9AYNXR4LVEUK89^Hf]eMG=eJW5m
RY6>PWVGNFalP71YLYZSU8ZDRX6DQg9KCD<l?TDl@4E7AClg<DQ3?C`n?S/hDDaA
F595BEQ2CDU1EWj=PHimMWagGdLo>FejOIB7OGnPZ;C2blg<c<k4`Kjm_[no_/2h
^/C3]K6h/;^n]KBj]ZVb/[>e^Kk2aLVk[:Z`/JJJYiN8RYJNVI2I[ZZSZYfAXHV0
O81jKFU^KW1^JfUYJ6EVI6EYJfYZJf]iQ81bJW5kNH28SHf;RHR8UiZ>RYFLVI6>
T9bXZIb?R9YWYiB>Se23THB4TiZEU9^7LUaIJGA[FeIOJF]UGeeNBDa@DeABD4i8
=S0nB44h>3do@dI:C4e=A4Q4?3m;CTQ6?cm3@Si7Ef1@?SHi@491=Ci:DUABCTcn
@A50?cdk>TA:BD94C4]1A490?C_n>@I1ATA1Adi6oSH1=cOm>70j?3ho?S`h=T@o
>ce2@cdf>3Lj@4E5?SLi=c@`;BXY:2h^;Bd^;c4a9RHX:R`];c0^;B`Z:BLV9CL_
:RlioiF9OEeUFE9ED4eCH6]_KfEYK6YWJgAmL6AQK79[IFMVIfIQG5]OI6MMFV1Q
G65[IVQ[KOi^Off>OW=bLFmhQiN<O75_MhF>MgYnPH5nNGI^K6UWJgN8U6UjR8Ab
IFE/PViSJgEeLgEZLGf:THj2NIMiK7b0L6UbVZ>DRYB:PIB7LU]=@c`nACa0ADM5
?cLaB4<m?3hn>cQAC55HDTE9F49=BD5FOXf1SWefO7MOAcliKGYmU8MmOj2X]<;;
cLc<c/C1_[fn_knn`;Rja<>e/KR`^kje];ZfZK:b/kFi_/;5bK^/Z[2aYYZWUhR:
UYjIT9V^ZZ>ZWI6QRH1lP7Y]JFi^L6i[JFUXIFITIFU[JVY[JgV4P79ZLG]iP8R=
SH^9R8RGVXj:UIbITHj@W:RYW8n8VVNWU8j?D8>AQ8BCVYFDVhMbG5UYM6]KEUmY
JfEOGEi9C51CE59@CTPf<3i8@CPh?Cm3ATY<CDe4B4@l?d]>B4Ho?d=2?TMGH50n
=SU0@T4e?TYBE59>C?i14D0o?C/jA4Y9@TA<Bd54@T0m>ohi1T56A457CTKn=P4g
=odhL3Xl?Sln?3PfA3lk?D93?CHh=cY0ADDn=cTg=30]:RTX;Rh];Bh_<C4V9RPZ
;2d_<2h];2XY9bHU=blZ;cWoUHUmGFEIDUE@CE=PJfm_IFU/JVM[M7e`I65/LV]U
IfIWIV5LFemTIeeJH65LHF]VJ6]]oVioKHinLg9aKgR7UhalLFmgQHigNWj1PGii
MVi/JFM[MhRDJGZ8Q79UIFb2KV=[MGEcMFYaOHZASX9iUgU/O81`JG:JXiB:U8Z1
U8MbFde3?3i5?415AdDo=c58@cdl?Shk>55<DEQBADUH@Te9@EInSH6>OGIlMem7
?cU]NWfDQgeoX:Rd`/_=c<c>a<6n_Kjo_kk0^;[4`kFa^;2k_[Fd^[JY/[:c]KVn
`/G9^jbZ/;6VVZNGR8ZFWYV@VJjZXjZMTJ69P7b0NVeYKVi`KV]YJFQUIVAUJF]Z
JV][NHB0LVYaNgV0R8f=RhV8R9NJSXZEW9VASY2LZ:VLShRJIjNDSXm@Pi64Q9>J
UIBKQg9LFFUdJe]FGfU[IEmMGTU<D5=DDU1>B3H`?TQ1>3Pm?d=6BTa=CDA8A3`o
Bdi8ASlo@d8nAeMPD3hf>D12@CDnBU9DDTi<oT4A@3lm>cY4BTU2A4a;@DA2@3dk
oST6@DI4@DM>A_hf0CLgoCPl>S`n?chl>3I4?c/m@T<m=SPg>T15AChg>CLd<2dZ
:BP^;Rd];Rla<BHV:2X/;Bl`;Rd/:RTW9RDg;bX_>@G8OoV>QGUII5UAJ5eBDUi/
M7MZL7AcLGF0RWY/IFicKFQYL6MLFE]LFEAdJF=UHEUJHf9UJVmaL6i/JV9SJfaU
IVidLVi]KW=hNgQlPHB3OgYfUgmTFF1YJFELLHN8NF]ZL7APE5m/KVe_IfU`O8F1
L620J6AgMf=NKYn[VhR6Nh:WOjU^C5QE>3A>@TI;CT]4>cI0B4i<@STf=c@]<C/f
:S96=diA@deeSH]iJf]kNfA=AS=]MgJ@QhFf^/?=dLg7`l;=bLC2`lC2`;fb/knn
/:jiZKRm]KFm]jRl^kZj^kfo`KZRSYBZ/j:=YibGY;NhXhb2Vi^GWi>8VH1kOXJ1
LFMYOg5cLF]XJFMRIfEVJFQYLGeZP9B>MF9QJGehMgf5PgM[Q9RPUY>PZ:BIUIFO
ZJNGQY2SJZjIRhn0RGYhQhn:S9N`TW1UM7i^E5QSKVmXH5iODeAEDTa1=c11;Ra1
DDe7BSPi>cdn?C`kEU=7?4=FGEQBBTI9AT=>Gf]F?cLoBDY5GcE6EUM;@TE=EDm5
?3Lg>ce?Bd8oC5U??3m2ADI3?SLc=dMABdM:B44h=cLh>cm3AD54AdU9AT90@C`h
>d51>S8h>3a2B4M0>CPg=C8`;B/Z<BhY9B@U:2X/:bXX9R@S8_dYoBYo;bhgCV_i
SXEiFFAIDFQMDU9NK7AgJW1dLg5eP8YjK6E^LfeXJG1WG5UKG5UDM6USIF5IFV=R
IFY_LG1^K6YRHf]/IFI^M79^KFicN7]hO864PgmjMYMoI5UPJFUUG767R7U[JW1d
H5AOK6i]KfMYL7b5PG1PP6QTMgMSGVjOZi]oR8IkPZNYKTaHECPdCT96Bdi;A3/f
@4Q>C48i=SLd;C4k=RXbASM>DD==MHf;NF][Ng]TCDHcKGMfT8N5][[3cM7=al?2
cLW4`/?4`/2m/[>o_[2^^JVh_KFe_KNX_;^j^[^m_l6jXXjDZ[>RSJNLUjBg^:><
PY^KUinCR9V0NgioQX5aIfUaLg5[J6UWHVMUIVUXJG5mJX2DSWERHFUmN7MmQH=g
JhBHX9JCX:RTVIFEWjVWUhJ@XfZ^VH^?P8UjN8N?RXbG/99`IGAnKUAHHfi_J61N
Ge=DEE9<@CL`@Bh/@E5=AdXh>C/m?Sdl>eICAca3EUeHDTY6BDI3CUm[ESmT=cm9
BTDeAUIGBd95CEE?AC`g=c/mCd]2?daICc`o@TE6@chg<cM7DD]7BTQ1>3Lg>3/o
@dE1A4M9BDI2@44l>3]1@CXb>3Pl@TQ7@3Th=cDb<2d[:S4^:BDT9BPZ;2/Z:2HT
8b;m:OdZObl^=di[nHj5NEUTFE5XGE9BGVadMfY`M7=aMH2:NVaUKW=]J6U`IeaI
FeaIE7AYHfEQFEYSHVEZKg5`KVaZHV=[K6EVKWAbKVe^LgQkN7b1Q8=oNWJGOfAI
H6UYIEaaQhQiJfY`M61DGfa^KFmWJG1lQH5`H81XI7MgHei^Wj^KOhR6Nh:WZFi<
F5Dh=4i2AT]>Bd@k=T18CTa2>CHg=2da>cHZ<THgCU53CGF=RgU[Jg]kI4e6<feg
MY27QKJj`lgAcLO3`/g9a<;3a<;0_K:c_kj`[[VY^;fe]KfgZ;bk^[Zk_Ko1^Z:>
U:ZcXXfWW9NT]kRSS8:KViNOThRIP7]nOhJ1LFMYLG=aJfQYIf9WIFIYJ6UaOFZ0
U8ieHV5YOGQgOHF3Mf^4V:2FTj2XY9VEUInYYiN6T:=Z[YV;Sh29NWR7ShZ<Uk2B
L6EdOViDF6=^KfQPGUmCE5EBC44g<44^;45ACDM:>3Tk?Chm?3]FDdLl@eIMF59:
ATU6@diOJeHoI3LoBDY5=DIFEd]2ADeECdDl=cLk?Dm;@Sm<FDll?d95AT<n=c<g
Ae5;AdY8@CPg=cPk?d=5@DA7BDU6@T11?3Pk@D4j<SPh?498Ad0i>3Le<S0]:bXa
;RTU92DX:R`[:RPV92<RoBWm:P@_;SM>J`F]OoeoL7AOIE]MEU1>E69/KfiKIgIk
N7AdMg5/IfQ[IeaAFe]SKFULFV5jL6=MH6I[KFYWIVU^LFm[J6N4Y8iLG8F1KV=V
I5eVN6AbNWMfMVeNLFm`KfMVO9R:RhEeIF5ZMWQdKf]XJF]/GfN7Sg5YLVUFG5iP
K7QdIJnfLdAfVXMnBTI<EEUFCD@n=3eU@EXeAc4o?DE@CCX^;CU@AS4a:28d>B]0
G61/MVN0LgF8TGmRCdQ=DU]aSIjQ^;o8c<_9blg5c<Zo_<6o]kNo`?jlOk2N[[W2
_kB^/kbl^k^j^KRg]ljO/<JOTjZXX9jOY:Z]ZZFBY9J1P7Z0X8Z=SXZ2NWIdXG5]
HFagDeUcJF5TJViaLhJIUGQ_OX1`O863OWQkRIJBWjRPT8^GYY>MUXN>Xin9Eg9^
W7^?IFFCNgJ@Yj:BRVefMf^1DWQMIfi]HE]KOe=7=dYNHUM>Ce@g>3Xm@4=5AT0n
?TA;BSle?dY:?ca:F5eQDCdf?4E9BB/e@44k=cY0A4eFE4Xo>c/dATi3>3a4ASTm
?3]5DD`n;2ld>C/k>CPc=CPj>SLd<CM1?c0/=C8U=CU0ATU7@d4Y<3a4AT4i<cdg
<S4c=C<`?2`R:2d]2C8k<C4`<2l^;Bgi9?PYOahgMZ7mOg1dGfEKGEI@CUARK6m^
FfMfNgQdM7MaK6MXJfMLDE]KHfeYG5YQNW1SGF1VJfeZIfIYKW5_JfQWQ:B>G5b5
PFiSIVAMIWQTLWYgMWI]GW5_L6mWIWbHRX^5MFEQJWIhM6m[J6U[K5mWQhmaJG9Y
EUaNH6ahM6F_]W=4CWJJQgi6C5EIETe4?S@mID5J=DLa?ce5D4dj;RdiD4Ha<BPR
=3T[@5aPK7IWP7=eR95oHTm8CE9KLHfNXKRob<c;bL_=aLc:_kc1_kNg_l3n_7n`
WZji`[nd[[>l_;^k^[Vh]kO>Wk36Wi>ZZ:2NWjBZ[JZUTZBFPH1jP:2:SHj:PWYf
M:5aKF5/Me=ILfUQI6Y^LG>6VIEhKgj0L7b1PgihNhVFTYnXX92;UjJCWIJ7SZ>O
REMbKYakSfEUTg]fT:NRTXY]MWM[PE9hGFM^KF5KFgmCAcM:GV9GCTmD=cPj?D13
ADI0?Si4BdXo=Cm:BSllBUQMHE4m=Sa5BDT[=D11>cLj@4A=EUA:?c/k=4I>@cPl
A4Hi?C`kAE5<?R`_=3Tk>cTh<cDh>SXg=34g@Cl`;3Db9CDi@4I9Ad=1:C0lA4I1
>C<m=c8a<cDc<3`/8RP];@Tb>c4a<30_;Rd]nBCh:GlN=gJQoGm`M5mUFeeFD4iD
HVa_KU]WMW]hM7AgLFaWJ6]WG55KFf=]JEaJHGY`HeePIV]]JVMVJFiaKf]XIhBT
SUaLQH5^HfITGFIhI79jMgIfKEiaKg1_IfIlV8Z;QGEUHFYfN7A_JfQYJfaOIhN?
LFUbJEILGV1/N7AU[kIcA4ifVXMnATaEFEI=A3hd?FE1FSE7<ClmAE1=>Rh]>E16
<C4X8S@i:d1LH6afIh1cMHRAOf9?B4eBFg6=WZ6h_lS<blW;cLG<b[nl`Kng]ko0
o[ao/9j^^L:o]:jc_;bk^kZi^;NgcYn`aYnCZZRPWYnTZZfZYI:TUX60NX2PRXf>
RX9jMWBQLFeQK7MCFG=YHFAZKW5cQYVEN6mnP71lPH=nN7^9UY:OZ:2@RiNVTifF
QhjSWhUGLVjLNhmUII=kMY2WXY::KGIgJh5BN5eWKVeQFe]oDdLgBUiREdi?E3Lh
>Se0@dE6@3hnA4]:?cDoBTXo?4YHGF5A?CHlADU9:cE0@C/g>T14CEIDBSlk>cA6
CT<h?4A6>Cdl>dEAC3h/;c@i>c/i>3<e>3Xj=c@a=d4o<2`e<RDe>D16BDM3@BT`
?4A6@CTc?CLb<C<e<c0l;28X;Bd9<S/a<C0`;bh];OTTn2T37SMfX@F`OoenKFmJ
HUYLF5YLGemLF5AIHVa_K6QYK75/J6QZIeeDFEMMIF1DDeaUGEIFGFE[K7E`JVY/
KFYWNG1oUX5CD71eJ6=ZJF9VLfmjOWQeMViPFUi[MW1SHfiKHVQXI6I`NGeiM6m/
K6i_KF^2R71^NFmXK6]WKGA]GYBAKU]mVHj0Oe5ADU=ABChe@C]<8S`]Bd1BBTU>
BC/e>CmBB3U0>353D4a/QGM`LVAcK721QG9JCE5RO8nDTiRP]Ko<d]3:a/Bna/Jn
_/K6_[k4a;k0`kZZ[kW2_kF`]Kg8alO6aLC3`lVSXK>YW:2RYjFTYj^/Yj:JYiV?
VYB<WYNGTH=aIFAWOi9cOViYKE=VJgE^FEAWN7]ULfmLGgEjJhV2OH29SX^6W:2S
XYnOXZJOX9ZCV:6MTGb<OYalSVmdLf9PN8^:PGn3PgQSM4I^EV=/K65KFU95>D5>
Ff9NDTPf=cTl?Clo@5A<@cm0?cXd>dE5>CI3Ce9;BDU;C4U1>cPnA4M6A4E7Eca1
AD4j=SPm?TiDAc`nA4E4AT<l@4M0<34d>Cdo?cdl?T12@d4n>SPd?T0g>DE7?Ci0
@T=2@3djA40k=cDf>3Xc;bd`=CPf<T8b:2//9RH];bl^;B`/:b[i9oTYObdO<FB6
oGi]KeYRFUaHFUaOGeaHE5URK6m/J6U/LFaXJ6YWGEAIEeeUH5ACG6EMEUIMIF]/
MG1ZJVa]JVMiL7nFPE=@L7EXHfYYHVIcKgYnN7EfKV1JGV]fL6=SKU]RJ6QTIW1i
OGUdKfa/KVm]Jh:8L6iiKfQ/JfM]M6eNU95^Oe]mVHj0DE5BDe59?SE1>d`R?2e;
@59:BDi9>cDi?e98>D0h<D=@C6b5Mg1bI7=/L865LUY=DF9lSiBCV:2e_lcBd<[6
a;k6a[jna/Jn_/C4_/33^ZZ_^L:o]K2e_LS7alK5a<?3bJ>Q/jVLX::WYJBWZjbW
XYZWVHnJU8bNUiNAOh=aIFAWTW=nKVU]DfI[MFiIE6MhNfEcKeaOMGY[RH9mP8V>
RhJLX:>RWinRYYnPVY>HXIfAO8anW7b>KgAcHV1hRhZ1Oh>3N6=dAViFHfa/HE]J
DTDi@DiKHUiBB3Hg>C`m?cm0E4a3?d0o>S@kADDi=T=?DT]9BD]<BD4k>3i4G4M6
A4E7?455@CXf>3dnCUA7?3i4ADA6@ca0Ad0`<C@i?Clo?C`n@493@Chj>3@n@3Li
ADLm?T12@d90?CY4@3/g=CHh>S<_;C0e>3Hb@S8X:b`V9Rd_;bh];2`[:_TWnBUo
;AlaI8KmOVe_FV9JG5QJG5mOG5QDFF9/KfaXJFaaK6QXJVMME5UGGFEPE5=LIEeF
EUeUJfaeL6YZK6eZIgU`OiJ1De1`MFQSJVURIW=_NWihMGI^H5YNJgI`Hf=^Ff9X
J6AVL7UmNGA_K6a^Kfe[PXQ`KWU_J6a[IfedKEjDTFioFgfISX1ADE9CDDTn=D4k
C28l;D]0DTY9CTTk=CToDTPi@3Pa@e1<K8EgL79TLfa`PHEbFTeAHWb?U9>HX;Fo
c=;@b/K4_/K6_[k6a[jna<Bn`<>jZZni`[ne/;Fmb<O7a/G4`l?9Xj6cZIbPXZNU
Y:N[[:NRVZNISiZDS9jGUi5oPg5UI6NBLgi^JFeCIV]eKUUDIgQkIG=_G5meNV^9
PWf0RHj;QYbPXj:OWj:VWj2JTiRQWI5lS7jLO8i_M7=RH7R;RX5oPh=hHgA6KUIS
K6aQFeYBACU1CU]RGU98=SLi?3do?d1DC4<o@3lj=3]5ACTf@dmBBdU9Bda9@C/h
?TALAdI4ADLl@DE1>SHh?Ci>E4Ll?TA5A4I3?417@30a=3Tm?clm?3i0@T=1?SXh
=3i0=cU5Acdn@493@T0m>TA0>cLe=SPj<bl]<3Dh=S92<RP[;2HV;Bl_;Rd/;2/Z
nBOi:@@]7c5TQPF`OoelJVYEGUQLF6A_Kf=FD51EFf5SI6I[L7=_K6][J65JJFEW
K6MLGFQVHUmRJFmaKg1ZHf9VJVYXMfQ]PGeTI7]_JF]cMG1bNFafNWIhP81gIFIb
PH1`IFEKHVU]JfYZK75_K6]/Kg=fNVejPG5fP75eN7A[JVeUEjRAT9RGWY^2Oe5:
ADI:BClfEde@<T];HeQBACm0?SLkAD1;?34j;b<bL6N0SG1OIV9THfaiMF1@C5MZ
SZVPRHfU]/;@e];9`Kfh`L>n`<[<aL74`KZmaL6e/K[1_kRc]kk5a<C3`/70`<:^
UYneYI2LZ:FSYJRWXYbMZ9^I[JJBUi:FUXYjMX6>OhQlUhA`KEeoG7IjH5=SM7IQ
J65HIH24MHYlM8BOZ9N1Ti2?UIjSWiVXW9NMWYJBU9BFP8U^O6acMFi`P8f?TIMf
LF5:HCYZEUmYJV5KFU13?cTmDFQZE3`h>CXl?3/i>4e:AdI6@c/d?dM5>CI1BTXn
ATmBCD@m>TE4ADY?DDi;EdQ:BDE1@TU?AeEHBd12ADACEe=:Bdm8>SXl?d94A4=3
?3dm?3Te<RlY<C@a=Cm2?DQ5@Cdi=cDe@cli=38d=cTW9bX`>3Xf<C`^9b`]9B8W
;2`[:RTX:2Oi:_TXOb`N9deXoGaZJUENF5aHI6m_HeI@D5EKHF=TIV]`Lfm/Jf]X
HEYYIFM/IeaMJ6IRGf9YKg5_L6YSHVIZJVQgJ6f1OFATNfmYJg=eL79iK7IjMWR0
P7MUIW:1P71UIE]RJFe[JVY/LFm/Jfa_LgIjKGZ1LGJ0LGEhM6]ZKFEGZ96@OiRG
WY^2DDY5ATY9?cIGCE0bBd]SF595?d0n=c]5@4/l<CX_8c9`Ih2=L5mVHVASK7Ue
H51<EfZ>ZJ29SJFf`]3Fd/W1_KS1`kk0b/c5`LC1^[g5`KFa^/6o^;>g_/G4a<?2
`L30`ZjFWkFUT9bXYJ>UZ:NRW9fXViV]YY:GTYJFOhYjMX6>R7bGQ71]GGmLMWYP
Df=dMV5XHEQUP8AeRWadQ9nXUh6CT8nEWZ>OVJRLUifNUY:DU9J0RFilK7=eKW20
SHnAUgIaHDYQ>VYFGfUZHE]JD4<o>CeAJ6YD?3Pi>S`l>cThCDY7ATI3>c@oAdDi
=T5:BSi6Ce9=A3djADA5G4Y?DDi;B4Y9AD52BDm7EEQ;@495A5=GDdY;CdPj>S`o
@TA4@d<l?Cdl>CDb;bTa=34e?d8mB4E1?CTg=CE3?cTd<S@g>BLW:S0h>SHa?2hW
;2dU8RL/;2/Z:BPX9oTZnBQo;1hWCFSmO6YZEEiHG5QTKfmSEU1@EE]QHfAVJg1c
Kfa[JfQQFVUUIfaWG5eXIV9OHVU_LFm`JV=RIVYZJ7MXKH5mI6AkKfU[LgE`LWU/
MWYfN820MfEVLX60L6EUFf9YKF]ZJVaaKfa[K6mcMWY]NX5aMX1aMGQdJfY]IENX
TI1oV9NNVh9ABTE6BTTo=UM=D39;Bf=HDTDo@3hg>dE0Bc`a>RlS<W1WP8e`GfIR
I6=/NGEPD4aGJXjYX8V=YKK2d=KBbL6m^<73_/3:c<G1a<6j_LG1]K6j`Knh/kNn
aLC4`l;1`<32[YJO]JF@W:RUXjFXYj:LWJRKVJfVTYNBUYIoRWYfPHj8O9N4L6eM
OeafNV1CHgAfHFQQF6F0Q7F:O7B4WjRGPI>@SiFNXinIZ9bGWIjFTYBDUX29KWa/
LgE^L82=Si6GMW5QBV4jJUIOJFYQFeY@@cli?E5XJU@l>3Tj?3`k>CQ=BTM6AT<k
=3m7ACTf@DY:?TI?DTe4?CY5A4ELBTmACT]8BTU5@D99CdMEF4]0@TE4DeMCBT]?
B3Xj?3m2A4A3@c`m?C`i=C8_:C4d<CDo@Se8AD4m>CLe=D<o>C@b=3Li9bLZ<3Pj
=S4l;RL/;BDR9b`/:bXY:2PWnB[i:0@/7RM=J0FZOoelJFUDGEQMEFQjNVYOHFYF
F5]OIFefO7MeLW1_K6QUM6i^LF]QIG5_K6Y/L71/If1KEeURJg1aPg1YMWadM7ie
LgAiOX66S7b2P7MeOGefNg5`NWigLWEYJFY/KVaYIUeMGV5WKgMkRWV3ShN=T7Ua
MgAYIf]VFhiULh9NDE4aGD8i<cQ4BTI09b/c;d54@2]9?S]0@Sm5DCY1=SM<Ad9H
UgEcN5mGJFmLH6]cJ59:CeaTPjBQSYZl_lO?dLc5`;nk`lFo`L_<aKfo^K6f`L:i
/k[0`;^h^ko1`<2o_[gn_7o0Wi^kY8BMXIjMXJFVXYfMZYfGYI^:U8RDWIV>S9VX
OWJFQW9^Gh9MIW=gKF9TKG=aJ6AfSXioP7EeS:ZdXHZ7Qh^CW9nKUJNDTZ2MR8>A
V9>2O6a_JViPHFE[Kg=lQ7QbHDaU?faDGFMXGeYJDDA9?c]:GV=A?3`m?d0o?3Pf
;c/hAe=GDDDlBDm;@3i8CDU1AdY4>cPoAdU2?T==DD]4E5ACDDm>D595DUE9@TM9
ATaCDda<DTm4@T=5ATOnB3Lm?3Xg=30]:bX];Rd^<S<aB4<l=C4a<cDV;3Dl?SXe
<2@U:C8i>C8/;B8P:c0[:2`Z:BPX9bHU9OTYn2Mo6QljD?elJFUDGEQMEFQjNVYO
HFYFF5]OIFefO7MeLW1_K6QUM6i^LF]QIG5_K6Y/L71/If1KEeURJg1aPg1YMWad
M7ieLgAiOX66S7b2P7MeOGefNg5`NWigLWEYJFY/KVaYIUeMGV5WKgMkRWV3ShN=
T7UaMgAYIf]VFhiULh9QGU5A<D8i<cQ4BTI09b/c;d54@2]9?S]0@Sm5DCY1=SM<
Ad9HUgEcN5mGJFmLH6]cJ59:CeaTPjBQSYZl_lO?dLc5`;nk`lFo`L_<aKfo^K6f
`L:i/k[0`;^h^ko1`<2o_[gn_7o0Wi^kY8BMXIjMXJFVXYfMZYfGYI^:U8RDWIV>
S9VXOWJFQW9^Gh9MIW=gKF9TKG=aJ6AfSXioP7EeS:ZdXHZ7Qh^CW9nKUJNDTZ2M
R8>AV9>2O6a_JViPHFE[Kg=lQ7QbHDaU?faDGFMXGeYJDDA9?c]:GV=A?3`m?d0o
?3Pf;c/hAe=GDDDlBDm;@3i8CDU1AdY4>cPoAdU2?T==DD]4E5ACDDm>D595DUE9
@TM9ATaCDda<DTm4@T=5ATOnB3Lm?3Xg=30]:bX];Rd^<S<aB4<l=C4a<cDV;3Dl
?SXe<2@U:C8i>C8/;B8P:c0[:2`Z:BPX9bHU9OTYn2Mo6QljD?elJFUDGEQMEFQj
NVYOHFYFF5]OIFefO7MeLW1_K6QUM6i^LF]QIG5_K6Y/L71/If1KEeURJg1aPg1Y
MWadM7ieLgAiOX66S7b2P7MeOGefNg5`NWigLWEYJFY/KVaYIUeMGV5WKgMkRWV3
ShN=T7UaMgAYIf]VFhiULh9QGU5A<D8i<cQ4BTI09b/c;d54@2]9?S]0@Sm5DCY1
=SM<Ad9HUgEcN5mGJFmLH6]cJ59:CeaTPjBQSYZl_lO?dLc5`;nk`lFo`L_<aKfo
^K6f`L:i/k[0`;^h^ko1`<2o_[gn_7o0Wi^kY8BMXIjMXJFVXYfMZYfGYI^:U8RD
WIV>S9VXOWJFQW9^Gh9MIW=gKF9TKG=aJ6AfSXioP7EeS:ZdXHZ7Qh^CW9nKUJND
TZ2MR8>AV9>2O6a_JViPHFE[Kg=lQ7QbHDaU?faDGFMXGeYJDDA9?c]:GV=A?3`m
?d0o?3Pf;c/hAe=GDDDlBDm;@3i8CDU1AdY4>cPoAdU2?T==DD]4E5ACDDm>D595
DUE9@TM9ATaCDda<DTm4@T=5ATOnB3Lm?3Xg=30]:bX];Rd^<S<aB4<l=C4a<cDV
;3Dl?SXe<2@U:C8i>C8/;B8P:c0[:2`Z:BPX9bHU9OTYn2L36QljD0F]OomoK6eH
HE]NFVemNVURK7]RH5eNHfY`LgYiN7A`KVi_K6IVJFAKGf]THV9UJVYTGf=OG61X
L7=cW8QeLG9^I5eiN7AbN8JBV9RISgY_KFQNK69QK79]Jg1SG5QMJ75aKV1OGf5V
KGAhSWn>X9^OVWeZLgA/K7AfLJ=jQI1WF5/nOcdf<C@mA4A1B5IKJFegHDa;ADI?
CdM6CCU1?e5cNXJ]ZG=ULf]YMgQPHfeaHTa7D5=MOjRf[kO<c<g<al6oa<W3bl[1
`<O7_l31^[:fa<Jn][Zo`;nn_l77alK5a<C3`k[=]JNiWhFSX9nPYZfa[j^R/jJC
ThR5WXjJYZ>ERh^@OgEVPWM^KeahO5eLNgaNG7Q`JfEYO8j=PGimQ9BTYi^>Qi6N
Y:>QX:6UUIFSWHJ1SiB>S7inLWA`IFa_K6U]M7VBSGm]Q5IgEF1XIeeHFUE9DTa7
B4e?BdE0@dE7AD0k=c4iADiBDDm=CE5<@T=<CTHk@TM3>cLmA4Lo>C]3AT4j5dY;
C4e<AShh?dU<ADA<CdXlATLo>d0n=Oe7>dQ9BT]7AT8o>cTg=S<a<C@e<c@f?cXc
;R``=CTR9bhd=S@`;2PY;38h=RlW;B8P:c0[:2`X:2LW9RDT9?TUnBIo9A`L:cWo
Ofa]F65KGUY]OGYYHVakHV1MGV=ZL7=jNGQdL6i^KfaVIVUTFem[I69RIFYZI5mS
GeaPJ71cLib8MG5bKVAMNGQdLWR6TYRHVHmjKfeXGVaRHFabKF]`HeaHGFQaLFiP
GemQIVedN8ioSZ2KWiYmJW=dK6adMW6SNXEoT6MHFchm=S4d?DA4@DQFFfU]Mf5<
BdE6Cdm7ATdi@CmALgZ6[JUcIG=[JGMhH6=]LF9<Ae1CGGnX]Zngc<c=c<O1_lC9
`l_:`L37ako0`KZb]/C6_[Jj_l2o_[o1alO6aLC4`l>jcKFW^In5Xj2OX:J]/Jn[
X[>VTi>8QIj>VZIoXiF;Ri1eIX9gKVmLN7aMG7]lGUahL6]UJGb>SH5nOHBDY:NK
SXNAWZBSXJ2QYIFEXif6PHnDSXanOW9dL6E/KfaYKGAiTXeoKHAFMeEPJ6MMF5YE
BE9<AdQ=Cd]5@4=5AdE0>cLa>DE>DU5?CDeAC493C4i6>d97@c/g?DA7?cTL>d=6
@CY:Bda=C4Hn>3m9C4E4C4m:?4I7?c]0?SGmAc]8BDY;AdI2?c/i=cHc<C4d=C<d
=Slj<bh/<3Di8RL^=3Hd<2`X:B`b>3H_9bdR82/`:bP/:2PW9bHU92Ci9OTVObDL
72/iogm/KEQQFeiJKGejJF9/Nf9PGEiSJW1cNWUhM71^KVm/IVIYI5]OJfARHVEZ
JVAOHemLH6Q`Lg>LR7EaLViTGGUhM79hQY:HV9V?NVm]J5i/HV5/LVe[L6=LF5eX
LG5^H5mOHFI]M7R>OhjPVinJOFYcM6a/M7IaXgZ5Oi1WF5/n?CHa=3e4A458EU]Y
KGMQC4]5ATm?AdI=>D4oDG=jQZfYLfEcJfUgN61SKG5RC4M@DeeoZ;J_]lc<cLc7
`Ko4bL?;b/70alNo`<6j/[K4a[jf^[o0_kjo`LO7a/G4a<?3^/feYkVOQJ>PWj2V
[K6_Zj:cYY>CR8FNSYZVOj>ERh^@MFJ2Mfi_G7QlGEakO5iLN71[IFUlSXf1OWf4
U:BWVhj7TIjTXj6PXJFEUJ>MQX6?U8j<OWibM71UK6m/JFedNI:=Off4EWMEH6QW
GEQJEDUBC4M8CDm;AD13ADM5@3/g<CU5CU9ACde=DDa2@da>AS]2Ad<k=ce4Acli
73]3AT4jBT]<CDa6?SPoBDa5A4a?BSa6Aclk@3heoDLkB4U:BdM6@Slk>CLf<c4a
=3Dc=3Ho>S<^;30e>B8W;S@f=30/:2T/<SPf;bL]8R0[<2/X;2PX9bLV9B@TnBGi
9P@U71`[>@FQN?n3M7QSJEmPHg9mMfMNIg=bJf=OGf1OGGMhN7=]JfibJFEYKf]R
IG1NGEmWKgAcL7EaKW1dMG5]QWi`J6aaIUEbM6iVKH6AUH>8PgE_M75YGUeWMWM/
IfZ0LVEVL7E_IW=aKV][KW5dMV]oTX^=QfYZMWUbLWf4PV_nFUM:B4HaADA1?cdl
?Ch[>blo;dLc;DI1A4e9>S8eA4U3CVEVNZjGGeUhNG1_IfYYKVmPBdI>=EN8/<?3
_;O@c/W1^kg7cl[Ac/?0aL>jalW3^[o;c<>i^kk1oL9V`l?2`/70_knjb<6e/j>H
YZRWZ[6j_kfjZ[^/Thj6S:fBVjJYY9^CSh9/PW]jPVf5UVQEK75NIXQWIVYfQi:A
RhR;Si>ETXf9QiBRZ:>KUiRRWj:WWXn;TX9kRWJ5Jg9VNX>5O7QmO_ij>7McUfj>
JVM/IeYFFe]CE5ACCTQ6B4]0@dQ:BD@m>E1=B44m@TiGBTe8@4A>C48b?D]BCdDl
=Ta6@?hn9S`iBDU;CTe6>BlmAdU4AU5CC4E@D4<j>SL`B4M5A4A6B4U3@Cdi=ohf
;R`W:34d;c4i=S8]:R/_=3Pl=B/T8RH]<Rh/;C8g=S4[?2hW;2dU8RLY:BPW9RDU
n2Ci9GdW8QlR9_n3M7QSJEmPHg9mMfMNIg=bJf=OGf1OGGMhN7=]JfibJFEYKf]R
IG1NGEmWKgAcL7EaKW1dMG5]QWi`J6aaIUEbM6iVKH6AUH>8PgE_M75YGUeWMWM/
IfZ0LVEVL7E_IW=aKV][KW5dMV]oTX^=QfYZMWUbLWf4PV_nFUM:B4HaADA1?cdl
?Ch[>blo;dLc;DI1A4e9>S8eA4U3CVEVNZjGGeUhNG1_IfYYKVmPBdI>=EN8/<?3
_;O@c/W1^kg7cl[Ac/?0aL>jalW3^[o;c<>i^kk1oL9V`l?2`/70_knjb<6e/j>H
YZRWZ[6j_kfjZ[^/Thj6S:fBVjJYY9^CSh9/PW]jPVf5UVQEK75NIXQWIVYfQi:A
RhR;Si>ETXf9QiBRZ:>KUiRRWj:WWXn;TX9kRWJ5Jg9VNX>5O7QmO_ij>7McUfj>
JVM/IeYFFe]CE5ACCTQ6B4]0@dQ:BD@m>E1=B44m@TiGBTe8@4A>C48b?D]BCdDl
=Ta6@?hn9S`iBDU;CTe6>BlmAdU4AU5CC4E@D4<j>SL`B4M5A4A6B4U3@Cdi=ohf
;R`W:34d;c4i=S8]:R/_=3Pl=B/T8RH]<Rh/;C8g=S4[?2hW;2dU8RLY:BPW9RDU
n2Ci9GdW8QlR9_n3M7QSJEmPHg9mMfMNIg=bJf=OGf1OGGMhN7=]JfibJFEYKf]R
IG1NGEmWKgAcL7EaKW1dMG5]QWi`J6aaIUEbM6iVKH6AUH>8PgE_M75YGUeWMWM/
IfZ0LVEVL7E_IW=aKV][KW5dMV]oTX^=QfYZMWUbLWf4PV_nFUM:B4HaADA1?cdl
?Ch[>blo;dLc;DI1A4e9>S8eA4U3CVEVNZjGGeUhNG1_IfYYKVmPBdI>=EN8/<?3
_;O@c/W1^kg7cl[Ac/?0aL>jalW3^[o;c<>i^kk1oL9V`l?2`/70_knjb<6e/j>H
YZRWZ[6j_kfjZ[^/Thj6S:fBVjJYY9^CSh9/PW]jPVf5UVQEK75NIXQWIVYfQi:A
RhR;Si>ETXf9QiBRZ:>KUiRRWj:WWXn;TX9kRWJ5Jg9VNX>5O7QmO_ij>7McUfj>
JVM/IeYFFe]CE5ACCTQ6B4]0@dQ:BD@m>E1=B44m@TiGBTe8@4A>C48b?D]BCdDl
=Ta6@?hn9S`iBDU;CTe6>BlmAdU4AU5CC4E@D4<j>SL`B4M5A4A6B4U3@Cdi=ohf
;R`W:34d;c4i=S8]:R/_=3Pl=B/T8RH]<Rh/;C8g=S4[?2hW;2dU8RLY:BPW9RDU
n2Ci9@@W8QlR9PFZOon8OH=_LVASIWB1P7=XIf]gKfMUJ6MRG6mbLVaTHfQ_IfI]
MgE[K7IWIFE[M7]lNWAcLgIiMVeUIFe/Ig60Mf5XL6mWKX:>RfQbM6maNgaeLg9h
OWM/LGnGQWMgOW]YEW=aKVe^LWIiJf5dPWQkOFQ/N7Y_JgAlO7f<NFA`M5a:OdQ@
EE14?T=:?eE2DRm>>Chn>Ce7ASXe>E5CATA9?URGTeeKNgATIVMeKF][Gd]3AcI`
Y;6c_;RZbl_9`kk0alo;dLo4`LK3^/S;a[o3cL_0^[^m`LG6aL?0`;nn_Kbl^k^a
^Kb_/[BR[Jb]];^o_KVZ]J:?UY>E/:2OX:BWXiR?OhYfSH>0RgfKOWadJVM]MW][
KgZ8Shj;RHb9QXN;SHf<Si>JXZBMSX:FY:ZQV9JCSGY`QV^4HFiNIFm`IfM^J5UT
IF=UTFnAKVmaIeMCGF5MCU5FEe=>BDHk?dE9BD@m>5EFDd]1?TA:C4i:A4YEDTE1
A4aDF597?E]JEDe5@D95EEIBCe5DDTY2ATe=Ad]DE4a>FUe@ATI5@4M5@T10@DA6
>cPd<C0a<c@c:BTb<RLW<C4_;2XZ;30b@CT^9R@Y<CH_;2/_=SXi=T8b:2//9RH]
:b/Z:BPWmbKi9GlV9RDS9On8OH=_LVASIWB1P7=XIf]gKfMUJ6MRG6mbLVaTHfQ_
IfI]MgE[K7IWIFE[M7]lNWAcLgIiMVeUIFe/Ig60Mf5XL6mWKX:>RfQbM6maNgae
Lg9hOWM/LGnGQWMgOW]YEW=aKVe^LWIiJf5dPWQkOFQ/N7Y_JgAlO7f<NGmTL7AL
BTQ@EE14?T=:?eE2DRm>>Chn>Ce7ASXe>E5CATA9?URGTeeKNgATIVMeKF][Gd]3
AcI`Y;6c_;RZbl_9`kk0alo;dLo4`LK3^/S;a[o3cL_0^[^m`LG6aL?0`;nn_Kbl
^k^a^Kb_/[BR[Jb]];^o_KVZ]J:?UY>E/:2OX7nTYj>HShYfSH>0RgfKOWadJVM]
MW][KgZ8Shj;RHb9QXN;SHf<Si>JXZBMSX:FY:ZQV9JCSGY`QV^4HFiNIFm`IfM^
J5UTIF=UTFnAKVmaIeMCGF5MCU5FEe=>BDHk?dE9BD@m>5EFDd]1?TA:C4i:A4YE
DTE1A4aDF597?E]JEEY=AD52AEIBCe5DDTY2ATe=Ad]DE4a>FUe@ATI5@4M5@T10
@DA6>cPd<C0a<c@c:BTb<RLW<C4_;2XZ;30b@CT^9R@Y<CH_;2/_=SXi=T8b:2//
9RH]:b/Z:BPWmbKi9GlV9RDS9On8OH=_LVASIWB1P7=XIf]gKfMUJ6MRG6mbLVaT
HfQ_IfI]MgE[K7IWIFE[M7]lNWAcLgIiMVeUIFe/Ig60Mf5XL6mWKX:>RfQbM6ma
NgaeLg9hOWM/LGnGQWMgOW]YEW=aKVe^LWIiJf5dPWQkOFQ/N7Y_JgAlO7f<NGmT
L7ALBTQ@EE14?T=:?eE2DRm>>Chn>Ce7ASXe>E5CATA9?URGTeeKNgATIVMeKF][
Gd]3AcI`Y;6c_;RZbl_9`kk0alo;dLo4`LK3^/S;a[o3cL_0^[^m`LG6aL?0`;nn
_Kbl^k^a^Kb_/[BR[Jb]];^o_KVZ]J:?UY>E/:2OX7nTYj>HShYfSH>0RgfKOWad
JVM]MW][KgZ8Shj;RHb9QXN;SHf<Si>JXZBMSX:FY:ZQV9JCSGY`QV^4HFiNIFm`
IfM^J5UTIF=UTFnAKVmaIeMCGF5MCU5FEe=>BDHk?dE9BD@m>5EFDd]1?TA:C4i:
A4YEDTE1A4aDF597?E]JEEY=AD52AEIBCe5DDTY2ATe=Ad]DE4a>FUe@ATI5@4M5
@T10@DA6>cPd<C0a<c@c:BTb<RLW<C4_;2XZ;30b@CT^9R@Y<CH_;2/_=SXi=T8b
:2//9RH]:b/Z:BPWmbKi9@@V9RDS9@F`Oon;Ph]fN6MTHW:5S8EiLFicKFY^MWUe
KfQ[K6EMFf=[F5USL6mUI6eZIF5SJ6e]Jf9TJG5fM6]SK7]mLgJ1M5UULgM`MhV?
QWMnOG5/KFMKSXAjKf1NMYAgK6MbPX9]Ef1QHVI]MWn4OWB3S7n4Sh5[MWIWGVA[
JgjROU=]K3dXOd9AGe]=Ae1M=eQ:HS==;S=3?T=AEeAGH5MKDU=GD7G0[gM^P6eN
LXEjKfQWGDY0@EZOb;FT]/Bka<S:b<C3al_8clk4`/S6_/?7`kboal>g^k^m`LK8
a/?<c<_:bLW8akbL[;^]`<VL[:ZZ[[Bf/ZjSYi:9WInIZ;^/W9>@QgIVOga]QgYa
NgFLD8RKN6Z0OEa]M86;R7]cM8ElM7V8UIVGYYnNZKF_UGf8XZZGSYJDQ8MjTW2=
IgUWL7YkM7R1Mf:7PG=YREmlEGEdIeEAGFETAd]CGF9KC3lf>d97Ad8k=Si>GV=H
Ac/eDeE@C5AOFdiLDTM7D5MFDfQ[J5a>Ad]B<eYABDYAEE=?D5ECC4iGE4Y0CeI=
ATY=BdI3?cdl?T53@Clk>3Pj?Cm@@Se3?B/V<34`;B_n:R0[;2lc=cTi=cH]:RP]
=ci1@C`/8RP];C8k;2`[:RTX:2Oi:_TTOb4V:BX^oh^3RgIhIfARLXF<QGUaKW=]
JVifNGE_J6]/IEeKHf]HFF=`KfETKFYUHF=XKFe[HVAYLGIdJf=/NgecMX5dFFEc
Mg1gRHn6MgimLFa]Ie^>Q7Y_H5ifU7M/Ig:2PVeGH65RIVefOhAnM8><OhB?PF]f
MVMNI6][OZ9nOe=]K3dX@U5OFde7D5dgF4YR<dd^<d<n@e5GE5MPEe]BDeM@ML2_
Mfj0KEibQGY_J6MMBT11FYo8]JBfa;_4b<[8a<?7blS?c/C2b<Jn`lO3_;o7`kNk
^kg1a/S6`lc<bl[9bLS7_9b/^jg0bIb/ZZZ^];Jb[Z>WTXVMWiVX^jbLOi>@QgIV
O6f7NW5kMIa@R9]hJX1mG6edPH^8Ng=dQGadNHREVINVWijY]JnEOHRRZYN>UYB4
QgZBL8eWNFM`NW]dN85gHXN1LfV9GgaEMGAWEE5MIFA7Be=MHU]<?cHk@TM7@S/f
?TiNHeQ7>cECEE1<E5mKCUaBAdM@EeICJ6]X>5a>Ad]BFU59BU5EDdm@EE=<CUMD
BT1?ETe6BTe;AT<o?C`n@D=1?c/h>3Xm?e12?D<m:bH`<C0]:ohZ82//;c<g>CTg
=RdZ:2dg?T51?2`R:2d]<S//;2/Z:BPX9oTZnBAo8BHY:RkoRh>;MWQWI69bQHb5
NG5^LfeZKWIiMFmXJfaUGE]SJeQIHg1_IFA]JVEQHfQ]KF]RI6UaMWA[HfakOG=f
PGAIIG=gL7N9ShIgOWeaK6eWFhj4NVmPGWJDMfaWLX:2KEMPHF9VKGIoQ7idPhao
Q8n1JgIfIeiTJf]nXWioDfe/?BQ2DEmKCDM@GCMHBV8cCBhc@ci3DEMDEf1GFe9C
Ee1e`:mgKX1]GW:5NVmXIee:@45JWlReY;K4^lC8b/S4`lO;b<o>a<;8a[k3al>l
_lO3]k^k_L76b<K3c<c;b/W9b<NlW:bk[L39W:bZZZjd][:^XjNBRIfOVJRk[9ao
Ti27MVIlKHMjLG]eW528VgQZP7eLKGB1RhQkLgB5O7AiR9FIUjJOWZVe[iEmR::Z
UhjFU8B7NY9`SFMiIg1jNgAhPGMRQh5cJHUOO5EeM6MEDEeUI4M;DeeRFd`o=S]2
AdM2>cHnCUiSF4Lk=E=ED4aDGe]>G597Ae1GEU=XJfPhG4i7Be9JDDU:DEECCe1E
Dda>EeA:@4mFCDI:CD]6@clm?3i1@d4o>cPh>SdoD48m@cd[9S0a<2d[oRXP:b`_
<cLi>CLf;BXX;CLn@D4l;28X;Bdb>b`/:bXY:2PWnB[i90@Q9RTZ;PG5GOJ0V85c
E6moHFQcNg]dJV9>GTaTK5i_F6UhNFaXL6eQLFYYJfAIFfMQGVUTEfakHgj3JEU[
K5eQFVmmNWYmKeY/LhfBOhF;MFeSGF9]LFUNM7alJeMHLHahOhAnKf;nG69WIeiS
LgI/Ng1dPWm_MH]PPhQUFWB2MIVDPFaYKV58AUMMDDUBGfDb@Di:>Bd`=ca4EF1H
BTeKBUMWIeQGNjFVRHR6JfAaKU5bKHQR>64m</W1VKJi]Zk3`Kjm_/75b<_9a/?n
`Go2^kk2a<C1_;W0`m;9/lCFa;boa<S9b<K4UiZR[[Ni/Z^bYJ6/][NmaZn/Yj:P
X::SZYjASY:@PgIWMWQ/JWQoNHF1TfiUOfmjLXF<P7j>VYYnJjU^TCj@/X>:TYRH
UiFEVjj_W9ZRTW>?NGF5PFa[OVYYJ6U/LGMkMVIKI7EiIa9CJ6EUHeI8C5Y9Bdi>
CDQ3@3DioSeT@4I<D5EDCDe?ASE<DeQCB410ADiADdm7@Cm0KdhkB5QBAT8gEV9@
BUQIBDa?CTLm>d9:@Shi=cY1Be5<@D1:AcPd?T/k<34d>4QJ6bLc=Bl[;34m>C<]
:BTZ:bDX;30a<2h/<33n;oh^3b/U82<Z;BPR8b@U9RPY:R[m8VhQ8B0P92<Q7alP
8B8W:bh^;?J0V85cE6moHFQcNg]dJV9>GTaTK5i_F6UhNFaXL6eQLFYYJfAIFfMQ
GVUTEfakHgj3JEU[K5eQFVmmNWYmKeY/LhfBOhF;MFeSGF9]LFUNM7alJeMHLHah
OhAnKf;nG69WIeiSLgI/Ng1dPWm_MH]PPhQUFWB2MIVDPFaYKV58AUMMDDUBGfDb
@Di:>Bd`=ca4EF1HBTeKBUMWIeQGNjFVRHR6JfAaKU5bKHQR>64m</W1VKJi]Zk3
`Kjm_/75b<_9a/?n`Go2^kk2a<C1_;W0`m;9/lCFa;boa<S9b<K4UiZR[[Ni/Z^b
YJ6/][NmaZn/Yj:PX::SZYjASY:@PgIWMWQ/JWQoNHF1TfiUOfmjLXF<P7j>VYYn
JjU^TCj@/X>:TYRHUiFEVjj_W9ZRTW>?NGF5PFa[OVYYJ6U/LGMkMVIKI7EiIa9C
J6EUHeI8C5Y9Bdi>CDQ3@3DioSeT@4I<D5EDCDe?ASE<DeQCB410ADiADdm7@Cm0
KdhkB5QBAT8gEV9@BUQIBDa?CTLm>d9:@Shi=cY1Be5<@D1:AcPd?T/k<34d>4QJ
6bLc=Bl[;34m>C<]:BTZ:bDX;30a<2h/<33n;oh^3b/U82<Z;BPR8b@U9RPY:R[m
8VhQ8B0P92<Q7alP8B8W:bh^;?J0V85cE6moHFQcNg]dJV9>GTaTK5i_F6UhNFaX
L6eQLFYYJfAIFfMQGVUTEfakHgj3JEU[K5eQFVmmNWYmKeY/LhfBOhF;MFeSGF9]
LFUNM7alJeMHLHahOhAnKf;nG69WIeiSLgI/Ng1dPWm_MH]PPhQUFWB2MIVDPFaY
KV58AUMMDDUBGfDb@Di:>Bd`=ca4EF1HBTeKBUMWIeQGNjFVRHR6JfAaKU5bKHQR
>64m</W1VKJi]Zk3`Kjm_/75b<_9a/?n`Go2^kk2a<C1_;W0`m;9/lCFa;boa<S9
b<K4UiZR[[Ni/Z^bYJ6/][NmaZn/Yj:PX::SZYjASY:@PgIWMWQ/JWQoNHF1TfiU
OfmjLXF<P7j>VYYnJjU^TCj@/X>:TYRHUiFEVjj_W9ZRTW>?NGF5PFa[OVYYJ6U/
LGMkMVIKI7EiIa9CJ6EUHeI8C5Y9Bdi>CDQ3@3DioSeT@4I<D5EDCDe?ASE<DeQC
B410ADiADdm7@Cm0KdhkB5QBAT8gEV9@BUQIBDa?CTLm>d9:@Shi=cY1Be5<@D1:
AcPd?T/k<34d>4QJ6bLc=Bl[;34m>C<]:BTZ:bDX;30a<2h/<33n;oh^3b/U82<Z
;BPR8b@U9RPY:R[m8Q0Q8B0P92<Q7alP8B8W:bh^;0G5Oon8W8AlHGMoHfQ`MWMb
K6MTLEQVJVF8PG9cK65VKfICKfQWJ5mCEF1OFVEREVUhHWAiHeQ[JEUNK7^2OGf2
NfajKgZ1Oi>IO7M_J6U]JEY=FFMbKF9XPYacNh1nM6]XJGahKVYlT8YfXi6;U8n0
Q9QoV99]HWb7NHB4MEY=Cda0ATMHH5QDHG1fB5AMFDa4B513C5i/J5eQKeERLG5M
E6f@VWn1PfYSKVUFKf]oF3IM@3[=`Y^k`L6mblW7a/O:c]3<b/O4`/71o/9]`L2o
_Kbk`<7@bkS8fLS3a<K6`kji]JJVZJne]:fV[jFU/[Rc/;>^ZjJQWj2RXj6FS8^@
T8IkMGilLG1jNFjERYMcJh5]MF9hQhJ6RhIiTg9_Qj6AR8J;RXnLZZjVW9ZVX8^9
Ui1hRXZ2MFmaL6cnI1AUJFidMfeNEEiaMfQEPGUdL65=ATcmCf1=BTM5>SPf=c]1
ADQ=EEQEF5Y??TE=EEUECTU8EUMECT@l>ceWCCi8DTe5A2i4Ac</=c<PADQ:ACdk
?dE3@3dk?D98C4To?TQ6>CLoBCdg>cTd>D@V;C@g=C4_;cDc<2`ZoRPQ9RP/;Rl]
:bTW:2T[;2h_<2`W92L^<BhY92@U9RLY:BXT9?dSOb8R:2LT8R0P8B8L8BP];on8
W8AlHGMoHfQ`MWMbK6MTLEQVJVF8PG9cK65VKfICKfQWJ5mCEF1OFVEREVUhHWAi
HeQ[JEUNK7^2OGf2NfajKgZ1Oi>IO7M_J6U]JEY=FFMbKF9XPYacNh1nM6]XJGah
KVYlT8YfXi6;U8n0Q9QoEIRBKF9lQgV4Q7EJCDm<@4MHH5QDHG1fB5AMFDa4B513
C5i/J5eQKeERLG5ME6f@VWn1PfYSKVUFKf]oF3IM@3[=`Y^k`L6mblW7a/O:c]3<
b/O4`/71o/9]`L2o_Kbk`<7@bkS8fLS3a<K6`kji]JJVZJne]:fV[jFU/[Rc/;>^
ZjJQWj2RXj6FS8^@T8IkMGilLG1jNFjERYMcJh5]MF9hQhJ6RhIiTg9_Qj6AR8J;
RXnLZZjVW9ZVX8^9Ui1hRXZ2MFmaL6cnI1AUJFidMfeNEEiaMfQEPGUdL65=ATcm
Cf1=BTM5>SPf=c]1ADQ=EEQEF5Y??TE=EEUECTU8EUMECT@l>ceWCCi8DTe5A2i4
Ac</=c<PADQ:ACdk?dE3@3dk?D98C4To?TQ6>CLoBCdg>cTd>D@V;C@g=C4_;cDc
<2`ZoRPQ9RP/;Rl]:bTW:2T[;2h_<2`W92L^<BhY92@U9RLY:BXT9?dSOb8R:2LT
8R0P8B8L8BP];on8W8AlHGMoHfQ`MWMbK6MTLEQVJVF8PG9cK65VKfICKfQWJ5mC
EF1OFVEREVUhHWAiHeQ[JEUNK7^2OGf2NfajKgZ1Oi>IO7M_J6U]JEY=FFMbKF9X
PYacNh1nM6]XJGahKVYlT8YfXi6;U8n0Q9QoEIRBKF9lQgV4Q7EJCDm<@4MHH5QD
HG1fB5AMFDa4B513C5i/J5eQKeERLG5ME6f@VWn1PfYSKVUFKf]oF3IM@3[=`Y^k
`L6mblW7a/O:c]3<b/O4`/71o/9]`L2o_Kbk`<7@bkS8fLS3a<K6`kji]JJVZJne
]:fV[jFU/[Rc/;>^ZjJQWj2RXj6FS8^@T8IkMGilLG1jNFjERYMcJh5]MF9hQhJ6
RhIiTg9_Qj6AR8J;RXnLZZjVW9ZVX8^9Ui1hRXZ2MFmaL6cnI1AUJFidMfeNEEia
MfQEPGUdL65=ATcmCf1=BTM5>SPf=c]1ADQ=EEQEF5Y??TE=EEUECTU8EUMECT@l
>ceWCCi8DTe5A2i4Ac</=c<PADQ:ACdk?dE3@3dk?D98C4To?TQ6>CLoBCdg>cTd
>D@V;C@g=C4_;cDc<2`ZoRPQ9RP/;Rl]:bTW:2T[;2h_<2`W92L^<BhY92@U9RLY
:BXT9?dS3R8R:2LT8R0P8B8L8BP];`FoOon:UgmoJWUgIfU]Kg5`KfiPKUMVJVF:
QXIlK6A]M6QCLV]YJV9FF6=/I6m`I7B3LG=gIF5gLV1WJ71bKFebL6R6JfI`OYjT
PH5jM7AeKf1CH6ihLfMWNHa^M7]lNGEdMIF3Kg:>XiMl/YR;THeoOhn<VXe]JH>=
OYBER6iJEeQG@d]JH5QEHFmcC59FDTY8CeM5BeYXI5QIIDYHK7AZIG^JTgZ0Qg5Y
KfIOKFadC3EGASc7]iBh`LO9a<?2`/?5alW<b/O4o/8J`lS5`[jk^[^k_k_:b[W6
e/G;b/S4_K>[YKbho[E^/Z^T/JZ^^kncZ:N]ZZFQWj2RY:BKU9BJVi>;NgYdKW9f
KEfJRI=fM8YdO5aWL7AiNg1PNGiJX7>HKX^<QhRHZZfMRiVNTG]kSHioQiJ:IUib
LeiWIfQ[KgAiO6EHD5Y/LfMGM6YYL6iOE5=>C4U6oDAF@3H^;cU3A498DUQHGVAJ
BT=8DE]RGeE=GUaFBclh>CaJC4=7BDA2AT5>CdI=HF5AA4U=C4Q5ATQ5@d50@494
AT8l?492>c]2>cDh@D0e<CHd<c@g>SPaoR/U;2`[:2HT:BX[;2/Y9bHR8bDX:Rd_
<2XW9BP]<2h[9BDV9RLX:BWm9OdV12h/:2DRoR5o8bPa>CooRYMoOfYiMfMYKFma
L6m^H6iGIVYURXJ6O6aTKGAXDg9[JFYREUQSK6A_L6AdPg5cMfEQMg9PIfQ`LVe]
LW1XQV]VL7jNY861NWAdMFmPDf1^N7=WIgV<KWAkO7UeM7FEPfmbSZ>GO;:HRi6=
Ogn?S9Z=KFV3SGjDUHQ8KUYGF5M;FV1HEF5_LdaBEU9:B4mGAD]JJ6AHFFE:F6ad
JVEkVY=jP8MaJFmVGfe/M4`eEdHlakND^<77bLC3`/;3aLO9c<[7a?k26/?8aL:n
^kZk^knkb/Zia]K5bl[8a;fcZjFl^?jeK[:[Y;6Z[[^o/jRW[JZUXInPXZBTViBD
VY^CRg]jM6ibMVeMVXVCMWB:M7aLIg1dNG]`H7UnFZ1cV6j;S8N8V:Z]WH^IWY5k
Nhf>OhNFRVINLW=NIfMXJfmdNGaUF51JK7=WEgAZJG1^GeACCTa9A_e4ET0f;Rli
@dA2B59HF5iTFTY3B55KHUmECEiLET/o>3TlFTa3AdU4@TI1CTm6CF5QDDA9CDa8
ADI8AD=1@412A4I2?3a2@S/k@S/e>450=C4f=3<d=cXh<Oh[9B`/:bPV92TZ:b`[
:BLV8R<U:2X];c0Z9bDX;C0^:bDU9RHW:2TYoBGm9P@^;2PU8_hQOb<X<CToohZG
OgmZNGMWJFe_LG1_KV1^EfIZIHZ6QWa/I6edJ5=bJfUZHUIHHfaTKg1TM8=aLgMU
HGMbH6MXL79]KG9`J8I[IW1nWZB1PGYdM7E_H5=PKWQcIfMiS6idNgaiMGAeUH=_
LXjSUgbbV8^ASGmoShbJSFeYPhenU9F8B6iJEeQGBeYPF5EQKg=<DUIBBTQ?EdE;
FVQTF5UUBUQ/M6YUNiZCNX27LFU_IUm]K7A<=EM6?<NgU;S1alW4`l;2`lG7bLc:
alCn`Q[3b<G2_[^j^k^o^l[:^LKFaL_:b<Bm/j^U_;Sn]FjbZjBaZZjk_k>XYjfZ
YJ6OX::TY9^DU9ZKTh]kNWA^LWI]GIZ9TgIdRWAlG6M`M7UkL61iOUZPLiQ^Rhb7
R9RZ[If;VIjANg^=SWn7UXYVGW9cGVMWJ6]_M7UlIEQ@FVacIeMdJVU`KUmDDdi<
BDKmA5I0=Rh_>D=4@TQBF5QNI5Y:@dQAFf9OEDeNG5I;?cPi?5Y<@dM9A496@Di?
ATeQHE54BDe<B4E6B4E3@D10@TA6@S`l@T8k>d8k=CQ1@3Da=S@c=3Lj>37n:bD/
;2/X9R@Y:R//:bTW9R8S9BPZ;Bl`:RLU:2d`;R/U9BHV9bPY:OdUoBH4;R`X9B;n
8@@S:34i?`Fo>On4S7=jK7IYKfe/Jfa_LWAFIE=^NFinJ9>:OGEeMViTLfe]L6YQ
I71`IG1fJWN6N6e`HFEmLf5[H6CmIgUTH85XIFehUiimMW1YJFe_K6M^N7edIVAb
PFa`MGMhMgMhSge]LhZIT7jPQgf7R7YgPgN1N6AZQH]l/ZbOSX9jLVaMIfQLEf1X
J4]:B4E3AdmEDE=MIUm?Be9HGfadKfn6XiQnQHmjL75SK6idKdHjDddg^JB5[KS2
b_k02<71`lC5cL_8aOk39/C6a/G2_k^g]L6ha/^k`ljoc/g:a;^aYj76`;Zg][>]
YkN_/[o2]oj]OjZVXZ6RYJNaZjFTYjJPVWmgL7=nPGEUSgZ7M7VAOHUeKfQXLgak
M7Z7GiAFQG6QTY6EWJ>NSX2IVHinP8f?QHV=OfENJfmUHfAVJFeaMGMXG5=JJ6eS
EV5HFFQ^HU==AT<n>CLh>ca4=BPZ>DA3?DA;CDaEHEmDCda=EV9UGEANF5]DB3di
?45=BDI3?S/oACPm>c]<HVEH?D56BDQ5@d95ADA3@T50?c`j>C`m?Cm3;2P_?3lg
=C/m=c8e>cX`9R@W:Rd/:BDR;2`[:RTW9B@W9bPZ:b`^;R/ZoBP19RCn9_dW3BPU
9RHW:2PY:C8_:bLSoR4n:Rdd?TGoQ8acNVafJFm]K6]/Kg9dEVECKWU^OVRCRWee
MGI^I7=]KG1ZHFA`L6E`MVYgQWQ]L65UOG=QJf1ToFMiI621J6E]N9NNOGI`JFU]
KfaWKWQmM6ITLX5/L7EgN7MgN8mmKG>:VI1nX8MmQhQjMh=gPGQTJXF;O;:/Whj2
NW9/GFMXG5MPJ6Q;BTQ5@dM?EE5CGFIOCd]BF5m/M6m_QZ>HOXF?NW1aHfa^M6m6
>U===kVTQJfh`/[n`0S1`L?4aLg;b<Gn`bK4a/K5`[nk]kG1^<K;^l?>_lk=b/Bk
/JNQa/2j]kJc[JNg[k:o`[On[GnZYZ:QXZFW/J^UY:NVX9YoMg1cOX5eIHmjQgAi
TGf9MFmXJ7=lNgAjQenDEXEaXI:AUIfSWXj0VIV>OX2=ShF9SGmUGV]_IF=TIVU]
LGEgJ5aCFVQ]HeIQF5UXKV9CCDI3?STg>3/lA3DX:SU4@ce4Bde<EF5OE4m<CEIR
IEeDGUQKE4Pm>Ca1CDU6@chk?dDh?C/kC69UF3e1ATU8AD=2ADE4@d91@3ll>STl
?Cdo@b`X;c`o=cDk?CLb=C/j<2HT9bX];2TU8R`/:bXY9bDT9bLX:R//;Rh[:_dX
0BHToRKm9`dX9BHV9bPX:BTb;b/W8ohQ?RX]=3i5ohB<LgY/MVU_KFa[K6mbM5IU
DfiiKWiXThYmMGEfKVAcKFe`JV5TL71UL7IZMhIhKG1QIGecHF]PI?eWNFAPPFQU
KGRGWWefL6UYKFm/IfihOGAVI7:1K71eMgQgMgR?OFecRYV@OZ27OHN8NWN3Mh5h
I6Z5Rgbb[9n>PWYbK5eWJ5aGH6QXBdY8AD=7CeEADeeVGdm;DUQOK7A_KhJSV7j5
SgY`LF=/KWA_ASYCCCNiY8F]^<;:o/08`L73a<G=blS5o/<Va<K6aL:o^kNe`KS6
bk_3c[o>cL[4^k6WXLK0^[Nf/jfW]jnb_l:goZeoZZJRXJ:UYk6[YJBWYZ2JOgM`
Lgj1MFF?NXMdNI5mRGE_J6QcO7]dNXMOU5J5LJ6BTIFMXij>P9VISWj0SHn5RHeo
IEi[KfESI6IYKG5eMfQLDeYXKF=FHEQIJ6iRDde6@chi=cPk?4@e:2XiA4<mA4]=
C5EQGeA?C4eFHVEME5iHFeA8?CTl@De9AT<n>cm5>3dk>daRIEPm@DI9B4E3@TE5
A4=2@D0o?3Xi?3dm?d</:2ll?cLe>cdg<SDk>S0V92LZ;B`Y9B8/;2/Z:BLU92LW
:2X[;2h^:b[m:04V9?hVoBL=:2DV9RLX:2TY<Rl[9b?n8@@Z;C@nA@G5Oon4Rfmj
LgaXN7A_K6a_M7QZKU5]PGQnFh:3PW]]HVA[K6MYKfaUJWMRDUiYGVIfKFITEV1i
K5YZJFadNg]dK6UbJGEiLhF>M6aTFUIJHfa`JG1dKfQ/OXi^KVmaM7EcLWQcLgZ1
Q8F6SGalSI21OhaVKfeSK823MZnLRhZ=PfaI?6I^K61MIFYWF55;BDiEFUeTHf]e
L61JGhEmMg=YIWZCV7f2S7Y_JeUgKH9aAdA>DSZcVWjY/[g9bL[;c<gmcP;<bLKn
a7o5`<?7b<Fm]Jo:^/OAa<O>`<[:bLFn]JbW^[B_[Zn]ZJBeZjZf_;Jc]jn/Z:FT
YZV[/jjYYZBPViN6NgJ0Si::PXYbPW=fRGN;Rh5jP8^@T8jLQFUkQ9VATiFQ[JjU
ViJFVIZESY6FTXV=N6a`K69XNUaMH6=VJ6YZLFEKG6EWGWEDJf1NJ6QE@CM3@3/f
=3Dg>D@f:R`jA44j@TA0>dAGGUQNE4]=EUiNFUQFD4Ln?457@TI5?CHg?D52?cTf
?dY7?C@e>C`n?CPeADA3@T0n?3`h>CPf>3e1@C0Y:S@g<cDo?cLa<SLg;RDV:B`_
;R/W92h];2XXoRL@<S4`;bd/:bXd=38^:B@S8RSm9ohV32@U9BLX:BXZ<Rl[9b?n
8GlP8BPd@On4RfmjLgaXN7A_K6a_M7QZKU5]PGQnFh:3PW]]HVA[K6MYKfaUJWMR
DUiYGVIfKFITEV1iK5YZJFadNg]dK6UbJGEiLhF>M6aTFUIJHfa`JG1dKfQ/OXi^
KVmaM7EcLWQcLgZ1Q8F6SGalSI21OhaVKfeSK823MZnLRd6:SH=/FFI^K61MIFYW
F55;BDiEFUeTHf]eL61JGhEmMg=YIWZCV7f2S7Y_JeUgKH9aAdA>DSZcVWjY/[g9
bL[;c<gmcP;<bLKna7o5`<?7b<Fm]Jo:^/OAa<O>`<[:bLFn]JbW^[B_[Zn]ZJBe
ZjZf_;Jc]jn/Z:FTYZV[/jjYYZBPViN6NgJ0Si::PXYbPW=fRGN;Rh5jP8^@T8jL
QFUkQ9VATiFQ[JjUViJFVIZESY6FTXV=N6a`K69XNUaMH6=VJ6YZLFEKG6EWGWED
Jf1NJ6QE@CM3@3/f=3Dg>D@f:R`jA44j@TA0>dAGGUQNE4]=EUiNFUQFD4Ln?457
@TI5?CHg?D52?cTf?dY7?C@e>C`n?CPeADA3@T0n?3`h>CPf>3e1@C0Y:S@g<cDo
?cLa<SLg;RDV:B`_;R/W92h];2XXoRL@<S4`;bd/:bXd=38^:B@S8RSm9ohV32@U
9BLX:BXZ<Rl[9b?n8GlP8BPd@On4RfmjLgaXN7A_K6a_M7QZKU5]PGQnFh:3PW]]
HVA[K6MYKfaUJWMRDUiYGVIfKFITEV1iK5YZJFadNg]dK6UbJGEiLhF>M6aTFUIJ
Hfa`JG1dKfQ/OXi^KVmaM7EcLWQcLgZ1Q8F6SGalSI21OhaVKfeSK823MZnLRd6:
SH=/FFI^K61MIFYWF55;BDiEFUeTHf]eL61JGhEmMg=YIWZCV7f2S7Y_JeUgKH9a
AdA>DSZcVWjY/[g9bL[;c<gmcP;<bLKna7o5`<?7b<Fm]Jo:^/OAa<O>`<[:bLFn
]JbW^[B_[Zn]ZJBeZjZf_;Jc]jn/Z:FTYZV[/jjYYZBPViN6NgJ0Si::PXYbPW=f
RGN;Rh5jP8^@T8jLQFUkQ9VATiFQ[JjUViJFVIZESY6FTXV=N6a`K69XNUaMH6=V
J6YZLFEKG6EWGWEDJf1NJ6QE@CM3@3/f=3Dg>D@f:R`jA44j@TA0>dAGGUQNE4]=
EUiNFUQFD4Ln?457@TI5?CHg?D52?cTf?dY7?C@e>C`n?CPeADA3@T0n?3`h>CPf
>3e1@C0Y:S@g<cDo?cLa<SLg;RDV:B`_;R/W92h];2XXoRL@<S4`;bd/:bXd=38^
:B@S8RSm9ohV32@U9BLX:BXZ<Rl[9b?n8@@P8BPd@@GAOon>V7V3PHihPGefLFma
MGQiLdUJKF]mHf=YLW5NCE9RHeiQIfENI75PC5QXGF9bKG9[FfR0LF5gKfigQ8Ag
KVmYKXB5L7V4LGmgK6=RJG=jLWQkMFe[M7iaKF]]LWEcL6UaP8^6OXJFPGMlRhUj
OiAZLW9YK7Z1OJ64L7R4NUm:@e9HETi@GF9NGE=9BU=KG5UPGVMfN6iYKHMiKVYX
K86ISW1cOg1WI51iJHigC4e5CdRjWHF`];g:aLK9blc<bl[?cL[7o/Eoa[o2aLK4
_[Nbb;C1eLc=e<O4aLG3_[Na[:JTXZBWYj6K[jBT/;Re];Zb[jbYZJ^_/JZWXinJ
UI6?QGQcOHR8QhZ=MhQgKWIVPgmmQIFJSX>0NWVDP9IkTHf7VJZZWYROZI^JVY^L
VY:9RFaUMgISJHE[KFmbLg9aL7=YGUaQHU/=Df9LH6]ZFTa9AD=0?Ccn>glo>38e
?D8o>T93?3HoDEUDH5M;ATYBFEeCDe19@Ci2Ac]2@3@`=c`jA4=3AD]?CT]2?ci0
A4@o>T=1?S/j>S/l=S/h<38l@Chm<bhb<B/^>3dh=3<d<bl[<C4b<S0^;2X`;b`Z
:R//;CLe<c4^:bTX>C/k=BdW9RPY:BPW9RHU9@`Q8R<U9RPY:Rh/:2DRoR5o8b0T
<TGoSYQiPh6>N85mMW5_LGEhNG=9FVe[OF=SJG9aGTeBHV=NHFMUGVAaH4aHJ5eR
LVebJe]XP75QMfm^MhB4Mfi_JFj4QG1iQ75oMfaSHVUcNW9hNgE]JgAnLFe[KG9e
Lg1YLH2;QWj6UX5gO8^9NWnDJW9bJFajPGfQQ718N8AjGdYBF5I>D5eRGUeCBDYC
FeaIH5iWMWQ^JFf7NFiZJ6b1VHi`Lgm`IfA@NFV>Mda=ADm8^Yf5/;Bmb/G6bL_<
c<_:clg:aok5OlJo`/G6a;jg//Rd`MG<cMC7a<G5`kjg/JbVY::TYjNQVjnTY;2h
]KBj/Zn/ZJV[[k6ZYj>OVYFAShEhLgf8R8N:SGN8MfifIX=oOHFEVXj3P7YiU82F
Ni6=QiVZZYjHWjVKVYZKW9ZBRHU/IGMfHfV5Jfe_LW=bLG1cJEiLHF9K3E=RG61[
JUY<BDE3@3dloS]o?cPb=Ce2?cY2@c`f?e5IE61GBdI:DUUMDe=@BD4n@TLk@T0d
<3Ll>TA3@dE;Cdi;@Sln@4A4?cY3@Chk>SXk?3Hk>30b?44n?C<^<S4[;SPm>3@c
=3<_:c4a<S8`;R`Z<2l/:RX[;2dg=C<a;R/Y:3Tk>cD]9bHX:BTX9bHV9BD<8B8S
9BHX:BX^;2PU8_hQOb<P9395ohjHNH>1SWR1OGIaKg5eN7UcBEY]JgeSHfUbLEi=
DV9SGV5WIEiTLF1<F6QMHW9]LV]KJ81aHGM_KWN4Q7M^KfU^Q8E`NHAaOgM/Hf9Y
LgYbN7]eKF]dOW5]JfebMG=`JG60RhInQYJ1Mgb;RGYoU6YbLVU/NX5mXHA`B7R4
NUm:DUQFCU1MHUiMDdU:De]LFF1NIgIhKVU]QgU^JVQ/PIV>L7=oL6MTD7UYSWM<
CDE?B;ZMQK2d_L[5a/W;c<c;b/o=b/OnaGo6_l;5a/Bn]k;8]<7Ec<gDalC5aL>n
]k6/YZBRY:NWXI^_Y:B`^;Fd^[:_[:VYZjnaZZNSWiZETHn5N7=mR8R7RXegR7M^
MVJ3Ogf5UIZ>Ph1jNIB0UW^ASHNIZZZNV9nYViZJVibJTXV9K6EgMV=YQF]]Kg9c
LW5`LfUNG65RF`eCHUaPJfYJC4U5@d0m??hkOclh<SDm@Slj@T<l=SmAFEAPEd]6
BU9IGE=CD4U1?T97>d90=30g?3Y4@d=5Bdm>Bd8o?T14A3lj@d4n>cXj>c`f>cP`
<Sa1?Sdc;S8a:bhh?CPd<c@c;b/a<C8b<2h/:S0_;2XZ:b`]=cDc<Bh[:BPi>c/e
;BLV:2TY:2LV9RDU324R8bDV:2TZ;R`X9B;n8@@S82@bA@G;OonFYH::S9f9RXEn
N7AcM7I[LeAQIV1mLUUJIFmVDe9NIf5RIV5HG6USC5Q/HV=dLgY]FFMoKV5lL6U/
NGU/JG1_LXR8Lgb9MhN4P7YfMWYnLW^4PgU]J6MbK6U]MG]iMVEaR9^FR8jPRGmo
PgAUMYM^M79WIWN=VJ>4KgAlLfIPADa@C4A7E5MAFdm4Ae=JEDeFDe][L6MRI6aP
Ff=/MX^PQ6AWMFaYJ5IdHIIkCe<jAUC1XXbg]KW7_/34alS7a<?@c/_8a/GnaWo3
_kbj^kk0/IZ[b<O9dLRo`<6o^kB^ZJ>SYJV]Zj:K/:V^_LBm]kVe/k2][[2d]jb]
[:RSX9nOThAlP7igO8R:N8ilJf]QR7imR9F>NW1eG7NRQ7aOQ9N:TibMV9ROYijI
UYVJU8b7O7EaLg9`Lg]iNWamO7UfLfaSFEMKGUYEDPICGV]YGE]QoT9Q@Clm>SPi
>Se0@D0m>d=8AT=:EUI<DE1<AdE:E5aDEEA=A3hm?cPn>B`]>S`b92Tb>S`k?T=?
B451ADM3?T0m=c<b=SXn=chi;Bdk@3Xl<c0f=Bd^=c/l?3Td<S@h?S`h=C;m<Gl`
;B`/;c8e<C0_;R`Z:BT/<C@`:2@W:bXY:BLV9B@T7QhP8R@V:2TX9b@R820Q8RlW
8R/loiJUPXZ<WHV:QGihM7=dMV]cE65VH7ebFEYUKfICDUiWHF9VHEQLJF=<F6aR
HgAcNVeIIgm^HGa`JFaiNFaYL6mbR8QcO8UgQhB0NWUfMWYnLW^4PgU]J6MbK6U]
MG]iMVEaR9^FR8jPRGmoPgAUMYM^M79WIWN=VJ>4KgAlLfIPC51<A4MDEe5KCdA7
DeYECEICFf]`If9TK61KHfafRj24I6MeK6UXEWAQUW]?DcY6E<6RS;Ne^LNn`<C7
b<O4`m3>blS6aOk6Ol>o_;Zk_/2aVZ_8alWAb;o0`Knk]:jYXj>UZJf[XY^`ZJjm
a;fg^KFc/:f^/;Bg[:f/Z:>PWinCQ7b0OWMlR8YhSWa[Jf68OWf8UHijL7ELMj:4
O5n4UhZCW9fHV9nWWYVFVIZDS8MlMG5cLW1cNgUjO7elNGIcK6=IEe]NFUEB1U=N
JfUMFf7n@V51?cdj>3Tj?D11@3dk@dQ6@dYFETaAD4a7ADYDG5AEE4e4?Sdo>3hi
;2dj?38T:C8j?3/n@dm8@D55Ad<n@3dg<c8f>Shg?ST];C]0>S`c<3He;Bhg>c`l
>C@b=3Pn?3Pe<_daOc0];2`_<SDa<2l^;2XY:B`a=30X92L[:RTY9bHU92@N7R0R
92HX:BPW928P824R;bLR:ccoUZF2RXbMRHZ5OWQdLgAfJg=DHFIPOG9IFVE_IU=B
GVMQHVIQF5aYHdaHK69SM7=jKEUWOfiQO71YK7UiK6U`Kg:8R7=lRGN7Q81jNGIf
NWibNhB3NFeXIg9/JFeeNgUfIG68ViJ8SZ29Ogn3M6EfUfidLVMVMhfIXhA_M7ac
IV1<D4a4AeAGDE]?A4MCFUE=EU=KJg1WHVA/H5]SK7J;X8ATIgE/JFQFM66FNdmC
>TID`J:<]kFiakk0a<O8alC3d<k;b<K5o/Io`knl^[^n`;6JZlS7bM78_l31_k^d
[ZVSXjFY[J^RVk2Y[[g4_KNi]K>`[Jj`];N/[JbXXj2OWi>4O81nMgb8RWR>O6][
HHQnOHRESWY`MEagXXAlGhBGRY>LWIRHWjNNVIJIVYB<QgaeLG=bL7=kNGYlOGai
MW=/HeUGFeiJEE86Dei[JEeKHOi2HD4o?CXh>CXm@450?C]3B4I3BUIFC55@C4M5
BUALE5EDCD@n?Clh?ST/;CXl<R@Y<SXl>ci3CdQ1@DE7@ci0?CLc<SHj?SLn>Bd]
>d0j?3<`=SD];SLk?3`i=38d>3hl>3DboC4c<2d/;2lb=C4`;bh/:RTY;34d<2PT
9b/Z:BTW9RDT91hN828T9RPY:2LT8R0P8B8_9b8[?0G5OonGZXF;SZ>ASh^4OGMe
M7AJNWF7Of^8PVALI7QjJV1TLVaZK6AHFVEJ@DiSFEUZJf]JA59ZEde[NVaZLg=Z
K7YiMXB5MXFBOg1eNW]hM7=cDFAlRXV0MW9aK6Q^NH61OVI^Qj6QTY>QXIF=QFaM
Mj9WK6UMGWJL]ZR;MWEdK6mj@fEWGe=CG5]BHUA9CE]QFDeNF5i[KV9JFVaPG6A[
KgZ8PF1SM6maM6=^FYQlD5@a?US2XXjh/[?0a/W=d=7@cL_@c/_8o/H@alk6^[6a
^LC<UGfB][ZobL;n_Gnk]ZnXY:b]/KJi]JZQ]kBndMO:_KVh][:`/KBh^[Zl_Kbh
]kRk]::GU8UkPIB0LXn0K6]WUifDTY>4LGF8SH9dKg^=TXfVXj2OXJ>TXj2FT96A
S8N6LH>1JfYmOV]`LG=cL6aVHf=KDe9GFeYGGV1WJem<BU@j?3ho?CPc<3@lA6A7
A3lm?4A=DU9HGUI6@DQ=BdI7D5YGFEQAAS`g=cPl=2P/?3`]?TA=CT<d<SQ6?38_
=3Ld;clj<bh^<cXo=clj:b/j?cL^:Bhj?CHf?CY0@che<cU2Ad<m=c@c=3Hb<2h]
;S8g>_dYoBYo6R0V91hL8RPZ:RTX9RDT8a/L7R0S9BHW92<Q7alP8B8`8QDD7onG
ZXF;SZ>ASh^4OGMeM7AJNWF7Of^8PVALI7QjJV1TLVaZK6AHFVEJ@DiSFEUZJf]J
A59ZEde[NVaZLg=ZK7YiMXB5MXFBOg1eNW]hM7=cDFAlRXV0MW9aK6QXKWV1PGiV
KXNQXI:CXJ6ESHE/GGNRIfaYGEifW;JXRgIeM6a_NVEWGe=CG5]BHUA9CE]QFDeN
F5i[KV9JFVaPG6A[KgZ8PF1SM6maM6=^FYQlD5@a?US2XXjh/[?0a/W=d=7@cL_@
c/_8o/H@alk6^[6a^LC<UGfB][ZobL;n_Gnk]ZnXY:b]/KJi]JZQ]kBndMO:_KVh
][:`/KBh^[Zl_Kbh]kRk]::GU8UkPIB0LXn0K6]WUifDTY>4LGF8SH9dKg^=TXfV
Xj2OXJ>TXj2FT96AS8N6LH>1JfYmOV]`LG=cL6aVHf=KDe9GFeYGGV1WJem<BU@j
?3ho?CPc<3@lA6A7A3lm?4A=DU9HGUI6@DQ=BdI7D5YGFEQAAS`g=cPl=2P/?3`]
?TA=CT<d<SQ6?38_=3Ld;clj<bh^<cXo=clj:b/j?cL^:Bhj?CHf?CY0@che<cU2
Ad<m=c@c=3Hb<2h];S8g>_dYoBYo6R0V91hL8RPZ:RTX9RDT8a/L7R0S9BHW92<Q
7alP8B8`8QDD7onGZXF;SZ>ASh^4OGMeM7AJNWF7Of^8PVALI7QjJV1TLVaZK6AH
FVEJ@DiSFEUZJf]JA59ZEde[NVaZLg=ZK7YiMXB5MXFBOg1eNW]hM7=cDFAlRXV0
MW9aK6QXKWV1PGiVKXNQXI:CXJ6ESHE/GGNRIfaYGEifW;JXRgIeM6a_NVEWGe=C
G5]BHUA9CE]QFDeNF5i[KV9JFVaPG6A[KgZ8PF1SM6maM6=^FYQlD5@a?US2XXjh
/[?0a/W=d=7@cL_@c/_8o/H@alk6^[6a^LC<UGfB][ZobL;n_Gnk]ZnXY:b]/KJi
]JZQ]kBndMO:_KVh][:`/KBh^[Zl_Kbh]kRk]::GU8UkPIB0LXn0K6]WUifDTY>4
LGF8SH9dKg^=TXfVXj2OXJ>TXj2FT96AS8N6LH>1JfYmOV]`LG=cL6aVHf=KDe9G
FeYGGV1WJem<BU@j?3ho?CPc<3@lA6A7A3lm?4A=DU9HGUI6@DQ=BdI7D5YGFEQA
AS`g=cPl=2P/?3`]?TA=CT<d<SQ6?38_=3Ld;clj<bh^<cXo=clj:b/j?cL^:Bhj
?CHf?CY0@che<cU2Ad<m=c@c=3Hb<2h];S8g>_dYoBXT6R0V91hL8RPZ:RTX9RDT
8a/L7R0S9BHW92<Q7alP8B8`8QDD7`FlOofJYHRJPh:2NWQeLFi[JVUYJ6IRH69W
JhB3Ph9oMFMMG6aSGfeUEV9MCdiJGUQNKGMgJEMKKgI^MhMJGg5OJF1bOh5cJ6]_
KEUjQFiRL7Q`FVicNX=/FViePWAYMW=_Pha_M8N3S9bI]H=VKg5VNZ9DLh5gO9NT
W8>;NhN1QIAFOe9FBT]GASYAFEA@D59BCTYIEFiPM9I/E5]cNF5?Fg9oR6A^RG]Y
K6Y^O6i]B3=>;eBNXJFPSkK=a=Jcdl^Ud<ZmeLZg`L2i`kk6`=K9`n?1R49CJXj;
L=6abnZeWKJOVZ:_][Bf^kN/[jFW][Za]<6b][NbZj^d_:nUWInY/:jYOhJ;TINJ
VINDJH:;MfYjU::WOi6SPh6<Khf?OFEbUj>C[YB1QY>IWZF/WIVMSWf;ZhaXIWIb
Mg]ZM5MHIVYiNf1JDU5IFeIIHeAFEeMDCdU5;cDe=3e;Bd4Y<S`m>3@g>c]5A3Tm
D5QA=TA7@DUMIEe5ATE1?Cm6CBa3?S@n=b/fCcU2B48g=3i9;SDk=bhY;C<];bd[
=D0j:SPl?cXb:bX[;BHX<cHb=3hl?D11?c/g=2X];bdW92HY8b@W:BTX9bH/;S4a
<2/V8bTX9R<P7Q`KnB@87RhP4DB9LbHPoR7m8WlM7R0Q8OfJYHRJPh:2NWQeLFi[
JVUYJ6IRH69WJhB3Ph9oMFMMG6aSGfeUEV9MCdiJGUQNKGMgJEMKKgI^MhMJGg5O
JF1bOh5cJ6]_KEUjQFiRL7Q`FVicNX=/FViePWAYMW=_Pha_M8N3S9bI]H=VKg5V
NZ9DLh5gO9NTW8>;Ngn7PHFDEU9FBT]GASYAFEA@D59BCTYIEFiPM9I/E5]cNF5?
Fg9oR6A^RG]YK6Y^O6i]B3=>;eBNXJFPSkK=a=Jcdl^Ud<ZmeLZg`L2i`kk6`=K9
`n?1R49CJXj;L=6abnZeWKJOVZ:_][Bf^kN/[jFW][Za]<6b][NbZj^d_:nUWGnO
ZK2^ZHJ;TINJVINDJH:;MfYjU::WOi6SPh6<Khf?OFEbUj>C[YB1QY>IWZF/WIVM
SWf;ZhaXIWIbMg]ZM5MHIVYiNf1JDU5IFeIIHeAFEeMDCdU5;cDe=3e;Bd4Y<S`m
>3@g>c]5A3TmD5QA=TA7@DUMIEe5ATE1?Cm6CBa3?U@d?SL[=SU2B48g=3i9;SDk
=bhY;C<];bd[=D0j:SPl?cXb:bX[;BHX<cHb=3hl?D11?c/g=2X];bdW92HY8b@W
:BTX9bH/;S4a<2/V8bTX9R<P7Q`KnB@87RhP4DB9LbHPoR7m8WlM7R0Q8OfJYHRJ
Ph:2NWQeLFi[JVUYJ6IRH69WJhB3Ph9oMFMMG6aSGfeUEV9MCdiJGUQNKGMgJEMK
KgI^MhMJGg5OJF1bOh5cJ6]_KEUjQFiRL7Q`FVicNX=/FViePWAYMW=_Pha_M8N3
S9bI]H=VKg5VNZ9DLh5gO9NTW8>;Ngn7PHFDEU9FBT]GASYAFEA@D59BCTYIEFiP
M9I/E5]cNF5?Fg9oR6A^RG]YK6Y^O6i]B3=>;eBNXJFPSkK=a=Jcdl^Ud<ZmeLZg
`L2i`kk6`=K9`n?1R49CJXj;L=6abnZeWKJOVZ:_][Bf^kN/[jFW][Za]<6b][Nb
Zj^d_:nUWGnOZK2^ZHJ;TINJVINDJH:;MfYjU::WOi6SPh6<Khf?OFEbUj>C[YB1
QY>IWZF/WIVMSWf;ZhaXIWIbMg]ZM5MHIVYiNf1JDU5IFeIIHeAFEeMDCdU5;cDe
=3e;Bd4Y<S`m>3@g>c]5A3TmD5QA=TA7@DUMIEe5ATE1?Cm6CBa3?U@d?SL[=SU2
B48g=3i9;SDk=bhY;C<];bd[=D0j:SPl?cXb:bX[;BHX<cHb=3hl?D11?c/g=2X]
;bdW92HY8b@W:BTX9bH/;S4a<2/V8bTX9R<P7Q`KnB@87RhP4DB9LbHPoR7m8P@M
7R0Q8@FlOofIXhFHQ8J8JFa`LFiXHEe]K6QPFUm^O9Z>P7MbJf1FJgM[I7EbJgaV
F5ERJFASJEaOF4iFJg9[NX1ULg=ZQWASIfn0UYYjDfYmOfaYMgMVOXAkOhijHfmb
OW1WMG9^PHIhPhf6UZRM[H5YM7EXMiUTLgE`Q:N_WhbER9ZGUIU@OdmRFDeBACQ7
G5MCE5QJF5ETG7EQHgQNHeAYKUY=G7R9O5m/Q79QJ6U5L5Y=?C9:=eNGU9nYW[k;
_<^]bLBUc<VidLNf`<6jaL?<`m;2_MjmJTQVMHYnGJZfcNbkYKnYYZZd^KFf_KZa
^Jn`^kbd]/6a/k>/XYjQYIRNYJZZZ:NW0hb;RHOnQWn7IGV1M6n1Uj:TP8jOPgn8
Kgb=RgQkUJ6HZifIZ;:/Xin;TIfSUX>0RXeeOHQeKG5UN65UL6acLUM[HEmUI5aM
IV9PG5E=ACdi?T90>d1:Ac`d>T10>cPk?b4gBDiADdHb?DU>BU1PI5aBDe9:@3Th
>RTo>S<o>C0n>T97@C@^<S@j>CTh<bh^<cP_=C@_<STe:3hh<c@h=RhV;2LZ=STc
=3a0@44o?3La;R/];R/U8bL[;2`[:odZ1bHW:BX[:RTXoR<18R;n8OTTOaP[9AHc
HEHS:2LV92<Q81lP8B<U9_fIXhFHQ8J8JFa`LFiXHEe]K6QPFUm^O9Z>P7MbJf1F
JgM[I7EbJgaVF5ERJFASJEaOF4iFJg9[NX1ULg=ZQWASIfn0UYYjDfYmOfaYMgMV
OXAkOhijHfmbOW1WMG9^PHIhPhf6UZRM[H5YOgAeJ7NII7=eL8BW[in<UHRJUiFI
D4mRFDeBACQ7G5MCE5QJF5ETG7EQHgQNHeAYKUY=G7R9O5m/Q79QJ6U5L5Y=?C9:
=eNGU9nYW[k;_<^]bLBUc<VidLNf`<6jaL?<`m;2_MjmJTQVMHYnGJZfcNbkYKnY
YZZd^KFf_KZa^Jn`6;^l];K1/K>c[::NXJFHWZFZZZRWYhb;RHOnQWn7IGV1M6n1
Uj:TP8jOPgn8Kgb=RgQkUJ6HZifIZ;:/Xin;TIfSUX>0RXeeOHQeKG5UN65UL6ac
LUM[HEmUI5aMIV9PG5E=ACdi?T90>d1:Ac`d>T10>cPk?b4gBDiADdHb?DU>BU1P
I5aBDe9:@3Th>RTo>S<o>C0n>T97@C@^<S@j>CTh<bh^<cP_=C@_<STe:3hh<c@h
=RhV;2LZ=STc=3a0@44o?3La;R/];R/U8bL[;2`[:odZ1bHW:BX[:RTXoR<18R;n
8OTTOaP[9AHcHEHS:2LV92<Q81lP8B<U9_fIXhFHQ8J8JFa`LFiXHEe]K6QPFUm^
O9Z>P7MbJf1FJgM[I7EbJgaVF5ERJFASJEaOF4iFJg9[NX1ULg=ZQWASIfn0UYYj
DfYmOfaYMgMVOXAkOhijHfmbOW1WMG9^PHIhPhf6UZRM[H5YOgAeJ7NII7=eL8BW
[in<UHRJUiFID4mRFDeBACQ7G5MCE5QJF5ETG7EQHgQNHeAYKUY=G7R9O5m/Q79Q
J6U5L5Y=?C9:=eNGU9nYW[k;_<^]bLBUc<VidLNf`<6jaL?<`m;2_MjmJTQVMHYn
GJZfcNbkYKnYYZZd^KFf_KZa^Jn`6;^l];K1/K>c[::NXJFHWZFZZZRWYhb;RHOn
QWn7IGV1M6n1Uj:TP8jOPgn8Kgb=RgQkUJ6HZifIZ;:/Xin;TIfSUX>0RXeeOHQe
KG5UN65UL6acLUM[HEmUI5aMIV9PG5E=ACdi?T90>d1:Ac`d>T10>cPk?b4gBDiA
DdHb?DU>BU1PI5aBDe9:@3Th>RTo>S<o>C0n>T97@C@^<S@j>CTh<bh^<cP_=C@_
<STe:3hh<c@h=RhV;2LZ=STc=3a0@44o?3La;R/];R/U8bL[;2`[:odZ1bHW:BX[
:RTXoR<18R;n8OTT51P[9AHcHEHS:2LV92<Q81lP8B<U9PG2OojHX86EQH^?J6mi
OgieJF5cL6QNFVAiRZ6<M6QYJV=JJWAUGFmaL8AbHei[Mg9WHEQLFeUSLWE^S7me
PeeDP5]/J6A]Qi^ANWV1NVa_OGIPQX9^LHIhHficOg5ZNgUcPgb0T8YkTj>:TG1Q
LGEXL8YVL7J0WKJXR96HS:BUWiE0OeV3Pf]/JV1VGe]GF5aPGeaOEGE/IWEdWV9^
KUY?GgfBLUe_P6MFHFAR[h=EED]ECE^CRibb[<G8g>?:e/bdblNcc<>c_l6lalOA
aLfi]]VeBE^7RXYcDX:K/=>/XL2`/k:j^kBd_;bea;^i_K^e]Kb_/[B`Z::PXI>T
][R]XIfOOj6KTXV4PhF7KGIhLG:0SI6SQhjJQh64MFR3THF2TI^HXiRHYZjTV9>2
UJ6KT8b7P8QiRI=gJFiWO6]eOG1cMEm^I61SH5IFGF=OF4m7@C`jBdi9?d16@CA1
@dA1?3/o@ca2@C/mB4a8@4]AD5AKFe=EEeI>@SLc<SQ9@Ca7?SI9Cci5BT@g;B/^
@S/c;c8f>CTc?T4g<SDd;D0c:Rlm@3<T;2L]>S`e<cY1@Cll=c4/:Bd^;BPS8bT_
=S<_:bTZ;2hR8R4R92LZ;20P8B8S92DVnBAo5RDX7B<d<b4^;B/X9B8P7b8S9RP[
oYRPPIF5RhmXKgUoOWEYHG=`J5iJI7V:XHadJ6UZHeYZM6EMKg5`Q79SGV]gLVMQ
F5aKFF=bMFj<OgF3GEB0FfaXI6f7Vi5jNH5jK6mmMV26PViaQWQSKW=oLFYkNG>3
O82@RW^CXhZAL65oLGEXL8YVL7J0WKJXR96HS:BUWiE0FH>3JfaZH6IOFeMHG61O
G5mEMFaVMGBNHVi^FTmOOI9bGFn0IeIQI6:_PeEEBeE=Fi>;W;:/aLSLhl[Fc;C;
ak?<`k>o`Kc7am75cKVffKE9FhN:RW=BPY^`djbQ`;2c/[Zk];Bl_;G4^kUo_K^e
]Kb_/[B`Z::PXI>T][R]XIfOXI^BRHB3QHM]MWQaLX2=TJ>7SYZ7PHAeJ8>AQH:A
ViRSV9RV[ZBHTh:EXI^@S8N0R7V9TgMYKVMlJgEmL7=eGfiTH6=PEUIMHemHCdM1
?3Y;CTTo@4I1=453A44l>cm3?491>ce8C4Q0Be5TD5AKFe=EEeI>@SLc<SQ9@Ca7
?SI9?TE:A3L]:bi2>c<_<SHi>C<n@CLb=C@]@3<Z;ce0<b@/9bdj?3Dc>T51?c`g
<B`Y;Bh]:2<S:Blf<bl[:BX/;R8R8B8T9bX/820Q8R<T9BKi97lF9BPM8c@c8Bh]
:bPU8R0O8R<V:2_nV:21UHF;SfQ_NGmnMFUQLg1XGUYTNHZQS7AXJFYSFVYdIEe_
LG24LV=NJgMbIf5HG5]IHg9eKXaoMH=ME81KK6QTKHNKTGYiPGY/KgefH8J2KW66
N6=^LgmaJW]iLh=lP92:Ni>SRY5`HGmaMFQ`RVI`MX2M]ZR8TIR<Y:FOUD1IPh=[
K6YPIUmKEeQLH5mLGeEeK6IeM9iRKViJCemmTW9MKh1WEV5THZn3EEE;EDeKTh^L
/Zc5b=cSb]K<]<_7/lc3/ko1_<O7dLG=^KKI]DUKQhZ:Le:2Vk3C[:70/;>b^[^d
];bl]LBk^Gnm^kFe_:nb];2XXZ2QTjBf^:fQWInQVi:9Q8>5QfefN75bP8fAXhN>
VXN1Q7EXPi65PY6KV:>HV:J^Y9RCPYFQVi2<Qh28NHVCMfU^Iga[MGe`LgEOKVAP
Hf1FEUeSGeQ?Ad4l>T]>BCm0AT4d@D=4@C`k?d<l@T4k?DQ<B41;DFA@E5]KDeEG
ETi2=c<b>4U1?4Ln=TTnADY4=bd[;T8k<blb=STi<ci1=c8e=2e0<bX_?D0c92`W
;CXl=C<j@D4o?3La;2T];RdX8b<Y;cHc;b/Y:R`^8R8Q8R@W:R`P824R8b@U9_TT
51HU:1dS=3<Q;Rd[:2DR81lR8bHX:`F`OonGWGfBPh^AJg9kPH5jL6UhKF9QJWN1
QHejIF5[Lg1XIg9TGFi^JGagJVA_OG]WEF9SI6M^LVmXTGQkSE1:Pe=QLWY_JGR>
VWV0O71_NGM[MGEUIGM^IG]fPGA_Q8=jR7b=WHYfTIijQFeWNGicMHMMM8jS/jf6
FXnAPIRNV8XaObeZLeMIHeiOHeaFEEULFeUMBF]]JW9dZWn0Mf=EH7fDM6MjPV1?
FUeR`h<nBdE4@f2JTj>f[LG8aLJk_KR_][F_b<2a_l:nb/GA`/Jd]]JZ>GJRVX]a
G7E]OjJ=SkJ]][Bk^K2`^K^eaKnj]k>_[k:^/[Jh]kBa/:Na^k^aXi^HOjVTW9B=
RHN7O7YdL79gN7FQSXbBRh5nNFEiQH:5TYVFYiJ=TYJBTYNKZZB8PIBOV8=_NhMc
KGE^PW9kOfmdOVmREe=FDdU8D5AAC4Q6AdU;BD]5>c]1>be8AT8n>c/o@UA=@3Hg
A5=K@DQ>DE9BCDQ:C4]5?CTk?Si9?CQ1=2e6Ace4BTLm<Rd]?cH^;cLk>38_?dHk
<S@g=CTa;34k?SD[;2P^>cdd<CLk>STf<bl/:R`]:bHR8bXa>CD]9bDV:RdW9B8Q
8RDZ;OhSm2Ao7B4T8b4Q8R@];2/Z:BLV9R<T9BP/oiNMOI:3Ri5[LW^1PGY`JGQ]
HV5ZMh65SGYUHF]cL6QWLVAMKViYO7MZI6mmNfMEHV=TIfibKfRAN7^=D4Z3Df5b
NVmYN8jJNH1lL6miMf]eMFEUMfiUNgJ1M6n4PgZ8O8fMRWJAWWZ5KFMoNGicMHMM
M8jS/jf6FXnAPIRNV8Xa;FYcEeUSGUmSG5IEFEaKFEe9JfeZLWBZOh1gHeEPOIAd
IgZ2H4mJGF;3Pci;ADA3H9ZCXkJ]aLS5a[^m^:nf]Jo8`;6o`[k:aM72a[BfeZXi
MZ:JRg5LMFeoYXf?]Zff];^i/;2i^kG5_kYo]k>_[k:^/[Jh]kBa/:Na^k^aXi^H
ZJBLU8f9QhMlNWA`LWMhMJ6>S9:;PGiiIGV5PXFBVIJWUXfBUY:BUi^ZY8R1U9nH
PfmkQg=]MFj2LW]oKgAnKf9GDeICBDQ@E55<B4I7BD]9BdDk>d4k;DQ6@Shk>cm2
E4e0=SM4De]1B4iLDE9BCDQ:C4]5?CTk?Si9?CQ1=2e6?DA:Acdb;Bdo=Rh_=c/h
<RloAS/b=3Le>C4/<C/n=B//:2hk?C@a=c/j>CHc;b`Z;2d[9R8S:S4i=BdW9BHZ
;BLU8R4R9BX]oR?d97lM8B@S8B4R92d/:bXY9bHV8b@U:2coUiemTX>;TF]bNh61
NW1YN6eRHFYgPHF=NVEQJg=`J6MbI5e^KVUlMfYTKgekIeERHfAWKW9_J95hNhe@
BX=CHG9jKfUhSYYiP7a`KgUgJgEeIFEgKVEkMX5dKhB3NXQlSIf:MY6NNXE]Igmi
OW=eQeedSZ>c[HIJSi61V9jHRS4]JW=GFF=NGf=LEUEIG5]IGDU[KFYbM:YoP7MS
EF1mU7AWNX9PCeYMH/>3?T]5A4=PVY>S]Zg5b<G6^kfh[kJe[lS0/Ko2_/[5dL;6
];KFZSUfXYZ;LEaeKGnVSHnf[KJd^kV`/;Vk]LFo^Wng/jn_/Zjb][Rg];6`Yk6k
^k6SViRYY9bDSHV7QgajM71bMgQeXHj<TX^1OWUUNHF2QI:IUZNFSI:FTY:GVjZT
R86DWiR3Kg^7LfeeKX9bNgm_M7i_HUMCEU=9B51DDDa8ATM9BdU;AC/k@C/]B4I2
?S/k?d9DCD0f=dACFd58CUaADU9=B4Y<BdDm>C/n?TTm>44d;DHmA4Y7?C8];Clf
;Rlg>cPb;cm6>c8d=cDi<B`a>che:b`X;S/m=34g>cXi=S<_;2X/;B/V8R<Z<CTe
;BLU9RX]9bDR8B8U:Rgn8o@T51dQ92<Q8B8T;B`[:RTW9RHS92DX;0G2OonHW7^>
OHB:IfY^LG5]J6EhJ5eXP8b2LgU]I6MbNGA/JgY`JgYcIgAdJfI/NGYTC5]IGFM^
K6EQOFQcSUaPXWE<KXV7NWAbL6ikP7E[KgUnK7YcKW9SI8MaNfi/QHEjQG^:VXYk
VJJ1UX=lQhUlNH=ZR:R`XhIPA8n=Mh^@T8Pd4RQTKe=FHUiOIEeDDE9EE59VAekn
Ggm=LHJ0Lf9GGWZEPWR7Qf5AFUIO^G@bBDiBDVRZZ;6gY/39][Fo_L?=a/R^b<2b
`<C0cKo<_<>h_]:F>hZVVXQaL7aVKiB1QjbS/:nf]Jb]]kVc`;jf[JVZZjZ][k6e
][B_Zk6/Z:Z][:BMW9bKUi6:PWioMg5cMG=^JiF<P866NGm^MWUkNWf<WJ6K[Z2H
W9jIVZ:Y/J>5P9VYYHm/J7A]L7Q/SGQhMF9YMfaNEE5FDd];Dde;B4I7Be1C?3lk
<cDm>Ba6@S`i>3Xl?C`oATi@BTA3AdU>E5==AdE8Ad8k=CHmABld:2Tf:BM7<cTo
@3/d;bdd;b`a>C/c:R4b>S8[<0Hd<bhb=CLfoSD_;BP/=cTa;cDa<C0_;Rh_;bT[
:bPT9B/a=2lX8QlQ92L`;BPT8bDW:RXY:2HT8R0OnB@@:24O92TX9bTW9bPZ:b`]
;RGn97lWoiRLNhimQ8YWJViaLFeXIGQXGFR0S89cNFeTIg9iM6a[NW1[NW=WM7A[
IVaiNVA<FeUMIfi/IF5mJ7>>G62RMDa^RHMjM79`KW^0MF]_NGi/NW=^LV=TQg5k
KVb5QGZ5NhZJRW^IYX6FPgb7RGaiPfZ8Z;2SQV14ShegRi2@R1<d:6A_DeIRGUmU
GEAADUEDDVI7G_iOOdeaQX1cHUMNNYF2N8N7HE5JEUniM399CU9BJ:ZX/KNV`<Vf
]Knm`lg6b:k8`;;0a<3=_lbl`kRndYHkRZJJR75`O6I_U867[:>`[kJe[:fg^K?0
_[J]ZJZ[ZZf_/KFf]:n[/JbXZZf/Y9fLW9^GTHZ2OWmgLG=eLfi[UHb0PHIiOfif
NG]jOHbMXI^^X9RLWYVJXZVaXhF0VJVUSfaXM6e`N6b=N7QeHVUgK5iEDEICBd]C
CD]8ATM;D5<l?c/c=Cdi;4I2?3Th>S`m?3m6CU1:A4=7BDiDDde7ADQ7@S/e=Se5
;c@X:CHY9dLc>Cm0>c@_;C@_;34i>c<Z8C8j<R/`1S@c;S8e=cKn=Bl]:2`g>C4_
=C4a<2l^;Rl_:B/[:2@U:c4d;bPR7b4T9c0]:2@S9BLZ:RTX9R@R81oi910X8AlT
:BPW:BLW:2X[;2d^9OhTObOoV9akSWf4RVMZKW5aKFQUN6QMJ82<PW=iKFAWLWUd
K6]jL6]jLfMdM6]VK7UjI4aKFEeWKVaUHGeXLhiLH:9eC6j9QgYdLW1^Nh1eJfmi
OVajLfibHfB7LG]^K8F5NXEkRYZ:NiVVPIJ3O8N9O7V3JXRX/:>6H4B?SGN;T928
4c@XI6mCEV9NGfEME55BEEABITMNoUmoCG66P7=REeijUH9hQhMQDEYFGkUd<TU>
DU9XZZRa]jK0bKJe_kg3cLK8[/S0//34`<foc;c3^;kBUS^:YYZ8LG1lIVnDPHN/
Xk2_][F/[KNi/l2n]ZfYZZ^Z[Jna]KJd[j^a[:RZ[JbTWIbLViNARX9nOgMaLgEc
KV^ES821QWUoKWIiNgYmS9fQVjjPV9bNVIZRZK6SQH2IZJF?K6QdKG1hK8ehN7ER
JGM/GUEAEU=;Be==BdQ6Ad]@Dc`o>c<e?CT/AT8l>CPj?3dl?dI>D4Y4@dM9CUAC
CDM5B4M2>cDf?DD_=2PY=RTWAc<i?d0k=2l]=2l/<CTk<bXQ<SXb:c06=3<^<SDg
=_he;bdX;3Li<Ble<C4`;bh^;blY:b/X92D[<C@_:28O8B@W<2dX92<U9bXZ:BPV
928P7oTT42PQ7b@Y:2LY9bLX:R//;BhUoR@09`FoOonIWW^:MGMjJfe`LG1/J6Eb
IF5cS9=oIgEbLG9dLVaWI7A/J7I/GFQ/JfQXL7=RBUYEG6egLfi`LVQTNeiNT6mb
LVi[M7]^FFYgOWIYJ7J6IgemMFiEE7UYLVEVPX=fOVYYMWMdTj22V8IkO7U^JVn;
X:nPO5a?CY2@Nhb?TYA8Oe1lOVU]KVM]IeiEDE=GF5MPAUYHHViCHWM/HEUDFgJC
SX>>RVMLH5>?`GM0BdeHBWFi]kfmYko8d<SNb/SD/Jfbbl>e`lK2c[g9^<?2b<Qe
CIRHThU`PXN9R:B>SZRIYJRa/Zf_^;Zc_;jfZJJ]/Jfb[ZZYZ:FNV:ZOUYZX/[6/
C9nQXZ6KTXR2NG5bO81jMWV:RgIbPG5OLX^2Nh:DYJVUWi^Q[:bOVI^MXYnEU9^M
Uj5fJW9]LWUZU7UdKeeRJUY/HUmSH5QHH5ECD4a:oTUd=3Pf<CI0?C90>cLg>S`j
=d0g=3Tk>T1;CTU;De98A4Q@CTPn=34e>bd^92e0=S]S;2hb=CDb<2h_;Rha=CHb
;aTV:bHT;2hY;3<j>C<`<cP_9bL`<B//=2/Z:BTZ;2l`92P/;2PW:RhZ9b<O7AhP
8S0^:bPVoRD7;B`Z9b@Q7aki97lZ9AlQ:c<a:R8S9BP[;S0a;2TU8R;oVIikRWEg
NV]]L75`K6QULVEQLhbCOfMeLW5bM79/IfAdK6QfK5eXK6]XJ71cHTYJEEa]Mg=^
L79XI7]NGY1_LW9^JgAkKUUZMgifJFQfQVMmOGE^EEAiJG9UIX:3MWiZJGIgM9>P
PYR6NgmlNFiZKh^P[j1lG4m>T91kS8nBU4Q@O7iYKFiWKFMNEE5CEeQGH4IJF69^
Df9gK65IE5]fThj3SXYWG61CSl5g@4]=F4Ye^KNm_JNob=38g/[8e;6]//_3]L?6
`/jmbKS3`/S8MDfHV9>9L8:7RHRTSXjXVJFX/K:][kRj/kbn]V6YYZfa[K:^ZZVX
YIjHZYnFVZRb/JbOXJ:QVi:8PWUaLWb0NWIiRX]fLX5aGg:;PW^2U:FYYInKXJb/
WiVKWJ:OUIBKWINQMVYbKG9iJYAiM6mMHVYJK69OHf1HF61EDe1<B_i9M3@h=S4f
@3db@3/g=cXl>SM0=c@i>cY0Bdi9Be=BB4A8D4i8?S@a=C/];R@]@3HkHb`^<SDe
<S0^;bh^<CDf<RlI9R/V92`^:B`c>STc<3<h;bLW<34[;3@[:RTY:R`_<2@X;2`X
9bX^:RLS7adN828`;R/X9_hU1bd/:RLT8AlNnBAo:RDO8B/c<BXR8bDX:bh`<B`Y
9B8RoiVNNhYeMgY[KG1aL6aXIG9UHG><TgmWMG9aLWAbK6MTM6aXMVaMJ6a[J6Q`
Lf9:FUELKGMcKW1bJ6AkGUj@Kg9bKV]dNfiIJWMnMVUXMXIWOGeeKUEDNFUbIFJ2
PgInJVUfMgBCX8:HQW]oO7U^JVn;X:nPO5a?CY2@Nhb?TYA8D7anJFe^IfeWGUEA
DeMHEf16FUQRKU=RMfaQFEAKMY>>Phj:IeaPDho1Md1;CEQ:MKVg_KfW_lS@b=k:
b=Ba[K;;`kG3a/;>_LVh`l;8b7E=V9RCRG22QhV8Y8j>Z9VUZ;6b[Jnh^[>l_[IQ
ZJJ]/Jfb[ZZYZ:FNV:ZOUYZX/[6/Wj6RXI^BR89iLG9lP7YfNHZ;MW:1LEmbRh9k
PYBUZJFOVj6/[9nIVifRWiFDVifGXGIZLVebNFZDNGA_GF9ZFVaRGf=PF5QPEE=@
C4[nBG@d>3Ha=T0m<T0k=cLj?3Xg@3Ld>C/j@4]>BD]CDTQ4B51>B3hd<CDk;BhT
;D0f>f</;S8e=C8`;Rl^;S4e=S8_6BH[9R@/;RT/<cXi<c0c>2lW9c0a:b`d:bXY
:BX/;c0T:2`/:2LZ;RXW8alM7R0R<2h[:2Kn9@L];2XW924O7_TT52XU7b4[<c4Z
8R<U:2/^<34/:BDR8PFiAonKX7b7KFUYK75hO7U`IUmXJ6ikQhMjKGIjO7M_JFU/
GVaQFf]VG6]UKFaUIfeSD6AKGg9jLfmcKW=EHEiBK5V2NFEFGG1fK_ieOg5ZJ75l
IGYkNWUODfi[LVEYQhYjPG=KGVecR9=mQGIYJF][KgFLYj^EK4i=FH^CQIRGVZ5K
DVIQFVAKDV9YHEUGGFAYJUI<I5ITQ75gM6EJF5AFKX^@Q8b8KVYZE:bZHC/`;3hO
Q;nf`<Zga/C7^MFbYjmcJKO@b;W5b<??`l^hOlO=ckU?KJR?UiMiTi:SVJjET:>>
VZ>^];:f_kjf_/>l[Jbj`;Zl]:bZZj^VX:ZWY:FZ/;Fg[ZbXXYZCS8UoNX2=S81m
QXjGNW:;Mf5mQ861RI:JXJJHU9VSXYRFWIZEV:>TVI:DWgimQWYkQGb=Lg=jLWQg
G7EZIFMREeELFUUGC5A?BDA1>Chl>3i8Ac`k=cDi?d4l=E0g8b0T;DMRBChnAdHk
>T=@E5E>@SPb<3`h;3I8>d5^=C@c=3Hg=S@f=C4/:Rli@BH];2L[<c0ToS@M=CLf
<bla9R8W:2@Y=2d[:2DU9bT[7RD^<2dZ:BXRoR7m804T9OhW2RDT8RXY:2LV92@S
nBAL8BXW6al`<bLT92HW:BX[;3Ha:R@Poi^PO8M]JFU/LGQlNG1VGfQXKW^7QgY]
MWYlMfmYJFaNK65KJfILJfE]K6EWKF=@I5]OLWYcKg=^LeEQGU9/FH9iIEIML7I^
oWEoLFYXLGaUNW]jNEmCKV]bIFV7RWZ1Le]NKG>8Tgf5MVUYJf]_MIbWZiE/CTeI
Ri>5V9NJXE]BIV5JI5]BHVUQFEMMI6UZETaTEVB4LGMdIEYHE5I^Ri24S8Q^JVYD
[:YQ>c0/?Qn4_kK0b[O6a<NieK:W[g=Y]m38^LG8`lo3bkQoalg?^Dm]Z8nGUgVC
TZ>I[YF@XhjJXjjd/[Jo_[Jn`kb][;[0^[bd[:Z[ZjJPZZNTYJZ`]KN^[:RRVY><
RGmjP8f<P7f6SYMjLX]gHGf4PH69TYZQYYRDVJ>RV9JMVYFHXjBITYBOOWf6NW^5
O8ecLgYbN7MLMFYUIf9GEEaJFEM<E4m9A44i?S`h?TQ7?3/g=CTo@C`eD3LS82@]
Af99?Si7AS/j@e1DEDi2>38`?3P/=TPk@Fhe=3<d=SLf=3He<B`Z;cU19Rd/9b/c
<2Cn=1de=cHc;c4V8RLX92Td;B/X9BDW:B/N9Bh`;BXY:R;n8OdP0B@UoRL:9B@R
:RTX9bHT92?i95`Q:RLK7c0c9b@T9RLY:R//=S4Z923oVj1lQfeYJFaaN7aiL6IO
J6Q^NhN7NVefNWagKfUYK5i/HE][IUa[IFe/IFM]He1TFembNW=_LficEF5NDVaI
PWUUEUe`MVknMGmaJVQaO6EjNgYiGe=^Jg9UJHN:NX5cFei]LhRCOHEfJFU[Jfme
W:N[UFa>CEV;ThFHUiZQFe9VHEYTFe9RJF5IEeeTJFYFC6AFI8AaMgAUFUQDEVj;
T8B<R6iZJUB/ZV4k<2`n7hBo]/3:]lK4akWE/ZN_LfVgd<RiaLS3cl?;^7o7cLni
CffXSiNGNI>BXiV^UI2SSYZS[[Bb][nn][k3_:f/^/2j_;B/ZZ^[YZ2ZYjBUZ[2e
]jj/Z::JThb9OgZ0SHb0OHJ>UgYbRgMQOHB1PHVBVZ6VV9BIXj:HUYfJUIRSY9VB
U9mnOHIjNhElSG=cNW9hMeaeJVEWHUMEG5YIEdaDCdU4@CTn?3PnB4Ll>cLe>Cm1
?3E@=b<P92e7HTTn?TM6>cY3D5AECT8h<S0l>2`fB3]1KSDd<c@f=cHd=SDa;2X_
>D4V;B`W:c<`9?hd7CDg=S<_<BHR9bPT:C@]:bPU9BLY:ahU;S0]:RTZ8_hQoB01
92Gn9`XU928Z:BPW9R@T8oTT524Z9a/O<3<W92@V9bTZ:b`f<BXT80FiOonLXWf6
If1MG6EbNGIXETYQKGZ0OGQfN7=jOWIZIVmjJWAUGFm`KX5RKW1THVYUEFMIFFQ[
GeQNHG=;F71ULfi>KhImJFA/Lh=fJf]]K6a^KWj0RIJ0K7acNVibTYF5RY]_JGj4
SY>2NfiVJWJ2T9^GXJNIMeI>EX6@Rj2MWJIROf=ZHFMjKVIoJfANGfQbNWeMGG5@
DWMXJh1^HUmHDfJ1SX26QG5cLUO9Z6MGAdUX@8no[koEa/g0bKgVaL7CTHRke<^k
al[4d<W?^/[DdjheRKN?XZV4X9^RUJR@Rib6Tj2^]kNlaL>i`l[3/kC5cLK7_[Fe
_<70_KRn`[ba[;:iOjnXWI68PX20ShZAVi=oO8RJYhMlVXE[S75iQ8b9R9:PZYbC
Ti:CX[FYUI>UYiJDXXmnSIZ8QiNFPFafRhnHTW1bIUmNEdU5C5IGF5QDCTM3@dM5
@4I@CT<h=CDlA4Hn=SX^;Sa1>d5@?S0^=cH[;3U7DE]MDT<f;d4i9bdi9bYGCdE1
?C`n?cln?cdd:24Z@5<k?3Lb>40h9chc:c0l?c<V<RDN8R8P9c@a;RTT8R8T9AXT
;c<a:bPX7QlR8b@S8R0I724U9bHT8RDU9RHW:2TYnB@75Bh_5a4W;b?m9odVOchh
;bHPoibROHIWH5eLIG9iMVQFBV5]NX1mN7IhLgYnMVYVKgYZM6EMKg1^PF9^L6AR
JVEEIeUIJ6]OF5iQLd]HL6EcKTi_QWeYI6acPgI[Jfe/K6i^OX29UX1/O7=jKW:B
UHF:VfmYOXB>Th9kKVIZMX:@ViNQYiUgETiFPI2;Oj2MWJIRHfYQIgY^IWm[I5iO
J79jOEeMLE1BMfQ[P6iRGeQCIX6>P8J5LG=bElVXIeM7BFQ0Skn__mG6cL39_NK5
`M>AR;_Dbk_7b/C@bLnjb]CC[SF9]hnRZHBPVj:EZ92;W8JCX:jg]kc5`kW3b/>c
]<G=a/Nn]KFl`L2m^;k2Okba[;:i[jRMTHR2P82?RY6KTgmlR9ZWQgbJQF^<LGV4
S8V8TZ2ZW9>CTY>R]JVETjFWUYBRSgj=VXR7UiJ1K7J;SiRBL79VGeiGBDE<EUMH
F5A>Ad=3AdE0AU1>@cPe=Ca4AShf>Rh^?44k@E0n<2hg=R//>DMAFeeB@cH_@CTW
E2di9bYGAD4m?3ho?cho?C@X8BY0Dc/l=c8h@3PW?S<[<3`o<bHb9AhR8R0W=34^
:B@R8R@U6R@_<c4[:2PN7b8S92<R81TL8BDW9R@R9BDV9RLX:BWi90LE;RlG4BL_
8odWoBIo?SP_9R3oW:9mQVMPGEaULWUfJ5I:HFejP7ehMWQcNWifJVI_NVYdIEe_
L6j1HVi`I69ZIEEWFEUXJemHGV5cBeQ`IG=^CVn6OFUTK7>3MV][KFa/KVinP8VF
P6alLgY^LY:EQHZKKfUnQ8jCPW]^IVYfPY2KUj6WVGMFCUJ1T8]oX9fMYV9SJV5W
NViVOf]TGUmXLWYmGEeaD59gJ6^0KV9OF5=VPHj0QXEaLg9GbJQWEdM9J42?_jno
eLK=`<Vmi/G1di68^mC;^lO:a=39ck[:e=>^=HVgSj:YQ:2KXYFXT8^LQY>P[[Ng
_<G3^L?:`k>daLg6akje]Kc1`;fh_/9o_;6//[V_Z9fAR8:0P8n:TI^COgb8VZN7
O9Z5JhaaNHB<RHRBX:ZLTi>BTj:eZIFCYJNFU::?OXfJR8NGUX5/MX^?V99`LVIO
GUM9ADaFEeQHE4i7@d=7AD16D4i3>3De?4A6?SHj;Rhl@C]1D3h`;SLf:b`iAe5K
GE93=Rm1>BMD;CTW:UM5@Cdl?Slo?Slm=2PQ:T1C>c`g<SQ0>2Ln<b/`?3lc9S8U
7R8R82Ld<BhY928R92DJ92lc<B/X:1hO8R<T8b8P6A`Q9BLV928U9BHV9bPY:OTT
1aD^;aLA9blSoBOm9P@n>2lV80GAOo5[OGAcD5eWHfMUHFQdMF]YK75fNWenOWmg
MGM]F4e=CeiWHEaMFE1JFV5aOGQSD5YVKVQHCeANKV=LI7=hJeaKGf5LEUMPJVEX
JFAPIWJ4N7QgLVYYN8^5QH5lH9AVL6b9TGU^OHAkNFMXPY2<TZFDJdI0BTi:B8f<
OifSWj=QOf]jPgIOFFb2MUE9GFIFD5]WJ6Y/KFe/K6I`GgI_Dg=iT7MaYVmTATZn
J5]<?4@fA9bb`lC3bL_7eK_Kdm_5NInc^;fm^k^o`l39[/jafY91X9J;RH^9OgJ@
/JF4R8n9SIVWX;?@/J_[[Zf]/KNj^kVm^[Fa[jna/lV`/[V`];:GOj>JWk6aVhZ8
Q7j3TIB7NgVPT7miOX9nN86JX92@XZ6>X8n7SYFBTIF?WZVSSh>7TJb=PIBKS8VG
PG]lOFiKHWQLGV5RH5YDD5M9FD53G4=8ASaGA3a8=T/d>3e2ADA2@2Hi?c4[>44o
?RDnPY5K;R`h>3DiBUQ>>S4_>d]7=2liGb`c>c`g<Rl_<c0];c8b;BTZ;C8h?T53
A4e4>C<c=3@b8bDY:b/Y9B<_;2@R;c`d8QhX<c<Z8AdN8R@V:2LU8Ql^:bHQ7alQ
8R`X9BL[;BXV92@S8R4P81lU9B<R8AlN7OhUObHX;2la8BH[;BcaJgedLe1MIf=W
IF5XM7E[JFaaMWYmOWioMgEgKEQ=CDmNIf5LGEU@FUYQLGehHe1JIViXF4mDGViS
G6AcN6]LFemQG5IGH6YUJ6UTH6IfQ7QhMg9ZJGR;QHF1O62DIW1/RI5iKWf4NgUW
J8:@S9:UU6]6@4Y>OdY8SHaoWJ>OXf5[NX=fGeU/PWIEBEeVEU1KIfQZK6e]K6aV
L5mfKe=cNI1gLJI_I4I:_VQKC3a4=TBL//?4`lW;amFkfm?KaGVO/kRm_K^k_l?0
bJk>/MZB@J2FRhV;RGmfT;6UQ8R?RHfIYj2cd;6[jjj][K6g^[^i_KZe/Jn_Ok6c
bK2b^K2d/YNSVYna/I^:R8AnPi6DQg]iX91oNGj2OWR1VZ2@T::QSZ2?QhjETY6E
SijYXhn3Qi6/SH6DVhb9Uh5kO7e^Ff9hG5iQHV1JE51GBEU1@ea3B4HlEd@lB3I;
=3Pm@TE4@T0V>Cla:cQ1?chU?X:AFbh/>3Pe>DYHJDhj<BlkBdLd;cT/<c/l=c8_
;c<`;Blb<RdY:Rdb>3i1@dA=A3Tc<c@d<R<U:B/[:BDS;b`T8Rll=28N:3<c:R4M
7R8T9RPW9B8O;R/V8AlO8B8/:2DW:bdZ9R@T8b8Q820O9BDS8R4O7Qgn9GlV:2`_
<B4V:bd/lF]mM7=@GFMSIfEQJ7AeJfU/LGIjOGinOgMeMfeHCDe?GVMQG5eID5YJ
HG5mN6=@FVI^J5Q?E5i^HeaTLgQ[G5]OHEaFEf1ZIFQYI61VMXAhN7MbJVUhRhF5
PGaPU6I`K8VANFimQ7]iIfR2T8bBYIA[AT1:CWm:B8f<OifSWj=QJgZ3MUmIK89f
EDUMIUI@FfMXJVa]KFa/IW1OMVmCLgV@Mg6VKfA6B[iXFd`lA3I4W;;3a<?9blOE
^m_CflEiWk>h_Kfk^ko3`<V^c[7JTT6PUX^9RhUoMY2aYHB8ShV=VJNP/m2aZn^^
[Jfa]kZk^Kfj]K6_[gna/lV`/[V`];:GXiZO/K6KRXR4OX>AU8MkNJ2@OgUnPWih
PIZPT92RXHjPShN>UI:AUHnNZJ>?PhNA[8f1U9^<RIN1NgamKU]RN5aNHF9PFUA@
EdUI@D=L@dQ6?5M4?4PfBc@h?D95A4909STo<B/h@Cln9Cj2TE/^;3Ph=CU:F6U>
>S4_>d]7=2li;3<k?3Lb;blc<2d_<S8]:BX]<SPn@D=4CD@i<c<d=38S9BT[:bTU
8bl/928_?3@R7RPc<bXQ7AhR92HX9bDR7bh[9R4O7b4R;2PU9b/]:RHT92<R8B0P
7bDU8b8Q7ahMoRD99RP/;c4Q9R/];0G54omePG^3HVMTI6QUGf1VH59]Kg9eoWMm
MXQkLg9[GeeUHV]ZGeeXLW9PGf=^N7ARDEMLHFATHfAUNFmWJG5eKVIVJfi[IFE[
LFUZJFEQHFI[HfYcM6YPGfAmPhVBOkF8Tfj:Th1iRY>;J61UNXjKZKEZF4]<C4Q=
EhF<QjJUW:1PGFE^LFm^LGEkGE5SKF9NJVe_LG=doWEDNG]LJF=DPY5oLW>]OFm<
ELAUD44g@cQ7YkS3_kk5b/OQ`<RhaL2Ca;g1a<?1`/O=c<fmcl7KOEN]XYJATHf2
N9b`WhJ9Qh:AUZ2QYJZNY/fg][Jh_?jnOl;0_K^j_;o1_:JZ]:fd]IbNTi>NW8Yl
O7]mRYfQV9BHQXEoMFYVJFikRH^3T:NQQiR<RIFOWYjSWj^bZiZCW:RPSXfJU7im
Sh5lP8MoKVehHV5QHV=UIfQEB5U2AV19CS`aBCD_?2]0=cXn@TE6ADDe@D<h=T57
@T4T94I@>BhkK459BD=3Ad0c>S@g@3dc=TE2AdU4>BlY:2/Z9b@R8bHX?3`m?C`j
=cI5?CDa=3Lg=R@V:B/[:BHT9RLR7RLb;QlQ:S@f;bLT9BPV8b4R92LY:RPT8R8U
:B/_:bPY;2dZ9R@T8b<R8B0P:2PW9bKn9OdT72LZ;Bl_<S8^9omePG^3HVMTI6QU
Gf1VH59]Kg9eoWMmMXQkLg9[GeeUHV]ZGeeXLW9PGf=^N7ARDEMLHFATHfAUNFmW
JG5eKVIVJfi[IFE[LFUZJFEQHFI[HfYcM6YPGfAmPhVBOkF8Tfj:Th1iRY>;J61U
NXjKZKEZF4]<C4Q=EhF<QjJUW:1PGFE^LFm^LGEkGE5SKF9NJVe_LG=doWEDNG]L
JF=DPY5oLW>]OFm<ELAUD44g@cQ7YkS3_kk5b/OQ`<RhaL2Ca;g1a<?1`/O=c<fm
cl7KOEN]XYJATHf2N9b`WhJ9Qh:AUZ2QYJZNY/fg][Jh_?jnOl;0_K^j_;o1_:JZ
]:fd]IbNTi>NW8YlO7]mRYfQV9BHQXEoMFYVJFikRH^3T:NQQiR<RIFOWYjSWj^b
ZiZCW:RPSXfJU7imSh5lP8MoKVehHV5QHV=UIfQEB5U2AV19CS`aBCD_?2]0=cXn
@TE6ADDe@D<h=T57@T4T94I@>BhkK459BD=3Ad0c>S@g@3dc=TE2AdU4>BlY:2/Z
9b@R8bHX?3`m?C`j=cI5?CDa=3Lg=R@V:B/[:BHT9RLR7RLb;QlQ:S@f;bLT9BPV
8b4R92LY:RPT8R8U:B/_:bPY;2dZ9R@T8b<R8B0P:2PW9bKn9OdT72LZ;Bl_<S8^
9omePG^3HVMTI6QUGf1VH59]Kg9eoWMmMXQkLg9[GeeUHV]ZGeeXLW9PGf=^N7AR
DEMLHFATHfAUNFmWJG5eKVIVJfi[IFE[LFUZJFEQHFI[HfYcM6YPGfAmPhVBOkF8
Tfj:Th1iRY>;J61UNXjKZKEZF4]<C4Q=EhF<QjJUW:1PGFE^LFm^LGEkGE5SKF9N
JVe_LG=doWEDNG]LJF=DPY5oLW>]OFm<ELAUD44g@cQ7YkS3_kk5b/OQ`<RhaL2C
a;g1a<?1`/O=c<fmcl7KOEN]XYJATHf2N9b`WhJ9Qh:AUZ2QYJZNY/fg][Jh_?jn
Ol;0_K^j_;o1_:JZ]:fd]IbNTi>NW8YlO7]mRYfQV9BHQXEoMFYVJFikRH^3T:NQ
QiR<RIFOWYjSWj^bZiZCW:RPSXfJU7imSh5lP8MoKVehHV5QHV=UIfQEB5U2AV19
CS`aBCD_?2]0=cXn@TE6ADDe@D<h=T57@T4T94I@>BhkK459BD=3Ad0c>S@g@3dc
=TE2AdU4>BlY:2/Z9b@R8bHX?3`m?C`j=cI5?CDa=3Lg=R@V:B/[:BHT9RLR7RLb
;QlQ:S@f;bLT9BPV8b4R92LY:RPT8R8U:B/_:bPY;2dZ9R@T8b<R8B0P:2PW9bKn
9OdT22LZ;Bl_<S8^9`G5??mkQ7f:KFYLIfaZHfEZHeEgN7UjNWQfMHMgJVQUHV]i
IW5dKFeiPX9VHf9YLFmSF5MEEemYKFMQNWMbKV_nJWm[L7AcKfa]KfMTHF5SHemL
IfieMW9^K6]VKGV;O:n2SgV@UhR3T9RBIG:1SIn`[jA6BeEHBcm:Gh:<RZZWViiN
F5UPKgenL65iH5MVL6]/Mfm`LWAgN7YkLWIEGEM=OHZ@PVjHLg=UR/YO@cTgAca;
]l73^[W4c<_J_kV/_l:[fRO2a<G3`<?;d]G:b/SAceMa[Z>FTY>AR7n[Zi>5R7Yg
U9RNZ9QoSjf^nkYo^k^o_;Vf];>d];NRYjnVZjfEXiVEVYN:Ogf8SYbWWhj:TXjL
XiMoLg^9LWUgN8fUWH:GSXnMYJ6PYInUYYb?SYb[WINLXY9hNHj<QHJ?SGiaKUaH
De1AEUaPBSe?>3eH@DM4=DTe<40_A3Xk?D13ATQ9@TA0>Se7Aci3=2X/;c9P?Ti3
DEI;@3lm=d<j=SHc<Sm@BD]:@cL]:2PV:R/T71/S;3dm?3Xg<bl/?3H`;c@h>CPV
9bTZ:RTW9QdU9AhP:BTQ7bL_<bl[:BTX8adI6b8Z<2TW9BDW;34e<bl[:bh^:_hU
1B@S8R4Q8?hZCR//;2d]9BDT9BHY;2hh>CTb:OmkQ7f:KFYLIfaZHfEZHeEgN7Uj
NWQfMHMgJVQUHV]iIW5dKFeiPX9VHf9YLFmSF5MEEemYKFMQNWMbKV_nJWm[L7Ac
Kfa]KfMTHF5SHemLIfieMW9^K6]VKGV;O:n2SgV@UhR3T9RBIG:1SIn`[jA6BeEH
Bcm:Gh:<RZZWViiNF5UPKgenL65iH5MVL6]/Mfm`LWAgN7YkLWIEGEM=OHZ@PVjH
Lg=UR/YO@cTgAca;]l73^[W4c<_J_kV/_l:[fRO2a<G3`<?;d]G:b/SAceMa[Z>F
TY>AR7n[Zi>5R7YgU9RNZ9QoSjf^nkYo^k^o_;Vf];>d];NRYjnVZjfEXiVEVYN:
Ogf8SYbWWhj:TXjLXiMoLg^9LWUgN8fUWH:GSXnMYJ6PYInUYYb?SYb[WINLXY9h
NHj<QHJ?SGiaKUaHDe1AEUaPBSe?>3eH@DM4=DTe<40_A3Xk?D13ATQ9@TA0>Se7
Aci3=2X/;c9P?Ti3DEI;@3lm=d<j=SHc<Sm@BD]:@cL]:2PV:R/T71/S;3dm?3Xg
<bl/?3H`;c@h>CPV9bTZ:RTW9QdU9AhP:BTQ7bL_<bl[:BTX8adI6b8Z<2TW9BDW
;34e<bl[:bh^:_hU1B@S8R4Q8?hZCR//;2d]9BDT9BHY;2hh>CTb:OmkQ7f:KFYL
IfaZHfEZHeEgN7UjNWQfMHMgJVQUHV]iIW5dKFeiPX9VHf9YLFmSF5MEEemYKFMQ
NWMbKV_nJWm[L7AcKfa]KfMTHF5SHemLIfieMW9^K6]VKGV;O:n2SgV@UhR3T9RB
IG:1SIn`[jA6BeEHBcm:Gh:<RZZWViiNF5UPKgenL65iH5MVL6]/Mfm`LWAgN7Yk
LWIEGEM=OHZ@PVjHLg=UR/YO@cTgAca;]l73^[W4c<_J_kV/_l:[fRO2a<G3`<?;
d]G:b/SAceMa[Z>FTY>AR7n[Zi>5R7YgU9RNZ9QoSjf^nkYo^k^o_;Vf];>d];NR
YjnVZjfEXiVEVYN:Ogf8SYbWWhj:TXjLXiMoLg^9LWUgN8fUWH:GSXnMYJ6PYInU
YYb?SYb[WINLXY9hNHj<QHJ?SGiaKUaHDe1AEUaPBSe?>3eH@DM4=DTe<40_A3Xk
?D13ATQ9@TA0>Se7Aci3=2X/;c9P?Ti3DEI;@3lm=d<j=SHc<Sm@BD]:@cL]:2PV
:R/T71/S;3dm?3Xg<bl/?3H`;c@h>CPV9bTZ:RTW9QdU9AhP:BTQ7bL_<bl[:BTX
8adI6b8Z<2TW9BDW;34e<bl[:bh^:_hU1B@S8R4Q8?hZ4B//;2d]9BDT9BHY;2hh
>CTb:@GA6_ikRG^0HfAGGF1MF61_Lf]^Kg5bLW5_KWUZH?iQOfakEVYkOGeoNW1U
HV1TJfeYI5IHGF9UHeiJKGAhLfQPGf9TJ6a/JVERH6EMEeYTJFMRLW=]IfinRHYR
H6EdGhaNLHBCUhZ4Rhj9MY6RWj2PQF13C5QKBSa7GHf<P:2VX9mIHF1TLGajJUY_
GUQUKfmcOVa]KW1dMg]mJWUQJV9BOgIfQ8E/TGEcI9_9FCm0AE50C/;7`kRjbMCD
_k^g^/o8]<jo`<2m^ko7cmK5ckkF/c^7YY^?SI:CSXNbXhIoQ6m]TifQ/8mTTL2S
]KNh][6_/;:l^[F`ZjNTX[ZUZJbLW9f6WIRGVYV@Q7f2RYRMSWYiQG^:UHekKgAo
K7EhNXRHOiB4V96DWj2FTIFPX9^=PXBEYJZRXJ:GQXNFVHj5R8Z1Kf5KEe9<B4M8
B4/nCcPkECe2BSU;=cA5=4Pg>3Xm@4A7BDI0>3LnAD0h;ce3?3Q0AdLmBDi8AT]9
@4@o>C@b=D=@>C`m>C8_<3<U<CTd9b4X<b`]<38c<c8a>C@^;S8eJCDc:2TY:RXY
:BPN:RdU8RT]:A`Q:2`];2XY8b4N7AlU:c0_;BXY:Rhc=SD`;2`^;RXU9RHU92<R
8R4X:2T[;2h_;bXY:2PY;2h`<SDh=C3nNhUkP6=TEeePGEQPKg=[KVmaLW9aKfii
JV3nHGm/NeIZNgemOgY`IF9PI6]]JFAFF5eRIF=NFVedN7=XH5mRI6Q/K6YUHV1U
GEMJI6UWHW9cKFM^OXV:HV1UM5n<GW64TiN:Q8^>RGJAXYnPX8EP@daHFdXlAef=
S82PYZ2OFF5PI75lNVYJKeiHIFm_Lgi/KFi`M7MkOFYiHFYRDWmfMXB5K95eLfBK
bETo@4EA@4k2al>h^/WDe;nk]k[?b;C>_l30_K^oaloFaLnne[<kQjJKShfBThj7
/Z>6OhA_KI>MXK2?I970XkFg^;Ja[k2b_;Ze/:^WY::jYJV/W9bMQYfHUiZIT8Am
PXZHWHijNHEkRYF=NfmdOfaeN7Z8V7nDQ9RAU9nPUY6EX:2KSH:4UJFZXZ6RUhJ7
UYV>QHR:PFmQFeMBC4Q7B4Q;?Tlh>eDm@TXiBcLdACA8=cPj?D14AdU6@3Pg?TE0
>2lm@c`h@4M7?DU>B4I;BD14?cTd<SE3D3Tl?CTb;c0c9C4i=2LQ:3</;C0b<c<b
<CTd;Rhb=FTe<bPY:BXZ:BTX7RX]9B8Y;BTL8BP/;B`Z:B<Q7QdO9B/`;bdZ:BX^
<cHe<2`/;RhZ9BHV9B@S8R8Q:2PY:b`^;blZ:BPX:B`^<38e>3D`oW^9Nh1SI5MM
H5eHH6mcJfi_LG9bLFm^NFYPoV5oK7]FJW]mOGmjL6ERH6A[KFUTEUQMHVESGUY]
M7QcJ61OHVAXK6aZIF9PIEeGFVAYIf9bLfeWKWj9RV9PIGAOS5iaQ9>GRXB;SXUf
TJ:OX:25H4=<F5]:?4MMSHb0X:JPWeUQH6AaO7YZFVmNF6E_Kg=nK6e^L7AgNgeZ
NF5ZHU9oMWJ4QFbAMG=TVlUI?d15DD1>`/O3^;[9e=Bo^kNjclRdc[o0`;fk_lO?
e/G?_]Jc>hNVVhn=TY>>Qk:SQWn4KffCWJ6`SfBA`:>e]kRf/Jn`/[bj]K2[YjBR
^ZFY[9bLWHJMV9NJVI24OH::V9f>NWV5NhZESG]_M7m/MGQjR9QoU8BHTIBOX9JA
UJ2PVhf2Q9FUZZ:QXYN6QiJISXF8RX5_HE]GDTa8AdQ8Bci?>3]E?D9:>D/g=4Dd
B3Lh>Se0A4M9AT0h=ci5@3P_?D<l>417Ace9CTQ6BdU0A3li=38e@e0i?3di<Rl`
<bDa>C@W8BPc;2d`<S<c<S4i=2h^<SE>=C<X:BTZ:RTY:1hZ;BDR:BdY724X;2d/
:RTS8AhM7bD[<2l]:RTZ;S<f=C0/;2h^:RDV9RDT8b8R8BPX:B//;Rl_:RTX:2T/
;S0b=CPe<0GAOo5oUWecEV=ODU58@4]SL6mIFeiQHfASHfiTH6IWHfQcE6MdLVm`
JUmQGUeQIfe_Ke1NK6iVH69XI75mO6mRGUmRHfAUHemIE71UFUYRJVYVIVMNEV9j
PGUhJFA_EX1FLG^3Qh:2R8^9U:BQRGYbEBm=BTeABdE@HYZ;LI:SY9mAOf9XKW9a
Kfe]J65QK7EhOH=_Kg1bMgf2QHBEN7Q/HHF1Ih=fXH]hE932E4=@Ee]5DlK9`kZo
d=WG//2b_]?3^L2m`<6o_Ko7cMO9d[kGU4FL[j:ET9>ET8V^W7egP6i/TIZPZH1M
V/^S/KFh]:fY[;2f]KBb[jbZZ;6OYZREUIR4OhR;Si:BSGmaIFemR85hPIAoPhN9
Qh=oO6emR8J3QX^;S8R=UiF:R8j_[:BGSHnMZ[BTUiJHUYFHUhYkMgn2MVISI6AR
GUQBCUU;FT53Fd96A352<352;Cdb=3Lk@4=6AdXo=cY2@clk6cM8@SXn?CA1@d51
CEQ??454@S/f>d9753Hh>3Da<cTo8S91@3<Y:S0X:blc=OhgBCTd;Rd`<2dY:bXZ
:BTZ:R/X<cL^:c<f<R8T:2da<S0^9bT/;c8c=3@j=S4]:b/];c8^:RX];RXV9bLV
9B@S8b8T9BHW:BX[;2l^oRao;S4b:blc<RoaOiImLeISGe9AB41;Hg1_FE]NHF=T
Hf=^I61VIf=XLeAWM79_L6YOHEiMHFM]Kfm@GVa^IV1RJ6AaOGa_HUiOHV=TIF=O
FEA`IEYJHVYZIVIWGUIRNX5iN6UTKeJ0EW5kPhN2PXR;RIBTXHUjLUD_CDY=DD]5
D69oVX]aTZ>TWe5RJ6ibLFm]KFQQHFaeN7f3Kfm`LWMmPXF4UGQhK665PFN3MZ6;
N5B@`UA3D5MKAE?6bL>j_m3Iek;0/[kC`kW0_L31_kfoalgGbM:neiA5W:nRUI2C
UI29[YamMh1^K96JX:V0GI[;Xk6e^;B]ZJb`][Fd/Zn/ZZQo/InVZ9FEV8B8RhnB
TXeoLFE]OHR1N86DOh>7RHN3Oga]OHR6PhJ;Rhb8SINERXR>[jbTUhf?WJZdY9NF
V9JEV9N:NgMoPWIVHfATHUiHDTiIBeY1@e]2AT@a@S0a@Rdm<S@g>d13ATM:?cLj
@T<o>a/gB48j?Sdd@D=1@DeHCc`L@DA2>cHk@TLf>3Pe<C<i?b8b@D0c:BX`:2/_
<cGn=dTi=2h]<30]:B/Z:RTY:RX[:3<g;R/c=S8R92P]<C8`;RLY;2lb<c@d>SHa
;B/[;Blb;RXZ;BhZ9RLW9RDT8b<R92DV9bTZ:b`_;_h/Obha<R/_<c8_lGnFOG=F
HemBDDQ0Bf=`KeUKGV5SI6=SKVAPIVMSJ7=DIgAbKg1ZGf5NGF5WKFm_D5i/KVIP
HVQTLGelKf9NGf9SI6ESGeUDL6EJFV9ZJVIVIeiFHWZ1NGQYI6mFP5IaNh>7PX:8
RhVDY:69NW9E;de:CE5;AE1ROiZ;LI:SY9mAHVQ^LW5_KFeXHF5/MGQmPfm_L79g
OH:5Q9EhN6aQQH5WPgJQRgQDT<9D@e1GFdECa/W3^[o@fMNb`;:ndl>i`;g0`Knm
_lO=elWB_]NDAIb_XYF@TiF@RJjLOGN0KVbAVZ2YP5fJbj>a]KRd[JV//;Je];:_
[:ZXOk6OYZREUIR4R8^?TY:=Og5UKGf8PGR1U7n3QhV7PgmlKGf8QX>6Rh^<R8fG
UHZ8SZn/Y9N=SifZ]:BGUYRFUIRGRW]gOh9fIV=TI69NF59>FD]J@D=K@TI4<D8`
<D8]?C8d=c]0@dI7BSlg>T93?c/K=dQ2>Shm=453@D5=F4ll7454@S/f>d97=SPh
=C4c>ClR<T50<bTZ<2P[;c<eoSM9>C@^;C0`;BT[:RXY:BXZ:bPc=bh[<cHb8R@X
;C4b<2hW:B`_<S<d=3Xf<Bd[:bd_<RhZ:Rd^:RHW9bHU92<S8R@U9RLY:R//;bkn
;0L^<C8[;c<b;`G@9o:8XX1`F6e_HUmBATiSKfeOHFAXJV][JW1XJ6m]I6=ZIVaX
F5=LIFKnGgmRIVY_LD]PMGU`Jg9lIW9oPGQ^JFU/JFETIF9KEGYcJVESHf1NG6AQ
G6UjKU9jIUm^F89NPFEZLW^5T9NK/jJ9JEQECdA<@T17C4iJJYF7KXnOWiU:FFE`
L6UYMH5VJG1iP8B6R7QgMgYoQhjCVZAhIeaOTYFBZgj?P7]`ckY?AbMKGee8G<C7
`kg3d=;:]lbV/<Be`L:m`/O7aLG9cMOFd/WDMW>]`K>RoYXMU8fTVgeaP7]hTI6M
U6]UX/>U[kJk]ZfX[KBPXZFYoZ/;ZYnAWJBDV:2@Ri6BoXioPW5_KWAkNGAoTI><
QhfHVHj1LXBBT8=nQHmoOHB?ShR<V:b[YYjGV:2X/:6BT9NJUHn:PgMaO8V4MF5T
JFe/If5MEDMG?T5I@DE6<dHg>TX`>bhb>T55AdI5Bd0l@dM3@dP^?4Do>3Xm?4a8
@3m<EDH^@TY:?cTn@Ci6AD4j=3Ao>d8R;STj<RTW:CLh>CXi=cDc=S4];2h]:B@]
;2XY:BX/;C0g=c4b>c/c;2X[<3Hh=S8c=S/o@3lm>d4m=RlZ9bLX;2PU9b/]:RLX
:2LV9B@T8b<T92DU9RHW<2h];2`];c0^<C8^9o:8XX1`F6e_HUmBATiSKfeOHFAX
JV][JW0>J6Q_KFASJVI/J5QCG6EVoUmoHVIZKg5;H7EiL6]bO6IbOh5hKVUYK6UU
I6ERFeEjLfYUHf=PGUaTHEaYNViBNVIOKUR2GX5UJW9kQI2GVk>VRFUHEDm4C490
Ada>FVZEQfj?WinIBUUUL71YJGF1IVU`NH24QXQhMgMjOhN>TiZTN6MLGi:ETZ]n
Sh1kL<njCdLWFemMB5c4al>m`m3Bb[O<Y[34]L72_L;7alG5bLgGe];9e7Ic[L6c
X_jJ7IB=Y9]mLH1kN96AWIA[IJ;3YJnf^kJ]Z:fdX::UZOj[2jZOTIfTU9RPT8^A
T_j>Oh9aKfidNgUdOi6CS8N=V9V>PG:4TY23OXF?Ogf4Shn8S9R/ZjJNUiRPZ;2Q
TY2GVYF?RX=gLGb9Q7EQI6U]K6MQGEE7Eci1FD55AS=6=cY:<3/^<SY1ADM6AD]0
?4=7@d=8;Sa5?cPj?Ca<B40oC5E6;T9:BSli?T4nATE1>S@dOc]28Rhi>S8Y9bTg
>3Tj>CLe<cHa;B`^;BTT;B`Z:BTZ;2d`=cLa<S/k<b`Z:c0f>3Hb<cHk?d0o?C]1
?CH_:RLW:2`X9BL[;BXW:2PW9RDT92<S92@U9BHV9c0^;B`/;Bl`;S4b;RObR::0
L5Q]Kf9ODTI>Hfm]Gf5TJ6Y[JfY`3VQXKfeTHfYVK6QHDeaUI_iOOf9VJVmaBf1e
NG1[LWaVLWn1N6iYJFaYIFAUHU]ENW=ZIF=SH5iLI65LJGY^DWYVGfiHPUj1IFYb
NhF@Ui^cYXUYF5E?A4a2@4M<CUYZUHM^SinOVDYIIG1`JFUePFIYL7V0Q8J8N7Mg
NWn7SY>JY7QWG5nBUI:[OXn0Ng3?^Tm79e]OGDQLa<O3_L?@d/Zgc:J`a;G1`[g2
alO5aLW=emKBbMAfLjg1/j;nVQfDSJBKOG60NgRATIfDJfFR`jF_][^f[JR]]:2R
YJWnZ`^ZWi6MY9BHX92;TI;nSWn2LFm^M7]iM7nAThb7SIRISX5bQ9:@Pgj5Sgmm
Q8n?R8bH[:^VWYNHX:R`XI:@UiZEShZ3Mg5lRHAeHFAYKFaWHEeEAeLn@EU1ADHc
ASLjBS0k;S8j@DE7ATE;@3a3Ad=3B2hlAClh>SdlC4Q0?daEARi2BTXo>Ci1?TI5
@CXd=6Hk@R8^>CXb:BLY=cPi>STg=C<f<Bd/;RdY92d/:RTY:R`]<3Lg<C8k>c</
:R/`=SPf<S<f>cm0?cdk@Cdf;bXW9bP/:2DW:bdZ9bPX9bHU92@S8b@T9BDV9RL`
;Rd/;2d_<2ha<RhW1L]onhbNNG5SNGE^KfIMHW1dKFe_LG9bLFm^MVaXJfIKFEm^
LFQFD5eZKFAUIVIUIFQZDEm^MWA`L75/KgAeM7=eMgUaJ6EVIV1JJg5eM6]PFEER
J69KJh1`CFQEE6aIPUf2Gf5[O8bIXZVRQVMGCTQ>FDI1@TQ8AU9SOH5kW9fASDIo
FFA^KVQVKWQNJWMoQHN6PgYiNG^1RYBITYmbGeIPUiVU^gMgL7MonKI<AUYIEDUZ
`LG3_/;8_jn`cYfY_jk7_kJna/[7aLC6cmk9d<EFYK6l[YnJWZ6OVYZQQG65T8bF
TJ:2G7VZ]:ZW/;JbZ:>Z/ibNXJBTXj2NV8fKXY:GXYD:WYnEQ867PW>1MFonLQ]l
Rh1eKFmgN6eQNX:<ShV3QXf4PXR@SXVAXINJoY`BWJ2SYZJTX9bHShN;SXQoPhf6
MOeUBfARH5mBAUQ2B6==DdHdBCi3DC4h;SE1Be1?BdM3>ce6A3a1D4U5A4I3?D18
B4a8@TA8?Ra:Ddlm=Ce0>da:@cTb<SY2;Rl^;2/Z:R_n>2Hg=30/:RdZ:2X^;b/V
;bdZ:2PZ;Bla<RhZ<Shi:b/W9BT`<c0[>CWn>0Li>S]1?CD^:?hVObDQ82<Y;2/X
:BTX9bHU92@W9RHU9B@T8b`Z:2LW:2TZ=SPh<RWkS9iiLF=iMFi_IUeRL7A]KFma
LW9aKfifK6Q[IU]IGfiaJ5I@GFY]I6EVIVEUJ6YAGfifM71`LFa_M7EdLgEgNG5X
IFIVH5Y[LGEdJf1IEF9XHU][P71=J5EDOfaIPUf2Gf5[O8bIXZVRQVMGCTQ>FDI1
@TQ8AU9SOH5kW9fASDIII6i^J6I^N5iZMgn5QhJ3NWUiNh6:U9VBWg9OEV2GVJFk
MgM`Mgoi]Ta6FUUEBF[1aL>n`/Ro[k3>WJVo[/No][k6b/O5a<K?g/W@aEJU/Kb^
WiZNXInJVZ65;g65T8bFTJ:2G7VZ]:ZW/;JbZ:>Z/ibNXJBTXj2NV8fKXY:GXYFN
WiF4PHN2Lh5eKoib6gb;P7E]KgMhKF5jPXb?RH>6SHB2R92>RI6QUi[nW1:MX:>V
YZBPW9R?Qh^>R7n3SHIeoFE;I69PGe96F498HdeCASA9?T=A<CP^=D5;D4m;Ad<k
?DI4?45@BDE4AT<m@4Q8C4Q2A4Pn;4YCCcde?D0kC4Y3>C8b>T8^;bh/:bXZ:ohh
9SLd<2`Z;BXX:Rh_:bH_;BXX:2X];c4b;RXb?ST[:bLU:C0c<2/i>Ohh1cTj>d4m
=BhXoRIo9B4P8bT/:bPY:BPW9RDT92LV9RDU92@S;2XX9bLX:BXf>3Pb:O^<WWUa
HgUeKVmVGF9`M6e]Kg5bLW5_KWI/J6]VFeUOKW5XEU1MJVeTIFIVIFEXJU5OKWId
L71aK6mdMGAcMGMiLFQUIVIPFV]aMGA[H5UEHVQRFf^0L4eXEEAoK5V2GH9OHF]l
S9VRZJ:6IeM>B4iIAT52B4Q6DV=mPG^LWI6=AUUTKViXIVihGVYgOhF7QX=jNGUk
PHZDVI:OLUmFH9NIYK]gMg1gOoVfC4IJFEE9J/75`kk2b;n_/<jMZKn^aknf_/K:
alG4a/oNbM35EZFa_:jOVYjQWiZJXHD_LHF@S9JAXX9LNJZdZZN`][:XXjZcW9jQ
Y:BSX9jHSI^RTYNRUIjOUHB1Qh9cPGE_oW8KO8^0MFe_MgQ]HGZ2S8n9PhJ=Q8:8
T8j9TJ6GV_jL4YfPXjJVY:2LV8n7Rhj8Oh>=QWGmID]THV1ODTIH@TQSCE=6=4Tn
@e4a>2he@D]@Cd]7@c/mAT@l@E19ADA6@ce0B4Q<B494B3h/BU=??CDm@3]<BT<i
<S8j@Rh_;R`[:RX[oSPV=c@`;2X]:RPZ;Rl[9Rl]:RPX:Rd_<C8^:S8n>B/[9bDY
<3<`:cTioSP7>CXk@Cde;RSn9R@U8B0S:B`[:2TY:2LV9B@T9bHV9BDT92</:RPW
9bPY:SHh>38Y1M5oohVBKW5[OG1QIfMSJWAaIFUZJVUWHf1NN6]QH5U=CEEUL79X
I6Y^JVU[K6UTH61QG5iSJg1[GeE]JFASJ71hOGicIf=UIV5LDfAgOG=TFEETHe52
Eg]iGF5?E79PQ5YnJ6M_PI:LY:]`E4E<B3LeADE7CDm3=cmBIGj:Zib4PTAoHVQ]
KVUSH5mDI7EnPH=oNGEdM7ImQi6GQ9amM6idXIYNTVj4PW9JaKE:@eA@C4Ue`<C3
_[no[YVMb9^ab;36/j^e`<G3_[bka=jlckHn`Z^UVY2AWJR[ZYBVSG>:X9^JV:ak
F8bbZ[2LYZjZWi^S[KFe];6/Y9fHWY>PY92BW8ioXij9KFIbLfQbHUYTLGf=WHf5
O7UiMViWOgb0RXj;R8VFTY>ESXN?X8fCVj:VZ:VYX;6m]jJGS8BGXZ2BS8enJ7Yd
K6ANGEeOHEI[F660K7<g9Sde>dLT:2liAe=IETm:=c8h@S`a>U1:?Sm<Bc/e?S]8
CTDn?cdgDUYA>C0j@CeR@d4j<B`_>T<n=BTS9Rdb=2X[;2`[:2HT9B<T:2la;RX`
;RXX:2X^<2l/928_?3@R91hJ7BDX91hg<b`W9RX`=Chj<b`X9RHW81dL82P/:bPY
:BPW9RDU92XZ:BLV92<S9bHToR9o92Dl?Slk<on9TViaJge`HFMWHfYdLFEYJVYY
If=PGWQ[HF1ICDeEIG1bJ6AZKVYYJfaYI61PHEaNHf]`JemEKFUTHfQ`N7enLfMS
IFIQG5=TMgecI5UEI6=A@UMkNEeQCeAbH8AJOVQWKh6BW:B[L5A5C4Pg=DE5Ade?
@cLoDVEoOXZ[W8B2A69XKFiYHf1OE6AeOX63OgUeM7AfOHNAUhBLOGA^M:6JGY9^
Q89bF/FeBT=DD4a9ML34`kjo_jjIWLRK/LR`a[>[]L35`kjl^lCN_<nf?/:[YIZ@
TIfXZjZDYXecRZ2KVYR/NeR</ZZ`W:J^ZYnKXjfe]KBa[:BMV9ioTj2TT9:LSZ>N
RFeVLW=XLV9JI75mSIf=QGaiNGI^IgmlP8Z>RhR9UY:CUHj7Sj2=Ti^RYZRYZJ2a
_KNVUhb4Uj:PTXb=OVQjM6aTGUeMGf5FJeQQP6ac=bHm=C]792P_>DMCFEI?BSLb
>48l<CY@BShoC4/k=ChkB4i5?Slm=e9YFU4i<3Y1?D=1>S4/;cY3?SDY8bH]<S@Z
:b`/:bPV92DS92P_<BhZ<2hZ:2PZ;S0_;2@R;c`d8R@N6QdU:2@N=c</9bHZ<3Dn
>S</:2HV9b0M720X;2/X:BTX9bHU9B@Z:RTW9R@S8bLV9?hROb@U?3ho>c?oRI9^
LF]mL65WIf=ZM75UJFYZJFMSH5ihJf5PFDe=EFE`LVQTJViZJF]/JFAPH65LGV=[
L6]OEFeYI6=XL7QmOW=WHfEVHEaCI7MmLfAIEFASDD9GNgUMHDmDLV24FWiXIfn1
TYbTZg1DADa8=cE5ADM=Cd<g?e9UOgj:Zib4PTARJ6e^JF=PGeATMGj1PgmiMGAd
MWf7TIN4W7edKWBQVUjBKXB2LU[5]DY3E51<BGG0a<>n_kn^VIg8Vk78/<JcZkG0
aL>n_;_4g[c?]Sk2ZjFJT96MZ:^ZU:J=LhZPViZH[7]HS;:Z/9bV[ZZOVj>]]KFd
/JbTWIRNOi>PY92BW8jSWXU]IW9cJ79RFVAaOHfMSHElNGUfKVMoO82:SX^8RIJB
TiF>QhnPSI>KXZJXZJVP/KfgYYN<Q9NRX9:<SGiXNWA/I5iMGEmQEV]HHH1/LcLV
?CDkAb@X;cU7DeUFCdXg<SQ2?34jD4Xn?da;>cDn>dQ>ACho?CMBJEYA>C0j@Ce3
@CXa;2lj@che:B<V;C8d:R//;2/X9R@U8b@X;c4^:S0^:RPX:Rh`;b`T8Rll=28T
7QXM9BPT7SLc;2LV:S0e?SXc;2PV9RLP7A`P:2`[:2TY:2LV9BDT:RXY9bHT8b<W
9RCn8PHT9C`n?c/c1M5ooiR_Sh=XLFMPIVAMHG1gM7f1Ke=FKg9NLGUhJV5RGeMK
IVMQJGQfIgQ/IfmaJVM[MVm`MW1SI722LVM[LW5ZIFe=L6aLJEQIAX^5H6e[Ffm9
CUAIFeaMGgEKJhMnLVmQKg]hLX>JRVE:AT8o?d97BTeDCU=JATYfOWiiY;:XVTMo
EV]oK83LaS5KMFeRMWYWH6i/Mh^ARXR?OWEgSJJUQFBBPJf8IG1jdH0mDf1>BE67
b/W7`kbd[:Rc];W1a/:g[Kc4c]7?c<_;b<;?b[@lmk:gTY6LShnNWIR;RYJITYNV
TK1T@YVVPjb^][^g[JJX[9na^JVGUIRIR[6JPIjLQIEoXYZCRhQoMFaZHf^0RXJ;
VWJMQ8^>KG=bSifBSJ2MUZNASHJ0OhF@V92DUY:?UZViXZb/Y:NbZiVSZjRGSYNQ
XhjVTG=kOFMLJFMSH5mQI6IWCd58BShg?59IF51AFeeGCT@j>D58BDIHFUY?=bTk
F3U1BDU5A4U??4Y8>d5EE40E=41;C4<l?D4i>3Db<C0a<R`i@S`b;oh`ObTX:bLP
9cA0=RPQ9CA7E3P/:C8g<Bld<RdW8b8U:Bdi=2`U8B4T9THn=2h];2PU8b@U9RPY
:RXW9RDT9BHY:R0V:b/W9BHY7RH^<C0^;c4l?Cho@?nH[hn3J75WH6ITGF5`MgAm
PFmCEVmbGW5iN6YQHUmGFfIWHFUhMVMhK6M_Og5ZIf]fKg1fL6=TL89bIf]bLFYU
KDe`K5aYF5U6RhEPKF]KKdU>E5UKG5eOME][QgibKf5_NgQbPiZ:IDY6@Slo@TM:
CEA>DeY6BWInOWVT/ZRJAeI[Ofb0g<HaFgE]HWIjIf1^K7N;THZ8SgieMhfVYHET
TX6]R6E`N]60?E=POdi9DHO:bLO3_;B/Z;>d^L76`[N]_<C>dLo<bl_8`/o:]3cg
/[NBTIb?SijMV8^:UYVBUjJA/6A2VJJ3[:jf^kN]YZR/Wk6iZINEV9V:/IZ1WYb5
UJ:JTh^8OgE/JV=[P8Z6RiYfWHB;SVecLXnMTXfPWIJWTHf6P7n5T9R@U9JBJHnF
ZKVR[:bTYk:[VJ>[Z9N>Uj6SSZJALg]mIeaYIf=PGf5TIVM?@DQ:?SLlDUUHD55K
GEM>A3Xi@DQ9AUQJFTlg:C]H>D59BDE4BDllBTPk@EED@3A0Bda3?3e1>CPe<S4`
<C8/>D8l<Ron<7lY:2/W82Ld@3HX8BDdAe@h;2Tb=c4_=38]9b<R9BT]>C@/9B4Q
92I6?S@^;B`X9B<T9BHX:BXZ9bHU92DV:BXP9R/[9bDV:AhV;S4`;Rla?3dn?d3o
V:n?PfQaIf1VI5eQL7MdOH5_DeI_LUiaNGQZHF9OEe]VIf5YN7IWN6aWKgmaJVM[
MVm`MW1SI722LVM[LW5ZIFe=L6aLJEQIAX^5H6e[Ffm9CUAIFeaMGgEKJhMnLVmQ
Kg]hLX>JRVE:AT8o?d97BTeDCU=JATYfOWiiY;:XVTMFJgm/P=c6<E]eKF9fNVMP
KVagRi6:R8mnMGN=YZF5I9:1[HQUL7[AP3eCH7m>BE67b/W7`kbd[:Rc];W1a/:g
[Kc4c]7?c<_;b<;?b[@lmk:gTY6LShnNWIR;RYJITYNVTK1T@YVVPjb^][^g[JJX
[9na^JVGUIRIR[6JPIjLQIFRVY>;R7meK6YSJh2:QX^JMYf4Rhi]Lg:?WI:=X9fF
Yi6=QX1oQI2HT9BFTVV?UZViXZb/Y:NbZiVSZjRGSYNQXhjVTG=kOFMLJFMSH5mQ
I6IWCd58BShg?59IF51AFeeGCT@j>D58BDIHFUY?=bTkF3U1BDU5A4U??4Y8>d5E
E40d@4]<@c`m@CTh=C8a<34b;3U2?38_oS1C:BP[9b0W=40f:24U=4MD>2`Y<SLa
;c@b;BLS8RDY;CTd;2DQ8B@VAShd;Rd/:2DS92DV:2TZ:RLV9B@U9RTZ82H[:bLU
9RTN9Rha<2h_<C`m?Sm01LYVoiR`VY^5QW9UKFiWIfi]IG=kLUmWPXMfIW5eKfe`
KFAUK6UQI6iZFga/HfEUGEYOIVY]JVIVJVehLfi[K7J9VY1UN6QDJV]kLiZ6IVaM
B5YVFe1?F65SHFYWQj6GUI^?V9N3JfahIOi2oT=7@D0o@E1EHVQ9?Ef6Q7^R[JBH
Ae5VLEES`<IHCH:DQhR4QIZ<Si>FVYfNWG66Vif?QHZDNVfPTgMeNLUiBE9BC4I<
V/g9`[bfo[=o]kbn^[:^/KJc^/?7aL;2`k_2^L^2HmB`/I6CX9JIZJJHRhJ>ShV?
WJ>KFU6N[Y2SXJBVYJ6OX:>]/ZnVYJVSUWZNSh2PYYRYWYRMPX=^NgYnKVM_MGR7
VfnBMWj8L7j2Ohj6Q9VJUJNUVHf:T9NFTiNGV9fSYjRXYJbZXJ:XX8mKXZnaYIbO
X9b9V8IbNFiDDEaJEeEEEeYLGD]0@clc;cI1BTi<DV5WHeI8?41>ETm5BdY<B3P^
?5<mATmACTa?DdE8AD15Cde3?Ci1ADM5?cY5A450?d11@Rhd=cCn<2/_8a/L9bdZ
;SP`<cLk?3`j>D`h:BX/;3<n>CHc<2l`<S@Z:2HU:2he>D4j<Oh]ObXW92@U9RLY
:BX[:RPV9RLX:R@Y;RhZ9bT[8BL];R`/;S8W9bPY:_nH/9ZKQHIbIFe^IfM^KFEc
Ng9OIh:7MVIaMFm]L6eTIFaYHFA^JU]lK6=UIEeJGfIZKFYVIVY]N7=^JfafRIZ@
IGQXE6Y[Ng>JQVI/GDQJIU]@CeQQHf5Z3FN7XINEVhnHUh=[K7QUoT;n@dM1@3m1
D5ERJ4TmGHJ4Nj:]Y9Q7DFIaEF?0aUQ=PYB7R8B5VXb?TiJJWIjMLHJKWHn5RYAj
KJ2CMgEibGU9DU9<ATbJcLW2_;Kn/gng_;jj/Zja][>j`lO5`/;3^l:ibh9Se;2a
TI>PUYVYYYR;QXj?RHnMXi]JDIj^T:>QY:JUXInPXjfb[jJUZJ>FNYj?P:2VV:VN
V9f2PfikNWi^IfmeN8NKKi9fOXQ`OX9oSXJ4VIZEYjFISHZ@UiJCUiNHWJ>WZ:RU
[:ZQXZRPSe^R[k6UW9nPW8VHQW9iKUAAG5YGEEEGFUaMBd13?c<_=T5:CTaBHFMS
ETPl@4iFCdE;BTa8>2hlDce6Ce5>C4mCADQ5@4E?CD<m?T55AdDo>TE4@D0o@452
;S@g=?h`:blS6a`W;BX^>30c=c/l?3XiC3PY:R`/<chi=S<`;c0b=2XX9RDX;SDi
@CXaoReo:RLT92DV9bTY:R/Z:2HV9bPZ92T^;RXW:B/Q9bd^;2`^<RLW:2TZoiR`
VY^5QW9UKFiWIfi]IG=kLUmWPXMfIW5eKfe`KFAUK6UQI6iZFga/HfEUGEYOIVY]
JVIVJVehLfi[K7J9VY1UN6QDJV]kLiZ6IVaMB5YVFe1?F65SHFX=IhNQUiFKSiRG
Pf]/N6Gn@_i3Ad50?d5@EF9XBCeMQXAkXZfTV4MAIW5EHl36F4f2U8N8Q8FJS8nC
UYZMWYeaQY^MShF:U7Y]X9=gMGW9NDUBDTa6C9[=bL:l]_jcOkNl_[Zb[[6f/k[3
alG2`/>k`[W;PV?D/;6ATj2FVJVVV8^6SXn9SifSVeYAWZj@Xj6TYZFQWj2S[K:_
YZFYXiIjWXn0X:JHZIjHWH:3KW]jOViWKgEhQi]_TWInR71nPWn>QXBIVYFWYIV=
RY2GUY>GUiRMXjNXZ:F/ZZ6RZ:2?Fj:_/JFLWj2LRIR6LWU^E55LFUMEEEMJG5e;
@4<o<blf@DY>C59QIf=FB3a0CUI?AD]:C4Ph;SaC?DI?DDi<Ce=5B4E0ADm=@cdn
@DE7ACljADA1@3m0@D8^=3LdoS0[;b<K72L]:Rhh<3<g>c`l>SU<>2TZ;2`c?STf
<c0_<38d:RPV9BP^=CU1>S7n;BHZ9b@T9BHW:BTZ:bXX9RHW:2XT:Bh^:RLY:b4W
;Bh/;2hb9bLX:BX5dGokPiZ@Xi:8IVEaN7EfNgI[KgYhKGF;SGmTKg=_L7IbJ71a
K6=SIf5ESWmfNGYcLWQJK6mOGVidJg9hMVUSN:?7]WYlI4mVK8:CUX9mRWISMgYZ
G5aUJ5a>DF27UXJ=UhJMUGUKEUi@=D95BTa;AClkA55DHFM7=eB?RGZMZ:6JC7mK
LGA=DZ_EY55oSXN=R8RNTj6QU9NZ[Z:8VjRINfimTgm/TYJ2MX;?IeIA@4a1@Zk<
a[fe/[Fj_[g3`K:OW:bn]Kc4alG3a<Jda:k5E9fb]ZZ@UZFMY;>/Vhn8RXZ8T9^T
KDAMTZ2ARZFRWYnSYjNU/j^OWJfhZ8j;XIB5UiR>VGn<Q9YZMU1dMge`IfQYJgN5
M99aMh=_P8EdPgakTYB@XZBFRXnOYj2EUI:FXk6aY9Fc]K2XYjVPTij]/j^RWiR=
RXemNXA^EF1DDe9ADE=EEUiECd]1=CDo>TE:BE5PIF5CASe5EE]@@Chj?44m=Sa:
?TMAEUECDU=BAT57BdI4B5=3?3ToBT]0=4U8AdI7BD]==c8_<CDf=SD`9BDe@T4n
@3@j@DE4?3<]BCL[;BhZ;3@`<34a<2h/:bDT92L/=3a0>C<];2h_;BTU9BHV9bPY
:C4_;2Wn:10Y9b``<2/X:R`T:2XY9bP^<ohUObHWnh>JT:>BR6IULGQeMW]fJfmj
N6eeRheoI6mcKg1fLVQ`LFaSHfMQEHioMWUjLg9hFVa_Gei^M6]bN7IYHgRSakIj
O6A?IVb2TiJ2OHYfHgMjJUaLIFQLCU5PQiJ6SIN6WIEiFeIND3E2ADY<BdDo>dAA
E65WAcMDShUjWJRQOiY<Fg5dCE:[eJAAOhj7SHR8WY>QXIBGZZjRR9^XVG]^OI=o
K9:FPWJ2cfMFDD1<@D:^c<Jm]K:e^[jm`l6bWib/_[Fla<O5`lC6]<B^aEBM/[JZ
T9JUWJBc[9^?R8Z:R92KY6e4GI:PTHZUXYjOXjNWYK>[Wif]^:R>Rj6DQINHOhjI
S8BJJWI@M7MmL6MXJF]gQGBBLGN3Kh25M8=lNi:DT::TUXZ?WjNPUIFBUZ>a/JBE
/kF`Z:NYX9>N[K>[XYnHSHZ=OGZ4KUEPE5=BDE5CEEINEDm;@CDe?cY5BTUAH6EQ
DdHmAEEKD44n>Sa1?CHlBSi7DEIEDe9CDTI1Ad]6EDA8@c`i?dY;@3A9B4M6AdU;
CCLb;c4e=SHe<2DU=D91?T0d>T55A3`c;DTg:bd^:R`d<30a<C0^;2/U92@W;3@l
@3Tc;B`^;bdY9BDV9RLX:BTa;b`YoRP@:BL/<30[:2X/92PZ:BLX;S?n9GlV9o^3
VY2STXQVIG5hMGIkMV]_NWQ]MH^=OfA_Lfm`MW9XL75/Hf=WHEF>OgIiNW=bN5Y/
KemNKWA[LWQfJF=hXlNfNWaTCfI/PY>FPWf:MV=gNVYLG6EXG4iAH8NFQXfGQYfE
NE]FGU0e@TE:C4]5?c]4DEAQIdLgE8n9NYfXXGnJC5]aM4eBZmFTDGn>Qhf8R9jC
XJ6DUjZ^XXRKZ9UkKWfCOfbBUX9fP/mWEU50C452[/c6_KFb]KZn_L?1/YnL[;je
_<C7aL?4a[C4[/EDWK:fZY2FYIfT/jbKShR:RXR@VjA]A5fBX96:YJ:NWj>WYjFc
ZinM[KRXSX^QU8FGV7n>VHb4VVYfD7AgOG1WJ6U[MhEdTW5gPfn0QGB3O7^BU92R
Y9J:SinWX9FETYJS/K6TUK>e/:RWZJ2CWZfcZj:OV8f:SGejQ6iEH5ACDU5ADeEF
GUE?Bd4e=CljADY9DF1UHE=6?DEEFe11?SXl@Cdf?4XnAe5FEE=BDe96@DM;AUE4
B4<l>Cm:Bd0dBDQ7ATM9Bddg<Rla=CHf=C0U9CE2@Ci0=3Y1AD@l<be9=b/];RX/
=30`<C4`;R`[9B@T9b`d?40i<bd/;Rl]:BDU9RHW:2TY<Bl/:OhX42TW;30`:bPZ
;2@X:RTW:2hcoRD19RL5`WodMXZ7Y9F2EF1]MWR0SY6:Mh62NWb4PGAfNGA[K7Ac
JGAaK6QZK6URI5YJIVaVHVEHLgEJF7=jIgElN6MUPZk=cH>1MfikIfVHPgfHYXel
S71`M7YiJU4mPhZPWhbDUWQYIEI9D5mKBda>Ce1>BTI3DUA;DE]5@6>AR7JGY:>Q
EgmOO7]CDIOFgh24L72AU7mmRjJ[Ui^f^:2FRWikP89nMib1QXn1MIGKC5M@=Tho
>KK3_kZg][Zn`L72_JnQX:jm/[Rn`;fk_Knj`Kf^DLNZ_JBAVjNOYk6SViB>SHnD
WJJMD4QgQhnEPjbSVifVZjVSZJ6FUJNcY8^KWiB9RHJ1Q4R7O9MVOU9eKfMWJg5a
K6QWPimjOXM^N7MkRGmkSXb6UXJ3QHnMYJBOR8^DXJb[XIJe/ZfXYjJPUibVZInG
UHaoQWaZLH1XFGAHo5MiF5UHF5E<?C<h@DE>D4]=EEE>@T52BU5BBT4n=SI1AClm
@Si5CUEGEU=BGDDnCDho?Da0?C/oADDo>410?cm1@dI8@c@/<c`n?Ci2<RloCDTn
>Di9@3Lc<cHh;RT^?D0a920Z;C4c<RhY9B`[:BPY;2la<BdY:Rh`;R_n9_dW1BPe
<bl/:OhX3bHZ;bhY9BHX9RPX9B8T;3?n:Wl[:oAfRXNTUH9EH6efN82>THYgPH9j
O8B1M7IiM6]/M7=YM75/J6Y/JF9TFUYVK6IRIEQcMEYHLgYWMGahIfF2[/g=Ph5g
KW]WJIR3OIRVSGb<L71dNWUZDCf3RZ2OS9BFN6UUETU@Ge];C4i?D4i:AT=BE4]A
FdE0Hi68MYNTXgnQEemlNe=AUmKOP8A`L96DOgf;YZ^GVkJhX9J:OW^0PWigW866
Sh5eUM]<Ee0fCSli]/>o^[Nf^[k1`L:m[j6P[[fb^;k0_K^m_k[1_JiAajZmY96K
YinW/J>KU8j=SiBMYYe@B7N7SiF3[:>KWJJ[ZJ>YXIJEYk>TRi^OU8V9QTZ1Q8Ml
UfInDWE_IfM[LG5/J6N3WgYnQfihMg^9Og^>S8JFQX>5SifUY9n8RiBQ[:^QU[Fb
[JRWYZ2GW:JYWiNES7n6O6YaP6QIM5SlEgUHFEQHED`m<cQ1ADi@BdeEEDi2@D9:
DE9:@Chf=T55?ce2?TE>EEMFDe9MACi=CSlmC40m>cm5AClh@40o?d53ATQ3=2`c
?3hm?T8b;cm=BChiCTU0=c<c=SP^:Bhm@34T82X]<C<b;RTU;2/Y:2T/;c4a;BTZ
;S0^:ohVoBL5:3Dc;b`YoRP?9RX_;RTU9RPV:2PU8R@/<ohZOb/[m7J:QjBEPUEP
KGIhP8jARWN1PWYlQ85dMWUdJfadLfUdLFaXJVaYHVAJFVI/IV9UF7=eFUQcNVMe
O7QWIH:^cLf3PGM^NfMYV8=mV:J=O8a`L7AjNFYA?H>:X9n<U9IhJFEFBE1OFd]<
CTm@CTY6@e9DBe5KAD1STHQfUjBSOj5GGgakDe6Ge]n0Q71`TIAoOH^VZiNK][RP
UXYnNh22OWNLPHJ?PGFEfdaGD3I>?cVf`knj]kJj_/71`[f_XJ2^_K:h_/2m^kfo
^/6m[U77Z[fTTI^WWjNaXi^DSXf?U9fVWE18MhN?UH>/Xi^MYZ^YXjVQUYFW/jB;
VinDRHV6BX64QgbGIWiBMFmWIf]aLFaXIh>ONWj7KWQgNhUoNhj<QYJ6PhF?WJFT
WhR;U:6/Zj6F]K:]Z:NVX9NLYZVOUiF<OhIlJW60J5UdF?aGNEQIF5QEC3dc>455
CU1;CEEECT91@TYADTY1?SHf@DDo?D8nADiEEeICDUe5?Te>?ce<@3dk?dE5?cQ0
@3lo@D=6B4<d;3<l?Sdn@S8_?de9?SU>BD0g<c<f>2hY;Se0<B@P:Rda<c8^:BD/
:bTX:B`_<C4]:BX^<2h[oRKm9`DX=C<_;2Wn:0lV:Rl^:BDV:2HX:2DR92`coRX1
:b/5aGooQ9F?ZIV6FEiXKFiiSIVGOXR<R8F4OgN<R7Y]LH25OWI_K71fNW]lEe=J
Jg5VFeUHLW5DD6YaGgQkLfYgW;W2e8NC[;^nQVZ@M86ZZ8EdN5a[OH9iK6=PZIFD
Sgn3NU<h>ci4Df9QEe=@C4U8BD]<DE9:EF=?BFZ<Pg6CXjR[IC=FNGYKEWbij[FV
PWnPXi2AU;>mZj^n]YMnKV=`RYN=OI>6O8^7OZG?=Di@=e13>[:g^K^mo[mC_/:l
]K2`/[BeY:R/ZjNTYZVo//b7Kl^a^Z2CWjJKXjN@TY:?SI>OZZjEEfjNS8^RUJ:J
TiFMXIfFWZ6NVZ2YXiBCQhJ7Oh68QiN<WH:HN85aIVecoWDiL6Z5XX::UGQjLY2L
SHBARWn=Mh:>U9BFWJB4SibSY:BX[:jVXJ6RWi^IXZFMShV=RGn1LUMIIeA<JoiL
LE]JFEQGAT]9?2h[<3E;E5E=C51<@SU3Ce=@BdY<BChmB4e5?Sm4B4mGG5eJEf58
?da>?ci=>3i4@S`i?44i>CPh>S`o@DDa:CDn>cY0>b/W=dA0=2mGCClb;Blf>bXV
;d97>bh[<CDk?Sdh<B`];2TW9OhT22/X9RT_<BhZ:?dWoRH4=C<_;2Wn:0lS9b/Y
920P8RHW9b<P8BP_oR=o8R;oQ9F?ZIV6FEiXKFiiSIVGOXR<R8F4OgN<R7Y]LH25
OWI_K71fNW]lEe=JJg5VFeUHLW5DD6YaGgQkLfYgW;W2e8NC[;^nQVZ@M86ZZ8Ed
N5a[OH9iK6=PZIFDSgn3NU<h>ci4Df9QEe=@C4U8BD]<DE9:EF=?BFZ<Pg6CXjPe
ZfEFNGYKEWbij[FVPWnPXi2AU;>mZj^n]YMnKV=`RYN=OI>6O8^7OZG?=Di@=e13
>[:g^K^mo[mC_/:l]K2`/[BeY:R/ZjNTYZVo//b7Kl^a^Z2CWjJKXjN@TY:?SI>O
ZZjEEfjNS8^RUJ:JTiFMXIfFWZ6NVZ2YXiBCQhJ7Oh68QiN<WH:HN85aIVecoWDi
L6Z5XX::UGQjLY2LSHBARWn=Mh:>U9BFWJB4SibSY:BX[:jVXJ6RWi^IXZFMShV=
RGn1LUMIIeA<JoiLLE]JFEQGAT]9?2h[<3E;E5E=C51<@SU3Ce=@BdY<BChmB4e5
?Sm4B4mGG5eJEf58?da>?ci=>3i4@S`i?44i>CPh>S`o@DDa:CDn>cY0>b/W=dA0
=2mGCClb;Blf>bXV;d97>bh[<CDk?Sdh<B`];2TW9OhT22/X9RT_<BhZ:?dWoRH4
=C<_;2Wn:0lS9b/Y920P8RHW9b<P8BP_oR=o8R;oQ9F?ZIV6FEiXKFiiSIVGOXR<
R8F4OgN<R7Y]LH25OWI_K71fNW]lEe=JJg5VFeUHLW5DD6YaGgQkLfYgW;W2e8NC
[;^nQVZ@M86ZZ8EdN5a[OH9iK6=PZIFDSgn3NU<h>ci4Df9QEe=@C4U8BD]<DE9:
EF=?BFZ<Pg6CXjPeZfEFNGYKEWbij[FVPWnPXi2AU;>mZj^n]YMnKV=`RYN=OI>6
O8^7OZG?=Di@=e13>[:g^K^mo[mC_/:l]K2`/[BeY:R/ZjNTYZVo//b7Kl^a^Z2C
WjJKXjN@TY:?SI>OZZjEEfjNS8^RUJ:JTiFMXIfFWZ6NVZ2YXiBCQhJ7Oh68QiN<
WH:HN85aIVecoWDiL6Z5XX::UGQjLY2LSHBARWn=Mh:>U9BFWJB4SibSY:BX[:jV
XJ6RWi^IXZFMShV=RGn1LUMIIeA<JoiLLE]JFEQGAT]9?2h[<3E;E5E=C51<@SU3
Ce=@BdY<BChmB4e5?Sm4B4mGG5eJEf58?da>?ci=>3i4@S`i?44i>CPh>S`o@DDa
:CDn>cY0>b/W=dA0=2mGCClb;Blf>bXV;d97>bh[<CDk?Sdh<B`];2TW9OhT22/X
9RT_<BhZ:?dWoRH4=C<_;2Wn:0lS9b/Y920P8RHW9b<P8BP_oR<18R85aGooRi^;
VHMnG6=ZJVA[OXR7OhRAU9:?SXfHTX=jQ9VOVGicKgR1PXJ=Mg5gQ8EeIF1IIfA@
C5aTGG=fKV^6/<2fcHBRe_Sg/XekJi>nZXb9QEeYM7=]M8VMX7M_NW5XFCXh?4A>
EeUBBE1=AdA4B4eAAU1EJgiQBf28P6nCYJ^`JfMNPH9_K72Ih;o1Zj2[XZ;0W[Bn
]:naXHQoQ8R7PWmoPF^0MhjCRjVU<d5B@4a<CJnc][_0`/6o_L6i/[:g^KF_ZJ^/
Z:6MWZ6jXl5YS;^c[Y^DXZJHWiioQHf?SIFU[J]mHhZZRH>NVOjGOibQXYnKWJR/
Xj2UYInRQHR=MWF3NiZITiVCSgY^NWagK6eiP7mgUW^<X8R:P9fXVHfHSh>AQ9:O
W8n9Tin@WJZ/Z:Rb_KV/YJZ[YJ:VZ:FFQ8:;Rh>9PF=FHEI=He]LFeYGDdm=ATa8
>S<h>cQ5D5A?CeAAAT1:EEUFDeAFDTQ7C4mAAd95CTe?EUiSHUmNCTA7B4A5BcDo
AT8h=3]5?C`k>S/l?d10;R/j?S8b?cP/:cY5@ShoADA2?SXd<2do<Rhh?ci0Abd`
=CPg<R`XnbDE92@W9BDY;S0/9bTY:2LV9RDU<Bl/:OhXObTR9RTW8AdM7b8U9b@P
82@Y92@S8R7oRi^;VHMnG6=ZJVA[OXR7OhRAU9:?SXfHTX=jQ9VOVGicKgR1PXJ=
Mg5gQ8EeIF1IIfA@C5aTGG=fKV^6/<2fcHBRe_Sg/XekJi>nZXb9QEeYM7=]M8VM
X7M_NW5XFCXh?4A>EeUBBE1=ODM4A4Q=DDI@EF]nHD]PR81_TjF[/6]NPH9_K72I
h;o1Zj2[XZ;0W[Bn]:naXHQoQ8R7PWmoPF^0MhjCRjVU<d5B@4a<CJnc][_0`/6o
_L6i/[:g^KF_ZJ^/Z:6MWZ6jXl5YS;^c[Y^DXZJHWiioQHf?SIFU[J]mHhZZRH>N
VOjGOibQXYnKWJR/Xj2UYInRQHR=MWF3NiZITiVCSgY^NWagK6eiP7mgUW^<X8R:
P9fXVHfHSh>AQ9:OW8n9Tin@WJZ/Z:Rb_KV/YJZ[YJ:VZ:FFQ8:;Rh>9PF=FHEI=
He]LFeYGDdm=ATa8>S<h>cQ5D5A?CeAAAT1:EEUFDeAFDTQ7C4mAAd95CTe?EUiS
HUmNCTA7B4A5BcDoAT8h=3]5?C`k>S/l?d10;R/j?S8b?cP/:cY5@ShoADA2?SXd
<2do<Rhh?ci0Abd`=CPg<R`XnbDE92@W9BDY;S0/9bTY:2LV9RDU<Bl/:OhXObTR
9RTW8AdM7b8U9b@P82@Y92@S8R7oRi^;VHMnG6=ZJVA[OXR7OhRAU9:?SXfHTX=j
Q9VOVGicKgR1PXJ=Mg5gQ8EeIF1IIfA@C5aTGG=fKV^6/<2fcHBRe_Sg/XekJi>n
ZXb9QEeYM7=]M8VMX7M_NW5XFCXh?4A>EeUBBE1=ODM4A4Q=DDI@EF]nHD]PR81_
TjF[/6]NPH9_K72Ih;o1Zj2[XZ;0W[Bn]:naXHQoQ8R7PWmoPF^0MhjCRjVU<d5B
@4a<CJnc][_0`/6o_L6i/[:g^KF_ZJ^/Z:6MWZ6jXl5YS;^c[Y^DXZJHWiioQHf?
SIFU[J]mHhZZRH>NVOjGOibQXYnKWJR/Xj2UYInRQHR=MWF3NiZITiVCSgY^NWag
K6eiP7mgUW^<X8R:P9fXVHfHSh>AQ9:OW8n9Tin@WJZ/Z:Rb_KV/YJZ[YJ:VZ:FF
Q8:;Rh>9PF=FHEI=He]LFeYGDdm=ATa8>S<h>cQ5D5A?CeAAAT1:EEUFDeAFDTQ7
C4mAAd95CTe?EUiSHUmNCTA7B4A5BcDoAT8h=3]5?C`k>S/l?d10;R/j?S8b?cP/
:cY5@ShoADA2?SXd<2do<Rhh?ci0Abd`=CPg<R`XnbDE92@W9BDY;S0/9bTY:2LV
9RDU<Bl/:OhX5BTR9RTW8AdM7b8U9b@P82@Y92@S8R45d6OgPY=hNFI/G6M_L6]^
NGegOHF@UYB@TiVJUhf7Tj>QU8imMWn4P8:<LVMUKFeOEEAOH5eHEU]VKVidJf9j
XjjN]W2Cb>GV/9aeMJg<XXnNUg5dM79dQ9faXWAlWY9dIEY@D5AJFe98@_i?Oe1B
E5MHDe]NM8IYCf6:PW6EYj^_J6f:QGenIWW9alB`[[Z[X[^SZK6d/ZZOUi>KW8mk
L7AmJIJ0RHj=Z7e4>EE9A5M//kRh^K^m_l72_kfh/J^Z[K2f^;J^YInPX[6UXf^L
/[2WUIBTYiZRWWZ6TiREW:b_YfMaUJ:9Q9>?Q8jJ0:?nYCfVWjV[XZ2UXiZbR8jF
Lg23MY:TQJMbSVQdMgegJFQeNWA_Rfj2WHjGTIZVVI:PVi6QTIRLUhj:SiJQYZfa
/_j`Ol6`Yjb[XIfTX9^<OGf7QWenRWEQKg1RIemOGU]FD4U5D5A=@45=CD94CeEA
DUQDBDi9B51MHEY@Dda<DU17B55<AdA9E5eOGEIDBSm1CDm8?3dn?3Xj?3m3@Clm
?3dn?d@f>DY6<S95A3/kA4I2A4dh>d11?SL^:4<d;C@j>Ce52BLY:b`[:2DR9ROn
:7lW9RDU92@Y;RhY8bXY:BLV9B@T:bXX9RHW:2XT:B`Y8ahN81hS9bLR7b0S:b/Z
:BSgPY=hNFI/G6M_L6]^NGegOHF@UYB@TiVJUhf7Tj>QU8imMWn4P8:<LVMUKFeO
EEAOH5eHEU]VKVidJf9jXjjN]W2Cb>GV/9aeMJg<XXnNUaMaM7AbM8BM/J9dO9jB
M6EJD51DFU]BB4;nCgm@DUAGF5=KGWB6JDmQRX9aUJN[[fQ]RXEmOVIibLO4/:jj
Zj:kXjVa];:ZWiNCVib?Ng1dOFVFP8V>SJQmA3UEBDAGK;>h^;Vk_Ko1`[nm^;6[
ZZf`][Rf[ZFOX::aYJ=[W;:`YiFDY:NJXYijQY>HUIb/[jMWLIFRRHBCShB>VP2S
oZDmYYnYZj:PYJ>J/XR>UW=`PgJBY8FWLXiXM7MmMfUXMGYdKh]^PYf>Ui6JYYVB
X9^AXI6HW9N>RXnFXJJ]/K;n/7o1/:N/Zj6MY:2KS7emQhImOXYeHFm`HVMOGeiK
EU19AE1DCD11CDe2A4mEDE9HE4U>BDQ@GF5JD5=<C59@AdQAC4M4BEAMGeeFE4Xo
@De?B3`m?S`j>S`o@d4o?C`m?Sm4=SU:AS8bAD@k>dA6@TA=>3]0@Chg;RQ3=2dd
>STmA@TW:B//:bPU8RHWoRQo9bHU9B@T:Bh^:B<Z:BTW9RDT92/Z:2HV9bPZ92T/
:B<N7R0N8bLW8QlP8b/[:RTXmh:CN7UVK5aWKg1[KWUmMgf5T9JDT9>IVYN=Qi>S
XIB>OGIoQ822S79WIFe]GeEDGf1MF5IKIVi^M6]RNZ>^W[I`TlSUi[2LMGF]c::?
WYLGLGAdLWB4WK6RM7bNTWAUFU1@E5YKDTQ2oTmoD59DEeQCFeidQVU?HHZ2LIFW
ZjmXKHZ5OGiVNLW7a;2^^Z^R^j>Y/KBbZYnGTi^LSg]`M7eYUX29SXfXOD@iEDU4
Efbc^;Ri^kfo`L:o_KRaZjZ]/;Jh]ZjUWj2R/JFSJibb/:NEU:BWVZ:NNXJCV9FL
[:nWIg6EXXV4Thn4SYX0XojU?JJOZJ^RX:FSV[:8SYIcL8=fTZB5Yg:>J7AgOGMY
J7EjM6n;KX:MSYNAVZJITZ2KTJ6AV9bGSXZ?UZ6V[K6bo[1o`K2W[:^QWJBPVham
OHN6OGj:MF5_L69WGemNFeI@BDE@E4e0@De=@TA?EE5BF5A9CTU8D5eQFU1CC4aB
D4M8DDa7A4UDGEmMEUA:?d5=CdPl?Chl>SXl?d=1?cdl?ChoA3HiBTHb<TE4>c]4
AT94CCPk@44n=bhX@c@]=3Xi?DD99bT[;2/X9B8V9ohX;bLV9BDT92T^;RTS:RTY
9bHU92@[:RPV9RLX:R@Y;2TS7QhP7R<W9b8O82<[:bXY:0GCOnmoTg5YEVQTIW9i
N7^3PGMnPhbBSHJ:TiZITXjFWI1kVhIlPX=iNH>1LV]aM6i]LfQPGfEUHg24KWI[
Ef>6TH:NF7JN[Jn=SXR>a<^6LHMkQ85oPXVBV9b3FG6SSei@EEiJFf1NE4e;DEIM
HfIUHf1]JUm[O6EFKhf6MIRXZZ]ROf^2MgAiDUNZhlJQ[MG8X9R/Yjjn`[Zi`Y27
OG^1R8Z9Rkb=Ogj6Z6aG=UM>?Ej3^/2l]kBf_<?9_/:o[ibGY;>e]K6XWINFVJj`
RWfR]ZjXTI>VZIbVXG^?WjJQY[BdYfR7Xj:FUIN@IgR=VI^JWZ>OXj2IW:>LSZ5d
Q9MjOifAOiJhRKYPTVJ9Gg1fKV]_IE9bRVMhUH^IUY2OUI:UYIj_THj;RhjATY:Y
YZN_]kBVV;JQUYZGRHB<TXj2MWR1OG1LNW5OM7m_IfEUI65JDTY5C4e4>41ACSi:
EEUDDeI@A5I2=45NJUU2Cd]>DTi6CE]4?3DiAE1EE55ICSTlDeI6Od@k<cHn@chg
A48o?C/k?3a=@d]MDcPiDD]3@44j<3E1>cXi=cDd<c8a:Rdk?S<Z:S0`<C4`;R`[
<30_;BXV8R0U92@Y;BdW8BXZ:BPV9B@S9bHU92DV:BXX;2l/9R4P8Q/R:2PT7ahO
:2PW9BC_Oi=aJEIXI6IbNGQkPh5gOX><Oi:=QXZCVYVBSYJMT7^KQWb2PgUiPh5b
Jg5dKVecJ61OIFESL8A^MV]GHhJAPYiHMYj][hf>R8k4bhIaQg^4PGn2RI:HW8=I
LJ>?GU1EGUYKH5iDCD]AEUeSIVESH6eZGf]lIEI_SHIeV:RZZf9[PWMdNE9GZ^?6
XJgEb:2H[:N^Okk2^[W2T8MmNh68RXV;_8eoOXJXK5LfEdhmGX>j`;bg];Jl`lVn
`[n_W9NT/kFe/JRMUiJI[[2:OJ:f[ZRATjJYW:JQNhnOYZ6V];BWJ8NSXYJEUi1W
N8fIViZNXinSX9VLXib>XGB4UgYoWI6F^8VjH99VREm`MVi[KfEBLXYWOgRERiVF
T9nETZFUWZnASX^;SY6BTZVVYjng]:JH]Z6FVYN9Q8bBSX9fN85mL5ajLEmdOfmW
IFETHEYBBTE<CD@h@55>?TYEFEACEU14ET8d@EiZFD9?BdiBCTI=Fd@l=CU5D5ED
DEU>>CaCETI4>c<f?T<n=dA2?cdk>c`lCD=;OeeC>3UABd=0@CX`=D4k>STg=C@c
<S4Z;C/n<bXZ<30a<C0^;2/`<2l]:RHR82DT92T];BLQ:RXY:2HU92<W9RDT9BHY
:RP/;b`V8B0R6b8X:2@O7QlX:2LU9>moTg5YEVQTIW9iN7^3PGMnPhbBSHJ:TiZI
TXjFWI1kVhIlPX=iOgV3PG9[LGA^KG=XH5mUIF=`Q6ifJeMSQY62WUQfWZf_SHj8
S/C;QW67NhB1Oh:9TYRLPeUaXhmND5ENFU]PGUA=Be5FGF=VIF=PKFYOJgaUEVn=
QWFHZ:Z[HV^2MgAiDUNZhlJQ[MG8X9R/Yjjn`[Zi`Y27OG^1R8Z9Rkb=Ogj6OjQ/
EcIGCSeNPk[0_;Nd][c3bKk2_jnLUjBc]KFaZ9fGUYV^/8YmX[J^Z96CYZVLYZ5k
SinVXJJd]:MXQj>RUYFGT6MhSIVKVYjSWj>PVIbSW8jQM8BGNWnMTIJhRKYPTVJ9
Gg1fKV]_IE9bRVMhUH^IUY2OUI:UYIj_THj;RhjAOi:BZJJW[kNdYYRfXIJJUhV4
S9:>PWIhPGe`G7YaGgAoKfMUIFAQFU9:ADa=A3Q0DDhnBUEIE5=FD4AF@SA1GVYI
@Tm;CU9>ATeKA3`e>DE@EEAAFDhi?5=FAT@k<cHn@chgA48o?C/k?3a=@d]MDcPi
DD]3@44j<3E1>cXi=cDdAS<b<BX]>chc:RX`<34a<2h/:c0`;bdZ9R8P9B@T:Bd]
9b4Z:RTX9RDT8bLV9B@U9RTZ:2`_;2HQ828K8RPX91lN7bPX9bDT1JAohh25QVag
M7MYL7QlNg]mP8MbMI:LRh>>XIJ>SHb5P827RhV3RYRKUGjFNVZ:PgBEJg1cMGQg
K5j5NVYOHFj0S9BDNG2AWhj5YK>l^:n[ZJJQS7fK_9]bNU]5O8j6S75]H6YbK5eC
E5YEBeAYJEEDIEEIHf]/J6]bMW1[Wk2RV4moI8=^IU92I5cHl:j^YGf/`:6fal2X
VJ2^WWAMLHJ:UJV4NGV8ThMYDT]HFde2FiO;bL:j][Vn`/>d];:_ZZBNVibh^IN4
Tj>QXin4PZ2RSXj;RYFVZjBQYZ:ITYbb_:^BCI6dUGf@WiN4VX><TY>bXJbOV9R?
QI>[Y820UIRQYYEoSI>KUGaWL8MdJ6McLVMXM7UcLG^?WjFUPi6FT9NY[ZJPQG5d
PXbFWkJWYKFm]kW4ZZNQV92AVJ6>TXQaIg5oQGR0OgE`L6IHL6=LHF5GDEA?BTM:
Cdi5?55DCDIBIfMGDe9DFV1QG5I0C4dn>4A>D5U?@cm4Be1ABD@n?D12@3hG=STl
>cTk@DMODDeBBSH^=CTj>SD^:bhbnClH9Rhh?3Xc;BTg=CDg>SP`:B@e?SH];2XT
:?hW0bP[;Boi90@L7R4U9ohX1bLV9RDT8b8RnBAo7AhO8B<T9BHO=2XN<N>0QHI/
MgAgJG1hO7]kOH27LWFBW8^3SZ6FSXf<QH20Qh^9PhZHViEnUWYZRX=dUF]`LgEh
MfaNQGYZGf5^P8bDU7U`TIn>QJFc_;R_ZjVVXHamVkbKLWYKAGb>QXaaKF1ZLVaM
DeAJED]DJFUEE6EEFF=oJfaXJg9fL6^O/::HCfB3KVIB@VALf?2^[ZEm[<2Q]/O0
Z9VP[YidGG66RYFYQ7UiR9>7JE9;F5]=@U^GblW2^[Ji_/;3];Bb[jZTWY^L^;VG
Q9>SXJ>OQ8:PXXj>RhZEYZ^TXJJRVI:L/[b[TTfA]9EmT9nGQ9Z3S9:C/Z6/WiQo
V8n5Tj^TP82EV:6VUHfCViElIg27M6QWLg9WJ7AiLg5kSinUYH>AUY2GZJjVX8Ea
M8:<UYnfYjFe_KNia:ZWXIR@TIVQSY:8LFMaOhEhP7meL71VF71SG65QEe5DCdY7
BTm>ACaAE4e6DVMWEe=BE5YPHEaF@4a=?SQ4CU1ICd<T?dA;D559A3hm@490?SHi
?3/i>d57Ge5=DTXf;SDi>SXe;R/^<_To62H^>3`j<bdY=cDe=cXh<2TT=Chf;B`Z
92Sn9`<X:bd_nB@471hQ9BOn:0LW9RHU92<R8_TTOadN7b4S92DV7c@Z7S7SP8F6
K7MdMfU`N7akNgf0Qg9eTYb;PhjQUXj=S8F0P8N;RH>:V9^EOYIjJXZ3M9E[L7=e
N7M/GXEjJUmQKX2<U9AiL96OSXFU/kbh[j^YYZ6<OI^lVg9jFdElSXJ<LFePJW9/
GE=DFUE;E6UYEEAUEEUSOf]/J6]bMW1[Wk2RV4mTPfiVDT9TG=S`[ZjUOJc0XKK7
`:RIX:jNM5eaQXZEZHAiNHRCQfUBBeQKCD9KUl_9`[Zf^Kk2`kBd/ZnZY9jKW;Ri
UhBCXj6SWhB2X::>SX^:UJJ[Y:6VXYVBW;:lZi9=TKBEOI2OUhBJPhbBTk:Q[9nH
OiR?QI>[Y820UIRQYYF=Ti^EO6M`QgAXIg=bIfQdNG=aNhnOYJF3TIJ@UjV^YZ25
LGB2S9JO]ZNU]Kfg^LBZYj6HT96IXHjBR75WLGn5N81oMG1`IUQ`HeaQHEMAE4m:
AdY?CTDlDEA=AU9WIeMCDUAJH65LET1<CChhA4i@FDm393m4Be1ABD@n?D12@3hf
>C`k>C]1AemACE9:=Rhe>CXj=Bh[;S;i?aPV;SPl>S<]:CLe=CLj>30Y93Dn=Rd/
:R@XoRL3:2/];oTT11`N8BDWoRP79bHV9B@S8R;i90`M7QlQ8b@U9Qld:Qha1K1o
iXB9RVeeKVmZKG=iOGekN8QgNiNQThjIXinKVIB@T9=gPXV;UJ>UWHRORh:JQfIb
NVQLK8fLRFelMFYQGEiSIf5LFEmaR8UfTYjZ[Zja][RLSWj=VG=JM659P969SW1[
J6a/I5I;ADAPGfMdMVi^M5iULWUbIVQcRX1gYkBVW5D_I85_LFQPOg??jK2a^J6l
^lo4]:>HUINJSXb7QX^=P6nGSHN<SX9ZF4E^VZVMU:2bo[Eo]k^n_[f_[jj/ZJBP
WJ2`ZXn6UIV=VZFFSj6QW:fOWJBa/ZNQYI^GVJZn_9inLY6XX8b7Tj2DZYFOXj>o
[:VRXZFMSiBTUWf;YJ6FQVMjQibTTWEZLGiaK75_IVQdMF]UKH6FXZF9UY^GWJ^^
YJBDRi:IVj2XYYVHZ;6_/[^[ZJAoVY6>TIIoQGi]IW9oPfIeO7E_KFAGMfIJGEeH
F5mABT=4BTm>BUaUHU=>EeYCCdi@EE]LF5=9BdY5@419DUIFEEADEUYMAd=0@4A6
@cl[;c<d<cDk@E94@TmCBD=7@TA4@3Xh?40_<C@h>CXi>3Li>SPd<2h];2X[;S8`
:B<T<cX<<R/];RTY:2LW:2X];oTT3ahP8bLY:RTY9bLV9B@S8b;i90<S8b8RoB5o
7S<W6BWVQ8V:KGE^KfY]LgUmOG]hR7MkUj6CSYVSWi^IU92@TgN2RH^EXjFMR9n;
PYZ7IW9jJ5a/SIb9KGaeJV5MGV=WHEaIGg68RGJBWZZ^[[6f^9b>OXfILeYdHDV0
THV>L6]XK6aTET]5A61OIgAfKVidGVEbNG9VJ7>:P7LdYkBVW5ETPFmaJ61oLloY
/;6iXKbkclBdXiREUiZ>S8N6Rhf0KiN=Qhb>PVYHAFjJZIfDX;;n]Gng^kjn_Jn_
[ZbYY:2MX;2ZShJEVHfJYIJ?XJ6L[InMY;6bYj6UViNIZ[jlWWibTJRPS8NCX9BZ
UInSXkn/ZJ:RYIf?U:BFOH^UXIJ6IgZ7W:BBMFYaOW5/LFmVJ7AeJfE]PIJRYHVF
ViNMZjjUY9B;TYVKX:RVVIRX/Jnb^j^YY7nJTHjAUWn5OVeVLWn3IWElMFm]I5Mg
IUYMGEQHGe5:@dA:Cdi:G6ERDdiGFU=?CU1EFeaHDdU;BTE0@4UBEUIEE5AFFUe7
@d10A4I3?b/_<c@c=C]1DTA2Ce=9@dM2A4A0>SPl@2la=3Pi>STh=cTj>3@`;Rd/
:R/^<S0Y8b@c>P`b:bd^:BTX9bLX:Rd_nB@?7R0S9bTZ:BTW9bHU92<S8_TT0b<S
8R;m8GlN<bLI:NJ4RHY]MFi_JVecNGemNgR8Mg^GXI>>VJ>OViVDT92CMh:9RiFS
YIf8Wh^2VXMVLWYXG6b=W8U]O7EZHEeNHfMQG5UOLHR9MY:NZZj^/KJhW8inSIUc
FWAQBH2ARHi`JfQ/K6AFBdE4H5mWM7I^KWANIG9iLVIXLhZ0McBW]:JLEFB1Kg5X
H7mccnV`/KVQ_;_?a;BSV9FGVXj<QhJ;SH1_Uhf7S8j2JUQ5KYZYWIBP/_jeOkNk
_[jm[jn^[:VTX9fP/:Z?QYFISIZUUXnQXIb]WifT/K:WXJFKUiVZ_[bNOW:AZ:2<
Qi>PU:ZEWj>S_jbYXZ:UWHnDY9ImRjFQUXIWNXNLY99eJW5nLFaaKfIXM7E[IFf1
UZ:URIJKUif[[ZFTU8^BVI^PZ:JIV:Ra[k:kZjVTOiZASY6FOhEnKFIbOh=VMGae
KfeTEgMVFUeMF5QODDY3A4Y?CTYLIF9CCUMJDdm>D5EKG5QCBD]:AD10BE9FEUED
E5IJGDM3@414AT<o:blc=3<e>d5BA49?DdU3Ad94A40j>3a0;c4d>3Tj>CPg>CXh
=30^;B`Z:bhb<2TS93<j338[;BhY:BPW9bPZ;Boi90lN82<W:BXY:BLW9RDT8b<R
nB@38b<R8_dQ11hc9aTY1K1QjHR@TG=fJfU]JfegPH9jL8aoQ9^TVYRRS9:ET8R7
SIB6TYREUYZERXfOV9FWVH68NVQMJX:?QgUnOG]hLfiYIW=LK7QbW<>[PHZFXZV`
^L6JT7aiLT]6MFA;P9><TG5YKV_nJ7mUGUQOJFi[KG=`IVMbQ8]jI6EeVH]lY[6T
W5IHLV5_MG>>N[oS_KW?bLV_g;RAQI>QWiFKYI1VG79hIIjIThn;PgIZKXNS[JNS
Z[B//;Fi^KF_[:RYZJRWY:2NXZNKR8RDS7N8WiV;T8fD]JnZ[KFbXi^NT92L]LBc
Qf:ETYf[WGn4RJ>>YY:MX9^dWZFUZ[2YVYJKTgb<YYf>Ne]jPI6NUWe^KG1XIfmc
M7^6Og5TIGF8U9R8TiVIWJFTWI>AUYnLU9JP/:BNXjFPWJ6SYJBOUY6BU8nGUHZ7
TifMIWZ7PWUfLFUkJ5YKGE]PJDa5?3Y0BDmAB5EHB3Xj@4=6ADE:D0eBCTYDAdQE
E4UAId56C?i?BE5CCD]:CE9CCTXb=c`m?3i3B4Pi=DACDTY6>cho>cLf>d0_<cY1
@d8o?DE0>S@`;bl`;bd_<cPh<R`U<3@/:2lb;RXY9bLX:R`^nB@?8B<V:B//:bXX
9bLV9B@S8oTTKRLV9B<Q7adL>De0<3kYR92ALgI[JFe[KGN1PWY`S7n4VjBJV::<
TYF@R8N=U8JBV9FFVYF:SInHUJNIPHQjJ5eZPXn7NGimNgQcKVUVLea/N7:L`j^1
RYJRZK2i`IZ@O7UbBdIeI4^0ThbALFU^JoiXOfENF5mYKV]]Lg1VIg:4RgYTIGFI
RgbV/JBLEUQbHFmeLhij_n>m^Lo9bJoL^965Tj6OUI^UT6ILLWQUWYVCSh^3MVY^
Qj>]Yj>Z]:b`]KVi]Jn/Z:VYZ:NTX9jRYi^8R9B<MhROVH^@SIBe[jZ]]K:SVij@
T9bea;>7HYFBWJ^MOhB9XhjVTYfPVkBNYJFZ/:VJUY^CO8bVWHikFgZ1TIjFOFi]
L6QWKg=dNhIoLFAUMHRDV8RCVIVMYJBMTi6FWibDUZ2`Y9jSYJ2MXJ>UY9nFTI:D
SiNERXNCWIeVNXN2NGIaJG]XFU]MFf1YC4Dl>T19Ce58EEQ8>SY0@dI5ADY@3E9>
BUA7B5EDBE5W@DI<oTm9DE==BdY=DU=>BS8g?3dl?T=8B3TeA5=BBTHk?Slk=cHk
@2lc>T53@SlmAD0j=30_;c0_;Blc>3Pb;2D`=2`X;c8^:RTW9bPZ;2ki90lQ8bHY
:b`[:RPW9bHU92<SnBA^9bHU8b4O7A`iCD0`?^V8T95cMV]YKF]]Mh62NW2<OhBK
Y9ZHXXbBUI28QhfDQY:HUIJJUHZ=WiREYiV1R7YXGFZ2ShMiOWekN7=^JFIcG6ah
LYc3Zh6:UZ:Y/;W1VY1lNG9;AWETBh2CS95aJFi[oVQoIEiHGfU^JfecL6IWLXB;
NVAUMIV;O:JaY9aFF79QKgEcSWZohkficlW9[mbhTHFCXInEVjF@IUabN6FNVI>?
Rh=fJVj7XjfWXjZd[;2e^KVe[jbXZJVXYjBPWZ:WVhR8U8agR9nIRi2=U;F_ZZfe
/Z>KWY2@W;G4/hMRUI:MZieoQ8VSSZJBWJ2K]9jUYJZ`ZIZFVi=lS:JMSW]KNX6A
WYImKVe`J6M_LgAkQWmaI6EeR9BHR9>IVIfUY9fCTIJOW9BFX;2TWZ>UX9fQXjFT
WiJATYB?UiF:Qi>MWFIjQh9iMW5YNfQJFeeKH6U<AC`j@4U?DDQEF4Pj>T13ATE5
BU0=DTi:E4M8EEA9DFM1ATcnCdUADde;BTeBDdi:<SLl?C`n@dQ8>CE4De9:AS/n
?c/g=S]0;c<j@D=2?ce5@3Xd<2l_<2l];c<h>38/9C0d;2P_<RhZ:BLW:2X/;_TT
3b4S9RT[;2/Z:2LW9RDT8b?i90`W9RDS8AlM73U=@30n1JeojHZDV7YnLFeeKVaf
Q8QlKY68S9^OUiJNN8R@Qgf0S9BBWJ2GTYJDSHREU8R0NX2CMgj5PG1XN91lOhB8
RXV7QGmEJFm@RLjgPX>=WZR/];nJRFaSGd58Oem5Ni6?UG=YMVaTIg1bJEiQLG1Q
HW5/EVYfSIN0HF9jUHEcW:NMVEIoG79NL7inTWJYgMS8eMFnXJnCO8FT^;6QYZF<
He9TNGj@UYJ@SHf7OIV?QHJBX:V/];Rj]jnVX9jRXjBTXj6NW9jQVHZ7S8=bPYRA
PXJ3Rjb^Z:R_ZYZCUXf=WKJlX7AFVIFMZZFCSYJ4WHZDUHfRRZ>TZ:^VWINFVgao
T8Z<T81oTHAmPH5jNX1ZJVmgNg]lOi:4MG5iPXF4PXV?TYFGU928SINNU8R=W[B[
YJFVY:6PVInTY9nKVY]oQhMnOXN;Qg23SH=hMgMdMfMMHVAQHVY5@C`j?456BC<k
?cXe=ca0?cdl@4I8AT===SUEFTQ?KCXf=3Y4BdY6B4M7Be1AC4Lo>d15AD90@dI7
=bhgB4/m<3@g>3Hc<cPm=3U1AdM3?3Q0>c@a<C0_;Bl^<3Dk>cH`9Bd^9RLa=S8[
:RPW:2T[;?TT3BDV:B/];2`[:BPX9bHUmbAo9B@S8R4P7alQ=BPH9^V:U9QjOW5]
MFi/MXB8O6jAR8bKWiNFWWR8T8MmP8bDTYfPUi:FU8f8UIB8P7Z0TgMnQH5`J7R@
O7n4R8Z9QhEoEFU_D8W>]h:3SIjX[;BoVXU/Hem1B7mOAG^ASiEcJGI/I6M`LVUN
HG5`HF9aK5IZMXeoUh1QHWZEQG>LYifIEUabGW1nOY9fZMgHb=GE_Z6_Tgb5Y;Ra
XJJUS6=BI7UnT9JFT8f=QgfIShF6TZ2Y[;Bh^[N_YZ2NXZ>TY:>QWYbNXIV:Qhb3
LX:HTH:6Ph^/[ZRX[jZJTiJ=SIff_:1dEYVEWJZUThjFQ9f:U9F=XXZSY:QoZjJM
UiJKO7n@RXb@P964OH61NWZ0JVY_Mg]kO7nBQ7EaNH:5Q8:9Si:EUiB@R8fGWYB8
SIjdZjFUYZBQX9VOY:BOViZKOhN7OWj7RhM`Phf3N7MgM7MWGF9THF9ZAD4l>Sa1
ATTc>clj=CLl@3lm?416B4I3CCHiEEY8Cfdj=SA<>TA;BTI8AdM;D55<Ac]0ADE2
@4=6AcL^=dQ;?C0d=cPf<c<h?C@i@DM7@c`h@3/d<C4`;bd_;S0e>c/f<2D];RHW
<CHb:bXX9bPY:bci90dU9RT[;B`/:bTX:2LV9OLTObDT8b8Q81lO8CDX62KYRYBH
NWiaKGE^K7J4R7a^THR<VinGUYihR927OH2<U9:MX9NBUYB=R9FDR81jP9=gOXF1
L6QhT7aoQ8R:RHN5OeEYKe29c[N2PhfNZ:bd_iZ9K6=O@DQoGdEkTHnELfUfK6AW
L79YGV5aL65RLFaFJWJ=OiN0HF9jUHEcW:NMVEILLUi`OWjBMZWMf<SEeKjQ[i=l
QJBh/J6VYHaSDVAiOY2FUY2=SHMmVHn5QY:PZJbd^;Zg[jJPWZ:SY:BSXIjLWZ6I
RXN<Pg:2V962QX>;[:jXZ:nZVY>FSHfM][bPM5JIUIfZYI>>UXBMRYBESJ::XjBX
Oj^VWINFVgaoT8Z<T82AQ7f1PGYjP6YZKgMkNgaoTXAeLGV2QHB2RHnBUINDT8R=
UijDR8fN]:^UYJJTXJ2IWjBTWi^JVgn7QginQh^7L8>=PgQgMgAgIeeRI65RJTE1
?3Xl@DI9<c/o>SDg?40o?Ca0ATQ6@ddf>EEJB4m]>SHdC3Y4BdY6B4M7Be1AC4Lk
@4E5@T13ATLg;SM8Bcd`=3Lh=S<c>3dd>D57Ad<l>40k=34a<2l];bh`=C/k=S0U
;BhV9c4f<R/Z:2LX:B//nB@=9BHY:bd/;2/Y:2PW9RGg90`U92<R8B0O7b4e:1PV
1K=oihRDVWn4NGMlLfifPhQnLYB@TIJDS8^@PIJOTHN@W9n8U9NATj>b]Zbkb[F7
MXZLOXFBUHAgRZYgNGj3RHjBUH]VOX5IPkfQRXF?Y[Bd^LFAME1?Fd]APULmMHnB
VWMZKEmBDU]MDD=YMgIYLHF2K6edRiZ3Gf5mSGe/UZFNWEaoLhA/NhN4U7B?do?F
cLJRVHJ5S::i_ZjKWYFDUHA]Kh>7TiJ>SI>>P9f<QIRf_jR=];Ng/:FOX:BQXZ:Q
WY^HUIJMW8n5PX5mPY25P9>GVK2YXZ>YYYZEVIZIYKNaTGAZR9VSXZBXVhJ?Yi>K
VY2SRZ2OW9NGVIRDUgIePWf7V9=oV8AdMGQhOHIbNX62OgQ/HY:9P868RhIoPh>8
SY2>S8fFVJ:TVHnL/Z>RX:6Y/K>_WZFZZZBMVYZ;T8f4PhZ9P7N2PWAYK71^KfAR
K6iVH696B4U8AT=2@T@m?4A=D4e;A40n@DM;BTM6;Be8C3PjDe0m;C=:FUM=?S/j
?452?STo>Sm3@C/f=CI6>S0d@dTk:3Xl?S`h>3e3<SHl?S`d:bDb;Rd`=3@]9RDT
9R/a<B`V92XY8bLd=c0/:bTX9bPZ:oTT0RHW:_h/2BXY:RTY:2LV9BGi97lO7b0Q
8R<T9AH[7a4RihRDVWn4NGMlLfifPhQnLYB@TIJDS8^@PIJOTHN@W9n8U9NATj>b
]Zbkb[F7MXZLOXFBUHAgRZYgNGj3RHjBUH]VOX5IPkfQRXF?Y[Bd^LFAME1?Fd]A
PULmMHnBVWMZKEmBDU]MDD=YMgIYLHF2K6edRgnJPemQOHemK9JUWYeLLhA/NhN4
U7B?do?FcLJRVHJ5S::i_ZjKWYFDUHA]Kh>7TiJ>SI>>P9f<QIRf_jR=];Ng/:FO
X:BQXZ:QWY^HUIJMW8n5PX5mPY25P9>GVK2YXZ>YYYZEVIZIYKNaTGAZR9VSXZBX
VhJ?Yi>KVY2SRZ2OW7nGUiVHU9MfMH9mQiRCV8AdMGQhOHIbNX62OgQ/HY:9P868
RhIoPh>8SY2>S8fFVJ:TVHnL/Z>RX:6Y/K>_WZFZZZBMVYZ;T8f4PhZ9P7N2PWAY
K71^KfARK6iVH696B4U8AT=2@T@m?4A=D4e;A40n@DM;BTM6;Be8C3PjDe0m;D`c
BUYGCChk>Sa1@Shi>Sm3@C/f=CI6>S0d@dTk:3Xl?S`h>3e3<SHl?S`d:bDb;Rd`
=3@]9RDT9R/a<B`V92XY8bLd=c0/:bTX9bPZ:oTT0RHW:_h/2BXY:RTY:2LV9BGi
97lO7b0Q8R<T9AH[7a4RihRDVWn4NGMlLfifPhQnLYB@TIJDS8^@PIJOTHN@W9n8
U9NATj>b]Zbkb[F7MXZLOXFBUHAgRZYgNGj3RHjBUH]VOX5IPkfQRXF?Y[Bd^LFA
ME1?Fd]APULmMHnBVWMZKEmBDU]MDD=YMgIYLHF2K6edRgnJPemQOHemK9JUWYeL
LhA/NhN4U7B?do?FcLJRVHJ5S::i_ZjKWYFDUHA]Kh>7TiJ>SI>>P9f<QIRf_jR=
];Ng/:FOX:BQXZ:QWY^HUIJMW8n5PX5mPY25P9>GVK2YXZ>YYYZEVIZIYKNaTGAZ
R9VSXZBXVhJ?Yi>KVY2SRZ2OW7nGUiVHU9MfMH9mQiRCV8AdMGQhOHIbNX62OgQ/
HY:9P868RhIoPh>8SY2>S8fFVJ:TVHnL/Z>RX:6Y/K>_WZFZZZBMVYZ;T8f4PhZ9
P7N2PWAYK71^KfARK6iVH696B4U8AT=2@T@m?4A=D4e;A40n@DM;BTM6;Be8C3Pj
De0m;D`cBUYGCChk>Sa1@Shi>Sm3@C/f=CI6>S0d@dTk:3Xl?S`h>3e3<SHl?S`d
:bDb;Rd`=3@]9RDT9R/a<B`V92XY8bLd=c0/:bTX9bPZ:oTT0RHW:_h/2BXY:RTY
:2LV9BGi90`O7b0Q8R<T9AH[7a4R1K=oiHF@UG^2NWYnMVmaNWmmNI:CThn8PX:6
RIjRTHZHX9Z>VIV<RIV[/hfSclfDPIFJNFIXQijMVZ66QXR:SiBIW:6E[[:CXK>B
S8>?[l2k_<R6ICi6H5ADO5XnMI6GWgUYBd4k@eAOGEIUJ6Q]OY2AQWUfQYV5Geml
Rge^W:bWYfIoM8EYLgYeQVUh_?_NaKB:X92M[[^k[Yb>[964RGYQK8nBVYB5R9JB
OjB@QIVlbKBHWjJ[Z::QZ[>UY::NVI>>RY:FUXj4PHF:LWabMiZTX:jZXjB/Zj:O
YZVY]KfYQh2@QYbVWj>_Y8ZJ/9NLVHjRRYNFSXF9UIRBR6ifQWj0RX5oR7ekPX=i
M7MOKWYnP89jK7ahMh2<TXf5RH>4SHn;SIFJVYnQVIBS^Zj^YijNYJ6GYj^^ZZ6H
U9>[[:BIVInKT8J:QGUeNWU`K6=TL79UFeY=DeMGDD]8B5E6@DeGDdY6C4M4ATa@
DDmF@Se;Bc/e?eI1;S=9FUYABdDo?T53@Slo?dE:B44k>3Tn?3LhAE59=cLj>SLc
<SLl?3i0?cXc:RD^:BL]=CH]8bTX:Bhc<bdV8bTX92Xe=2X^;2XX9bLY:_TT3bHW
:BXZ:BPV:bXZ:BPW9RKi97lL7AlQ8bDV9bLl<28ciHF@UG^2NWYnMVmaNWmmNI:C
Thn8PX:6RIjRTHZHX9Z>VIV<RIV[/hfSclfDPIFJNFIXQijMVZ66QXR:SiBIW:6E
[[:CXK>BS8>?[l2k_<R6ICi6H5ADO5XnMI6GWgUYBd4k@eAOGEIUJ6Q]OY2AQWUf
QWnIQEmOO8]mKYb/YjMVM8EYLgYeQVUh_?_NaKB:X92M[[^k[Yb>[964RGYQK8nB
VYB5R9JBOjB@QIVlbKBHWjJ[Z::QZ[>UY::NVI>>RY:FUXj4PHF:LWabMiZTX:jZ
XjB/Zj:OYZVY]KfYQh2@QYbVWj>_Y8ZJ/9NLVHjRRYNFSWn5RIFHTXQ^MXInP8Z1
R7ekPX=iM7MOKWYnP89jK7ahMh2<TXf5RH>4SHn;SIFJVYnQVIBS^Zj^YijNYJ6G
Yj^^ZZ6HU9>[[:BIVInKT8J:QGUeNWU`K6=TL79UFeY=DeMGDD]8B5E6@DeGDdY6
C4M4ATa@DDmF@Se;Bc/e?eI1;T`cBEYJDD]5?ci1@d8o?dE:B44k>3Tn?3LhAE59
=cLj>SLc<SLl?3i0?cXc:RD^:BL]=CH]8bTX:Bhc<bdV8bTX92Xe=2X^;2XX9bLY
:_TT3bHW:BXZ:BPV:bXZ:BPW9RKi97lL7AlQ8bDV9bLl<28ciHF@UG^2NWYnMVma
NWmmNI:CThn8PX:6RIjRTHZHX9Z>VIV<RIV[/hfSclfDPIFJNFIXQijMVZ66QXR:
SiBIW:6E[[:CXK>BS8>?[l2k_<R6ICi6H5ADO5XnMI6GWgUYBd4k@eAOGEIUJ6Q]
OY2AQWUfQWnIQEmOO8]mKYb/YjMVM8EYLgYeQVUh_?_NaKB:X92M[[^k[Yb>[964
RGYQK8nBVYB5R9JBOjB@QIVlbKBHWjJ[Z::QZ[>UY::NVI>>RY:FUXj4PHF:LWab
MiZTX:jZXjB/Zj:OYZVY]KfYQh2@QYbVWj>_Y8ZJ/9NLVHjRRYNFSWn5RIFHTXQ^
MXInP8Z1R7ekPX=iM7MOKWYnP89jK7ahMh2<TXf5RH>4SHn;SIFJVYnQVIBS^Zj^
YijNYJ6GYj^^ZZ6HU9>[[:BIVInKT8J:QGUeNWU`K6=TL79UFeY=DeMGDD]8B5E6
@DeGDdY6C4M4ATa@DDmF@Se;Bc/e?eI1;T`cBEYJDD]5?ci1@d8o?dE:B44k>3Tn
?3LhAE59=cLj>SLc<SLl?3i0?cXc:RD^:BL]=CH]8bTX:Bhc<bdV8bTX92Xe=2X^
;2XX9bLY:_TT3bHW:BXZ:BPV:bXZ:BPW9RKi90`L7AlQ8bDV9bLl<28c1JYoiX>9
RfmgLG9jMFeYJg5hOHbATXZ1Oh:5RIZHQ8:DUHF4T91nLWR3R4M?Pi=YIh5gL5YN
QIjCQHFCUYZOXjFWYiVOXifFUXejRGb8Z[RZXZ^5JDUDJeQBMfQ:OiVNY7UU@Shn
BEYXKViXFUU[OhF5R8inQIR8H5agS81cXK:[ZFMoI7MMI6QUOFIUVnkLa[63/k>g
^[F/Y:2Q]9]mIf1ZQIjNWHUdP9nTT:JEQHZO]/31RIJTYj:OYZjZZ:BMUH^4Oi>:
PX:6R8Z=KG]eNiZOUj>^YZJ^[ZFTZjN]_L2NNXFZXIfPYjRRX:FP/iNGThVNR8^=
QWj5UiR=PfaiRX20RX5oOG^2RhIfKFmIJG5aMhF5NfYTHV]jQHJ2RWilQXV5S9Z?
SI:IUiBO/KNi[YfIWYN7VinRXI^GV9^JV8f1Phb8OHf@SH^BV8YeLFISJV]PF5Y=
DUEBC4Y>E4]0@4a<@3Y0Ad8n?dE:C4]DCDQ9BdU1>d8n>S]1BDi?FU15@455ATDo
@4M>D4a7ADHe?Cdj@U1=?SHh>3@^;30dA4A3@Cdh<c0l<BLX<C@^9C8a<C@h=S0Y
8RPX9Rhg<28_;BXX9bLX:OPT3RDW:2PV92</:bXZ:BPW9oTToB5o8R8S8aP/7a0N
iX>9RfmgLG9jMFeYJg5hOHbATXZ1Oh:5RIZHQ8:DUHF4T91nLWR3R4M?Pi=YIh5g
L5YNQIjCQHFCUYZOXjFWYiVOXifFUXejRGb8Z[RZXZ^5JDUDJeQBMfQ:OiVNY7UU
@ShnBEYXKViXFUU[OhF5R8inQIR8H5aoMhb0Lj6bZjUWI7MMI6QUOFIUVnkLa[63
/k>g^[F/Y:2Q]9]mIf1ZQIjNWHUdP9nTT:JEQHZO]/31RIJTYj:OYZjZZ:BMUH^4
Oi>:PX:6R8Z=KG]eNiZOUj>^YZJ^[ZFTZjN]_L2NNXFZXIfPYjRRX:FP/iNGThVN
R8^=QWj5UiQoSH=/NHZ0P8Z1OG^2RhIfKFmIJG5aMhF5NfYTHV]jQHJ2RWilQXV5
S9Z?SI:IUiBO/KNi[YfIWYN7VinRXI^GV9^JV8f1Phb8OHf@SH^BV8YeLFISJV]P
F5Y=DUEBC4Y>E4]0@4a<@3Y0Ad8n?dE:C4]DCDQ9BdU1>d8n>S]1BDi8CeY@AD11
ADI5@4M>D4a7ADHe?Cdj@U1=?SHh>3@^;30dA4A3@Cdh<c0l<BLX<C@^9C8a<C@h
=S0Y8RPX9Rhg<28_;BXX9bLX:OPT3RDW:2PV92</:bXZ:BPW9oTToB5o8R8S8aP/
7a0NiX>9RfmgLG9jMFeYJg5hOHbATXZ1Oh:5RIZHQ8:DUHF4T91nLWR3R4M?Pi=Y
Ih5gL5YNQIjCQHFCUYZOXjFWYiVOXifFUXejRGb8Z[RZXZ^5JDUDJeQBMfQ:OiVN
Y7UU@ShnBEYXKViXFUU[OhF5R8inQIR8H5aoMhb0Lj6bZjUWI7MMI6QUOFIUVnkL
a[63/k>g^[F/Y:2Q]9]mIf1ZQIjNWHUdP9nTT:JEQHZO]/31RIJTYj:OYZjZZ:BM
UH^4Oi>:PX:6R8Z=KG]eNiZOUj>^YZJ^[ZFTZjN]_L2NNXFZXIfPYjRRX:FP/iNG
ThVNR8^=QWj5UiQoSH=/NHZ0P8Z1OG^2RhIfKFmIJG5aMhF5NfYTHV]jQHJ2RWil
QXV5S9Z?SI:IUiBO/KNi[YfIWYN7VinRXI^GV9^JV8f1Phb8OHf@SH^BV8YeLFIS
JV]PF5Y=DUEBC4Y>E4]0@4a<@3Y0Ad8n?dE:C4]DCDQ9BdU1>d8n>S]1BDi8CeY@
AD11ADI5@4M>D4a7ADHe?Cdj@U1=?SHh>3@^;30dA4A3@Cdh<c0l<BLX<C@^9C8a
<C@h=S0Y8RPX9Rhg<28_;BXX9bLX:OPT3RDW:2PV92</:bXZ:BPW9oTToB488R8S
8aP/7a0N1K=oih:5PfE/IfQfLV]RGfIcOXJ?THMoP8J8SifFPH:FTgaHJgAYH6I`
M7ESPi5]NYV7MgF8X9EbJGZ;TIbV[:j]ZjjeW8JBUXb>QgMoWjN>OX:<N61XMU]B
N7IFR:6SYWQRH5YDDE9EEEAmHUadQ7aiPj27QYV:HEUbRgmcX[:XY61oHGMOIVUX
QgIKPmgHbkN6`lNn/::MY[O5UjBKPX>MY9FQVGaUO:^jZHfCVj6X]<;=P9:UZZ:I
VIf^ZjFMTXMmN9N0KgJ8THj:PYFATJ>NTj6^YZF/Zj:QZ9^V_;fCK82a_ifH/JjA
VKn]_YjMUhjUT8:8QGj8VYV9RW1gQWf6ViYoPWn2QWe^KGImQGi[IW1_I6EKDeMT
LGIeQ7EaNgmlQYR<RY6MX9bR[YfUXYZQ/[BVQH^BUYRLY:^SX9>7RiJERH24QhnN
XX]/NFUPHf=KF5a7BTU4?d9?FSdkAE18=SU;?3Ha<SPn@3le>SPd?DU4=3E3Cde3
@4YFDdLh<30e>3Tk<3U3AdI4@dDa?d4h>DE3=dA6AD0j=cXn>CPf=38a;bm=>bTT
:c8_:R`Z:B`_;2DN8RPY:30g;Q`_;B/XoRL0:?TT3b<T9BHV928Q;2`[:RTX9bOi
97lV9B@S8AlN7BXm;Q`Xih:5PfE/IfQfLV]RGfIcOXJ?THMoP8J8SifFPH:FTgaH
JgAYH6I`M7ESPi5]NYV7MgF8X9EbJGZ;TIbV[:j]ZjjeW8JBUXb>QgMoWjN>OX:<
N61XMU]BN7IFR:6SYWQRH5YDDE9EEEAmHUadQ7aiPj27QWnIRV5ILX]oLj:bZ:AP
HGMOIVUXQgIKPmgHbkN6`lNn/::MY[O5UjBKPX>MY9FQVGaUO:^jZHfCVj6X]<;=
P9:UZZ:IVIf^ZjFMTXMmN9N0KgJ8THj:PYFATJ>NTj6^YZF/Zj:QZ9^V_;fCK82a
_ifH/JjAVKn]_YjMUhjUT8:8QGmnR9ZIRHY`MhImQY^JPWn2QWe^KGImQGi[IW1_
I6EKDeMTLGIeQ7EaNgmlQYR<RY6MX9bR[YfUXYZQ/[BVQH^BUYRLY:^SX9>7RiJE
RH24QhnNXX]/NFUPHf=KF5a7BTU4?d9?FSdkAE18=SU;?3Ha<SPn@3le>SPd?DU4
=3E3CdQ=@d1:EU=7>30`=CPi<3U3AdI4@dDa?d4h>DE3=dA6AD0j=cXn>CPf=38a
;bm=>bTT:c8_:R`Z:B`_;2DN8RPY:30g;Q`_;B/XoRL0:?TT3b<T9BHV928Q;2`[
:RTX9bOi97lV9B@S8AlN7BXm;Q`Xih:5PfE/IfQfLV]RGfIcOXJ?THMoP8J8SifF
PH:FTgaHJgAYH6I`M7ESPi5]NYV7MgF8X9EbJGZ;TIbV[:j]ZjjeW8JBUXb>QgMo
WjN>OX:<N61XMU]BN7IFR:6SYWQRH5YDDE9EEEAmHUadQ7aiPj27QWnIRV5ILX]o
Lj:bZ:APHGMOIVUXQgIKPmgHbkN6`lNn/::MY[O5UjBKPX>MY9FQVGaUO:^jZHfC
Vj6X]<;=P9:UZZ:IVIf^ZjFMTXMmN9N0KgJ8THj:PYFATJ>NTj6^YZF/Zj:QZ9^V
_;fCK82a_ifH/JjAVKn]_YjMUhjUT8:8QGmnR9ZIRHY`MhImQY^JPWn2QWe^KGIm
QGi[IW1_I6EKDeMTLGIeQ7EaNgmlQYR<RY6MX9bR[YfUXYZQ/[BVQH^BUYRLY:^S
X9>7RiJERH24QhnNXX]/NFUPHf=KF5a7BTU4?d9?FSdkAE18=SU;?3Ha<SPn@3le
>SPd?DU4=3E3CdQ=@d1:EU=7>30`=CPi<3U3AdI4@dDa?d4h>DE3=dA6AD0j=cXn
>CPf=38a;bm=>bTT:c8_:R`Z:B`_;2DN8RPY:30g;Q`_;B/XoRL0:?TT3b<T9BHV
928Q;2`[:RTX9bOi90`V9B@S8AlN7BXm;Q`X1L9ofgJPThYTJfQ]JfUYJfmdMh64
R8^:PgYcR7mgMgj4PgmbM7MnR9>NYJZ^YiRAU968QXnBQgE^MhAfRY^OXjZYXYJE
Vif:M7V?RGj0UZNTVIB9JU5TLDe9OW]SLi:FV9J0De5EFE14Ae=/DeN1VHUcKiN<
RH]nJ6A`T8>2V[JeTF]oM6]ZLW9ZJG1bOLCZ`k_:/Jje[InYaL^mO9:VXi24RYJ>
WFQDSj>WgX:8Z:RH_<1jN8NHWifJWJ:_UhfETX63UWZ8T8b:T9:<O7Z5UinLWJB[
YZBX[Z^NTjNAWjEkJi6dVIfKU9RRWi>U[:nXVi6BUYV4RYFAWZNDLW:7Sh:9RF]o
T7>AM765FVf8MHAYGfeMLf]eHGIhKifXR9AiUgBDOHZGRH^NYj2NYIFJYk2YVi^V
ZYZDW9^CV:RNSGelRI:@RHN0SZ>HMF]jKF1FGFieK5mIDDm>@34lE51>BTM7BDe?
>3Pj@DU;Ad8n=cU2@STg?T=0=S0jBDPkA3/f?diCBcm7>CPj?D0m=2a2A4eDC3m1
CS@j@40k=SDeA40l>c/h<BY3<28S9RD[=BTZ;2h`<S@e<2XT8bHW9B8e=SHe<B/U
8BTX9bLX:R`^oRDD9RT]<C<T8b<R8B0O7b@J6RDZ8alRnBAo6QTK8boKMZ2CRVA[
J6e[JFU[KgAgPHB8RhZ3NW>8OgMgOXB3Og9dMgj8TijUZZjWV96DTHR6Si:7MFig
Q7J:VinSZZVRUYFKWHYdNHn9OX2FYjBIU8UZDFAaCDUnNf=cTYJHUX1CDEEID4A7
DfaCEh6IRG=_Uhb9RgiXI72@Ph9oV[JeTF]dJfYbLVYYL79ma>[3^lZa[[F]WjW5
bkelTZJST8B:UXjMJ5B?XjONPXRXZ9Rl`7YhQiROWIZMXZnGSIFBPH>FNXR@S8Z@
TXalNXFGWibMY:^VY:R^ZijCYi6OYG][TKBIWI^DV::OTjF/[jRKTI:FVHB:UI6N
YiAbLXMoSh:9RF^@Li5dLHEJKHQeQ6UOKEecJgEQMWQ_WJR8U7VGM9AmRYN9RijW
X9jUUIZW/:VKVjJZVYBLVi>HZ9j=OGb9TY29Qh2>XiQeJgY]H5IMKWE/GeUACdi0
<CaDD4i:AdM9CDlh>3Y1BD]7@Shg>D92>CLn@d0f<3Y9B3]4>cI<?diCBcli>3Xm
@3dd;494CEA<?d5>=3Y0@3/f=CE4@3`k>cPa:T<`8R<V9B/e:BX/;S0b=3D`:R@S
9RLU8SDf=SDa:bDQ:BPW9bPZ;2kn9A@V:Bda<b@S8b8Q81lO91XJ9BXS7b;i97lJ
6A/S;m]fX9>:I6]XKF]YJF]_M7N1Q8R;RX=jLhQoMgMnQ8=oLWAgOXRCWZFZ[ZNH
TIBAR8J?TXMeKWN4MXZKWj>ZZJ:FUI^MRWAiShUnP9JWY9VDRFYAI75=BGikHg>B
UYRFP5=AEEU@A4MCK5=GPIV9LfnGS8V;OVQTL923PWnJ][FAJgA[JW9bJVU`LWg4
j/>kb[6^]JfOZLG;_GbBYZ>@Q8ZFSYeXE8nSYmj2R:RXV;c0NWR7V9nMVYfR[iN=
UI:1PiIjR92<RY2BS7ajQINOW9fTZjJTZ:j[WY>WTInUNf^A]9VMViBHXYnCYJb_
Z9^ATYJIQ8ZETIjWU79bQgn?PXV9Ji1cTGAaQEY]R7F4JEm]GG=[MF5fN6nMZ8RD
NIMdU7f:UhV;WZNPWZFEVZN`ZI^KYZZJU9bKTiRXWXemO8VBT8V7P8jSV7E[NVeP
EUe^MFaOFE5?CT0a?5A@CTY7AdU=CcPh>T59BdM2?SLi@T8i=ci3@3H`>TU8>d@k
=T`oCU=;?cTh>Se0?C@/@TA=E4`o@Dhd>T10>cHe=DA0?3/k>34Z@c0R8bHU:cDY
:R`^<38d=C0Z92<V9bDR=CHf=C4[9B4Y:2LW:2X/;_hU52HY;C4c92<S8R4P7alT
6QXU:R<O8_TT11XI6b<_1Kmoi7FEQhAYMWEcLW1_LGAhNWAjPXJ4P7ekUhn6PX>2
O7InPhZ<SI:KXi^RXINDVYR?R9BPWY:<TY^:VjBPWJ2MUIfKWI^8M7N9NWAhPhN2
Q8jALeY[N5A?PFQDJXb<QGMJFEIJH5aCFFIOCUIiRgibMXN7SY60IV1[VHb:W[Nc
SFQ?I69WKfeWKWaPJ;3Tbkg5]KbTVk?=b[6KW:J/XiB>V:FDSiRIS9>TYLVSUJ:a
]Y9FMXBCVINFVj:MVIbQVHV3Qgn<THV3QXEoThb>VIjKWj[nYgnZZjNNUjJPZIf0
RZFSWZ6OV9fVXiNJXJFOTh^=TYZ9TYZ@VZFENWF2Pg=kOEn7I79GGGeUO79ZQWI^
MEUWMWaRLfeFLFmiQG>CNib<VXR7T9bJT9JVZZV^/:JJWZf]XIfUY9bO[8V5P823
RHf?QGn<X9MiL7iaJ65TKG1ZHUE>CgIDC3i0CTe<Bd]<CU5B>c/nADa?C4Q1>S]4
A3/j@DU>BChoCUUJCT4g>D=6?317ATI9C4Po>38`=d=2>S]5>d56AT4l>c`h=SHk
@TE3?ch_9bd_:RT_;2`[:RXY:BPb;2HU:2XX9R`^<34`;BXX:BPW9bPZ;2hY:?hV
4RPZ;2XZ:BPW9RDU;B@R9R8F51ci97lY9bT`>^AeUHN4JGIeLg9`Kg5dN7YdNX:6
Q81mNiN?QX:3PWafOX>:S8fBVj>KXZ6GU9ZHShRDX9jBS9:KRY^TX9fPWIFMVifK
R7AgRGYdN8>7PXB>TG=JJgQDCh5XE6Z<S8EgFUUFFV1LDeUVGdiFNH]nLWJ7QhjA
P6IPJiV<RUBN]k>=J6ARIfm]IfilH6R`i<^maKFlY9^ccLZaVibV[:>DSYRUU8nH
VHbCY:G9XiFR/KJBEWJ4TiVGUY^RWIVLXIV9PhMoS969PhJ5Oi><SYVNVinZoZMo
ZZ^WWYNVX:VMP8ZUXijQWiRMYZ>GVZ6UWi>;SI:JRI:JT9ZUUGYePX=cNgeOQfAb
EeemIGabJXIfKWEIIgIlHW=]EW5_NHEcTg^LS9Z8Qi2LVY2FYZZY[[2VVYj][J6M
YJBLWjb9QH20PhV=ShEoS:2GNG1nLFQQI6e`JV9ECTmfE4`n@4i=C4];C4iADS/k
?TE<Cda8@CXkA4@k>T59CTTn?diIFTi1=cU3AS``AdI6BDa8?cPb<3M3@SXkAC]1
ATI1?3/l>3Hf>d95@cln;bL];bXY;b`/:bXZ:BTX<R`V9BPZ:2H/;S0a<2dZ:2TX
9bLX:R`^:BSn9Q8X:R`Z:RTX9bHU9BdT8RHR5Q@LnBAo:BLY<3[TMIF7Q6UfMG=b
L6maM7QjM7Z2QXB0OG^GShJ2Ph9lMWj3RXb=TY^SVj:QUiBJV8n8U:2NTXbBVhZK
Y:2MX9fEWI^MVhQdMhUjM7R3Qh:4SY5cFV]hE4n1J5AZS8b5MeYIEUYPG5=IIUm>
EWV;OW9fQhN>TH1VH6^IS8YDW[NcSFQTHVM_KFM^O61X/>C;_LFe_:BK/lg:/I^L
YZbSU8jHYIB?V9V<TjBUbJ>EX[6fTUIfQ9>IUiJKXYfIW:6IRH>7OhbARH>6QGnC
S8jIWY^OZ_jWOjZ[YijGYZ2YWH2:YJ>NXInHWJJSUiZQYInCRhfBVXVBVY2JYIEj
MH:3Lg]mGhMTLUMMOFElLVZ6MVieFFMfO69cKEIaKgV5Li=kW8bJR8N@W9Z@UZJZ
ZJj`YYZN[JfQWJFTW9n/RHF0P8>9SHn5OhbPUgU`OW5XHFA]L6YREDi?MUA<?T1>
CDa;Bda>DE8k>ci5C4m<B44j>dA4>cY1BDi9?Sm>FEY>@CLi@dHl<4M6ATU<B3lh
<S0g@d8j>dDk@DI6@C`k?3Pf=S]2AD<o?RlW;BlZ:Bl/;2/Z:RTY:38/9RDX:RPV
;2h`<C0]:RPY:2LW:2X/;RTXoRHB:2X/:RXY:2LV9BD]928V8QHD7?TT12TW:C0j
1KaokgB9N7i/Ogi]K6]/KW5dMVehPhN3PHF:T8b6Q8=nMVm]NXN8PGn9U8ZDUi6A
UY>9OHZHViF?SY6@WJ6HTYFESjBPWIR7MgR4IfimQgi_LX22J5=XOVAPSg5SPJVY
W8ISC4Y@FUYCEf=CBEEePgYeOFilT9F3K6YgX9BAXkN`RVEoHf9WKVYSK7adLZgY
f[R]Y;NQZLkG]IRE`kb]VHV5Ri:<NK74QhfbTZb>LhR]W7E^O8NBU96@Uin7U9N:
OWalNH6>TXV4R8V3ZIjIWYnLXZfRYjb/Yj6OWYnW[IN4X[6?XZFSW:2ZYi^FW:6L
TXfAV9b@WJ:?U:6FXYBFT7n9SW=KT75cHfn:N8A[HWmaKGMNKVYaFgEiHgEZVj2<
UWZ5LGImQYFKT8JAYJnYYj>GRi>UZ::QZ:RRXZUnQH^;QhR?UXIoQiJ=LVMaLg1]
JVUYJ6QPF5QPHEM?CdA5B4[nC3I;ATA3ATY:AD10>3U0@3Th@45=CSliAUUSDT<d
<ca0>2e2@3m2@d0h<E58BEAIDTiB?498B4<noSdo>3<b<c8]:3T^;3@f;BLY:RX[
:b`/;Bdf<2TW:bh^;2DV:R`^;Rd]:BPW9bPZ;2h[:BHT8b<T9B/Z:RTX9bHV:_hV
0a`A5bOh97lQ8BH^kgB9N7i/Ogi]K6]/KW5dMVehPhN3PHF:T8b6Q8=nMVm]NXN8
PGn9U8ZDUi6AUY>9OHZHViF?SY6@WJ6HTYFESjBPWIR7MgR4IfimQgi_LX22J5=X
OVAPSg5SPJVYW8ISC4Y@FUYCEf=CBEEePgYeOFilT9F3K6YgX9BAXgng/8YUHf9W
KVYSK7adLZgYf[R]Y;NQZLkG]IRE`kb]VHV5Ri:<NK74QhfbTZb>LhR]W7E^O8NB
U96@Uin7U9N:OWalNH6>TXV4R8V3ZIjIWYnLXZfRYjb/Yj6OWYnW[IN4X[6?XZFS
W:2ZYi^FW:6LTXfAV9b@WJ:?U:6FXYBFT5moRHicT75cHfn:N8A[HWmaKGMNKVYa
FgEiHgEZVj2<UWZ5LGImQYFKT8JAYJnYYj>GRi>UZ::QZ:RRXZUnQH^;QhR?UXIo
QiJ=LVMaLg1]JVUYJ6QPF5QPHEM?CdA5B4[nC3I;ATA3ATY:AD10>3U0@3Th@45=
CSliAUUSDT<d<ca0>2e2@3m2@d0h<E58BEAIDTiB?498B4<noSdo>3<b<c8]:3T^
;3@f;BLY:RX[:b`/;Bdf<2TW:bh^;2DV:R`^;Rd]:BPW9bPZ;2h[:BHT8b<T9B/Z
:RTX9bHV:_hV0a`A5bOh97lQ8BH^kgB9N7i/Ogi]K6]/KW5dMVehPhN3PHF:T8b6
Q8=nMVm]NXN8PGn9U8ZDUi6AUY>9OHZHViF?SY6@WJ6HTYFESjBPWIR7MgR4Ifim
Qgi_LX22J5=XOVAPSg5SPJVYW8ISC4Y@FUYCEf=CBEEePgYeOFilT9F3K6YgX9BA
Xgng/8YUHf9WKVYSK7adLZgYf[R]Y;NQZLkG]IRE`kb]VHV5Ri:<NK74QhfbTZb>
LhR]W7E^O8NBU96@Uin7U9N:OWalNH6>TXV4R8V3ZIjIWYnLXZfRYjb/Yj6OWYnW
[IN4X[6?XZFSW:2ZYi^FW:6LTXfAV9b@WJ:?U:6FXYBFT5moRHicT75cHfn:N8A[
HWmaKGMNKVYaFgEiHgEZVj2<UWZ5LGImQYFKT8JAYJnYYj>GRi>UZ::QZ:RRXZUn
QH^;QhR?UXIoQiJ=LVMaLg1]JVUYJ6QPF5QPHEM?CdA5B4[nC3I;ATA3ATY:AD10
>3U0@3Th@45=CSliAUUSDT<d<ca0>2e2@3m2@d0h<E58BEAIDTiB?498B4<noSdo
>3<b<c8]:3T^;3@f;BLY:RX[:b`/;Bdf<2TW:bh^;2DV:R`^;Rd]:BPW9bPZ;2h[
:BHT8b<T9B/Z:RTX9bHV:_hV0a`A5bOh90<Q8BH^1Kaom7B3Lge]O7QXJF]^LWMj
O7AoRHZ4Ph^DPH:5RH^9Q85OLXB5NWF0SWj:Sh^;ShUnPHN<SHV4P7j5T9B<RY>I
Uj>OVYB:PGn2K7R>WiN1Mg^4K5AUNV9JP5a@LYfQUX5OATIAH69GDUMBCE]lT8Yo
O65iTYJ5N86AWI>CY;J^RVQoO6mZKfmXJG1eKIWHg[NNW:Nkd]6bUYjfa;NUUi6A
TiBCQj>YPH>LSF>8Q7nBPGZYSIFJUhn<TYZ;VHm]Gg:3Ph2>U8j>UibI[::OY:BN
XJ^OZ:n/XifOYIVLZIn;VjN>XZJSWJ6ZYibJXJJRVINNYYfGYjR?T9jETWijL69b
NV4lVHV8Qi6DOG5eI7ANG79ZQ6EYDgB1LHAfKGAgQhZHVIn3S9RJThnGXZZUY::F
RY6RWIbOXjBQWj6:SiBGUojENiJ?TIN>Mfa_KG1aJf=QIfi[GUEHGea@ATi@E5IF
Ddm<E4m9ATE2>S@o=cHm?CHg?d9<CD4mB59CDT<d=D59ACdn?3Xk?C/d;U92>T55
?38a>3i4A3lj>CY4?C@_;BXS7SX^:S4b:B@V9BP[<3Hk?d4j<b/Y;C8c<RHW:2Wm
:alY:2LW:2X/;RLU8b8R8b@U9RHU92<R8B4M7R<V7QTZ@_TTOa`I5a/Qm7B3Lge]
O7QXJF]^LWMjO7AoRHZ4Ph^DPH:5RH^9Q85OLXB5NWF0SWj:Sh^;ShUnPHN<SHV4
P7j5T9B<RY>IUj>OVYB:PGn2K7R>WiN1Mg^4K5AUNV9JP5a@LYfQUX5OATIAH69G
DUMBCE]lT8YoO65iTYJ5N86AWI>COjBf[XYXO6mZKfmXJG1eKIWHg[NNW:Nkd]6b
UYjfa;NUUi6ATiBCQj>YPH>LSF>8Q7nBPGZYSIFJUhn<TYZ;VHm]Gg:3Ph2>U8j>
UibI[::OY:BNXJ^OZ:n/XifOYIVLZIn;VjN>XZJSWJ6ZYibJXJJRVINNYYfGYjR?
T9jETWij@G1RLWYQVHV8Qi6DOG5eI7ANG79ZQ6EYDgB1LHAfKGAgQhZHVIn3S9RJ
ThnGXZZUY::FRY6RWIbOXjBQWj6:SiBGUojENiJ?TIN>Mfa_KG1aJf=QIfi[GUEH
Gea@ATi@E5IFDdm<E4m9ATE2>S@o=cHm?CHg?d9<CD4mB59CDT<d=D59ACdn?3Xk
?C/d;U92>T55?38a>3i4A3lj>CY4?C@_;BXS7SX^:S4b:B@V9BP[<3Hk?d4j<b/Y
;C8c<RHW:2Wm:alY:2LW:2X/;RLU8b8R8b@U9RHU92<R8B4M7R<V7QTZ@_TTOa`I
5a/Qm7B3Lge]O7QXJF]^LWMjO7AoRHZ4Ph^DPH:5RH^9Q85OLXB5NWF0SWj:Sh^;
ShUnPHN<SHV4P7j5T9B<RY>IUj>OVYB:PGn2K7R>WiN1Mg^4K5AUNV9JP5a@LYfQ
UX5OATIAH69GDUMBCE]lT8YoO65iTYJ5N86AWI>COjBf[XYXO6mZKfmXJG1eKIWH
g[NNW:Nkd]6bUYjfa;NUUi6ATiBCQj>YPH>LSF>8Q7nBPGZYSIFJUhn<TYZ;VHm]
Gg:3Ph2>U8j>UibI[::OY:BNXJ^OZ:n/XifOYIVLZIn;VjN>XZJSWJ6ZYibJXJJR
VINNYYfGYjR?T9jETWij@G1RLWYQVHV8Qi6DOG5eI7ANG79ZQ6EYDgB1LHAfKGAg
QhZHVIn3S9RJThnGXZZUY::FRY6RWIbOXjBQWj6:SiBGUojENiJ?TIN>Mfa_KG1a
Jf=QIfi[GUEHGea@ATi@E5IFDdm<E4m9ATE2>S@o=cHm?CHg?d9<CD4mB59CDT<d
=D59ACdn?3Xk?C/d;U92>T55?38a>3i4A3lj>CY4?C@_;BXS7SX^:S4b:B@V9BP[
<3Hk?d4j<b/Y;C8c<RHW:2Wm:alY:2LW:2X/;RLU8b8R8b@U9RHU92<R8B4M7R<V
7QTZ@_TT11`I5a/Q1L9om7J9NX5[M6aZKG9hOX>6R7^0QH9mOHB;P8F;T96AT91g
RIVFQgn7U7J3S8b@UiF;W9RCTY>DTY27TYF=S9RPWi^JUY6@SXR1RhR@Wj2DSI2O
QfM[NEa9HfiNNZ2RVHQXG5eZO7i]GUYKFFV;YJ:;NG>;WIN6PHnOThf@XkF_T75o
T7QXL7ajLg1EDfn_fLN_];OJfjb=XL39ZJBQYJjc/k2HYhUgRWQJJWFn_8j<RX^/
XZRZXYB<SiFDX9IfKH>CTH>@UHn@VZ6OWiZNZJZQWZBOYjfZXYfQZ9jAYkNJRi^T
XJFRVj2YYYZKXZJRViZT[IjHZJ^@SiZARGA^J61eOfEoT8f0RHj5NfMfI7AMG7=]
R7ekG79hHW9SHVIfOI6DX:2CUYRJWj>RWZNW[K6XVj2^V9fOX:6SXYnMUi>HXJ2D
Qj2JVYjKShN6Ife^IeeKIG1^GT]4Be16>6AUIfMTGeYFFUA>C4a:AD59?ce3@cdo
BE9EDD]?Ee11GDdo?d]CCdQOCDY7B4a<Ad9A@3Hl?cL^;CY0ATI1?3/l@S`h>3e0
@3ho;bDY:R@S:2PZ;S<h?D53?3@/:Bhd=cP_;R`Y9bHV9BTX9bLX:R`^8B0P8B<V
:B/W9bHU92<R8Q/M9BXT8CA=nBAo9R8P8ROdMXUjPF]dK6Y]LWQnPhJ8Nh25PWem
Q8^0QH^@TI6@T7N9VIJ7OhNDMX><S92GUH^LV9>BTiBBT8NBUHf<V:2OViZFTI2>
R86;R92OX9B=T9n7If]iG4USKUijX::IR6QLGFYlOVeNFU]IJH^UXX]iLh^MUhJ1
SinCSI1oXkF_T76@N6Q`O7YcL5ECKjoIajnd]m[K[8fQ`<VYY:6U[[>c/9RWRGN:
N5YZMKjlSXb:RjbRZ:ZRU8b?UIBPUWI]Pi>APi2ESi2JXInOVYjYZZ6NY9nW[JZR
WJ6XWY6W]iZ;VjBQYJ:KX:VVVY^RYZ:KVZB]WYRYZi2?VY69M6ioJ61eOfF@SH29
SXEkIgITM5eLLff8OG]LLWQRLV=RIWImTIBPX9>FV9ZOXj:NYjN]/JRKX:jHWInP
XJ>RWifGTiRQX9B7X9ZJWY^?QhIWKFiWGE]UL6iNBdA;D4HhI6EWIfAOFUIJE4i<
C4Y5@DTo?D=3?Cm9DUEABdmGD45MCCmT?d]CCdQ=BTM8C4a7@U50=S`o=bh]>T16
AT4l>ca2?3Ph?D10?Sl_9BTZ92<X:2X^<cPm@D<l=2`Y;S@g>2l^;2TW9RHU:BPW
9bPZ;2hQ820Q8bHY:bLW9RDT8b8R6adU:R@Q=4gi97lV8R0R9oAfRGZ1JgA/JVeb
N7j3QXQkP8F2OGf4Rh25Ri2ATI2@MhVIUXMoQiAfPhb<T9NERibHTi:CU9:@Qi:E
SHbHX9nKVYJAT8j8PH^8T9nPU8f@WhMWJgULBF=^GWZPXYV8J5aMJWanKEiJFeUY
RjFRRgUcRifGQX6?Wi>=T7nS]Jn@LI1hJ71lNW=`EE=_[mW7[kBgf]^/SJ70bJVT
XJF^/k>`V:N9MhYhFVYe_[b>S8Z;[::XZZ:DS8nEU:2FMVf3Ti63T9F?T9ZQWinJ
WZVZXIjTWjN]ZZ:MXJRNTJNgVX^KY:6UXY^PZJJJVj:VXY^JY:fNV:V[T8nJTHUd
KWmXH7EoII2=P8V>QG]WMVAdGEacKHQmNeabN69bHf9VMWfAU:2PTiJHVYnSXYjW
YjfaZ9^P[YRMWj2QXj:OWINCV:6PU8NPVYZNVhn7QVM]KVMMFfE`KUi;A4]@ASQT
IFMWI5mJEUYDCTa<BTE1BClm@d<m?dUBEE5;CeM@@Ee=?f@oBe=?B4e:AdQ<C4M2
DD0f?3lg;Rdj@4I6@C`k?48l>3Pm@40n?blU:BXT8bPX:Rhc>3e1@c`d;2T^=3Lh
;bh/:BLV9RDY:2LW:2X/;R4P824S9RT[9bLV9B@S8R8K7BDZ924dCOTT12HR828W
1L9om7fEQXM]MFiVJFidN7]mOG]gLg1`LWEgO824PWeiNWb;UYfGR824SGN4SI2I
YZVSY9^CUIjUYJ6IXjBIU9^OW9BFUI:GVXejWhj2QH^@WJfHQFQ_QG5OM9N3UkF`
Y95aKFYaPH9bHEaUJgfGZZJBOhjRZib:RI:ISXbBYkVdUgaoT7U[MHB6Ph9YKFfF
emo6bMcS_XN?b=NgYJN[[k2YWIAhUVmXYY5FIjG:^HnF[9n8[K>e[9bASi:6SXn9
RHn=QH^EUhf9TYNEUi>JYjVOVinSYZRVXj:TYjVC[<JXSYndXJFRW:2YYi^EVijI
TY>MZ9nEY:RBTIV:TgmmOGbCVgioRI1cOX5iTHA^I7i_K7YWNX^=L8>2JWaaPgf=
NhafOW>IW9^JXZbWVYZLY:^UVYn]Vj:SWYnXZJBSUhjDWj2@Ohb:RXnFUiBBKFm]
I5YIHF]eJEI8CEMA@emPGeiKEeABFeIBDeQKFeUGC4U>CTU<EeECBdE;DTLcIeQ:
BE5ECD=7D4a:C59DDTmDAd=:CDM7CD98CTi9A493C4Dl>CXk>SQ3<RLY:R@S:S0`
<C4b<S<c?C@[:2dd>C/h=C0[9R@S8bTX9bLX:R`^oR0:8RDY;Bl^;Bd/:b[n:@HV
:BdW82TknBAo:2DR92WdOIF6QfeeKVIYKWAhNgemNgMcL71bMGMlP8B2OGUjO8^F
WIN8P8B=MhB=T9VVZJ>TVi>EWZFUXIVSY9VDVinLU9JETYNJSGZOSX:5Ri2M[IR5
J6n5LEmdUh>G]K2TTG5]JW61PW9QG6E[OINZYY9oSZ:[W8Z9TYV>S99oYkVdUgb@
NF]eQ8J3PVU]KIKGglK9g>>nQho8ekNUYj^_/:VMU7RFKfRVTEIWYLZiSiJ/WhR]
/kF/W96?TXJ>ShV9Shf5RiFGSHVBUiFGTiZWZInKWj>VZ:JSXZBWZI>/aZR>WkBQ
YJ:LX:VWViFKWYVBTifXWiFTZ9:AVHZCOgeoOGbCVgj9T7=nPGVAQ6iTOVm/NVMj
Rhe`Ph9ZO763OHekS7InLiVLViZR[:NJVYbTZjFJWjfKXZ>NWjRYY:>GSYBOX91o
S8Z:SiJGU99]KfeTFUUQJgEYETQ=Ee53Gf1OGU]GE59KEU9CF5]KFEM<BDi>BDaG
EE=;AD]BAc=WF4Y<BE5ECD=@C4Y<DUABCeA7@dY=AdM=@TQ>CTU4@T=<AC`i>S/j
>4<b9bTZ92<Z<30a<C8b<c<m=2/X;C@i>cPe<2/V92<S:BPW9bPZ;2kn80XR9BT]
;bh];B`[:_hY1RHY;BLP:C_i97lX9B8T:OAmUHJ7KGE^IVU^M7QkOGekMg=`L79e
Mgb0Q89mNGYlRiJMUhR0Q8egQ8f@VJJYXjBKTiFNYJFQVJ>TVIBKWibDUYFBUiZ=
NYn>PXF;T9f]V8EXKhEaGgBGPiNe/:BALFeZLH62LV5LIF]mUjZVTWn>XZ^LRXVB
VHj<TWnW^KBGO91iJgF4QX>2JFe]U]OOa/WLhkj7SlSG]jFWZjn`ZIfDN9I_J:JA
EVNUb[V?UZbOR:fc]JbLTHnBQXj?RHV?SHF;UIN=RI:GUINCVZNYWi^OXjJXYZ>R
Y:NYTjc6Z8jO]:6UXYbPZJNKUI^NVI:CWJROUJBXTY6IRY=oOGmmO9>KOXV@Lgj1
NI64KVAnKfajIgZ;SG23PVYlLH=mSG^<MWicVIbKVZ:/YiZJW:B[YIZO[I^RXijO
Z:VTXiN>U9nPT7n<RXZ?UYNDTVe_KFAJFF5[MFUFB4eGDD=OH5mNFeMDDU]FDU=H
Fe]IEda9CTi9C5MEDd]5Be97<fMHBTa9DEE=@e1<BTaBE59?E4M3BTe7Ade2B4i>
BDA2@da5?3Tj>cXh@c8W:BXT8bX`<34a<S8c<cdd:bP]=3Tk>3D`:bHT8b<Y:2LW
:2X/;_hP2R8U:Bd_;Rd];2/ZoRT69RT]9b0Y>oTT12PU8R@Y1L9omhFPSh]bPX=a
LgIhN7IcLG]^HV5ZLW5]NGakM6YUJ6eoPhF2OWf2R8>>TY2EXZJPVi6:Si^OUX^M
YjRMUIRITi>HV9JNXH]]R81mOgf1VK>9NV9/RX1aPXUeRJNOSgUFL6AOJ6aSG5aW
O9:IUY6?Si2T[Z6FV9VDU9>K[kniWXAoRh1kOgikPi68TgIocNcDd>CF/IFXc/RS
ZZnd/JB@OG9fMgB:/kZQTZjKTY6I/JYoZ[:h/j>FTYB5NWV9UI27PhfGV8j;U9^I
WIJHXJ6IVJ2XY:6RYJNVY:VM[KRTXZjWYJVVX:B]ZinBUiRCRhbGXYn@W:>EUYR2
NVQ[LWB9S6]oOIEgRhUiXiMhK8AbKGYVNGj=OiVHOY:;HUemKI=mU8R>W:2HV::R
VYBBUIRARYBWV:6OUINUZZ>OVYJHW9bESXN4PXB<Ti6;OgYaIEaIG61[Jf5DEf=N
Ce=BD4m@DE9DGeUCDeIJFEMKD4]@D4]@Fe1@AcXi@dDnGU57BE=FC3llAD90A4]@
D4hn=cLl>C8hADA9Cdm:ADA5ET`n=C0]:BE3=S0e=B/V:3Dd=3<c<S4a?3<X9B/c
>C`k>38/:?hV3RTX9bLX:R`^9bHU9BLY;?h^3Bd/:b/Z:S4X9b/X7A`SnBAo8QhL
7bCgQJ2?Rg:2Pg5cMWQhMW=aNfiRHFYbLFeiO7]dJVEXKGn3QH9nOH:8PhjBT9FR
YZ2KTHZ?VinFRifWZ9fEV9VCTiRHUYjQRff8P7eoOH6I/hUjHVb:P762RGF9Yin?
NEI`I5mXK6=LG6MlTYVFTHn?T:B^XIJHVIBDTi]o[kniWXB;P7]oOW^3THRCMWo=
k=C@i=JaUJS>b:>Z[kBaY91mLWIgM8Zc^Z6B[Y^BTIVaZWnZ/[RcXiJBU8EjNHVE
T8N3SINHSX^DViVMUYRQXIVIX:RTXJ:UYjJTZIf]^:BR[ZNUZJJPY:f[Wi:GV9>;
S9NRWi2LXiFFV89jJ6]oLWB9S6]mUGN;RGVSUgQ/Q79]NVIiOXeoVIQnTX]RGGe]
TgfDR8jLX9RHXZ:JU9:EV96:U:NHXInEUjFZXinJUYRLW9F>QhB2Q8bCTH]oNW5U
G5ULH6][HEAGHei?De9@Ce1ADUAOFE=CEUYIEe]@Be1@Be1KD517>SU3ACiNDDM1
BE=FC3m5@T14Be1@CShg=c`i<SQ5A4U?CdY5A4EFC3he<2dY9D<f<3De:bHX=C@d
<c<b<C4l<bPU:c<i?3/h<R`XoRH>:BPW9bPZ;2hW9RDU9bT/oRh=;B`[:bXZ<BPW
:bPM72?i97lR7Q`O9?N5X8n;LX:3LG=fN7QfLg5kKV9QJW9aKGUlNgAZIFQ]Oh>5
PWimPXR3SY:@UJ:VX9^ARXnKWiJ;WJNXWIFHVI>CV9RFWZ6;KHR0OGmmPIVcRGYR
K8Z0LH:9MHVWWhmiEW1TGfQ/HeaLIgbBVIJAShn@Y:jQUYRIU9BCVgn__kVNQ8^0
NgmnNh>AR9=fOlg/e=3Te[6EZ<k8XjZ_];6TT7ebMWMdR[>jXI:^Vi:AVK6ZOjZb
^;>SUY:DQGYiRIF@Qh>=UiR>RiBKVIfFV:6QVIVPZ:BQXZFWYZBYWJfhY::^YjFY
YZ2T[J^OTYNHTh^<Uj:OT9bSUIJHPWYXJgmbM8V<JgfEMh^9NJ>GN6b4LVejIWUn
SGnIV7jBRf9MOFfCOIB8SYbPV9RRXYZDTYFHTHZDYiRQWiFGYJZSWiZFV9bLUHj7
Q8:4S9>ARgmjLFELFEaPJf]QE5MSGTmCDU1?D55BE5mIDe=FFUUGFe1;D51;D5]@
D4Lj>D=5?UiAAd59DeI<?dE2@4A;D51>?SLg?3Tb>4E4BDm?BTE4AEI<?SD`;BTU
@cH`=CD[9RPe=3@c<c8a<C`c:2D[<cTl>cPb;2Sn9PhY:2LW:2X/;RLV9BDW:Bcn
;Pd];2/[:RXa:2L[:1dL8oTT128N71lT1Kaonh^WThefSiV@T96?RhAnNWi/Fee]
NGI^PXF4O75^MGa^Kg5eOHN@UY>HUH^9TI:;VY6:T9VEPW2@W:2GTIBDSIFLW9ZQ
XhMRH6n6ShAkS:RJRFY[PW5JIHemUkVdY8]VMf9DEeeMGfIVQYnFOgZ:WH2HYjBR
Z:BFW9bT]/BmXXUFRhf?R7AXN9=cQUiK^?3PfM78_k^i]:^SWZVd]JZKT8^ZNiBe
Z/WP/;60S:RFVJB:XZfg]:NJUYJPOW26V9FDWHZEVI:CXJ^[ZIfHViZDV:>[XibO
YjbXoZ9oZZ2H];V@ZJfZY:Ra[j>DV9VCRhbGXYn=UJ2FVIQnQ7AjQ8NJVG=VT7jL
UGFJQXihPFENLf^7M8Z5X9MdQ7]iKh]^SfYlJX2IYIN;TY^JXIZFU8b8V:jBViN9
S9jUWYbPXj6MW:2TX9bDT9BJUH^?QGIXGUYHF4eHF4mAG5I6F5H^EEEIGfEXIeiD
CD]:AT9FBTE9BDE:EUMMECle@UEOBD0kA5=HD4A3@3i3Be9DDeOnDe=8?DAD?dA:
BTE0?d1=AC`h>Sho?T4h>D92=2LU<c@f>3/m?clk<RLT:C8i?3/g<RdY:BX[:BPW
9bPZ;2h^;2XX9bPY:RTY:2LV9BDT;B8O9bPN5aWh97lQ7b8Xnh^WThefSiV@T96?
RhAnNWi/Fee]NGI^PXF4O75^MGa^Kg5eOHN@UY>HUH^9TI:;VY6:T9VEPW2@W:2G
TIBDSIFLW9ZQXhMRH6n6ShAkS:RJRFY[PW5JIHemUkVdY8]VMf9DEeeMGfIVQYnF
OgZ:WH2HYjBRZ:BFW9bT]U[4_J:9Rhf?R7AXN9=cQUiK^?3PfM78_k^i]:^SWZVd
]JZKT8^ZNiBeZ/WP/;60S:RFVJB:XZfg]:NJUYJPOW26V9FDWHZEVI:CXJ^[ZIfH
ViZDV:>[XibOYjbXoZ9oZZ2H];V@ZJfZY:Ra[j>DV9VCRhbGXYn=UJ2FVIQnQ7Aj
Q8NJVG=VT7jLUGFJQXihPFENLf^7M8Z5X9MdQ7]iKh]^SfYlJX2IYIN;TY^JXIZF
U8b8V:jBViN9S9jUWYbPXj6MW:2TX9bDT9BJUH^?QGIXGUYHF4eHF4mAG5I6F5H^
EEEIGfEXIeiDCD]:AT9FBTE9BDE:EUMMECle@UEOBD0kA5=HD4A3@3i3Be9DDeOn
De=8?DAD?dA:BTE0?d1=AC`h>Sho?T4h>D92=2LU<c@f>3/m?clk<RLT:C8i?3/g
<RdY:BX[:BPW9bPZ;2h^;2XX9bPY:RTY:2LV9BDT;B8O9bPN5aWh97lQ7b8Xnh^W
ThefSiV@T96?RhAnNWi/Fee]NGI^PXF4O75^MGa^Kg5eOHN@UY>HUH^9TI:;VY6:
T9VEPW2@W:2GTIBDSIFLW9ZQXhMRH6n6ShAkS:RJRFY[PW5JIHemUkVdY8]VMf9D
EeeMGfIVQYnFOgZ:WH2HYjBRZ:BFW9bT]U[4_J:9Rhf?R7AXN9=cQUiK^?3PfM78
_k^i]:^SWZVd]JZKT8^ZNiBeZ/WP/;60S:RFVJB:XZfg]:NJUYJPOW26V9FDWHZE
VI:CXJ^[ZIfHViZDV:>[XibOYjbXoZ9oZZ2H];V@ZJfZY:Ra[j>DV9VCRhbGXYn=
UJ2FVIQnQ7AjQ8NJVG=VT7jLUGFJQXihPFENLf^7M8Z5X9MdQ7]iKh]^SfYlJX2I
YIN;TY^JXIZFU8b8V:jBViN9S9jUWYbPXj6MW:2TX9bDT9BJUH^?QGIXGUYHF4eH
F4mAG5I6F5H^EEEIGfEXIeiDCD]:AT9FBTE9BDE:EUMMECle@UEOBD0kA5=HD4A3
@3i3Be9DDeOnDe=8?DAD?dA:BTE0?d1=AC`h>Sho?T4h>D92=2LU<c@f>3/m?clk
<RLT:C8i?3/g<RdY:BX[:BPW9bPZ;2h^;2XX9bPY:RTY:2LV9BDT;B8O9bPN5aWh
90<Q7b8X1KUom9>DSGB6OGB9OG=fP89hK69ZM7]oPhN:X9N3L6mjNW5dLGbAUHf@
Wi:;Q8B;U9VJTIVQVX1/NI><VXn;Vi1lPhB0Qi>GTYFOWZbKR8Z3PYb9Gf1[RhU/
XjaSQKjMS8aLLV9DFFUcKF5hQ8AiNHJ7O9fNYJVNTYVYY:>Y]l6gVh9oO9JUVXZ<
V:1jVW9aL]oPc<C0_Ko0^:NHbZc1UiBbQY3?^IbAXkVcWZV9P8fVb/29Yk_:_j>?
TYf<S92JXZ6FRY>:P7j7UJ6VW:2RWiVJY:fXW9:EXZ^XXIbLTHB=XJ>DXIf?W[Z]
V:NIRIf`WXn7M7anSXM^Ni:9Kg1UVX^JNXAOJhBMWXanPH^9P7enNGAnSX1mO7M[
JX>SJ6UaP8f=PGB>Qif0UgjKVZFHTYRITi>IZi:ATHNEYibOYJ2CUInJRI>2R8ao
RibCP85oM6EKG61CEeUCBTM<Dde:BU9KFe57oTdPC4Y6@T12Bd]0?TYCDciCD3Tn
FUTnDDHm@TiDCD==CDi>oTlBD3A8E4]2A4U:@DA:Ce5;@3Pn?_hooSh<<S0/:2DT
8b<g>3Pi>Ohj9cdb<C/o=c8d:RPV8b4Q8R<V9bHT:30a;2l^;2PT8bL[8B8S8b@U
9RKi8PL`:RDT9RPV8odYOb[dTiB=M8ImM8UmLgJ0PWQ/HVYdNgn3QhZPUh=`KgYj
LGAaO96ESI2OTX^4Q8^DVIZAVJ6JP6aiThbJSh^KT7b3Q827TiNBUInN[9^8RX>2
W8UOH6^;RFbS[6>5_Yf<S5abHUAIJG=]HGR4Q7UiQXMlWIjUZIjBVJVTXjVg`KNK
Oh9lUZFJRXbHX7ZJLW5bgn3<a<2m_l2hYiS:[<6GU;:6T<niW96S^K>NZHV0SJK:
`8VW^lZoXhnBWHb<T9ZRXIJ:ThZ0OXNEXJJLX::OVIZT[JRLTYFRZjRQW9bAQ8fQ
XiBQWHnN^ZfHYiV9WK2NShMdO7j>QfikTXU_L6FJRiYjH8A[Q9fNS7j1RhV0OGii
M7j>P7elMf]ZPj=XJG60SHf1M8j7WH2GOY^JYIRBV9VCTiV[TY6AQiFWW9nUX9>E
WiZ9Th:8S7n;W9>0PGmdIE]LH5=GFE=:AdaCCDY:DU]KDDOnCB1<BTI2@49;Bd0n
BU=C?U=@>CiJFCiAASe2CUA=@de=CTknCa9@=4QDBd94BDY1A4Y?DD]0>3hnoSon
?P`b<2`X9B@S8cLh>3TioSXW?C8a>clg<S@Z:2HS8B4R8bHW9R@X<34/;bh/:2@S
9b/Q8R<S92DV9_TR1c0Z9B@V:2HSoBUo:_BCU8edQWedRGecMX22N6aRJWAkOh>7
RZ2GPg1_NWYaM75lTIF=T9nBRhB4RiBIVY6IXIZ0K7VCS9Z?Ri^@O8>4P8NCUi:E
Wij/VhR:Ph:LREmPJh^9K:>/HhFnWHb<G79RE5UYLfeQN8B4NGV6QgbMWZFYWY:I
ZJBSZKO1]i]oPWbFYIZ:S9RPNYYbLG;Oh<c4`;fo`;RWV<Z/`IND/XJ@ckVLTJ>i
/ijYRH2=Y/[0RJNkb[nSSi:MS8b@VZ:QUXZCRX1nQiFQYYbPXYnIVZB]Z9bBUJ:[
Z:6LW964SJ6SU:6MSijj[IRWVHVM/9j?QgAlOXj7KW^BRFm`IIZ;VWYPQ6^4WIj<
OX6;RH1mOWUdOXj0OGagJfZ3XfQYLH2=SH5dSXNMP9MnViZUV9:HVI>CVJ^BTI67
UJNLWjFPTiFOVXVCPXR<Oh^LTh21OgAUFeaPDeMIDdY7C5==BTYBFe]AAoi=84a:
AT90@T];@3i:De<nDe0i?UYI?U56?D9>E4e3CDe>C_i?4U0dB5A;@TA9BT54BTmA
Bd0h?Skn?ohn338`;2PU92<S=cPh>CWn>RLm<S4k?cLb=2XX9R<Q8B8S9RLV92P`
<B`_;R`X92<W:b4R8b<T9BHVnB87<2XU92HX9R?m:@0Z1L9olI2@RW>7PGUaK6U_
NX1nN8N;T96>RXJ4R8EiL7V=UY5WIg:3QXB@Y9RARHJ6QH5nUI6DUi23QI6AU7ee
Rhj6U9NCU9R@P7YoTJ6BPHAlNiBBKFieShISTjY/Qk:JWZ^1JFEPGf5RGeaaPXQo
O8F9Pi6DWZFMTib^VYBFZ;ZhWhIoPiJPV8nEWIn9UgaaO/_Of=3DeLbn/k2b^:6e
U9FbSiNo]ZNR/<2iYZNEUinXa/bWQibd_;6QVINOWIfRZJVRVYJ=Q8::U9bPUYbP
WYVIWjFVW9BGX:BNUJFWWY:GZJnXXYn@V[BVTIjER9VRQWZ2OWMiRH=/NY27L7AY
V8FEO8YoQX^@ShQnMgBDQh>>Thb6Qi2;RHEfJG21OGQgP8^ARh>BRj65WHFPWYZC
TibLTH^?WXZ?UHbHYINGWIR>SiVDQZBCV9V6S9R;LWEeKfEQHfQEF5YFCdeCFEAD
EeaPGUMAD4m=C4Y9B4MBGV1FD5=DCSY=DTM9F5Q9F5=?DeYJDTT4AdM8B4WnBS8f
BE99?d97AdE4@dA5AD=1?d=8C4]7@C`i=c@a<2l`<3/l?D12ADM8?30/=3L_;2lY
9bGn8aTU9RPY:BLX:BHQ92HW9R@T9RPV9RLX:BX[:oTR1bhY8b8U9bDRoRQo9bKa
T92:LhN1NG5/JFmjP7ihQh^@THj:QXB8QGU`NHfFTFMWLX>6Q92TV969QXJ5PGjE
TIBGT8>5TI6DOGF;SXJDUi>DV920NWnAXI:1Q7akU99]KWF?QV>CZVb7/YZNZh5Y
IF1OHF9OG762R7mlQHV3TIBNYIfCW:jJU9JX^[QoWhJ3UZ2HSiFMWhVGO75nbmoH
d=CEc;jc/;:hXKFDUK:?UknfYj:``;VVYiFGWjS6c:N7W;Bl/J6IUinMWJ:YZJ:J
UXf4PXZDW:2FW:2NVIVOYJJLU9NPY9jEYJNNTYNY[jRRWi2J]:JAWYF8VJ:6NX9n
MgV9PfajT8M`M6VHQIEoO8Z6Ri2?R7igM9B7PhjCS8J7T8^9QGIYL85mN7N0Ri6;
Pi:;XHFMQJ2NVY>CW9bARhnNRXnES9RUUiNMV8j?VIB6Y9>HVHJ<V8]bMGE_IF5S
J5EHFUI?CE=IE5AGG61NEe5@Cde<BTU8Ae9NH5I@DeA>>TeBAdUHF4UHDdmCFUX6
DTU7AdQ8BOi:<SI9DTTo@TM7ADA3A4E5@d4o@dQ<BdM1?3Tg=34`;c0`>c`m@495
AdPl<2`d=bl/;bTW9OhS6BDV:2TY9bPY9R4T9RLV92@V:2HV9bPY:R/[nB87;RTS
8RDW9B;n:7lW9_6@T8YcQh5iLFaYKgZ0OWR7Ri2ASXZ6Q8R5NG1iSIJAIfMbPhJ4
T:BHTHV6QXF1OYFAU9N@PhFATIAmMH^>QYBGTiBHT81jOi6QTX64O7^DTVe^MHn6
Hi>ZK8NbVYj[PFUUH5mQHUmLLH:8Ogb5RH>AU9jUWI>L[YZDUZRj^7nOQX>FX9R?
UIfORIMlLGk;gmS@e=G<_[>`/[RQ]IBE/XnG_kJWX[30^JJWUINOZ<K<YhNL];ba
XIVGWifMXZVYXYZFSHB2RYBLX9JLX9jIVInUYYbDUj2TWYFUYijBUjV_Z::OT9Zd
YY6NUHRIXXIjPWigNHV3K7Z@Qg1dJIR5UGmlRXJ;T8n8OWMdU8N3SY><QXN@RhV5
MVU`PGehMh2;TH^3TX^QQIf5X9jJTi>LW96;Sij:SiF<V:FGUifHSXnIU8JTTiRI
QXbHRg9eMFmUHF=XEEQJETm=DeUDE5MLH5iGDE1?CDa:BDQ7DUiPEU1CE4hjCE97
BEQHBEQCCe=JFPIBBDM7B4Q9oTXb=TUBBCm2AdM5A4=4ADE3@Cm3B4a;Ad4l>CLd
<C0_<30k?3e0@TE7B3``;3@g;b`_:BLUoR<I9BHX:BTW:2TV8B@V9bHT92HX9RHW
:2TZ:b_i8PL^:B<R9BLU8_hX0BLV1L9on9JESWN>RhEMH6I_N867RIBFV9RDSHAo
T8f1LWF2Qh9VJ6icL724WJBPW9ZHTHInV8Z7UZ2KTHj;RgA`SI:8TH^<UZ:MShbC
XKJ^XZNLUjbPPh^@YYY`VIIfTk:R/;R:O8>:R81jNWe/PI2:PhJ>THnDX:FJSIJY
Yi^H[<G6ZHUoR96DT9>MX9VER85[RJOHi]OPh<fdZ[O8/:FfXJK0Zk32aL:h]kR^
WJZT/[F[`=G7WjJa^KNZUXRHUIFHW9fIUJ6JTY2EVijOSiFLWIZGUiVOVIFIWifC
RHV=R7akRIJJX:6AUZbPSIVHRYNGMFb3RgakRH9ZMHMjO8EgVWb>O8moT8=iOhnF
Sh>:NgZ=W9B1MIJ?SY67LfQZP7I/KWR1PWn@R9j4WXJPVifIWZRTU8Z<Sgn:UHjI
Y9>AU929S9>?Q:>CVYb8RI61Jfe^JfAQHVEEF5UGE5EJGeIKHF9NFUQHCT]8ADE7
BTa7EUeFD51<A3I1CDm<BTiCEUQJFeYGDDe:@T=3ADI7AdPjBU16?dE;BTe8@Sdm
@dY??D=<DE18?SLl>SPg=cPi>cPj?D14B4Y<?BhV:bdV9BXW9RDT9BLY:R/Z:BTV
8R0P:2LUoR@99BDZ:b//;Bh_;oTTOb/V8B0T9R@Q:BPW9RChUYF>Mhj;QEePIVmh
PHN9U9JHV9B=Q7n@SH5bMH:7PVIXKW=`L8BMY:2LVYRAQWjHRXNFX9^ASX^;M72=
TXRARhbFXYf?S9>Q]ZjRYibG[:23Ri2VVW2IUWJC/Z:`^8YlPhZ8P7YjOFb1T8Z3
QXjASiBPOjFJSIJYYi^H[<G6ZHV8TIB@TifPVIF8PF^9YmSVen3PcKBZ]lR`YKJQ
Y/2[/<;5`[Rg^:jMZZBb]J_0eLNOY[6i]jZFR9REUIRLWIVEXIZBT9FKWYn?UIbM
VYNGVInIUIVOWI>9RHf8O7^9UYZPXI6F[:2=VIR:UiMeK8>;O7^9Oh9ZMHMjO8Eg
VWb>O8n@PgUoSiJ?PhYkNXfLU85eUXn>THMcJ6Z0MVa^N862Oi28WXBNQZ2KWIVN
Z:BDRXb?OhZESYVTTi6DT8V<Thn4Xi>JW8R9TH5[KFi[I65RIEEHFEMDEEYOEU]Q
HUiJF5Q>BdQ5ADM:C4MFGEI@D4a4=T5=Edm<BTiCEUQJFeYGDDe2@d=5ATM7B3Y:
D4HoAD]:CDQ2?Ce3BTlm@daAD4Pn=c`j>3Lg>3Tk>3Xm@4A8BT`m;RH[;BHU:RLV
9B@U9bTZ:bXY:BHR820X9bGn90TU9BX[:b`];Rl_nBAo:bHQ82@V924Y:2LV9?RF
UHigSX^5GF1VKgR1QhVDUYRHU8f4Oi2=PG9ePXN2IVQ^Lg1`Q9fTX9bJV966OYR:
QiJPVi6>Rh]dL8fBR96;S9JRWHn<Tj6f[Z:WW9N/X8>;T:JJL9VFMY>bX[2hRWb3
RXR0NWYmK86@RX>6SY6?U:1oYIZ=UZVWViR/aLJYRHRAU92CWJ2IUHR1JhVWf>KG
h>3=]:Zgb;2U]Z6V`:^``/G2^;Nh[YfZY;:eZl3EainV/KVgZYJ8V9FEV9bMVIFQ
VY:@UI^NWhnEW9fJUiNIWiVEVInMThV9SHQlNhVFVZ2QTIJ/X8fIV8ZGUgE/Ph]l
NhUoPVYeQgYlQGNJO8ilSi23NGn?UXn3RW]jSIbDPGFFShjAQg=XJX1fK6ihPH9o
T8RNQ9j6X9^MVIjXY9B:S8moRYF>VJBCTIB@RHbCShBSTiZLR8VAPF]]KV]THF9U
EEQIEeAEFUmFFf5RGUYHF4i;B4E5AdY<AeIMEU1@C4@f@DeGCda:CU=FF5YKFUMA
CD93@dE6AdM8>TY@ASm5BdY=B48m?D=:Cce3C55@B3hg?3Xh=cLh>C/h>Se0A4Q:
C3d^9R/]9RDZ9bHU92DW:BX[:RTY9R8P82PW9OhT2BDU:R/[;2d^;boi90`[9R4P
92HT8BTX9bHT1L9omiBAQfn4PG]LHfecNH29T7YlP8N<S8J1UY>5L6U^KfQaM7AZ
GUmeRfm_LGEgLVQNThN7Uj>LTHb3RWf1WYQlN7MnTJ>SV9VSP9bPWZBEQiJJQiNK
/JMlXGMkY;fd^JagIg1jOGQbKfi^Q9NFRhRBWYVPZjbIQXbN]:FR^=7;XGMoSHf8
QY>SX9:FM7iTShK<kMKFcKVVYKK9ZJ^dZk32_K^gaLVm];BaZ[F^_Kj/^M3;akjf
^;fhYYF1Q8ZAUIFASZ2ITY2CUYJDRi6HWIbGTHjDTiFJWY^@QI6FUHb7Sin[VZ6D
TjRRTijSSI>DNGF8S8F2S8=ZLWi/QI:1V7>8O95oT7e]LHFCT8MjLGB8UHj0NXj4
Q96DQgUdOW=YJG9iNGF7OiAlVH:ITJ:MWj>JR825RgZ3SXRFY9JCTHj<Si:>R8ao
RXmnP8MgKVi]J69MFEQCE5EEEUQMH59JHV1GDEAIBTI1?Ci2B4`fADa7AD]<AcPk
A4]1=D1FBdi@CDU8BdmGATI7BD]<CDhoC517ADmGEeABCTU7BeEL@4=6B4I0>C@h
=cHf=cTl?S<d=SPj?Cho@C0U9bPS8bTW9RDV9bX];RhW92DT8b`iB3h_9B4R92@Z
:R//;Bd^;oTVObTT7alS9R@R;2/Z:2KgU967KhB1NeaSKG=iP8V@NWb0Qhb<QX6F
ThE`JFi_J75dM6YNGgF;KfmaMGMbJ5jCQhNGXibAS8>:OH6NV7ahMgjAXj>HVJ>0
W:2NY9F7UYZ7Ui^aYgbQMg^T_KBi[7MWL7YmN79_KVj4UiJ;R9:NVJ2[OjbIQXbN
]:FR^=7;XGN=SHR6Tj>PTYIdOVB?Q/c]e]K=^JJU]/VYZkB[/<:m^kO5bKfd];6Z
]Jjm_Zbid<_7_[Jh_KRVUH64RY6EUI6>X9VBT9>FUYB;TIRMW9NASYBCUIZNVi25
TIJES8N?Wj^JXIBCZ::CWZ>=TiAiMHR<QH:<Oh=ZLWi/QI:1V7>8O96@OFeaQI>@
QgYaM8RESX1jSXB4TIB7NGAnLfUYLWUiMHMoU7bIPYVAXYfOXiZ8P8F;NX>>R9JT
UY>ASXb?TXj8S7n:Sgj0QgM^KVeXHUeIF5=DEEEFF5ePDUYRH5MAE5U:AT4m?T98
C3I5C4M5Bda7>3]4I4]1=D1FBdi@CDU8Bdm6ATM9Bda=CSm<D4M5CeMGE59>BDM;
EEa0@dI8AT0i=3Pg=SHg>C`n<c@f>3Xm?Sm1<2DW:2<S:BLV9BHW:Rd^;RLT9B@S
;3U8?RlU8B8T92XZ:b`];Bh_nBIo:B@O7b<V928/:bXX9_NDTHM_Q85kG6=]LgV0
RI1jO827S8b6PIJCQG1YKVmXLGAdJUiOMH]_Kg5eMg9XGY>7QiNSW96<PhYmPIjH
O7QgOY6SXiRIXh2LX9jTUHNFVXNGVk6WO:5gNjBm];V/MfM`NWehLVm^KXBGUX^8
TYjIX:]o[9V6S9jdYJ:hdL^QMhf=R8JCXj2BUWAnI8n6c>gFe/fiYZFfbJV[]:^`
`[fk]lG9_KBd/JZe[[fn[;W@blNn][Rm^:JEPHB:TIFETHjPVI:@TiJFU8^AV9fL
Ui6>U9>EVYjKT8FAUYF<QhnOZiZQU9>XXY>NXhfCU7UeR8b5PXaoPfYbOVb5TX6H
LhQlTI1mKG65Ti27NW5dR9F>P7Z>Q8BAU8MiM7icJFUbNGUeQgnDO9V2VI6RWInS
VXR0QH]jPhj8UZBFTi6>S8nBSXR<OhZ?OX27Mfi^KFQRGEUHDeAEEEIHGF1BFV9P
Ee5DFDY6@Cdn@TQ<=TE<AdE;C4Lh>dATBd4e@5I;CU1=BDQ;CdI6AdU;C4e>?da@
AdE?EeMDDTi9Ad]EG413ATQ6@3Td>3Lf=SLi?3hc=3Hh>Sdn?d4`9BLX8b<Y9bHU
9RLZ;Bh^9b@U92</>DPn;bDQ8R@T:RX[;2d];Roi9P`Y91lO8bHT8R`[:RPV1L9o
kh^7Nem`JF1PIVe`LWElPV][KgV6SXf9O81jK6YdNgQeNGEWFf5cPUeMH6I[JV=L
QhF;UYB7PhR>UXV9WY9cKh>9V:6EPWn8JH^HWJJCOhZ<P96?XIU_TV^1Ykfl^jV4
LG5cN7YcIU]iRIZKSXNBXYVS/[:MR8jRYI^N]lo2Sf1oUY25Q9JXXY2BK7YZTWc1
k=W8/ZFV[kVnVZZWZ:^`^[2Q/k^b[;K4b/>a^Kn^/l6h_[Rg`<_9^JUkQIBPY::N
Vi>=QHB7RXV7SI6HWIjIT8V:SIBLX9bCS8nATY2:RiRWTZ6FTJNXWZVYR8J@Ph:8
O7mkQh9^N89]MXMfR6N5OY9oUXMeKFiaKfahMGb:SHR;U8f0OXfHTXV6Qh1lP8R:
Q7^4NY1jVXBHSJ2JUY>5MGAnTWaoQGn@Y9ZJThnAU9:>Rh5cOX9`LWUYJ6MVIVAP
FUIAD4mAEEULGE=KHEmGDUMMCDU4@D96C50nB4U0?DQ?CTM4ATHk<T9KAdI3?Sa0
Be@LCDi@DUAFF5Q9DU9:CE]VIUUNHEmJF5eSCDY5@Cgn>cLh>3Lh>C`o@CDe=3@c
<c8b@c<X:R/U9B`Y:2LX:B`_<C0S7B4S:41MLE/l9QhP92HU9BHW:2TZ:_TXObTT
820U:2LT;bh^;2__RhMkGg1YH61VKG1bMGb2Jf]_NHJ>SHUlP7Y/JWAkN7EiMFMK
HG>2GEePIV]ZHeb7QH^FU8N3R8jFRHVNTW=_PhVHXIF2OhQYRiRMYY=oRXb0THnQ
VFnBJh6W_KbkZHAaLG=hNW=VFgV9VY^>Qi:RVJ>bOk:MR8jRYI^N]lo2Sf2FT8F4
UZRRT99/NVZBO<7/fLRbYJJ_^KjJZZNXZk2j/:6c^k:/]/C:`k6i_jjc`KRn^;O0
blViZG^5U:2TXYjKThf5Q8N:RHN=TIRMWYV@RHZ=U9bPW9><Si6BT8Z;V:NBXIJA
YjRNZJV8QY23PXQlOg^7Oh9^N89]MXMfR6N5OY:FQgE]KW5_K7QeO8Z=R8^DSH1n
SIRBRHJ7P7b0R8Z4NhAjT7ZJQ9R=X9ZFThEeM7jBO7n5Oi2TVYZCSi6DTXj;PG=n
PW1bNFUXIfIVI61JEU5@Ce5EFEaMDe]QGeMBEee=BDA1@TI<D3i8BD0mB4m>AdA6
:DHk<T9KAdI3?Sa0BeA=CU1BE5IHF4UBDTY=FfIVFEiQGeYHGF==BTE1?Ohk=cPh
=cPi?3m1=CDd=3<c<S93<bPZ:bDU;2TX9bPY;2la<2<M8B<X@5eaFc`V7R0T9RDU
9RLX:BXZnBQo:B@P82DX9b@_;Rh/:nn;Qg]OL6UPH6I]L79eO89[JfmiQXj=RGb0
NVaZM7]hMGUeIe]QLh9MGF1VJfYSG8N5RiJDQh>8SYJ9RIjBLfn3RIRQUH9oR6V;
V9fVTgn:S82ASj6IKi9[PJNm_;^YQ75aLgQjLfIKNHVJVhj7TZ:IXk9o/Yf8SZ:U
Vijgcl:?H9J@QHBFZ::@TVajJY9l`NcIb;:UYZni_YZZYjR[/;Z`XK>k/Zbfa<[3
/KVo[[?1^;jh]l3;bKVYNhFDX:BRWY^CSHF4QhZ9QhfAV9fNVI29RXfDW:2LThb?
TI:@RX^HYi:QUY6WZ9jYZHR6T8>2R7aoNhMoPVihPVefQgJ8IhEnTYJ7MFe^LFm/
N7ElRXf8RiB=P7j=V9:9QXN0O828RXAkQ7Z@NYZ4V8fPVYJCQGEdOY9lOhEoT:BJ
VY>?TIBBSX^1Lgj2L79iJFQWIVITH5YFDE1?DEEIG5eCFf5OEe9GGDe9A452ATa@
?TQ9@3e8Cdi7A4HYAS/b@U]7AT<n?41;E4e>D59DEUQHBE9BBTeKIVIIGV5OFUQM
Hde:AD4moS/g>3Pg>3Tl?d4e=C@d<c<b<T<c:2X[9BD/:BPW:2T/;c4`8adQ8bQ0
GG5K?2HN82@V9BDV9bPY:R[i:0`Y920P9BPW92l^;R`[1KP6mI>@QFMdJ?iLOemR
If]]KW]dL7N5Si2<NH1nLFegOgi[LW1VIG5lOgehM7EhNGMcMgb6RWe]LH2IX8^0
SHEfPI2GXjJEP7j:JX^GW:NHR9JISiZ<Ui9[SWB6WK2i]Zn_TXj;RhZ1L6:6RY:D
RGn8VX^J[kBQSiV`W9VR^m31TVJJTXF2TjBOS8mcOgIiS8:^enG8ZZ>b`;fdVkNZ
];>]aK:__;f/XZ^k`lZa]l:c/;FY]kc4bLBeWi1mRIVSYZBSXiVBRXR=TiJFU9FI
Wj:NThZ:T9ROXInIU8B0PXN4OX:=S:6HSj>ZY:nWPGb:Q8B3KfeYNG]_OXYdIWUV
NEn7Oh^;QWihMgQjO7IdOgZ1P7^4UIN9QI2GT8V9Pgn0Qi2?Q7V7O95nXH^MSZ>N
ViR:O86@Vh:1PgZ;X9JMTHbBTh^6QhIfO7aVIVeLFUYMHfU[IV5CD4e?EEYKFUUM
H5mMGF1TE55>Bd]=D594BdLh<SY1@4mBDDU3AeAOD4]4@498CeAADUAFFE]MGUMK
CEM=D61ZJEaVKVeTGEiRFUE<A3lo@D<m?C`l?D13AC/j>CLe<c8a@C8Z;S0Z:2d]
;2/Z:b`_<34Q72<U:4I/OfA09alR9BDQ8B8S92DV9_PZ1RHQ8bL[:RSl;PKeTi25
IgAXoUaoGf9WJfe^NgA`MhF?T8aiP7iaKGMoOV]bL6IULGaoOGQdMGQiMg=gO8J:
OFeaP9VPRh2=QGJ1T9NSYYF0OXYZRiNLYiR8UYV?VXbGTV^>M8JM/;Vf[jnBSX^;
RX5`HXJ:TYB9OhRJRiZ_]:6?VK2LVJ:kd<6BIYZBQH:CY9n<Sg=oMWV<PZkGiLRZ
Xk;0_KBK]jZd/jg5/Znl_JbRZk_3b[6g`[>`]JVg_<C9a;FOT7f9VJ>VY:>SVI::
R8fCUYJDUIVOXYjCRXZ@V9nQWiVDQ822QhAnPXf<XIR?XjZT[jN1O8Z4Q8=_KFUi
NfmnRWAVNFIiGhMoRh^6OWQgN7YlMWAoNX60NhBEUhV5T9N@RHV3Oh27T8n4NHMl
TGjQRif>XijKV8YlPI2KPX63NX^PUYfAS9:CRhJ7QWIlO6IVKEaJFUeSJF]VHE=@
CDmEFU]JFEePGeeMH6ADDDi;Bde@DTA;AcPb>T50Ce9ABD=7E5m@BdA0@TQ?E55B
E5IIFeeNEe]=Ede@H6YYG6I^KFAMGV9JEDa4?cm1@cdm?3`m@4=5>cXi=cDc<S51
<RX^<2XX;Bd/:bX[;2l`<B4L8bDXAVaoI40W7b8U9B4Q8R<T9BHVn2X69R4S9b/Z
:?`^1_FCT8EWM6SnG7mOHVM[KFikM71gQHn@S7V0OW5]MgmnJg9`IVEaO7mmN7Ae
N7UgLgMlQXYmKG60VJ2;P8f5MX6@Uj>VUH1nRVZ;UibWV8RFVHnJS9NBJhidQYf`
^KJ_[i:>Rh^:PG1RQXZBU8UoR9Z;VZndXHnI/9bIX[_@`I9VVY:5PY>TWhb?Lgmf
NHb2[]OUb:ZS//2m]9^gZ[Bc[LFb[kbm[::[^l?:/KO2/k2eZKNla<W4]In@OHVI
XjJTXj>ITXZ8SI>FUYBEVInRWY>:RY2HWj6OVIB4P8:7Q7j2SHbQV8nSZZB_Yh5l
RXB4Pfm]JGUkKgj:M6IiIWUOQgn;RhInN7MhNWafM7mjPH1kQ9FGRHF@Ui29RH=o
P8N@ShAiQgbAOZ6;WHjSWY^HRWb1T9^2PH=jRj2FWI6<TY>;QXN6MWalIVI]G5YJ
GF=YJfIQDe1=CeEJFeYIGF1OGEePI5AACT];CE1BA4]7>38j@D1?DU59@dMDGe1;
A412B4mDDE9DEUUKGEiGFdeGCE1PJVULIVi]I5eNHUYEC4@o?d53?Cdl?3e0@dDk
>STg=C<b<D4b:Rh`:RP];B`[:R//;c0a8A`S9BQ6K7mT@2LO8RDU8B4R8b@U9RKh
:PHV8B<W:bXXo2h5`WodUIR@Lgi_H5=?CUQVKfiZQGQ/KGZ5R8F1RHEdJFaaKfQ^
K6I^OGa_LVQMFEaSIfQ[K79fJemUMH>DRX29PG^>R8nLWi1oPiEHLG5^NgMeS:JM
XhfGVGZOMhJF[kbVWKR0QHV7OWE_KI26PhInLgV9PYF]/in=V;6YYZ^kakRBL7n=
QWUcOhn;NhIjJh1gQ8f]k]6c[[c4^Z^Pak;4`[CF_[S2`:nTZkJiaK6oc[Z^]:g9
cLZhWXZ5R8R?UYRFUijTWiN>S9>NYZVNW9bPYJ:ISiFJX:>RWY^IWiBEXZBHTIF:
XiV:VjBPZJN5PX]oOhEiIV5`M6UhPFUkRFmlHh]iNGmfM7ImQhj?SH5fM7anN7Qn
Vi>CViZ<PX=dL6mgP85hKXEiSWbRS9b;TYBLX9J:T:2NQhR;OhZHRiR9PXZ9O7Ij
PFmcLEaOJUaHEe]TKFmYHUYDD59IGUeIFEMEF5iSI6=AD4m=BdY9BCm9BCdg?3lk
@U=HCE1RIUULEDi?E5A=AEM<CDmBEEQKG6QWG4e>G6=PGFM_JUiEF5iIEDm9A40o
?S`k>STj>cho>CTh=cLf=SDi;BTa<b`Y;38`;R`[;2d^=2@S;BTQ>5iZDcHU92LV
8b0Q8B8S92DUnB]o;2PT9R/_;R`X:2X[;OBEV91cOVmPDdm>F6I_KVZ5N6a]NXF8
QH69QGAYK75_J6i/IVimO6mbJ5eIG6=WJ6]/LWI[GfEePiB:P8V1Nhj8SibOT7n3
UEQaLFikMgF<YYfSSININYmgQYJ__:JM^825RHMnMFm]T8J3QWicNHV2UJeo/in=
V;6YYZ^kakRBL8f6NG=oSh]kQWY[P7N4SJg^dK>^_<BjZj37//C2]=Jn^<;0[jB[
][W5/Ko>^Zjd[LW=b[RNRXF8R8nFV9JGWZBOUhj<TijVZIjLW:2UXYV?UIZPXj:N
ViVOU9FRY9RAUHZSVHZKY:2YYhF2RgmoQGUVHG1oM6UhPFUkRFmlHh]iNGIdMWf7
SXn=PGIdO7ihN7jKTi>KVXb2PgA`KgN0PGQ^QGV>O::<W8^BU9bPUXZ@X9j7R8]o
RYR;V8V2RXUlMWZ1Kg=aG5mZG5QGFfA]KfURFUA@DUUNGEUIEeEHGV=THe5@Cde;
BTU9?dU9?CLl?c]2DeQTCE1RIUULEDi?E5A=ADa=Ce9EF5]LJ6MLCDiLHf1MIfmZ
GUEHGUUECdU4@3ln?3/j>CXk?Sli>CPg=cHf=CT]:C4c;2T/<S0^;2//;Bhd92<]
:B4hGVYC=RDT9bHS824Q8R<T9BGi:gl/:2@V:bl^;2PX:R/]m9FHT7=nKf1CCdiH
IVm^JXEhK6ejQHR5PHV5M6U/LFmXKVaVKWelKg9XGEULHfMXJfabMV]OIGF3U8Z0
RH5kSXR?W9n@Oh>EF75aKW]gMHbVWJ>=UiUjWgN6UZnlYYfhP8F9QgieKff@QX>6
OW=iRH:E[GncWhfH/JVVZk_7^99`SHIiLgn?Rg^6NV^0MhB=[NkA/jjla;Z[X<Nb
a<:de[jh`/2_Y:^f^LFa_ljj[[B]bLg:^9j:QHR8SiJHUYNNY9nGSXbCWZJYWYbL
X:FRVHnEVZ2SXYjKVInDUJ:TV96ERZ>IRY^TX:VWQH:;Ogn5NFIQL7mdJGR1JG^9
KgaSRgUiMWAfOHN>Shf1MWAlOWQhOY^CTi^JS8:3M71_Mh21N6j5NHilXXbLRi:D
W:2FRY2PWXN8Rgn:V8^HRH::RGafNX5_Lg5LGfYLF5MKI6e_JF9JE51BFEiMFEUG
EEQNHfASDE1?CD]:BDToBDTm=c`o>d9CF6A=D69VFEaECTmDE4e5C4e?DUEHFeaX
Iea=CUaSH5eWKfYNEEQNFEE?BDA0?chl>cXi>S/n?cTi>3Lg=SHe>BdY<C</:B`b
<2h/:b`];S@T8bdY8CQNJU<f9B@W9R<P8B4R8b@U9OT[32`X92H[;bh/:2PZ:bd5
`WoQQ8Z6JgIUEDm8AeE/NgYcOFeMG6YhO7]bO7a]HfU`L6ibKVQbOW9JMf]MF5m[
MWaTGUmUHU]PKEeoRXbEQg^<OhB<RWEQIWQ_P7E[N7f7YiZCVH:?VX>/L86G^lFE
O9f5UjJTUi2IYYF2N7YeJFelQYR_/Y^5SZJb[:V][YinI7mlMVUQJWQeJ7YkGGmQ
Ofn7kmNn][fo/Z>G`j_2`:oH_IRW/:fb`m7D_[;:fkn^^;W>c;^HN7JC/YfNViB>
TZ2/ThUoOXNDX:JUX9jQYjJMU9nSYjJRWIZJU8F5Uif>P7j;YIZ7UIjIXJf@T95k
Nhf=KFI`L65[KeBQZXJ;KHi`IWmaJVM`OX9gJYZ7OHRARG]cUI>JY9n<P81`JVI/
MW]fKWiaQWJMQiJ4KgR9UY24RIRMRXnDQX^BP9:0NH60L6U_LEiSI5AMKF9RGf1V
KFeSFF1IDeEMHUmKE4e8CUYQH5]7B4Q7AD4m>ci=EU9@E5A>;D]FC5McKDiQFUEJ
HEY5<S]6AdU<D5=EEg=_Gda:EEUDGVIZHE9;DEY>CTe:A3df<CDd<S4a<S@e<C4b
<c@f=cLb:2Ha=BdW:SDc<2gn;1P]=BP[=bdI9dU>?BTS:2`W828R8b<T9BHVnBao
;RXV:2da<BlR8bDX:n64RXI[MVEECdQ7EFakNW=mKEeLJWQlNg9lO6eSJG1`KW9^
J79nLUYgJeeHGf]fO6ANGfERFf1]GGn:S9F7NhaoQ8b:MF5VN6n0MF]hOHNWVY>I
PXnJPja`PINkaIElWHFGYZBGT9VVUH9hNWEYKGb6V:mo/Y^5SZJb[:V][YinI7af
JF5ZN7EXNW]MOf5oKhO_ekjf_KnbXiO3Zl;0[mRmV:N`[K;3dMBn//[K_jjh^Lk<
^iQhMY>bWIjKU8jBX:bCRGmnQiBPYZFPWZ6WYYfDWj>WYZ:MVYZDQHFGWHj0OX^U
VXNEWYVQ[I2@TG]kSHe]IW1oL65[KeBQZXJ;KHi`IW5ZIg1nPWMZVXMmR969Ng>E
TiZTWhb0P71ZIVafNgI^OW66MYf7UXA_N8VFT8B9V9f:SiB6Ri:0TX1iPH1`JFma
GV=TE5e]HV9OH6I]KF=IH5UCEEeRGe]DCDQ>FV5PFdM8B4M5@Cdk?TeFDU1DE4h]
BeI8C5McKDiQFUEJHEY5<TI7BDa@DeEGLfmOC4YEFEANIVYQDT]AFTi>CDY4?CHa
=C@b<C4b=3Da<C8c=3Hg=c8X9S4e;BLZ=C<`;Oh/62de:2/g;ATWBDhm:B<X;2LP
8R8S8b@U9RKi;7l^:RHX;C4a;b8S9BP[hHB:QV]fIEE?B4MEK7]jLge]GEaZN7ak
LWalKF=YL71^LViXLWibFWM[GEQOJgIlI5iOIF9KH6eMOhZ<UHMkS7n4S8YeHFIh
Kh1eJgQmQjNJTiV2SiZ3[721Uk_5UGbMQINVY9N@VJJEPWQjMFU]O8JH[gnbVhF>
Y[:/ZJf^WWiTO7IYHFYhMFQjNeeoHGm_QnoG_[Jm_k:SUl>[`/2_f;fHYk2]//?A
e;jbb]^o[[Ric/bkV7QfTk:MWY^DSY:P[9>9Ogj7U:2VYJ2NXJNVWIBOXjNVXYfJ
VYB5QINMSX1nRjFJQiFNVJ6]T92ANg^=SFeVL7m`HF]_E:6ZQX]]SW1VLFYWL7j2
MfZJQgf8THUkLiFCVZBOS820L6YVK7IkMVinLHIfWHNFQ6mhRIJ@Q8VHWHZ?U8J;
TX2BP7V1P71YKg5NHfADGFeRHUmPIVe]HeUPFE=EGF9OFeA=B4iJHF1KAdQ8AdE1
?C/nCEIBD5ADCRe;ETQ<Eg=]CV5JEEYQFTDbATM9C51CEEMcKem<BUEIE5iVJV5B
Be5JCTi=BT@m=S4e=38a<C8d=C4a<S<d=SLg<RPV<CD]9bXe<c0]oR`H;CDX:cL]
6BM9CSdY8bP/9b0R8R<S92DV9_T/32hZ9RP]<C4_8R<U:2/5dGoULHAYJEQRE5M4
BeEAIGU_L6QPHV]_JfAhNGIYFU9DFGYZHfMPCdaFHeaFF61THUeDGFEWHf9VK7=/
Jg9dLgj=Mhj=LFIfOW=ZIfagN7EnSHVCQh::Oh6TN7nA[;feV7emQ8F1RYfXZ:VL
TXb2NH2?OYVNVif<QZ6NVYf^_kB4EGmmPE]VMFmcAgAOE61`Mgb1cNK6Y[BVU;2_
a<Zl][VZTJjm^jbfd]G2_[Njb]7;a/V/W9:DVIj_`YF?T9ROWYfOUXf2OX::Si6W
THjSYiNHZjj^/kBVTi6KS8VPNI2_MXG;f]c<^k6STj2LV9RJV9>>PWQ`M824O7:G
UiR>MfMdSGmUM6>=M8m/K7EjQXf2L6iiMWf<UX]cJ6aOL7UbK6e/IVeiNHNQVY>[
VXR=XIIhOIfOLemePGIjT9B8JVMjM7JFJ6eaKVAIDe5:CE9HGEiLFDAQBU=ECfI7
BDQ>E4m6C5];@CPj@dY8A4I:DEUOHEeJIUQ=EFUfLVUGDDe>CTe@EeAKDdi>Ad5:
FV=OFUMGFE]MGeM>BTY;BDIBD4To=C<h?C=4Bd8m?S0L>cTe<c<e>C/R9BX^<C0^
;C`f;2@R9ble;Rd[:RX[;BlZ;C0^:24M71`N8B@WoRQo9BP]<34_;2XN;2lV9BhZ
6aTR;34`iG64JFUHHUAGA4]EDFEiKg1XH69[Kf]TN7UfJEYBE5UjJV=WH4m<EV=L
EUQPI69ME5eUIf=RIVacK6]bM7=nSGN>SG5VMWicJVM/MgQeOXf9ThN2RWn1Y7Qo
TJbm]IQmOHB5PHZMZ:RYW99oS89iP8mnVIjKWHb6XIjJWJjo]8AEOH5KIWE_LdMd
GeAPL7MlPLgVaZJdYYB`[lC:_;JiZY6^_K^/]];E`[jg^/[AblK9[9bBU9VN[l:E
Si2HWijMWiJ=PWj2RXnAYi6>XjNGV:^^[[>dYY>AVhb9X7V@[gJ5bm[Lc;^aXi>P
W9QoV9ZHThj2N71dP8AlLYNGV8igIgB=IGASSGB?K6aeNXJ=PW1^NGImS9J;LfQ/
Gg1iLVa]K6I]NGV7XIZCZiZ8SJ6FN7fMWg=OMH5fNY2DR6YWNWAfUVQ]LFiTFE=A
BTeBF5eNG5U4HDYCEDmVAdU8CUA?ATaKBd4h>T=:B4A6BU5YFEmQGEYVF4eEJGIb
JEMACDi>CE1GFe=>CTM1BUYSGeYGEeUKGEmGCTY:BdU6DU19?cDc>3dcA4]2?Ch`
73/i=C<c=CTk8RDZ;S4`;Rdl=R`T8RL_=Bh]:bXZ:bd_:Rd`;RPQ7A`L7R4T9ohX
ObDX;C0a;b`Z7R`_9RD^:Q/I8R`a<>EaQ6UYF69DEdA;EE5UNFm`J61RJfm[I7Qi
MVUJDUAINVYSIf1?C5ISG5IHH6ARGEAMIFMSHVI/Lfa[LWAcOXegSXeaIWInLfYW
K7MhMGj=RI>7PXYoPJAhOi6/_KFHOGf4QH6:WJRXZIbBOhb2NH2?OYVNVif<QZ6N
VYf^_kB4EGf1FfIeKg=7M5mDH71gO87=i/JV]:JD/:o4b[bf^JZA[[fk[;KBeL:n
]k[:dL_6bJbLTYBIWZo2UHn@V9nNWInFSH9nPXZ?TJNASZ>WUiR[[Zjc]:JCTI^<
RJ1iT:mfQL_Jg<bk/J>CX9bHOiRJV9>>PWQ`M824O7:GUiR>MfMdSFEdHhedSfa/
MGZ6SH9`KWUfOHbFRg=XK5m`NG9/KFaVKGUiQj6JTj^JR8fQUWQmWImcGgF1MWZ@
U8QZIgYdMYIXKG5^I5UCDDY=DUQMGUaIA65:DeE?ITM9B4iDCdI<Fd]1>3Y3BTQ4
ATYAJEUOHEeJIUQ=EFUfLVUGDDe>CTe@Ee]CCTi7@DYJHemJEeMIFeeOEdi:BT]9
AU9@BCle<cPm<dA;@Sdn<1`k>CDc<cDi>b8U:Rha<2h]?3H/928W;cD^;B/Z:R/]
;bX]<2hX8AdL71hQ92On:1@U:2d`<Bl/:Qh/;bHU;RXK6B8/<C05dGo[NXmgN6E]
GUA:FfMMJ7IZKVALGVU`Kf]]LWEaIf1OHFaRHFa^IfYfGEMADe]QHV1[L7EcKF]^
LgE/Jfm]IVYeP9>BNg=oOFa[K7J0Nf]TJXZIU9BKRXBQS8fGZkbiY8moRHj:S9:?
QHj4OWegLGZ:QZ2UXj>>RJJOW9j^_[JBKWnCU6AMHFF4LEiGGWJ5Og5ZUM3I/9nV
[[NW_<:f/[N[U;W@dl2oeN7JbL73c/o1];:SW9n]^;k;fZfLSHnIWY^EYZ2KVinR
XZ2XT8bR[:2P[Z2RZk:ZW9j[Y9JRQ9R_R:WVk>kRb:nSX:nZY9jFRW]_OGYkPHZ@
T8j9P7]mMf]YLDYMJ6=_Ff9FG71cOXV4MgEnQHZDV8UdLWe_PX^0M7EjNhnITiV[
WI2UWhf:UiJ5PXfGOGB7THEiNhf;N7R5L5e^KG9eL6IKEE=7Be3nDgmEF55>A4e;
@DmGCe9MIf9DDU]FCDM:DeQDCSm:EUUEDUILJf5IGFQaL6]JEeIGF5MIGEI5>T17
ADI=D5EIFEIHGfMNEdi:Bd]8A412@Sll?TA;?dY;@D17A3Ph=S<a<C<f>3Dg>S`l
>SLdAT4i<c8f?40`;b`[:R//;B0T:B/[:WlY:AdP9BT[:bTX:b`^<34a<30R;BhU
92`Z7b<eCF1XjgZ?MgQUKEiDBU]WGFQfJViTG5iYL6m[KG9eLFMPGf5/HV5/KVMZ
MUeGDE=KHF9PJg1eLfe[KW=eK6]_KFIZMH2CTW]cOge/JfafP7][I6Z:VIBDVhZ4
XHb=Uj^l^JB?Ogn9SXZ<TXn5SXAnOGMaNXZ6X:FSXhj9YYnLWZjn]Y9^TiATGF5U
Q75NEeifQGmaJYG@fK2OYZjgYkc2][:gZiBid=?0_mGQf/W1`lk?`KBbXibO[KRn
bmZ]W8f?VIjKUJJPVi^OXZ:PZ92<XZbPX:jPXZ^bZYbNZjBFXXBH[hRYiVW/k^;8
[j>P[jZTWYJ:NfmmNW^1RY2@SXV0NgegJfUaGFQSKe]REUa`Lgj9Q7MeOXF:U9R9
M79mKh:;P7AeNW^?VI>IZif@YIn=RYNFQH:=UgedQi65NG^=RgQhQG1MKVebMG1V
FeECAd]@oU=oEEQACTA=Bd5?EdmBGFMRE59KETe7BU=HE4hoBUIIEE9FG6]QFEeX
LG1[FUMFEeQGFEeFACY0AdE6CE1EFEUFF5mWGUM>BT];B4A0@T8o?3i4Bcm:Bd50
Ad@h>3Hc<C4c=SPe=cXl?3Xg=4I1>C<b=Sa0<2l/:bX[;2dP92T[:bYo:BTM82DY
:b/Y:2//;S0a<C0`8Rd^9B@/:QlS=DePJ>]jSgMhIFeNE4YKIeeXMVY^I5aNJG1_
JfebMG5WH5mQK69QK6iWJWIMEe5CFf5RH6]`MG=]JficMFa[KfeVJWF0Ti9kLgmm
K6]/MX1kJfAZRYVDU9^:Q:6<SIN[_;VTSgmoRHj:S9:?QHj4OWegLGZ:QZ2UXj>>
RJJOW9j^_[JBKY>DI5eQIHAaGUMNMXEoLFZEd=V`WjJ^]jNl`[Jb]j^D^M3C`;oE
hM[9`L?>cl6d/Z>LWjfh_/_J[Ib=SiVNViFVX9^KWj:RX:R@S::/X:2^X::[/ZZL
WZ^TUZ:4V:n8ZNIYk>kRb:nSX:nZY9jFRW]_OGYkPHZ@T8j9P7]mMf]YLEeXHfmK
HUILL7=nRHAgMGj5RYBHRGAbOFn2Rh1dMGYkSiVCVJ^MT:FOSHZGUXF2SIMmM8NA
QGUkSH]hN8E`GFi]LWE`IU]EDdM;D?iCOeEHDDi4CD]1CeM?DUeWHUABFeI=AdYC
F5A>?dYFFEEBEUa[HEUMJ75`JeYGEUMHEeUMETDj@4M5ATe@EEUIEUQOIeiGCTY;
BdQ4@492?c`nA4/oBT]1@4M4>3Pf<c4a<cHh=CLj?3`j=cA6@CTc<SHl@30_;2/Z
:b`]82@Y:b/Z7RTY7B0U:B/[:BP[;2h`<C4`<28];RDT;2XO8cE=H6P5dGoRM8ii
NfI[FE=DKg]XJ79VKf=IFVE_LW1UK7EhMG1^KX5hLgA_IFAZGUQCE5aUJVacM7=^
J6EXK7=/K7=bIfEZI7ImNH6@RWI_MHJDRg5OG8FHVj2XThNPVIFFXk>eZ9V>WJNU
XYj?OY^ARhV0Mgb:TZZ_[Z^ARjfc[Jbd^J^>MWnLXgEWH6>>Qe]HHgb8OViVI[Oa
c9BUaK^W^l6e/kbcW[G>eL6faMOKe<[8c/RdXifVY[;8eMSNj<NXQh2BXI^<WYbL
X:JWXij[TX^P[jVV[9^NZ;2YW:2]ZY6>PI>HRlC/jN_V`iR@XXf<S8j?RGidMgMj
OX:6RHV5LFMdOgQ[HgmdMXA`LV5bMVARJgYlLg5gPhR?S7QUK81cPXIgJVmiOI2K
V:6g[::gY9R>SYBCR7j?Pg^0Rhf2MVmeJg23M69_KW9cKV9GDE1;DEICCDeDGEU1
DUE=A3aQCda?EU56Ae9@BDI;E5M@B3];F5M;ATmLGe]GE5AFFE]CEEQIFeaLFS1A
>RdjBTe8ADM@F5YEE5YPFE=<BTa<BDI8BTU2>C<b=4Y<AS/j@dQ4>CPf=CDf>3Ti
oSYo=c@`;Sll>3Dd=STk<c4^;2XZ:b`P8bHZ;Bh^;AhS:Bl`;RXW<2l_;Rla=3DY
;b`S8RTZ91ddEG5ohWB>NG]VJeUCE6mkJ6QbIVmSFEYUKg9`IFaeN7E`KVj1N7=d
KfETJUiHDeALIFY/LgAcKVQUJ6acK6acLVMUJVAfOGV1T8YoMVmeQYB;LEmLQIRK
X:RCQj2IUIJS/kFXVHjMYjFRWXmnVi6;RH1gO8ZBZZn^Zi6;[K>][;BiZhifW:=e
If1SSXMKF6=lR7i^IVJglLbDYLFkYk_1]K>l/ijec]G1]/GGfmC:b<k8]:>MYZJb
b=GHg^S7Z8N0TZ6KS9jLW:2VYj=oWZ^BRj2_ZJJ/VijX/:VLX:fZTHj1TiR;a>cY
jnK3V92RSHb<SXn9OWAgMgYnPXJ9RHEaIgAoN6]SM7J4L79QLWITHV]jO7=aMh>8
ShahIFb0Lh:6MfY_NGf@ViRQ]jbR]jBHSXjDThQnSh=kP8^=PWI_MF]`PgARKfib
LfiREe5YD4]AEU==CEAMFD5BEDe4?65?C4mFDDI7DU19AT]DEe18>d]HEd]6CeaO
FeMDE5IIFe=EF5UKG5aJDCX]>TY=B4E7D5QJEEAJH5UCC4Y<C4U6B4Y9@STc<SA:
C4Hk>T=8A3Th=SDe=SPi>OhjOcLd<2ho?3Pe=3Hi>c<a;R`Z:R//82<V:Rd^;RdN
8bT_<2hZ9c0_;bh_<C@e:Bl/8b8Y:R@M=5EaOn9dSWUkIV]IDeA_NfQXLVI_HeUJ
IFmbL6E/MGQeL6i^PGQcM6mUI6YNF5=DG6EZK7=dLfiXIFQ/Lfa/Lg9WIFYTMWei
PI2:OgI_MHJDRg5OG8FHVj2XThNPVIFFXk>eZ9V>WJNUXYj?OY^ARhV0Mgb:TZZ_
[Z^ARjfc[Jbd^J^>MYbSMFMPHhj7FeQSO8QnKVIV]o7<U:G5^jNk`KFc_;>N]LkE
`KK5em_Db/S>b;BSWJJV//SEf=kXajR7P9:QVhbNW9bPYZNSOij[TX^P[jVV[9^N
Z;2YW:2]ZY6>PI>HRlC/jN_V`iR@XXf<S8j?RGidMgMjOX:6RHV5LFMdOgQ[HgAf
Q71bHG9fI69[NWacLGN3R8n<N6E/P7>2QWMZKgUmT9^HXKN/X[NTV8j>U9>8OXn3
Nh2;SH9fKgE[L8=dHVm^LW=^HUMAJE1;DEICCDeDGEU1DUE=A3aQCda?EU56Ae9@
BDI;E5M@B3];F5M;ATmLGe]GE5AFFE]CEEQIFeaLFU4j;CY:CDQ5Ae1HFUEDFV1I
Dda:C4a9ATQ:BD8i<c8dBTa6>cY3B4@i>3He=CHh>CWn>SPg=30^?c`h=C@f>C/c
<Bh/:RX[;20S9RX];Rh]7R<Y;c0^:RL`;bl^;c4d=BT_;2<R:BXT7CAELGl5dA_L
L8ilOVQYEEMKN85WI71XMFQIEf1ZKVe]L7EgoWQoNHb5O7AZGeYJIF5MGVA]MGY`
KfaXI6AVJ79/L7f1NG=eIG5kPHnJSWMbNXjPVh=cLGJ:SYBPShNRY9jMZ;Nj[IjE
Y:j[Z:FGQYjGUiZDS9:OW[>h^K6?R[:]Z:bj_JZ@PI>TQ85iKhIaKEmKIVm_L7IS
W>o/Xj;7^k33akVh`[aoZKG6bKVa_L[=elW1`kj^XZ6k^L?Fg][Lhm^dQWJ;XIR1
T8f=Ti^QXZ2aVHnN[:ZSXZBUZjjQT8nJWhMkPi21S=CWg>;U`8f<[hF4QHbEViZG
SXInOX:2NW:=Mf]fPh5hM6ILMUQhFgI^J6AYMg]dLGImPhb9LUmXOWenMFQWLgYo
MXZFU9ne[:>iXjFLT92FSGb?Q71SL8J9OF]`GeecLfeoJfi^Ie]AC4]DFUiHCdiI
I594IUU?DciLE4Dj>CHd?Ti9A4=:DeA;@DE<DU1:BDmGEUQGCdA1Adi3C55@DEIC
C4Ti<d1>CTY;DE5BEEICCDQ>BTM9CU1?Be=EE4`o=C0K;d=0>S8`<cLg?3`k>SXk
?3`f=SDd<S0^;CLf=?hc1CDf=C<`;Oh[@B`^:bX[;BdZ9b4V;C<d<B`X<2h[:BX^
<SD`<2/T8bHY:1L[AEYRg72>O7iXJEEGFgR1IfA`J7EXFEMPJVi]KG1eMoihOgV<
QGadJUmJFVEQGEiTKGEjL6m/J6ATIVQbK71mPGUcMFEaNh6?VXigLWZ>X9^3Lg5f
RXjDX8n7XZBNWJRg^ZfNUJB^ZjRUUhJNUiNJU8bBWijc^;VaShZb[JR/^[fZT86C
Y8B1NFn6LFeOFfI_Kg1fHic_k:>Rak^``lNi^<:lOjVea/Vi/Kg:cMO9`L>n[Z:Q
^kW3e]kJg>?K]8IfRj6HPI2=SI>KXJ:P/IV?WZbZXj:TYJ^^XI2?VYn7Nh>@PHcD
imcRiL2=S:n5Q8F<UI^JUhj6OWj2PWYbSGM[MX>1N7AVG7IHN5]fKVQTJGMkM75f
OH><RG9OJ7imOWEXIg=jOgJ:UYBO]JbS^J>UW92@UXelShA`Hg26RGe[L5mMLg=]
Of]^KVMKDDa;E5YNF4m>FFABA6IICe<nG5A5>STf=3i>BDA3BU=DBd55C59@BTU?
EeIHEdm4@DM>@daAD55FDda9>C=0CTi:Be5ADUEFDde8CTY7BDi@Cd]CEEA<?cD`
6bm3@3Xb<3<g=c`l>cXj>c`l=SHe=38`;Rdg=SCn<`De=SDc<2gn:d4/;R/Z:bd]
:RLQ9Rdc=34/:30^:bTZ;S8e<30[92<V:BPG:dEJH]a`SWanJ6UEEe]hPFMTL6Qe
J5UGH6Y^KFe`MGOnN7miS8ElM6YOFUYUHEeNI6eeNW1_K6QTI6IXLVa`OH5iLgEU
LG^1SiZ>Mg9jSZ2KPg=aMXZ>U:2?Qj:TWYfX]kZ]WYFT[Z^XYIN6WYNGVYB<TYnN
/kRi/Hn:/ZfX[;ZmZY21TjB4PGU_QW5]Ge]VKfm`MV>LknbSX/Nk/<?7^KS2_7nY
]LK9^K6mb/gGbL73_ZjRXK^i`mKNf]cSfkB6MX^QV86@SHfCVj6RX;6ISij/ZZ>R
Y:F[[Z6@SiZOQg^3T86<e>OLh^G0SHb_QHB5S9FKVYN>QWinPX9jLXegJgJ3PGQd
IUafF7QKMViXI6UgNgAaMWf3S8UbGfQnOGieJ6McNWmfRYJDWkF/XkVSYIb@T9J=
O8n4L6=`QXUmJg1OGG=cKGm[KViWFe5<BeAJGUQ?CUUTDTAVFDmC?UaDACXi=S@n
CTU4@dYCE4]1ADaBD4Y9CeMFF5M?A457CT=<DE1AEU=<BCTc@4i>BT]ADE9EEU==
B4i:AdU>D4m;DeEDC3le<1/_@d0j<S0c=cLl?3/j>S/l?3Hf=C@b<2h]=cHdoS<5
=CHe<c0]oR/U;2h[:R/];BXW8BH]<c@a;2P`;R/Y:Rhb=C0`:b@S9RTX5b]5FV85
cWoTNIR6R71_FUeLLgQNGg9^OFiMF5eTIF=nNG=`LGIkOG9cLVi_LgEdIVETHfE[
M7Y^K6][KG1aLGQ`M8>:PGQgSY6BTI:=Mf1bMX>ASWefNVIfMG^:PXFWZjN[^<K4
/Yn?UiN>RXb6NX60R9JJV:6`YKNm_[:8Q;:ASYjla[BKT7nEY8N=S7f2G71OEEQM
H6YgL7O4l/6U^knda<Ff]<6n[<[<b<;4c<g7ckjc]KJ`/;O?b<_GfmSLiNc:VWn9
VXe`UHn;SiZX/;BfY9VNYZ>KUjJUZJZJQX>=TXUiTIYjVNC[hNS^cZ:Xc[jf[:RZ
[:f/]J:ATIZIR7J=OG9cM7=jQWmbGW=NS75mI7UeNH:1MWElP8NBTh1]LH:FR7=Z
NHj>Oi^SW9n^WHjQWj^ZVHb=S8JFRW=RJgenL7f6LVIfM6QaK6e/IEYACTiDF5UD
CTmGH4U>Ed0iBdYAETQ0@d<n@Ta=BDM>EeU@AUE<ADM@EUEAG61PEDQ2BE8kBDe7
B55>@S4m>3e8BD94CEA:@dYGF4XjA493B51DDe11AT]:AT=3AB/Z;34b<30b=cLh
>CTh=cLh=odf3CLg>STh=cLi>c`e<c0^oReo;S<^:BX_<BdY9BT^<S<`;2T/:RLU
9RT^<CD_:RPV92HZ8R`h@43TNIR6R71_FUeLLgQNGg9^OFiMF5eTIF=nNG=`LGIk
OG9cLVi_LgEdIVETHfE[M7Y^K6][KG1aLGQ`M8>:PGQgSY6BTI:=Mf1bMX>ASWef
NVIfMG^:PXFWZjMoZkS6a;:OSiNGSXZ<QWZ1P8RFVYRQ/:Fg_KjbR8BbTHjN_<Jd
Vi2EY8N=S7f2G71OEEQMH6YgL7O4l/6U^knda<Ff]<6n[<[<b<;4c<g7ckjc]KJ`
/;O?b<_GfmSLiNc:VWn9VXe`UHn;SiZX/;BfY9VNYZ>KUjJUZJZJQX>=TXUoNI6J
NYWTjn7Xk/jRZ<jn]ZbXZZb][;FRTI6JVHQfSGebLgAcNXIbGW=NS75mI7UeNH:1
MWElP8NBTh1]LH:FR7=ZNHj>Oi^SW9n^WHjQWj^ZVHb=S8JFRW=RJgenL7f6LVIf
M6QaK6e/IEYACTiDF5UDCTmGH4U>Ed0iBdYAETQG@4=3?T9<CDU7CUMID4IEC4E7
D5IEDEaPH5E8@TUB>dU=AdQACT8m>3e8BD94CEA:@dYGF4XjA493B51DDe11AT]:
AT=3AB/Z;34b<30b=cLh>CTh=cLh=odf3CLg>STh=cLi>c`e<c0^oReo;S<^:BX_
<BdY9BT^<S<`;2T/:RLU9RT^<CD_:RPV92HZ8R`h@43TNIR6R71_FUeLLgQNGg9^
OFiMF5eTIF=nNG=`LGIkOG9cLVi_LgEdIVETHfE[M7Y^K6][KG1aLGQ`M8>:PGQg
SY6BTI:=Mf1bMX>ASWefNVIfMG^:PXFWZjMoZkS6a;:OSiNGSXZ<QWZ1P8RFVYRQ
/:Fg_KjbR8BbTHjN_<JdVi2EY8N=S7f2G71OEEQMH6YgL7O4l/6U^knda<Ff]<6n
[<[<b<;4c<g7ckjc]KJ`/;O?b<_GfmSLiNc:VWn9VXe`UHn;SiZX/;BfY9VNYZ>K
UjJUZJZJQX>=TXUoNI6JNYWTjn7Xk/jRZ<jn]ZbXZZb][;FRTI6JVHQfSGebLgAc
NXIbGW=NS75mI7UeNH:1MWElP8NBTh1]LH:FR7=ZNHj>Oi^SW9n^WHjQWj^ZVHb=
S8JFRW=RJgenL7f6LVIfM6QaK6e/IEYACTiDF5UDCTmGH4U>Ed0iBdYAETQG@4=3
?T9<CDU7CUMID4IEC4E7D5IEDEaPH5E8@TUB>dU=AdQACT8m>3e8BD94CEA:@dYG
F4XjA493B51DDe11AT]:AT=3AB/Z;34b<30b=cLh>CTh=cLh=odf3CLg>STh=cLi
>c`e<c0^oRdU;S<^:BX_<BdY9BT^<S<`;2T/:RLU9RT^<CD_:RPV92HZ8R`h@405
dCoQM95nOVEUD61IJFiKHgMcOg1PFUiRGe^8OW5ZK79gNFidM6mbOH1lHVEVI65Q
IV]NGUmUK6m]JH1dLh26O71/oXAoPWieIeaaKW9hLVASK65^J6]lNX>ZXJ2U]<6l
YI2EUX]iLWUjM8j<TibJTI>NY[Fk_jemN:bRUIjmajb;OJ:/RHjAQi1]Jf=SJfeW
JG5hI9?If;Bba:Zj^ZZ[^kb]cLW6b<g=aKc3/jZ`]kNmam38b=;Hf>3/k^2lVI:I
RFbKU8eoSiZX/kVh/:RTXYnJUijNY:NJR8NBNhYeTYIbYNS[iNSVcK6gdm78_;Fc
/k:`]JJHVJ:RUHJ7O79/HUm^Q8ejNgNERX1UMgMmPGIWJWQlOHB:P75bOYB5L6Ul
U9B4TYbFWJnQU:VLXjJMS864S9f=Og]mMfIFIgiiM8R6L6m/KVaoIEaEE5I;BTU9
Bdi@DDQC;3Hg<5Q=AT15E5M:?ce9@Sm4CE19@EY:?3m@FeU@EeYID4E1Adm1D594
A55@@3Hg@4Q2=SM2B3dg@55HCd93@T=9D5=ACC<f=c@^:R``7QhX>Clj>Ch^<38c
<c8`;S4_;Rd];c4b=38_;Bha=CPb<BmY;Rh`<C<a:B<W<STg<RX[;Bh^;B`[9bHU
9BHX:R`g;R/^:b<S:BDY;2/XhGBAOWiUIE1PFFU^Ff=gLgm`H5YNHUmKR7iaJVab
MgU^M7A_LWf0O69UIVAQHFI[GUiOIFa_KFV0M7>0QWa`K?j4Oh9nMFMLLFibN79T
HfaQKVQ[O7Z3ZZ6PYKC1_:F@UIJ;NG9iNWB>S9>LVY6CWZJe^kn]OGR/XYFN_LN/
RgfR[8V>THN@KF]SHf]]IfUaN6BCfMRd//BZ^[ZZZk^l[Lg9a/S=cLFl`k>Z/;Ng
_LO@b<SBf=SPk>kP_9VBVHU/ViB=OhnJZ;>i^;2XY::OVYNNWZBWVXR7TW^:MI:F
LZGXjnGXi/fa]m?Ab;be/k>b/;FVV9VRXYF6QgabK69OKXB=NW]gUHZ0IGMgOH5f
IfYhO7f4RX1aLWjDQG1YO9BDQ9:LUYf_XIBYW:>VWHb1Q8bMSGmkOGMVEVMnNGB8
QW1_K6i/OfELEEAFBdY9BD]>D558Db`f=c1HCDI0AEAGBSlmBD8oA4e@BD5JBS`o
D5]ID5MJFE15@DM?@E1BA4AAD40f=d18@SHg@TPm=d1AF4m2@d93BE1CDDdc=SLd
;RX/<1hN:3To>STn;S0b<c<b<2ha;bh];Bla<S@b;bd^<CDh<S4_JBh^<34c<BTS
9c8i=c8Z:bd^;Rd/:bLV9BDV:2X/=bh[;R/S8bTU:B`[:>5dTGinIFE@H5UYKU]S
Mg=oL61JGV9OFhQnLFY/LWMiKWAdKg9mP7aRIFITHF5VJeiNGfE/KfeYP7AcP8Il
L6cnQ7n2OWEWG75^LWQbI6=/HFiXJgajPjZQX:Fd`KbUT9FFRgUbNGYdSXbCW9ZA
TijV]K^o[Geh[::EW[g7[8]mXZb9SY67T6e[Hf=[KFMYLGQTTmWH];;4Z[ZjZZ^k
_:g=bLK8cLg5_<>cZ[2g]kg7d<S8d]SHh>c^h;bITYV9K9^DSGn?VZRc^KR`Z:BR
WiZGWYjTYiZ8Qi9kRWFBUW:Uj>_Uj>K=/KOCdLRl]K>c/[2eYYRIXZ:EQXMlLVaR
Gfj4SGYkMiF:P6EgMgf1MVMZN7amQ8Z0LG9nU8E`JGbDU8BBW9JM[j6DZIbSYYf<
PHB<WHeoNgegIUIWOWUdR8I`Kfa^K7mUG5EDET]:BDU;CU1AB5</=SL`F4e6@4ED
EdXo?DU2?dA=D4U1FTXl?e1KFE1GFUU@AD57Cd5@DTA4DE10=SM0B48f=d98?CM0
DEQ?@T=2@dU@De5=<cHg=2hZ;30N7RPi?cXi?Rh`<S<c<S0^<Bl^;Bd_<C8d<Rl]
;S4e>38a;bT^;S0a<c4Y8bLb>CLb:R/];Rh];2/W9RDU9RPZ;3L^:bh[8b<Y9BT/
:bP5dgoKKHM`KeIF@UmCHVaRKWmdN6aPGF5TGeR3NFiZKG5aKgV0O6eZLW5WHfU^
Jf=LFeiDE5QRJfaTFh1aKG^4OW=`JV]^KfaXJFicKVmbJemOJVYfL760O8BZXYnR
[k^fXHfFUXUgM7n7QIfJWjFMSXZBY;6g_:MaK:FkWi^ha:R5MWnK/Y^QWiBVSHF1
QHj=Ph::QGj9_>?;//>O[[2SZKk4^;c0a/_6^k>a^Jj]^L2m_L?3_;o:d<kCg]CP
e[JWZj28X9ZEUijVZZZf^[R^Y:6RY9jOYZZNSHfILIEgSXia^??XjN;A_:n`^;Vf
/kBe/jbUVI^JUY2<Rhf?Q7]fJf=/OWm`JEIUHG5MEg1hPh=`GfUoOG=`MWMbM7eg
MFaSJgn8Q7j:RIF]YIfcWi2>UhmkNHNNPG9nP6aKFTaWI61kPW=bHV=RG5A@DEA7
@Ce4D5E?ATaE57J2;6A=A3TiADa5?Sm5?CHi@TM4?U15>ca7DeMGDU5>B4A3Ad]8
EeE0?Tm@?Wm2?3i9B3/b<cdn?d52ATY=BdU8Bdm>Ad4g=S8Y81/N8RdX;d14>cU2
<38e=cLe<S0`;BTU92@V9c0[9B8S:C4f;Rh];S0c=SPh;B@W<cXg<2h/:RLW:B/]
9BHY:b`[:bXg;B`d<B<O9bDX:BDPfff7L6mFET9ODf9/HVioM7Q/H7mMHFAOF8=i
KVY]LG5_NH1lKFYbLFMSJFi[HeaKGUADF69[K6AKP75]NhAnLg1ZJfi_K6QYKW=^
Kg9[GemZJWI`LH1lQ:ZRWj:_^kJQSIJFRGMdOhN5WIZOYIf>RY:T/KNlYg5/YK^O
VkS4Z8EfVk:KXInDYXf5PHF>SH>2RXEnRGnlhl^b`in^/:>Y_/Bh_<36blJk/k6i
[Zfi`;fm`l>l_l[@c]?Ne>3F]ZN[X8RPVYFGWZJZZ[Jj^:jTXJ:TWYnVZYj=SIUa
UGN>SW6hlnSYh]6l[k2h^KJc];Fc[:FIViZFT8b;SHn4NgI[HfanL6UFIF5aGEM`
N8>3L5mYOgecL7mfMg9dOGMeK6=[OhR4OXZ9UJfUWK>OT8jGSg]iQij1LWj0K5]J
C6MTH7^2Lg9RHf9LE51AE4M1?DA@EDm6C5DDMX8/I4e4>CU5C4Dn?dDm=SU2Ad@n
D4Dk?4MCEeMBDDi8A4=7BdQGED0nCe0n@S`nBDPk<S<m?Sm1@TI:CD]9B7m;Cdi7
@CLf<RTP6ahR;BP_@4@k>D8`<SDg=cDb<30]:BDT92HW<2/U8R<Y<CH^;Rd^<3<f
>3P]92Lc>SL`;R`Z9bLY:bdU9RT[;2/[:SL];3@a8alW9BPY9B3KKHM`KeIF@UmC
HVaRKWmdN6aPGF5TGeR3NFiZKG5aKgV0O6eZLWmaIf=YKV]SG5]NE5AHHV]/I5^0
LFekQ7icL6Y[KVm/J6U^Lfi_LV]OGfYZMW1aP7b4ZZ:OXZnk]Z6=UYJ9MgAoQhFM
VYnUWHj:TZBa]kbWLFbU^inK^<BXQGJK/Y^QWiBVSHF1QHj=Ph::QGj9_>?;//>O
[[2SZKk4^;c0a/_6^gnc/KV^[KW0_Kg3`kbob]3>dmkDh=JfYj^PR:2JUINNYZZZ
][Zh[ZBQXZBNWjJZWXf=VG6EMhj>LKScj>WRdKb_/;Ri][>d]K>/YIVKVYJ@S8^=
ShAkMV]SK7i`JEIUHG5MEg1hPh=`GfUoOG=`MWMbM7egMFaSJgn8Q7j:RIF]YGnM
/in@SYN?NgV7WX5bOX1/FeY<IfAPNh9cLV9SHUaDD55DAd4mA51ECdI<EAAfPRaT
CD@i>DE<AChoACdf>D97A3i@AC/lAe=GEe9ACTQ4@dM;B5ME@3i?D3i2?3i9B3/b
<cdn?d52ATY=BdU8Bdm>Ad4g=S8Y81/N8RdX;d14>dHi@S0b=CLg=C8`<2dY9B@T
9RL`:bDR8bTa=Rh^;Bh`<cHh>2dT9c<j=c0^;2XW9bT[;BDV:B//:b/Z=bd/=34S
7bLU:2TU80G>OnEeS7=aF5U6G4mOL6aiQ7=`IeiNI6MQFWYcK6ebLfeWKGMcI65[
Jf1YLWQeJEiJFeiNI6mhMVYNNV]XNHR8PX20OgiiKFE/NGMcMgehKVmjMH9mOX^2
QZRi/k:kalFdXXF7P7AgR9>CNWf:VYfGVZFQ[KBiXVUUX:b:QJc8^Z:I;HNb/Kne
XKBO[jJSYZ>NYK>GZI^]i]je_IZ[[ZB]am77/l7Be/Fb[[Jd[[?3bL3n^7nc]l?5
_Kc3/]?ObK[1_Zf]ZZRZ[JjYY;>n`[FWYJbaYjN][j6?SIQn[HRGUX7Eoo7eilVd
/:bT_;bn`;f`WY2=WJRLPgN2TZ6CRXR2MgImJg9DLEAjJ7QlRIVGOfelV8ikKG9j
OH><I75cIf9aQ8f6ShZ@XYB8W:>1MhnCNG1oW61^EVM_H61dFVYD?U9PFf1DEEE?
B4E8C4U0>dMIGeA5CePHc^4mKTaMA30`>D5=Fe57?d19D4m:A48n>ce7E5eLF5=@
DE=EETQHDSTfBT`iED@oC5E9=R/lB516=2lnD5=@oTdZB3lg>S/j=cDjA4e4>3M2
?c0^>3Pj?T10?SXh@3`f<2/Z:R/k=RhY:S8l@oh/Obha=CTkAST[:S4d;B@a;BLS
8RH[;RDX;C0a;b`Z=R`]>3DS7BDb=CHa:>EeS7=aF5U6G4mOL6aiQ7=`IeiNI6MQ
FWYcK6ebLfeWKGMcI65[Jf1YLWQeJEiJFeiNI6mhMVYNNV]XNHR8PX20OgiiKFE/
NGMcMgehKVmjMH9mOX^2EhJX^K>b^lO5]::5Qh1dMhRCTgYmRYZMUiZUXJfd^J9Y
IJ2/RXF/b;ZRVHNb/KneXKBO[jJSYZ>NYK>GZI^]i]je_IZ[[ZB]am77/l7Be/Fb
[[Jd[[?3bL3n^7nc]l?5_Kc3/]?ObK[1_Zf]ZZRZ[JjYY;>n`[FWYJbaYjN][j6?
SIQn[HRGUX7Eoo7eilVd/:bT_;bn`;f`WY2=WJRLPgN2TZ6CRXR2MgImJg9DLEAj
J7QlRIVGOfelV8ikKG9jOH><I75cIf9aQ8f6ShZ@XYB8W:>1MhnCNG1oW61^EVM_
H61dFVYD?U9PFf1DEEE?B4E8C4U0>dMIGeA5CePHc^4mKTaMA30`>D5=Fe57?d19
D4m:A48n>ce7E5eLF5=@DE=EETQHDSTfBT`iED@oC5E9=R/lB516=2lnD5=@oTdZ
B3lg>S/j=cDjA4e4>3M2?c0^>3Pj?T10?SXh@3`f<2/Z:R/k=RhY:S8l@oh/Obha
=CTkAST[:S4d;B@a;BLS8RH[;RDX;C0a;b`Z=R`]>3DS7BDb=CHa:>EeS7=aF5U6
G4mOL6aiQ7=`IeiNI6MQFWYcK6ebLfeWKGMcI65[Jf1YLWQeJEiJFeiNI6mhMVYN
NV]XNHR8PX20OgiiKFE/NGMcMgehKVmjMH9mOX^2EhJX^K>b^lO5]::5Qh1dMhRC
TgYmRYZMUiZUXJfd^J9YIJ2/RXF/b;ZRVHNb/KneXKBO[jJSYZ>NYK>GZI^]i]je
_IZ[[ZB]am77/l7Be/Fb[[Jd[[?3bL3n^7nc]l?5_Kc3/]?ObK[1_Zf]ZZRZ[JjY
Y;>n`[FWYJbaYjN][j6?SIQn[HRGUX7Eoo7eilVd/:bT_;bn`;f`WY2=WJRLPgN2
TZ6CRXR2MgImJg9DLEAjJ7QlRIVGOfelV8ikKG9jOH><I75cIf9aQ8f6ShZ@XYB8
W:>1MhnCNG1oW61^EVM_H61dFVYD?U9PFf1DEEE?B4E8C4U0>dMIGeA5CePHc^4m
KTaMA30`>D5=Fe57?d19D4m:A48n>ce7E5eLF5=@DE=EETQHDSTfBT`iED@oC5E9
=R/lB516=2lnD5=@oTdZB3lg>S/j=cDjA4e4>3M2?c0^>3Pj?T10?SXh@3`f<2/Z
:R/k=RhY:S8l@oh/:Bha=CTkAST[:S4d;B@a;BLS8RH[;RDX;C0a;b`Z=R`]>3DS
7BDb=CHa:0FoOmQ_L7EPJeiGDeEHGF=XJfiUIVANG6MmSgN8TX^2OG9UJ6Y[JVMQ
G5Q;DFASNF6>EF]bNGMXGFEdL6]WJgAoQXR9ViZ0KWN8SUn0V91jKV]ZKW]cJg1Z
NJN]Nj6ma<FJRhf6OGYlOgmmSWRO/WYXT:>HZJf`ZXAjX:>FVK2n[i9nOijBV:b[
WZk@XY^MZ:^VZ;6^YY^Q`][5WZ:X[k2`];k8^/JfZ;6]Zl6i]Ko@ckjja=7;`[^h
^Kg1c/k@d/o2/:>[[:nb]KNh^<70_KVf/Zn^Y:2V[J69QI5aSUf@RLKTk=C[hJj7
R96>VYnLV:>_XXN@U9NAQGQ`KGecK71jOWI[EgM^KG9/IGB>KF5nR6imRV=ZS6f1
N5j=PFEPIW1_L8RXQ7]oSi66Q8n:UYfCPWj>XGQ]KWQdGeEIBcT_>deCC4EBBde?
@RlcAT`T>X62A3a`EE58?3@f@D_n>g@l?T12@dm1=ce=EDi3>Sm6C4i=BDI;BTQ7
BDa@DeI<A4=2@498<5aI<DB2P4IICClj?T92?dQ0C69I>cI9=S<]9B<Z>DDg=C8`
;bla<R4Z=chl=BhZ=BhY;CLk=2`f;blf=2TU:bL[;Rd/;SDk;2l`;RXX:B_i9glP
<3Pc;c8`:2<V:R/Y8a`G8RHY:b[HKg1eH6]NEe=EF5eSJ6]^IFITGUaWOHmgR9:;
PWebIFQZJfYWHEaHBe5THgUQSUE[LWUgJ5eUM71[If]dOhJ8RI^JP6igR8iOP9R@
NVi[JVikLf]`JWVW[G^Q_LC5VX^=QWejO7moOHihWgnbNVR@XiRY[K2ZQ7ZPXiJI
/;j_TWjNTYR/Zij^d::KWJR[YZRa[ZJKXL;JaIjRZ:n`/;Bnb;[6]ZRa[J_1^KFo
d<nn^/CAbl:k^;Vm`Lk>d=;?`[2SZjb_/[Fg^;S1`;fi][:_[ZBPYZfQRHFALHiM
T8W6i>cDjn6^QhRASYZOW6bHXjnRQi2DUi65N71]OG=/L7YnMV]gKVebK6EdSVeQ
OXQ^OHYSJXa]PGQNSH5UH6I`Kg28Z8AkOhnAQXB?RYJMTh9nSZ5hKFihM5mEFD/i
;c]=Dda5DT]=Cd8_<dI<93Z1PT@lL5EAB3`d=T5;oS]d?3i0@T=?@CLmCEE>@cXo
ATa>CDU6BdY8AdU<D5=FC4A3@T12B31LFC54PX16FDdo>Si2@Sm8@4aRFC/fBCHc
;BDS:SU5=cDb<2l_<C8Q:SLn?3D^:SD^:Bdg>c@/=Rl_=S@Y9B/W:bh];2he>b`_
<2hZ:2T[nBMo830h<blb<2PS9RX[:B<L5b8V:B/Zf6m`MF1[GUMCEEQMHfQ[KVEV
I5iLIgf?MhRBRh9mLVEXJV]ZIf5LF4]AI6=iHHiEJg9iMfQMIGA`JfM[M7n6R8VK
VX1^MhR>Gh2HT7Y^JfY^Ng=[L6YiYjekXKg4aIZ;SHImNWaoOgf>N9mo/WYXT:>H
ZJf`ZXAjX:>FVK2n[i9nWY:H[:^N[]2RVifXZjJX/JjVVj72f/FNXZR_/;2d_/Rj
a[JX/Jf[`KVe_m3?_[[4dL_2^kRi_L7>c]3Bcl:`Xj^/[k:e]kRh`L2m^KJb[jjT
X:J]XHV5TG6>GI29a^C/e>_Q[XN8THjJWia/V:>_XXN@U9NAQGQ`KGecK71jOWI[
Mfi]LVaUM8i]HGj8KWf:HfZ<KH5hGXf1IF1VL6m`R:R4Ngn?THJ4ShZFWI>2OXjQ
N6e^N7AOEEU;>BlkCE=<AE9;CDm2;c=6C2@jPH94?71EDDPl=3I1BohkM3`n@493
Cd4g?DeECT<j?dI<CTe9AT]:B4M9C51CETa4@d90@TP`G5TaA8:0AUU=?cXn@T8o
B41<HUTk=TTf<bdU8bXiACLe<S0_;c4b8BXg?S`e;RXe;RT]=c/d;3H_;cHd:BD[
9b/^;B`^=C//;c0^:RPY:oTW520`>3<_<S0X8bHZ:bTS71LR9RT[:PG>OmUeOH5W
K5iIIFEVIfQYJVYYIfARIW:4TFUkQhB0P7Y`N7YlOWejMgAjLh1lOe64HW=cMWQh
MWUmJf]/KWAmQhjCX9j:OHB=SVn1QgMVIF]^Df]cNXIlPZRZNZ6k`<NWXX=nNg]n
OgahTIFPSV]bU9nS/kFg[XMkX9^>TJRfYhUeA9ZDX[VgYZg7XY^LYJNQXZ^WZ:BU
^]?Eaj:V[KFj^kVf[;^^Y;6`/<Nk^;o=c;fh_jna][c4bm7DclJi[J6CPgRPYJfe
^ofnOkfk^;Fc/JnOW:2VVhJ1Rh:KJI>?aNG[gN?>Y9:MWi>9UYZCU9jMTY6EV9:6
NW9_JF]fRYbNTH:;RHf@OfMRKF=VN7mkSIN5IgeMK6IAMfU/Jg9mO7Z=YiR<R8f9
O7Z3Y9AmJfQfS9e/I6=WG4M0ATXn>DABDD8dAcXh@dQ3Ae8SOaXYADH_;D5<Aclj
>3Tj>Shk=c@d=c/n?cln?Sm2ADM1@dE8B4I4@UMHF5ICCTY7BD4l?D14Ad]8>cI1
BdU0>d0m>d18BdQ2=TA?CDM6A44m>cH^:Rdh@C0_;Rd/;2/[=CTn@D4n?C`N9Bdb
<Bh[:CD/;38a:BT`:B`]:bPX;C8fOcHd;b/Y:BXZ:2HU9BHX:R@c>C4/;BXR;c0b
<S0]:BLZ:bXU7mUeOH5WK5iIIFEVIfQYJVYYIfARIW:4TFUkQhB0P7Y`N7YlOWej
MgAjLh1lOe64HW=cMWQhMWUmJf]/KWAmQhjCX9j:OHB=SVn1QgMVIF]^Df]cNXIl
PZRZNZ6kJ<37Yj:3OW]kOWmlN96EX8i[LYBOXk>e]jj7Nj2KSY6X]ZN9MIZDX[Vg
YZg7XY^LYJNQXZ^WZ:BU^]?Eaj:V[KFj^kVf[;^^Y;6`/<Nk^;o=c;fh_jna][c4
bm7DclJi[J6CPgRPYJfe^ofnOkfk^;Fc/JnOW:2VVhJ1Rh:KJI>?aNG[gN?>Y9:M
Wi>9UYZCU9jMTY6EV9:6NW9_JF]fRYbNTH:;RHf@OfMRKF=VN7mkSIN5IgeMK6IA
MfU/Jg9mO7Z=YiR<R8f9O7Z3Y9AmJfQfS9e/I6=WG4M0ATXn>DABDD8dAcXh@dQ3
Ae8SOaXYADH_;D5<Aclj>3Tj>Shk=c@d=c/n?cln?Sm2ADM1@dE8B4I4@UMHF5IC
CTY7BD4l?D14Ad]8>cI1BdU0>d0m>d18BdQ2=TA?CDM6A44m>cH^:Rdh@C0_;Rd/
;2/[=CTn@D4n?C`N9Bdb<Bh[:CD/;38a:BT`:B`]:bPX;C8fOcHd;b/Y:BXZ:2HU
9BHX:R@c>C4/;BXR;c0b<S0]:BLZ:bXU7mUeOH5WK5iIIFEVIfQYJVYYIfARIW:4
TFUkQhB0P7Y`N7YlOWejMgAjLh1lOe64HW=cMWQhMWUmJf]/KWAmQhjCX9j:OHB=
SVn1QgMVIF]^Df]cNXIlPZRZNZ6kJ<37Yj:3OW]kOWmlN96EX8i[LYBOXk>e]jj7
Nj2KSY6X]ZN9MIZDX[VgYZg7XY^LYJNQXZ^WZ:BU^]?Eaj:V[KFj^kVf[;^^Y;6`
/<Nk^;o=c;fh_jna][c4bm7DclJi[J6CPgRPYJfe^ofnOkfk^;Fc/JnOW:2VVhJ1
Rh:KJI>?aNG[gN?>Y9:MWi>9UYZCU9jMTY6EV9:6NW9_JF]fRYbNTH:;RHf@OfMR
KF=VN7mkSIN5IgeMK6IAMfU/Jg9mO7Z=YiR<R8f9O7Z3Y9AmJfQfS9e/I6=WG4M0
ATXn>DABDD8dAcXh@dQ3Ae8SOaXYADH_;D5<Aclj>3Tj>Shk=c@d=c/n?cln?Sm2
ADM1@dE8B4I4@UMHF5ICCTY7BD4l?D14Ad]8>cI1BdU0>d0m>d18BdQ2=TA?CDM6
A44m>cH^:Rdh@C0_;Rd/;2/[=CTn@D4n?C`N9Bdb<Bh[:CD/;38a:BT`:B`]:bPX
;C8f8cHd;b/Y:BXZ:2HU9BHX:R@c>C4/;BXR;c0b<S0]:BLZ:bXU7`GCOmaoRhaZ
JUmMJ6QYJVY[K6a`JfIXLh2:ShRIYJ:PXj2GOh64QXN7QXF?Qi64NTZBRGEaKFmf
NWI_JG1eMGAiQY:IWY^@Rhj<QHN?RgU/JfYTE6]bNhV1QZZPMInf^<6Z[iFBSXj?
S8AnQ:BAHEeeQY6V][Nh[XEiWIV>TJVfYXIbOiJH[<C1[:^lZ:2PZ:VQXJVRZjjZ
/LWQk;2[ZkBn_[6TWk2WXK>e]lnn^l;?d/W6bLO8bLS4_[RdZIb:O7A_JfNVZk:i
_Kjm_;Rh]kJe];>cZZNY[::BSI9eSV^CX=7ko^gP_ijKYib2S9bRUX^?Ui^DVIbG
RgmgM5eQKX:EVi>9OinOX9^5K6AZHgUfL8:9PhQjOemWIeabI71aN81nOH^NXYN?
SXIjMgb>Og5bO7icIW5]JfIE@T19?c`oBUIE@RiF@S@j@d=0@C=9D4=2DUE9BdM3
@T91?CU8@c`f=3Hj?S4lA3lb;cY8ATA2@3lo@45=Ce5ACD@l=TI1>STnA4E3Oe@i
=U5F?2li<3@mB4m>ACd[B4hi=de?>cdm>cD^;S<i<34b<S4_;2/i=cHf=cTl?A8S
=CXb:RX^=b`Y;RdW:S@[;BdZ92<W:c/g<2/W9RLX;R/U8R8U:bhY=SXa:R/X83Dd
<S4`<C8c92HY;2oLOh^<JVYOGFQXJFYZJfa/L6]VOfQcP8Z?R9VUXZ2SX9MoPHB6
QhN6QHn7THAjBY:9MG5]KgIjMVmYL7EeM7V6TYVNVi2;SXb5Qhn;NFa[JVADJg9k
RH66ZZ1eWkJh`JZ_UI:>SXn<Q7j4Y95QGGF6TJJf]kR^QGVMVHjAZKJVQW:FV:c4
`Jb[_:RPX:RYXJ6YXZ^^OjZabN7//:^[];jn/JBO/:NQ/kFgckjk`/oBbLK9alS9
b<Bn^;BYW8YlM6m[IjJ[/[Vm_[fl^;Rg][Fd/k>ZYjV/XY:=TWF>Ji>PdO_nkN2o
WY^WW8:<W::FRhnGViBIW9N;OgMdGF5^PYFKThVOWj2KQFaTJV=iMW22RH>8NWmO
OfMWG79TL75hP7imRijRUhn>QWYgO8ioLG9lOW=VLFe[IUE2@4To?3m:EUE2;UI2
=3Y3@d11<dU@@d9BEDU;Ad=2@T4m>DQ3?3Hd=SXn<Ca4?c8_>TQ6A490?cm0@De?
DE5=A3`fAT4j>Ci4AD=D>CIAES`_>C0d?DQ?CTDm:dQ>OcTgCDlk?Cdk=Bh^<cT`
<C8b<Bl/:cTg=SHg>C`m4R<e>S8Z:Rhg;2T^;BLZ=2/];BXT8bL[>cL`:bLV9bP^
:bDR8RD[;RTf>S4Z:bPP=C@b<C0a<S<T9RT/;maoRhaZJUmMJ6QYJVY[K6a`JfIX
Lh2:ShRIYJ:PXj2GOh64QXN7OhJ5ShNAQ7Y:TXUeLFe_MWYfKfU`MGEdNHJBVIjK
T8^>S8F7Sh]iK6]ZI5A[LW^9PHJZX7FO][S1ZZnETXj>Shb4OXBTTF5MMHJAY[Jg
^:j5NIfISY6Y]ZJ6LYJH[<C1[:^lZ:2PZ:VQXJVRZjjZ/LWQk;2[ZkBn_[6TWk2W
XK>eOkO?_[_2cm;9a/W7b<W8a;jh]:VLRWadKf]WYZ^b^Kfn_Kbh^;Nf]KBc/jZW
ZJbRTXfBMHi[Tj3Anok]h;nNVjNLPXbLXYJ;SiNKU9VLUh]oMgAMHFj2UI^CRInO
X9^5K6AZHgUfL8:9PhQjOemWIeabI71aN81nOH^NXYN?SXIjOgMlSWmaLWanLfIa
KF]VED90BCll?dYFED8^ET8d>T=3@44cBE13@U9EBD]7@d92@CdiB4<l=S@f>Sha
?4@o<RljB4I4@T0o?d11CDmADDe4?3I6@CXi?TA5@e@i=U5F?2li<3@mB4m>ACd[
B4hi=de?>cdm>cD^;S<i<34b<S4_AR`[>CLf=SLi?3dB8cDj<RXZ;SL/:Bh]9bXd
:bd]:R@S9b/k=c0[9bHW:2h[9B8R9B/^:CHj<BX[:20e=38a<34b<b@V:B`_1LDT
hhN@Rf=SGVAKGF1TJ6a_LGU`JVmlQXN5QIBKU8nAShN:Rhb>S_j?Ogj>VWUdK=C?
NWeiL6iaKFE`NX9nM7B0SYFCT8nBT8AgO8R?SXj=OfebNg1[MW9nYiQcX[Vc]YjS
[ZJMUiFARXEiWX9OMWegTIf]/;6YPGJKXYNL]<2_SWRFW:o1_Jf[]k6YZ:n]YJB[
YJb_[:jne^O?_J^Y/[J/X:2bZjNi^kgD6l71am?KfmWHg=K:^ZNEQgn0NWAgPXnI
W/;0_K[n^02io[Gl]TV_[Zf[Y9ZDU76;N9ZacOG[c<6ZVZ6/WX>TZZVMTI6JXI^O
XijCQh1mMg1ZK7EoPh>LVI>8NWJ0SWNKR7F=PVEcR7aTIFe_M6YaL?ia9gF3TIVF
U9>=Q7elOGMeOHEmHd]`LW5VEDQ;E3@h?4ABFDdjDTDh=CSn>Gl_B4hl>Da>?DE8
BD<j=ca3DDm<B4E2@D4c?48l<2df@T=0?3Ti?D96@dA5ADA1?Sa?Bd8j?TE0=D18
BdaBEd`j=3U2BDa7?cPgADHh>4M:?cDh>SHa;c4e=cTk?3/h=C8d<S0a=CLg=B<]
>Cdj=SLj?C0Y:bTS9c4Z;2dZ9RHZ;dTe;bLT9BLY:38]9B0P9Bdb:SHk<R`_;bP`
;BTV9RX_<b@W;CI0hhN@Rf=SGVAKGF1TJ6a_LGU`JVmlQXN5QIBKU8nAShN:Rhb>
S_j?Ogj>VWUdK=C?NWeiL6iaKFE`NX9nM7B0SYFCT8nBT8AgO8R?SXj=OfebNg1[
MW9nYiQcX[Vc]YjS[ZJMUiFARXEiWX9OMWegTIf]/;6YPGJKXYNL]<2_SWRFW:o1
_Jf[]k6YZ:n]YJB[YJb_[:jne^O?_J^Y/[J/X:2bZjNi^kgD6l71am?KfmWHg=K:
^ZNEQgn0NWAgPXnIW/;0_K[n^02io[Gl]TV_[Zf[Y9ZDU76;N9ZacOG[c<6ZVZ6/
WX>TZZVMTI6JXI^OXijCQh1mMg1ZK7EoPh>LVI>8NWJ0SWNKR7F=PVEcR7aTIFe_
M6YaL?ia9gF3TIVFU9>=Q7elOGMeOHEmHd]`LW5VEDQ;E3@h?4ABFDdjDTDh=CSn
>Gl_B4hl>Da>?DE8BD<j=ca3DDm<B4E2@D4c?48l<2df@T=0?3Ti?D96@dA5ADA1
?Sa?Bd8j?TE0=D18BdaBEd`j=3U2BDa7?cPgADHh>4M:?cDh>SHa;c4e=cTk?3/h
=C8d<S0a=CLg=B<]>Cdj=SLj?C0Y:bTS9c4Z;2dZ9RHZ;dTe;bLT9BLY:38]9B0P
9Bdb:SHk<R`_;bP`;BTV9RX_<b@W;CI0hhN@Rf=SGVAKGF1TJ6a_LGU`JVmlQXN5
QIBKU8nAShN:Rhb>S_j?Ogj>VWUdK=C?NWeiL6iaKFE`NX9nM7B0SYFCT8nBT8Ag
O8R?SXj=OfebNg1[MW9nYiQcX[Vc]YjS[ZJMUiFARXEiWX9OMWegTIf]/;6YPGJK
XYNL]<2_SWRFW:o1_Jf[]k6YZ:n]YJB[YJb_[:jne^O?_J^Y/[J/X:2bZjNi^kgD
6l71am?KfmWHg=K:^ZNEQgn0NWAgPXnIW/;0_K[n^02io[Gl]TV_[Zf[Y9ZDU76;
N9ZacOG[c<6ZVZ6/WX>TZZVMTI6JXI^OXijCQh1mMg1ZK7EoPh>LVI>8NWJ0SWNK
R7F=PVEcR7aTIFe_M6YaL?ia9gF3TIVFU9>=Q7elOGMeOHEmHd]`LW5VEDQ;E3@h
?4ABFDdjDTDh=CSn>Gl_B4hl>Da>?DE8BD<j=ca3DDm<B4E2@D4c?48l<2df@T=0
?3Ti?D96@dA5ADA1?Sa?Bd8j?TE0=D18BdaBEd`j=3U2BDa7?cPgADHh>4M:?cDh
>SHa;c4e=cTk?3/h=C8d<S0a=CLg=B<]>Cdj=SLj?C0Y:bTS9c4Z;2dZ9RHZ;b@e
;bLT9BLY:38]9B0P9Bdb:SHk<R`_;bP`;BTV9RX_<b@W;CI01L]ojHR;PUQMGVQM
GV5TJ6]^KgefLWN1QH5jP8fBRXF:RhFMW9^JVIRHVF^EXVedV?ojNXbAP7=fNgUk
QH^4Mg5jQI69Qi2FT81dIg=mQ8nHT7miOViVLF]bUiYi[<Bk]96@Z9jCS8b?Shie
RGf3X8IbViFVZk2ZQGbRZ9fS^lNdTGYoV9n/]K6Z[[ZbZZR_[J>RZK2/ZZfb]kg4
jm:cXJ2WZjb]_kNb`/70eL[:blkEfMC;]jnSUX^5PX:9RY6Q]lcIg]S@a;Ve^;k3
][Jg]kRi^[ZXZ:BMVIJ?RHVPUZBg/<Z/SY:DVJB]YYR]YIjLVifRZ:2UZ:FJShR5
TXUmMWEiOGmoOhB5OWZ2U:1nYIJ4VXYXLG]UFeIRL6ERM7=/I6EaPH^=TiRGTXUm
Lhn5Mf]VIVQYFUmOEDY7BThm@Shi@e=A@Rle=c<b>DE=<CQ1AD8l>cdlATTk:2Di
Cde@DeAABd@o@Sdh=cPj>3Dm>CHe>3m8CUA@BDA3ADY=CTi4>d=@BCH:=C]2B4e>
ASdi?D7lA7m@?cY5ACTjB38g>c/i=cXn?3`m?C`j>3Lf=3Dk@T8j<c/e<3<k@D0m
@S@/:bLN8BXX:bh]:b`c>C4[9BL^=3@b<bhV8B4V;S<W=3Tb<3Hi=BdY8b0P9B``
<S4c>dCYR8^2F5eNJ5eNHFAXJfi_OGIbMh65PGZ0SI::QHZ;QIfLVgnJVIRHVF^E
XVedV?ojNXbAP7=fNgUkQH^4Mg5jQI69Qi2FT81dIg=mQ8nHT7miOViVLF]bUiYi
[<Bk]96@Z9jCS8b?ShieRGf3X8IbViFVZk2ZQGbRZ9fS^lNdTGZHWjbe/JZ^^[:Z
Z:n]Xj:Y/:bZ[K:g_LC[d[>QX:N[[:fo]gnb`/70eL[:blkEfMC;]jnSUX^5PX:9
RY6Q]lcIg]S@a;Ve^;k3][Jg]kRi^[ZXZ:BMVIJ?RHVPUZBg/<Z/SY:DVJB]YYR]
YIjLVifRZ:2UZ:FJShR5TXUmMWEiOGmoQ8EnNX:DX7jUUXBJRVQaNfEKEV9`IF9d
LfaTIG61RhfCV6NGTXUmLhn5Mf]VIVQYFUmOEDY7BThm@Shi@e=A@Rle=c<b>DE=
<CQ1AD8l>cdlATTk:2DiCde@DeAABd@o@Sdh=cPj>3Dm>CHe>3m8CUA@BDA3ADY=
CTi4>d=@BCHe>d98CDi6?CTm@Oa4Oe0o>TE5>CY8<SLk>cTg>Shl?3dm?3Xh=cHd
=C]2@SXc>cD`<c]1@3e2=2`[9ahQ:RP[;Rd[;3<i<B/U9bhd=38c;RHQ8BH^<bLd
>C8`=STe;BTS820U;30b<C<kA>V8Rh9HGEiXGEiQI6Q[KVmmMW9gPHF1NX2=TXZ5
RX^5WIbKOiZIV9RIJiFRKGBHooYjS960LgIkNG^5RhAgLGZ5THV7T9J@P7AWLgf4
SiR@OgUnKVIaJg:GVWV/a;^dTI2XWY><S8n?SWF9OH>PQW:KUJJ[/:Z5O::XWJ>k
akBANYRO[;FaZZjj/ZZX[jfSXZV`[:Z]/[Nma>_B/j6PYj^/[KngOk;2`L3Eb/[;
c]GIe<^g[j>FRhF2PXV:TJ6gc=WNf=34^KFh_/>f][Ng^;Vj^ZRXY9fIUXn9RJ2F
Y;N`bZb>TYBIY:fVV:fUWYbKWJ:XX:FXYIZ?R8FBRGefMGUmOgn4QGijPYBPOZFF
Q9Z:J75kIE]FHW1UHWAcK6AULH6;SI>HIiNBRGecShEgJfIVJ6UJGemEBTM:CSe2
?SU3De52;cDg<c8iADda>455@S`k?Ca6BC/X9CU?CE1CE55;A3m2?CPg>3Xh=Cdi
=SDh?dQ>E519A4=5BTe>CT@k@e19=SDk@TQ=CTHm>Ce1o4ALD3ljADDi>TPb=c/k
>CLj?S`l?Cdl>SPg=S@e>d92>S<k=C0c>d50?D8d;2/W7R4Z:2/^;B//<cTa:bDW
;S@d<S<^9R4Q9Rhc9c@i<S0f>CD]:B<P82D/<38a<c]41M1ojXF4OEUOGF=/K6]Z
JVUXJ7YjO8:6QX1kP8fBS8^EVYRKVIJCTY:CU6N<UfIcTOOCIX>?OG1kQhN4RXf7
OGMjOh^3Q9:HSX5lPH9hJf]dM6aSL6ebP7A^RIej[LW4_9:9W9F?SiJMXJ5ZK7JC
WWeaTINY[kFaSHF/YI^R^/JaSGEgVJ6Z[JZZ];n_YZF/ZZ6PYkZ]Z;6h]:j^im_4
Zi^N[Kbjc<Bmb/K1eM7@b<74akf[[JRQVi^PYZ^ZZk6mc][Ph=gEbKnm`/_B^[Zk
^kbl_Kfa/Z^PWZ6JSXNKWInkX;^DSI:IWYnKThbMTXjFW9jT[YnTZ:FKT8Z7oXEo
Ph1kMG5XO8^:QhfBTV^4QH2<RWYhMEYSEV1eFf5gN71UJ7V6RHF?U8j8PgIWO821
NFYPH6=>E5=<C59ABE5DAc<dAdTk<D17>c8f?d=8?dQLFTE3EDUADT<`;dIM@4A9
C4]7@Si??c0b?d@i:cTg=CHk@d]AGUI9?cXl@TLo@cio>4QNFD1@;cAKFc<^CSHj
?d52Ae1GEcXdBT`e<dLg?410?Sm3B3dk>3He=SLh<Rh_=Sm0=B]1=2LX<c`k=Chb
;2dX7QhW9bX^;Rd_=S`b;BXa?D<o>C4^:2DU:2ha9C8f<2hg?CX`;2LS8bH[;Rd]
=4EGjXF4OEUOGF=/K6]ZJVUoJ6QjNWb2QXJ0Nh2=TXb;UIZHViVFTi:BTiAWS9MV
Li7gdfJ3Sge`NhN7Q8Z=QgegNWn;PhBBV8j1O862N6][M7A/Hg1]LX1dKXVMNZg9
a;bBRIbEShnFWJ6QJVafTiimLI6GZJne/Hf5[:FKX[[6/HeeVJ6Z[JZZ];n_YZF/
ZZ5YX:Nj[JRa^;B^[^OKa:^KWZfl^/c4_L[6`MGAd<S1a<NmZjfXXI^KX:J[ZZ^a
_LkJh>3MeLVo_L;;d[Zj^k^l_;fm/K:[X9jQVXj7VifO^j2kU8fBVIjOVi><WI:>
UYbNY:jOY:RUVi2:Qoj5Oh>0NgEaJ7b;RXN=TY9[Q8F0S8YjN7EJHeIPME]QMgQ`
IFQiQXV5SiB>R8=fIgb0PGUZH61SCUACC4aBDDUAE4Lc=4M9>c50Ac/b=Sm3B3m8
G5Y5@eE9DE93<2m6GD14BDa;Ad8nCcl`<Sm4>B/i=cDf>d=;DEiFBClj?497?d<n
OcQ8GUU0D2ldFe/c;Thf>Sm1@TM@EeLj=4Y<=C=7=ca0@3ho@dPm>cPf=CHg>38^
;cHo@3D[@C@W:3<l>cDn<R`]:1hN9bLZ;Rh];cHl<RdZ<Ce3?cTa;RPU9BP^<BDb
=S0^=cdj<2`W8b<V:bh];CA5EnZ5Q7eIGeeSK6a[JVYYOfQXNWYlPXJ6P7^0SI:<
RiFJV9^IUY>BTY>DIhbGIW>Amm=VPhmmL7^7QhB:SHMmMgYoRh>4TYR>PGb1PWQ[
JgAdK6=`KG:0M6j9WGZ]bLBlTXVLUHn?UYfQXFY/MY>NOG6AUjV_]K6=QJbUVj:j
a[6=MIVQZZfZZ[Bo[jJU[:ZQJJ2W^ZfX/KRd[ZkWflB[Vij]_;[<a;g:a/7EdM38
`LC7_J^]Z:6KVj2VZjZ[/Kg>f^3PgMG9_kg2bm:j^[^k_;bm_K6bZj2NXIZ>Qi^M
Wk^P^iB=TYVNWi^CS9fBSYJLWZB^WjBXYI^@RXOnQGn3P7]eLFQlRhZ7SI:BJhB5
P8b:NWQeFV=FH7EKHGMhL6EXNHJ9QHnDSXR3MVMlP85iJV1PHdiDDda<DU59DEA7
<cA7BC/a@4Lk<SHo@dPoB5aJAD=EBE5B@c0_AUe0A4U<BdM2?Tlo<38oA3T[>CLe
=S]3Be5NETTo>Sa2Acm3?W4hB5iI@50_=5]K<bi>=SXo@D97D5MG>SA:C3DcAcLl
@40n?d=8?C/h=SDf=cPb;Rlf?d0e:d4d9bPc?3/e?S8/;BPN7RLW:Rh^;Blf?38]
:S4m@cli<BhX9BDX;S4U<SH`;SLm>S0/9b<S9R/^;BddAEL5bgoUOh:3IV]MF6]Z
JFQWIVETLGZ6SHj;RHU^NG]cLG^2PHj<RXV9S92BPX6;OhU_[h]RNh9bKh:9OhJ7
QhJ4PX20OgMlS923OH6;SH=_IVY[IVA`K7:4NG:;TVRG^;k0VHjGUYRNYJJRW6e[
PXilNHJ7Vjba]K2;PZVTVj:ka[2;LTNFXjj_[K:k`[B/Zk>bZZVa_Jn/^;be/k_5
dmW7ZZ2`a[oAbL;?bL;Ebl[0]K[2]Z73`Knn_l;6b<>o_L38c]3?hMgFcl_;c<km
`?joOkk0`[V[Zk:[VWj>UY2jWLFN[:FOWYbDRhFDT9BKUHfGZiVNXj2FS8F3Ngal
N7=_KFeaR9F?RY6ETG]iPX1ePX]hNemhHfMlEVA]MGE^M8>7OWEoOgAcNWM/HW1o
PWIRDTUDF5E@FFAKAUAKCC8`@dHfB5ADACdo>Bdk=CU2@3PnOdeACdY4@D=;DS/j
>S/m@DE8Ccl`<Ce1=RLk>SXk?TA9CE9=A3dj>ci1=Cdi<dMSG3mE?T1IESXhDCTo
ADM6B51HA3/g?D=0>cXj?3dj=cLl@TA0>C<b=S/o=RdW:cHk=2`g<bh];S0`;c8Z
:2h]8b<Z:2/^;2TZ<3D_:RXc@4<jObl^;B/Y:B/];R@`<bXX<3Dc<2dY9B@U9RPQ
8c1:InEoPX=VJeeHJfYYJ6MVIFAaNXJ=SX^9RFiiNg=aNh:1SXb:RHV<T9:2PH]o
RFn_Rf9kPW9_PXUoQXN7QXB2P81oMgb<T8=mPH^=PfmVJV]VI71/LXAiLX^BJ9Nh
_/2ISYNFIIRNYJJRW6e[PXilNHJ7Vjba]K2;PZVTVj:ka[2;LYJS[Zn]/[_2]:b[
/k:ZZK6m[jbh_;Fc^lGCfLNZX;36_m79`/o9`]G;b/2e^/:fXL?1_kjo`/K8`knm
`<S>d<oQgMK?bl_<c_g0o[mo_/32^J^[/Z^JOXjFT;ZMaIj/YInNW9B;QIB@U9^E
SIN[VIjSX9J<QH=kO7ahLfm]KG68UHn:TIFANgV2P7F2RgQkGgQSIgaFI6eeMFid
PhMnMGmoM7=jMfaRL7n2MV9BBEAHEE1II5]6E5]=<S13ASI8E5A5?Cli;C/e>D90
>3ioCE5?BTA1@d]B>cXj>ce1ADQ??c0a?D4f9c/j>S/nA4U=DTe4?CXk?T4e?CTc
Af=L?eDn@5UF>SQA>Cm5AdI8D5Q4>cLm@d0k>SXl?CXg=ca2A40i<c8f>clf;BL[
=S/d;3Lc;Rd^<30_<RXX;RdS8bXX:bh/:BX`=BlZ:S=0@cYo;bh]:bTY:bd^930c
:RP`=C<`;BTU92DV:24S<4YWiGn2PfI[GEQ[JVUXIfIUI75jQXf>RhV9KWUkLg5k
PX6>S8Z9RHb@TX:1Rgn9Kjn;HW^2LVn2RGn6QhN6Q8:0P7mgO8b@Pgf1Rhf3KfIZ
JfITL6abQ7UbRi9XUkRn`9V>UiIUV9jUYZ:LKF^2SWaiQXNK[;6e/8^2ZJBKX[_6
/8]bUZ>^[jfb^l:d[:^c/ZZY/Kf_[;Rl]K>kaM?IajZP/<JodLW2clW2eL_:`;Fj
`[JQ`l6o_[o2a/S3_kg0b<k@cn7Me/o;blc>oL3n_gnn`<:iZj^bZiYnSYJ@^Yg5
WZbUWijLU8^5U92DViF=Uj^IWZ>PUXb5Pg]lO7QcKfe]LHREShZAUI5kNH:0MH:;
N7]ON6=WO5ITKGEeKWB3QgieOgmdLgYgK69`Oh9fHU99E5QED5UTFdIDFddb<4=6
=TQDE4Dm?cT]>cDi@T0h?Wm=DDm:A453Be8k>SXk?D55B4lo<34m@CHW>cXj>ci4
BDeBCD@m>S/n@CDm>C=7He`oECi0FEHj>54i?dE7ATQ@F4@k=ce3@3/j>S`m>SLg
?494@3Tc<SHk?cH]9b/f>c@/=c<^;Bh`<2lb:RP^;B<S:RP[;R`Y:S0e;bXZ<d13
>Qd_;Rd[:BT[;BhT<3<Z:30e<c0]:BDT9BHX8B<`BVL5`WoONh><M7INCeYKGEmQ
I6EVJWV<UIBATiN;Ti:4OXB9Qi2?SXjBUifP[8NBZk9SQ6YjRXMgO9:@N8B2PHF:
RhN3L6YaPXAfM7mPMHB6R92BSWenJVIfLgNGPU9mXK6nW9>@TiZQXiV9O8J8XY9Y
RJjAVZZ^/JV3N9jWWZFob[>=M3BBY;>f]KW0`kjf][jn]kNn_;:b_Kff`=>Sb>SP
_:Jbb[k@bL?@b/?F_l6i/K_:`Zbl_lK<dOkCOmC=aLG;d]OHjNSUgmK<`kg5a<?2
`L30_ko1]ZNX/Z^GTYVKR;:?_IJ/VXjEXjVWY9ZNZ:N@NXNTTiRMVY66P7j?QgQY
HVIbO8RGUhF0TJ6T/IJMU763VgakGh5WIGQ;GEm^MWAkQh9aHV]XG69gPGaiLFIL
EeIGFEAFD4eKJ5PjOdQECC<bB4`jA4]:ATmJCSM4BTLl>dQEFD@h;S8n@cX_?cXc
<3@oCEI:?S<b>3Xa:3lo?Sm1@dI7BDU:Bde>D54h@3X`@eiD<c5?DSLeDE@l@DYA
D4U4AT/^?C`^=Te7;3Lg=BlY:BhdCTPn=cHlA4Y:>bh_>dA3?R`f?CX_:2X_5bPR
9Bl`:BP_:bd]:RDT:2dY92@^>S/]7_T/32D_<2HQ:2`Y;2XW8b7n7glT92i4GMmk
PhadMUi?FU]MGf5TIFIZNHbEU96CUh^CTXAnQ8V7T8n>SY:GWJ2/Qi:[/V>4JWZ:
QgMlTY1hQ8:1QHZ;Qh=`JW62Q7IdOf1eQ8J8T9:>OGiZIWIcMiN2DWfQ/KjLTi2C
VZ6SVHUlQXRRTVV9[Y6JZZjaZH=hWZNNYCVob[>=M9:T/kJe^L33_[Jf_[jg]kjl
/[:m_KK0dj?8j>2lY[;:_]39`m3:`mJo`KVa^l[2[;boa/cAo]=oe<g5aL_BemSY
j>GOe/c3_LG4`l;1`<2o_l6fYjRbZiNBVI^8/XnmUZbJSYFSZJNTVYjXYi1jQjBC
V9fJTHJ0OXn7N6URIW9lR9NGQH2AXJBaUYfDLH>KO7]OPFMUN4]MGfifM7^7PW5R
JfQLHWN1O7UaIUaGEUMIE5I@CE]XF3YoB5E=<c98C3Y4BdY6CeY>=dA:Ac`kB5EI
A3P^<Si3>Rlo>S<`=3m=ETXn<c8h>S4X?cln?d53ATM9BDY;CDi@DCQ0>S13GU@c
<DmB=cEAE3a1BU5@BDA6Bbhm?2hfCDL/=cLe;bTY;SA>B3hg=Sa4BTXk;RlkA4<n
;3Hm>RlX:RlG:28U;c0Y:2l[;BdZ9B@X;BTT92hj>bdNnB`<9Bl`9R4X;2T/:RLS
8OhOOb@T;TAMgg^3S7AfGTmJFeeOHFAUIVYiS9FDTI>GRi>BQ7j4RHN@Shj>TYNM
X:b7TZ^bHhAZNXZ7MgbBT7R4PX65RX^7Pg1ZLH:4MWAoH7F4QXR@TXimOVYVMW=g
Uh9BOJ6a_YbCT9>JXJ>IRGb6R::BJHV^TIZZ[[6YPgRNYijU>Ko:/hedTZBc][Fi
`<>n][Jn_[Ng_[bb/[fm]/3CXlSXh;bV//Znd<W3d<[3e[o1^K6kb/:/_;o6c=7n
dgoDcLG5bm;Gf>WXiMoFc<>maLC3`/70`;no`KJWZ;:[Ui:IVhRbSkfF[9Z>UJ>Y
YjBJWZRWT7Z7Y9>HWIZAQX1nShMhJF9VLWb8UiN5P96QY;6FWIAaPi]lNen1IfEh
BeeOKWIdNhN2LF9[J5aRMh5lNG5VG5MFEeUDEU1=FfQH>Wm8EDdc<TQ<>TA;BTI?
FThgA4Y7?3]8EEU4>2hb?T<j;clj<c0d?deFBShc<SPj<BPo?cho@D=6AdU9BT]=
CU1A>40j<4=NE3<aCe8g=E5D?45:DE19A4I;;Sdl;SI=Ab`g=cD_:BT^=4i8?SLf
?4A:BS/^;c]4@ch/=Sdj;bPZ;aLX8RD_<2TX;b/];BXU92P]:B@T;SXk;Aki;0`U
;c0V8BP/:B`Z9b<QoQl492@^A5d5`WoQNYQlLee]JEmJE4mAEemTFg>1P8>?T8J8
OGj8Qgb1THafHfV1U9>:THZ<TXI]I6ecFhNIL8NVMIn9R8=]LGeaS8Z:SY27MVM[
H61bP860QG]=MfEDLVJ7WZ:;R[C1Xi6?WYZo]8JFUhfNZjFIUifS[;Jo^9n:S9R/
VKVoaL:CUWn[];fl/Z^//;2_/kVbZ:fk]IjBWk6h^[bkYiG0j;:DdKRm]jffbLJd
_;o4alFn]k:icMgE_k>kb]3Ac;jb]LSJg^3Pf]7:b<[7c/VfZk6j_KjaYZR`/ZNK
WinNViVLYZfYViFFS7j1TZ>OWY^@RYZb/;>KU[NgTWbOR7EbLF]YKGmLNHb5OhJ:
QHbHViBGWiN4Og9TH6AXI5m[K6ibMWIcL6]YJFieMgEaN6INIfaPDDY2?TEDFEAD
Ff12?3dfAUE5BT]<CTi:AD4m@dU9@cdj>SQ@EdU4CDLb=B/^>S/b>4T]<BlW8bT_
<D@h<cXn?D=?E4<oBT/n>T4b>T8o=B/X:@l/=41:CTa6@CdOBT9Y8CPmoRi4<3<f
>Sa2A3//:C@i=R4n;STk=4L[:B<_;R8d@c0_;c4h?Slk=C<]9B@W:RXX:R//:BLY
<3Lj72Dg9Q/U9BPV8b8S9b`_nBao92<R8B8T9bPM8BPb?>5jV7acGFeYGeYDCe5G
GfAKLh60Phn@QXQmOXR7O86AS7ISJH6DThZARXbBQVeTKG=KQiU`QjIeWhV8Pfea
OG6<RXZ>T8MfIf]PH7:0PH25NdegIEAbIXNNXX^:]<6STHnNV[ndQYJGSIj[YIVG
WJ>/][mo^9n:S9R/VKVoaL:CUZ^d_KbbZjb`/:nc^K:X[K^eWY:O/KRj_;^WUL3X
/YCA^;fg[KK9a[Bl_lC7aKjg/[W=gMFo/k_:d=7<_[:eb=[Nh>3JdL[8b/O>bKJ[
/KZm_[6VZ;2bYi^OWijKVIbV[JVKUIJ<OX6BXinNVi2:V[:`/i]oU[NgTWbOR7Eb
LF]YKEaiS8EoQXZ5S9RKU9NOUhAoLVAPI6QTGf]/KW9fMW=`JfUYKWEgMG5hIUiW
K61ABT8nAEAIE5AKH48l?CI6EDE:Bda>CTY5@Ce3BDU3?CXj>51GBDA=Ac8e:bhj
>c8hBBda;bLS:BlaA3Pc>Shm@dmD@clLBT/n>T4b>T8o=B/X:B`d@4Y>C4I1?Am:
@VTQ>3gn;T@`<cHj?494>b`Y=3Tf8Ch^>C/dAb/Y8bl^8SA3<2l_<CPn?c/e<bdU
92LZ:RPZ:b`Y9bT`=cXL9CLV6bDU:2HS8R<W;2oi;7lT8b8Q8R@W:1dQ:38lhGZH
O7=MKFUOFUA?DEMOI5]cPH23Si26R7enR8MlPI6<MV=YPIBCRY6:S9:6KFA]Le^7
VG27YWFORHR3KG5mLHb:RXj@QgIWJf1PLX21P8EkCGMUE79VQijRRhZd`J>ASijJ
_kB6UYN=WZ^UVINMXjbf_gnhWhZ<V:bI^Ko5`Y>FZkBm_;:[[;2`[k>i/ZR]^kFN
TYna^;Zl^jNE`>RbU=6h_KN]]/W6];boa<O5_[Nb^LgMeKnc^l[@dLbn/[G8f]kP
h=[Ab/S:alk9]Z^a^[fn/JJX/;:WVinOWY^IW:J]ZI^EUXanPI:SWijKT8ZJ/[2c
VgnF]kNBO9n8MG9aJfU]G7V<QGn6RXF<V9^DUinGQ7mbI61TJ6AOJfa^LWIfLg1[
JFU^MGMeLGQVGVM/H55:@Si5E5UDE5]P@S`m=TIEADY;C4i>BTE1?D=9BD<m>SXh
D5M9A4e7<SD[;SXk<SQ9;C4_9b<Y;c54>3<j?Se3CeA3?aa:Bchj@C8j@Sle:bPY
;3A0BTi<AT4m7dY2JB4h?Oh^A30c=SXl@T@k;2Td>CHQ?Rhi>cA7:bTS;bhR=4<`
;bla>3ho>cDc;BDT9bXZ:2X[;2TW:C0g>Q`U=bHK9BDX9R<R8bL/;oT/32@S8R4R
92LX7B4X<S`5`WoJMIN0N5mZHFQSG5EADUAFCVMlOh65Og9WGf9`M71hR9F;Q8N>
R7=PMW=jQXAhN8AfJhN?Lh:AKHIgOh5]KG9QNGj8UIZAOFeiQHInPi67L8YeRfMH
KG2cRXj;W;fjWI6CVXJSZ8^ANWn?ViR?SiZTX:^j_ZbESYBJR:Zb^;>2PgnU[[Ng
/:b`]kFd^/2j[Znk^:^W[kFf_LW3YHVVg^2l[IFPZ[2h`/:m`/?4a/S:blc5cM?@
al73b<S>d<Nl^L?>cM;Fdl_3_knnalFf[K>i^<O0^;Nh]:RNYZ:LVIVLX::`YZ:U
WiBJZX^9Rhb3OHZOY:jMV[ZoXYB;N6Y/L6i`N7n<Vif9Ngj4Ph>CVY6>UYJ=TGmY
GEmTI69SJg=cKg5jPfiZHe]EDE5BLV5IHFAGB49LE5=HDT8j?EY8BdTe?4i6@TE6
AD4o?d11ADM6@d=8CDA?Dda9BTHl?SDe?Sdd>4D_<C<f>S/e;3Xc=3`m>T5?ACLc
?D0g<cTi@4I4?CLh>Q8a=Se2@d0k=dM8<ehiB3EE@T4ooSi1?clf>S@W9Bh`:cL^
5c`j4RH]<b/e<R<b?RXX9RDY<3<`;CTc;2X]<30^:B`]:RLY;cHO@DHC0d5A4RPV
8b8S9b/^nB`09?hSOb@W:R`];S0b=MYeUh1hGfYQJ6=LEE5BE5I>IgaoPHEoLVMO
HW1dL7R8UH^4Qhj8Lf1fLgZ6Q7QhQ7I[QhmcPY5]QWMoPFe]LV5iOXREVY5mKGV5
QWj3THM`RWF;IeQ]L;>:SX^L_KZMTI>JQZ>XRi5jOhnKV8n?VZBPZkZn[9F>OiBJ
R:Zb^;>2PjF^]kN`[;2g]KBj`;Z^[k^hZjN_]KJmbL>URJKNh;b]UJ2Z/;S2`[g2
`lC6b<[;c<G=dm37`L?8b<k@akbi`lk=d]KCbl>o_kk7aKJ]/kVhal2h]kRdZ9jV
XYbIVIbPX[2VXZFOU9ZZRhV;S8=mRYnT[YfJ^[nROiB;N6Y/L6i`N8bKWHUkOXB3
Pi>JTHjFUXfAOfUMGfATHV=[Lg=_LGZ3KVYSFeEADE9bHEUQI5M8@UaDDeQB@SXm
FTQ;BCDlCTI2ADI5@Clo@455AdI3@dQ=A4mCC4U:AS`n=CDn?C@hABla<cHj>cD/
>S<d?3dj@Dm5=c<m@3Lc6cTi@4I4?CLh>S4f?D93@3/gAdPcGSU8=EE2@Con?T4o
?cHj=2LU;S0[=bhG?3XB9Rdc:cDb8c8n:RPV9BT`<c0]>C</:Rd`<2hY;2dZ9bT_
=Qm1AQ<3@E4B:2HS8R<W:bki;00ToR=o92LZ;2d^<38efWFGP7QOJV5XHeaEDE9D
ETiWO7n1QGmbIemRL7A`N8RERhB7SXQcH7IcNXJ4N7R4MV^7Sg>2TFf6Mgn1KFeb
HGUnR9FJTGe]NHF6OX>AQg2:MH]WF6e`/hZ>Ribm^YfATiZ6XjR;TGYoSi^HShnJ
Y:2[^[j/UHioU9Z8Z[:h/h:3YJjg]k2//;Ne];[0^Zj_^kR[Yjne][g9`jF9Y]kP
_:fEX:Z`^<;2_L;3a<K8b/_<aLgCd<O1`lS8c]37_;W3c/gBe]?;`kno_/O5]Zfc
^KS7`;Rg^;BXWZJRW9VIW:2R/:JRYInDVZZ;RH^<Pgf:WjB^WIZj_j9oU8]hJVa`
KW1hS9^MRG]nQ8>3TiZASYJFSI5oJEeOI6ARHf]cLfmaNX=^JV=KEE5ADW9QFF5T
EdQ2G5ACF592>SeJB4]9=Ca>AT95ATE1?cm0@DE7AT=3B4e4Ce=<BDY6?3he=Chm
=3Q5;c4c=SXk=B`j<c@l?CY1CdDg<ce0=c<K>CU0AT@m=cPj<CHm@T=0>cM7B3=N
>DPeED91?ohn@Clo=SXd9bD^<2/g;QLl>Q8V;C<[=C8S<ShZ:2HU:C0c<2di<b`Z
;C0`;RT/;BXW:Blf7d564`=1DA8X9R<R8bL[;_T/02Cn8`PT9bX/;Bh`<SD5_goM
NYj:Q6YaI6MTGeYEDe5ABV1eNg]iKf=mLfe`KVMYLH20PXR;QW]aS8R9S8EjNhAX
M8:8SYbOU8j4UIj:QXE`KWR:VYjBO6]]SYF1R:FMMgI^H4MXMfNVUXJ:ZKb^VYV?
UgN5Th^>HgAoRXb7Rib^V9nb`kZPT8nJR[2i`;V5Q7nPZK6a[:^c_;Zi`<S3]K6h
]k>e^KF_^L[5[9F<Z>3T/I:HYk[1_l;;c<W6a<K;d]K8a/C4a/O5`lC=eM;8`<75
bm;HfMC?cLk2c<^n^;g0_;^l_[jk]:bV[::GUY^OViJPVi^OViNNZj2PYZ^UW:>c
VZZNUk2cWiZ4M6Y_Lg9gP7moSIB<QhjFV7n>UXn;TIRJZiAhIfE[KfmRKgUeJVUh
R96@R7QVGV9YIUMAFE]?@Ce=AdYCDTI2Ae=;F5Dh=dU5@4A6@3Pg?TM5AdM4A4UD
GE9:BDm=A498AShk?chh>40l=S<i@D@n>3Lg?TI1>T5AA3Xg?d8m>Sdo@D=1?Ce1
AELl?Chn?3Tf<alk:eTZAb0]D4i;B4A0?S`g?S`c<CLf;U11BZ>QACU6?C@k=R@`
>bDi<bh_=C/l>chg<2ha=3@c:B`^:bPY;S@/HW0l?YjoNRTW928S9RX]nB_n97lU
9b/^<34a<2l^gGZNRXAZLFAWI5mJEE=ADDYPMG]kNFmSOG=]L6iWJG60P8:8RhIk
LHb8RHb5NW^4J7B2R8jLWiB>Q9FNRXJ5L6ihRYZNTWa[KHjEPHRUWGMfKV17J7MW
YYJ6RZVl[YZISiMgQI>;SV=dOhZ<Qh^L[YRO//>jX7n@SiZ:/;W0^HF4X:Va/Jb[
/kbj^L38`kFa^;Nc]KVe[kW:aJbES:SPi;6BV:Nj`Ko2blc9a/C6bm;Fb<K4a<K7
aL?4cMGBb<31aL_Bf=WDclg>`/c;_[Rm`;bk_;jn^kB/YZbRUiJKWi^FX9^KWi^G
WZ^PX:J[YIbS/iZZWYN`/gnOVXAdJVmcLWN0OhfDS8N>UYQoSYJ?Ri6HVZ^DN6MU
Jfm_HVmiMFYYN8RAT8QhIUiRJFIGDEUKCd4mCDM:De96@TMCBeQE>3M9AD14AT0h
=ci7ADM7A4A9E5eBBTU?CDA2B4Hn>cln>3Q0?3Hc>D54?SPg=ci6@CY1DD@j=cm2
?F4j?Cm1@d4m?D55?3dn?S`i=S<O>b]I:TLP;E1>BdQ4@3hl=chl<c4g=Ri@@DZS
XDDiASdd>cHT<3/U>C<^;cDk?3/n=c0^<C@d<bT/;R/X:Bhd;69`?3jN_gXY9b@R
8bHZ;OT[oRAo9BL[;S0a<C0_;]ejWXZ4JW5TIfAOFUECDE5:H7EkNgU_HgecKG1^
IfUaP822R8^6Ng6<R8V<QGYkQ6QdPXR>W9nDSXBEWXZ6QG1^N8ZJWY9lJff>UH68
YIegMViPAfQgIjJFQXZY_:jJVHnGMhFCRhiSM7n:S8N;W:jHWk;3^Z1oT8nJR[2i
`;V5Q:2Y/K6/Zk>l^[W0b<>e/KRg/kFi]Jnib/F/UHbXh>BaTYRW^/6o`/_<bLK4
a/_Be/S6a<C6alG3a<gEd/S0`LG;d]SIe<o=c/;<bkjh_L2l^kbn_[^d[:J/XYNF
VinKUZ2KVinKUij[X:2VZjFLXk>JZYjG/;=oWiZ4M6Y_Lg9gP7n=U8b7SYJHOhjF
Sh^AV9Z[U7QWIF]_Kf9_NGEZJGR8TI28N6INHVUVEe5IFdm1?De7BU=BAT97Dd]H
ECPgBDE0A4I0>3LnAdE7AdA4BEAMDTY9Cde4@TQ6?S/o?SPh@3`f<cU1A3hh=cLn
AT4j@E54>SLo@SeQ>Sdo@D=1?Ce1AC`m?Shl>CHc7c/[FBY782e@CT]8A40n?3Ln
?3<a=cH^D45:Xj55>DHm=3/f930k9CTc;Rle>c`k?SL`;S4d=3<Y;2h[:2T^=2aR
L3`nW[mj:BLT8R<V:Rgi:ohT2BDW:bh`<C4`;bh5_0gPMiN2OfUaIEeLG5]KF_iI
Of=/KF]ZJVVCR7aeLFaYJG1]J6I[NXbJY:6NUhf5QHYbRhb>Z[F^/Hf3Ti^6PX5[
NH:@VYV=NfihRHb0Pi>AOi69F6C7di^a]hJ2Z[JXWY]oVh1mOh2BKW9gP8F3RJ:l
XIj/`KfQSXjOTKS3b/6;RJ2X[jjYZK6k^kRob/Nh/;>e7jj^];:[[KRo/[>>IioT
fkJVXk:k^;g;d/k9a<;3a/S;o/Yoblc=cLC;d<k7`L32a/[?d=3Dg>?;d<Zl][bm
^9jW/kRf/Zn^ZijBU9nTWI>@T9:BShnEWHn?UYnIS8^EUZZLS9REQHN=OgMiN7Ag
PEa]PHfCV9fNRhj@T9BKX::TTGU/K71`KVI^MWE_JficM7]nLEeBEUmICTaFFDi5
A3`h?di@Ddi>EDi6EEQ1@D]0ADU9@CLhAE94AdU8AdYBFEY3?D]<?3a<AChj>cdl
>ca6>C0a<cM1CSm2BU17>Sm>AT0k?T0n>SQ1?SXf<cHk?dE4@ClmoSa?>49B?4Dl
ACQ;BTQ5@3/g=CI0@S/j?SX`;BXnW9i4<cLo=Sdg9C8l9dY2>CLmA4Q:>S</:Rha
<BlY;Bl]:BT/<Cdb=B/H:3DQ:RPU8R<V:Bci:_hU5bHY;C4c92DV:2[PMiN2OfUa
IEeLG5]KF_iIOf=/KF]ZJVVCR7aeLFaYJG1]J6I[NXbJY:6NUhf5QHYbRhb>Z[F^
/Hf3Ti^6PX5[NH:@VYV=NfihRHb0Pi>AOi69F6C7di^a]hJ2Z[JXWY]oVh1mOh2B
KW9gP8F3RJ:lXIj/`KfQSXjOTKS3b/6;RJ2X[jjYZK6k^kRob/Nh/;>e7jj^];:[
[KRo/[>>IioTfkJVXk:k^;g;d/k9a<;3a/S;o/Yoblc=cLC;d<k7`L32a/[?d=3D
g>?;d<Zl][bm^9jW/kRf/Zn^ZijBU9nTWI>@T9:BShnEWHn?UYnIS8^EUZZLS9RE
QHN=OgMiN7AgPEa]PHfCV9fNRhj@T9BKX::TTGU/K71`KVI^MWE_JficM7]nLEeB
EUmICTaFFDi5A3`h?di@Ddi>EDi6EEQ1@D]0ADU9@CLhAE94AdU8AdYBFEY3?D]<
?3a<AChj>cdl>ca6>C0a<cM1CSm2BU17>Sm>AT0k?T0n>SQ1?SXf<cHk?dE4@Clm
oSa?>49B?4DlACQ;BTQ5@3/g=CI0@S/j?SX`;BXnW9i4<cLo=Sdg9C8l9dY2>CLm
A4Q:>S</:Rha<BlY;Bl]:BT/<Cdb=B/H:3DQ:RPU8R<V:Bci:_hU5bHY;C4c92DV
:2[PMiN2OfUaIEeLG5]KF_iIOf=/KF]ZJVVCR7aeLFaYJG1]J6I[NXbJY:6NUhf5
QHYbRhb>Z[F^/Hf3Ti^6PX5[NH:@VYV=NfihRHb0Pi>AOi69F6C7di^a]hJ2Z[JX
WY]oVh1mOh2BKW9gP8F3RJ:lXIj/`KfQSXjOTKS3b/6;RJ2X[jjYZK6k^kRob/Nh
/;>e7jj^];:[[KRo/[>>IioTfkJVXk:k^;g;d/k9a<;3a/S;o/Yoblc=cLC;d<k7
`L32a/[?d=3Dg>?;d<Zl][bm^9jW/kRf/Zn^ZijBU9nTWI>@T9:BShnEWHn?UYnI
S8^EUZZLS9REQHN=OgMiN7AgPEa]PHfCV9fNRhj@T9BKX::TTGU/K71`KVI^MWE_
JficM7]nLEeBEUmICTaFFDi5A3`h?di@Ddi>EDi6EEQ1@D]0ADU9@CLhAE94AdU8
AdYBFEY3?D]<?3a<AChj>cdl>ca6>C0a<cM1CSm2BU17>Sm>AT0k?T0n>SQ1?SXf
<cHk?dE4@ClmoSa?>49B?4DlACQ;BTQ5@3/g=CI0@S/j?SX`;BXnW9i4<cLo=Sdg
9C8l9dY2>CLmA4Q:>S</:Rha<BlY;Bl]:BT/<Cdb=B/H:3DQ:RPU8R<V:Bci:_hU
2BHY;C4c92DV:2X5/`ONKXE/KEe/H_]LOe]KJFAOFUMJIW=oMfeXKGEgLgE]H5=A
H7V<P8J;RhbCW:6BXiVBYZZJV:JGX::=RhmmRHjDV9JASHZWTHF6NfMWN9NKGgOK
fk2j/75g[;N^XXM`X9F9MG6GRg=`M7YjOig0]:JZ_;FFRI:FR:nj`KR2P:>[/[2Y
Yjfd^;>iaLFg6:j_^ZVS[[NaZ:FjZKZUHVnkfmJgWYn]^L?nbaK:bLO4`/7<eMcI
dLkDg;bl^kNc/kNl[_j_Ok?0d^3?d<Je/;Fd[9NP[K>b[jb/Y9V@UJ:YXYREVYbG
TYBGVHV8SiRBPW^0TZJFPHV5N7j8OGUkN75ePG=gOXF7R8bBW9:<U:2VYJ:3N6i/
LG9/I65QIW5kNViRHG1lMfEFDUE?B4]GG5A@De19Be9?@Se1Bc]7DdY?DCY8B4Dm
C3LjAe=1Ade=BDI5AePn=496>3M6?CXe=3]1@3Xk=3Dh<BTgCDQ6BTi4=CI1?S`f
<S<d;bM8@CPa;c4d=T0n?3/k?T53CT`j7aX_ATi0oT53?SXf<b/f>S@d>3<X;BhL
@48R=SLi<CXf9cE1;D<i;b`a>3i0<R/T8RDY:2LY;C4_:bPZ;Udg?E8j82<V;2TV
8b8U:2[i:OhV4BLY;2la7AhP8bKNKXE/KEe/H_]LOe]KJFAOFUMJIW=oMfeXKGEg
LgE]H5=AH7V<P8J;RhbCW:6BXiVBYZZJV:JGX::=RhmmRHjDV9JASHZWTHF6NfMW
N9NKGgOKfk2j/75g[;N^XXM`X9F9MG6GRg=`M7YjOig0]:JZ_;FFRI:FR:nj`KR2
P:>[/[2YYjfd^;>iaLFg6:j_^ZVS[[NaZ:FjZKZUHVnkfmJgWYn]^L?nbaK:bLO4
`/7<eMcIdLkDg;bl^kNc/kNl[_j_Ok?0d^3?d<Je/;Fd[9NP[K>b[jb/Y9V@UJ:Y
XYREVYbGTYBGVHV8SiRBPW^0TZJFPHV5N7j8OGUkN75ePG=gOXF7R8bBW9:<U:2V
YJ:3N6i/LG9/I65QIW5kNViRHG1lMfEFDUE?B4]GG5A@De19Be9?@Se1Bc]7DdY?
DCY8B4DmC3LjAe=1Ade=BDI5AePn=496>3M6?CXe=3]1@3Xk=3Dh<BTgCDQ6BTi4
=CI1?S`f<S<d;bM8@CPa;c4d=T0n?3/k?T53CT`j7aX_ATi0oT53?SXf<b/f>S@d
>3<X;BhL@48R=SLi<CXf9cE1;D<i;b`a>3i0<R/T8RDY:2LY;C4_:bPZ;Udg?E8j
82<V;2TV8b8U:2[i:OhV4BLY;2la7AhP8bKNKXE/KEe/H_]LOe]KJFAOFUMJIW=o
MfeXKGEgLgE]H5=AH7V<P8J;RhbCW:6BXiVBYZZJV:JGX::=RhmmRHjDV9JASHZW
THF6NfMWN9NKGgOKfk2j/75g[;N^XXM`X9F9MG6GRg=`M7YjOig0]:JZ_;FFRI:F
R:nj`KR2P:>[/[2YYjfd^;>iaLFg6:j_^ZVS[[NaZ:FjZKZUHVnkfmJgWYn]^L?n
baK:bLO4`/7<eMcIdLkDg;bl^kNc/kNl[_j_Ok?0d^3?d<Je/;Fd[9NP[K>b[jb/
Y9V@UJ:YXYREVYbGTYBGVHV8SiRBPW^0TZJFPHV5N7j8OGUkN75ePG=gOXF7R8bB
W9:<U:2VYJ:3N6i/LG9/I65QIW5kNViRHG1lMfEFDUE?B4]GG5A@De19Be9?@Se1
Bc]7DdY?DCY8B4DmC3LjAe=1Ade=BDI5AePn=496>3M6?CXe=3]1@3Xk=3Dh<BTg
CDQ6BTi4=CI1?S`f<S<d;bM8@CPa;c4d=T0n?3/k?T53CT`j7aX_ATi0oT53?SXf
<b/f>S@d>3<X;BhL@48R=SLi<CXf9cE1;D<i;b`a>3i0<R/T8RDY:2LY;C4_:bPZ
;Udg?E8j82<V;2TV8b8U:2[i:OhV2BLY;2la7AhP8bH5^@cYM8I/KfAeK6ITH5aI
oUQoJf5JF5EEHgF7PG9XKGYjL6=RGUYIH6aeHFmhMg^7T92>SHb<TYjKR:JEVYZ5
R9:3QXZ>T96GX:NZQGR5NU]TRVj9FfJ8MhRVReQh/kBbYG1gX9NCNVZDUWM[J6i[
KHni_jb/^Zb:Q9VHR:fg_KN3PZ:/][N_ZZba]Jj`_L6h/;5o_jbU]<6k[:>iX:Ze
Sg>;Zmg?]jRdd=kL`L?6bL_<bl^iaM7?a;g0ajjYXijOYJfcYZFTXZJdb=KGfmK;
bL[0/:Z//;Bd/:ZUX9ZFVjFYYInDWZ2GTIBFTZ:NY:j[Vi:DS9f=NhV=Q8]gL71d
LFY`OX]nMWQlPI2QWI:?VZ6MVYa_MW=dOHJ6NfmMFEa]P8EgIWn;V9N8MFQSCDU>
G5mHEeeFCdmED48k?TPd?di;De8hAT4k=cPnADY1Adi>B40l>e0o=3Y0?CTk?3Xd
<3U6@cHf;cQ7@Bd]?Da2?T8n<c0e?d4l=3Dk=RY@B3dg=cPh=_hcE3@g>Si0;4lI
I0aB63Tk?D12@3dh=Blj?CLg?3T_?e@j?cddBcDb:cDd9SI3;c`c:RH[<CHg;RPP
7b8U9B<Y;S8a;2PY:`d>92dU=D0Y;BXV8b8T9bWh:00WoRH2:2//oB<=8^UdQVa_
I7E/IVAPG5WnF7m[HEYHEEESMHN1LVQ]NWY`Hf9NFUUPK7EQKgQgNhN@T8j=S8bB
WY^8YYFJVXF8TX>6RXj@TINPYjZ5N8EjFfB:KXUKIXQgR:J;F7Rc];:UL7NPUi=j
JYBFMf]XKV]]SkVo[:bj[8Z4VIR8[KNm]h>2XZbf]jnZ[;6e[[2m`KR`/Gno[:Fd
`K^/XkVPZ[F?Lh^[gLngZ;C@g]c1`lK9blc;bkW5dLo4_L37[ZVSWYnU[K>VYJBR
Y[C8e]OKe/_9b/2`ZZb`];B`ZZFPVYJKYJVUWiBNX9NAU9JBXYjT[Z^KTYB<WHek
RHf4RgM`L7AaJW1nRgifN7b1T:6MTXnJXIfJW6mfLgAmQXIkKeeIG6f0QGMVOh^H
UhQeJ6==BDiLGeQGGEI?CeE@@S/nB3@oCT]CDSQ6@C/g>3i5BT57CTi8@3`kD3ld
>T0m>C/l>S@`>DI3=SH_>4M1;BdmC48n@Shc<3Do@C`d=C/f:U18?CLg>3PfoS=D
=3Lj?T0/CaUT358H>C/m@490?CPe;cXm=cLl>BloE3Xo?CA;=C8[=C@V=T<_?3<Z
9R/a=SL^:20O8RDU8bT^<S4/:2T[3@hT;BDe@2T]:RHS8R@W:OPX02On9P8X:bcm
8`dRjGB6K6mTMFaVI61LFOiHOf]QFUQEEF=eQh5bJ6ejNW1SHUiJFF1/MF5_N7Mk
Qi2@SXf<S9:NVhRVUIZJQHRBPhJ:SY2AUj2WZXEhQGYKI8Y^RE]VR7N8YX]HN;>d
/ZE`Mj2GTgYZU9IgJfQ^Jff?^Kn/[;Z/RXBIV8R]]kfgPh:R[;Jg[jZ//KF^/;g1
^;2aOkn/YKC1^jbS^J2Z]HmcRj_MckNX]=3Ng<73a/W;c<_;^LGAclBm`<N^ZJ>N
WjF]/jJUY::V]<SFem_FblW:`;2Z[;2d];2ZYJ2JUY^UZJFOU9jPUi6DUY:RWZB^
Zi^BU8bMSG^9SHB;Mg1`M75ZL7j;OWIhO86@XIfBSiZQWIZLKgIcM7f6QW]_GEUL
KH25MfIoRiRGR7EXHde9CUaOF5MMETm?EE12>ci8=3m>Be=B>4I1>cLh?TE:@DM>
CTQ0?3]@?c@j@3di>c`j=30iAT<f=RlhAd4];Ce<@Si2?S<`=Cm1?3@e>cHZD4Pm
=cLh>3Kn<e@d=cXn@2a?6F@<DQPi>ce0@T0m>3D_>Sdg=c`i;cmD>Slm=4/e<R/e
=2Hf@bll<bXV:c4f=bhX81lR9BDS:Bhb<B`X:B/=3R@]9CE0:BdZ9R<R92LYn2P0
9ohV0RP[;?dS0285`WoXM8QaMfYgJVIRGEQGFEiQIV9YMG9UIW:ITh1_Lh9oL5]K
G65XKW9cJ7QoMgAkNg><MHNDRZJfSVeNIf]KH6]MM7UnOh26Tij3M71gLVQeSg6?
MXMjGiFUSFVA/iJR[7FDVWn?RW67OhA`J6]THhJe_:ba`:^3PInTTkFl`kj=SWnJ
Z;Rm]k6a];J[ZkRo^[Fg^:j__<:g[JZb/JZ[XGadVKoKg;nken?E`/2n_Ko4bLb]
/[Vm^kB[YJJQW9^PZ:nc/;:d/k>h`/_<fN?Vj>?;/KF_Zjne]JfTXJ6RY:FUXj:;
VIfAS9>DSHj9SY^MTHZ=RYN3MHbESI=gLW9dK69WMGmiKVmoRH^EY8^>V9jBP8>E
MWIjQY:CR7a_JVM]N7agL7IkPH5iJeaBDTiDGemFE5a<AdYEED]8CD<fA4i2AT`i
C40f=d59BDA6BTa9@chn@DU5?3HnB44aA4<j<S]9@c5J>R`mASXf@EA1=Ca3?cXk
?DA1>Ci:AcU>ASdk?T4n>ULa<S@f>3Xk>cEK<9hlL1a2>C`o@3hi<blh@D8l?4=2
>B=0=DA2;cPI<BXc<B<c@2`k=2`Z;S<d=38/9B<V:BTW:Bhc<RdX9bT^=d0/62le
32h[9b<R8bHXnBMo:RPV92<T9BHV9B@S8NQdR75gJWMZIV9MF5MIGV5VHVUeLVEV
LYVCP6mcPWm`Fe]LHFQ^LW=XN7mgM7]kLhaeQiB:Y[J>KEiWJe]PJeedNGioP8JC
WX=dL7MbJ7F?LHmfQgYOUJF=JI6cUZ:/MIBJOhn:LHMoQ71XJfASQ[Fl[;5o`:^3
PInTTkFl`kj=SYZX^;fg/K6d]Z^[^;nj]KNh[Znl`[N]Z[:aZZ^QO7BI_m_L_k_G
hmG2`;jm_lC9c:fb^Kfk]:^UYZ6LVj2X[k>`/[Bc/kS2blcIhnKXhl^a]Jn[[kFe
[JBQXJ:TYJFSXX^IWI6<TiB=SXV>VifARXf:Uh=oMHbESI=gLW9dK69WMGU^Kgn9
RiFTRhjHWY:0PiEfMWZ6TY>8O6mZIfehO7M`MW^1PGU[G59BCUAOGeIDG4a7BUEE
BdQ=@cI4CT96C3U<@3Hg@DU9A4I:C4U3?Si1BDDl=Si8@C54@cXb>dU3<EXj;3e6
>SI1E44e?4<o>S/mA45T>Ci:AcU>ASdk?T4n>S4b=3Hh>S/k=E/`WSa`748i?3m0
?STc;cQ1@S`l@d8i8d0eA48_>1Ta:S<a8c=0;3/d;2X^<c@d<R`U8bHY:BLY;S<b
;BPW:Bhg@2`H;cD<;R/W8b8S9RSi9glZ:2HT8b@U9RHU92<Qj7B8LGMZMfYVHUeH
EeUNHFIRJGEbIFIbVI>0Kg>2Og1KFeaQJ6ibLfQhOgMdNg]cS7F7U8ZV]Xi]GVM[
Ff1[GGAiOWn0QY>NPgA`Mg9XMHmaSgJ7NUnEYHeYTK>FXZaeU9YoShYaQgn4L6Q[
I6>6]Kb//Go0Zh>1WjBC]Kc3_Xf>VZRh_KNa/KBfZj^h_kZe]kR^[kc2]jfZ/[6Z
Zj5lM9Vofmbo^mOSeL;0_[foa<W<[K:i_K^dZjFVXIbKX:R_/k2b];>c^<;;c=WS
i^SSbk6e[j^_]KF]Y:6QXZBUYJ>RRiVMTHbCU8f>RHjKWI6:SHZGPgmeS9F=TgMb
LWA/HVMeNFi_OhV;UJB;SYRNTX23UGIfNXJBThQlKfYWKGQlMg1fNh61NF]LDU9>
E5mOEUALC4M:EEE;B4e3=TA>@TI<>Da0=SM1BDU4ATY<BD<n?T59AC`f?TQ1<DA3
>S8kBD<aFSX/?DHj=T5D@CDl@clj>ce4@F@i?TY7>Di6?C/n@Chj<C8d=SPj>c/e
Fc2N?70L@STl?d0n>C<_>452?3a3@STS@3E4@Rlh6C4Z<c4S<d0/>c@/:Rhc=3@b
;2DS9RTY9bT^<c8]:2LY;SM0;1P_=@`^:bLS8R<V:?TW32XX9R@S92DV9RDT8b45
`WoAH7QVKEiTDUeIEE=GH6YaHVQoUiElKG23Og5WMHjAPWU_I65VK6m_K82:PWn7
QGZ_QIf/S:W1QfeRLG]^M7i_I6Y_KV]]MWmbOG][HVM^KVmoLIf@M:B:/I2]Zg:;
]8V_TVB6V7]kHi=kKVmWHhJg/jRdaZj1P:>VTk>i_kb=T7nBXkO1_KRf^KV/ZKJo
_K^mZjbf`;^]ZK2XcK^ISW1c/97Bk<B/`<J`b/:g[Zba^/2i]KJob<>^VjNTXjJ]
];Ri/kVo`;^h]kV[`MWXk^?1W[2UWZFc^[BZYJV/ZZBPX:6;W:6FTYbNUHV3R9NM
UY:ES9EmKhVDRXf8PWmlKEeNJWmUIGREWXanOWR8Wj62I72@K6Y]N8B7OgF8Q7]a
JfY_LgEdM7IeKfAKEeAHHEeACeIECe5HEDQ3AclkCU4h=d@kEDHi?TiGDDI<C4U3
?Si5C4E<@cDnDDL[CTe1=Ce;@bf=Ba/S?4=9E5i5=Cm>D4a:;CHf;cM8B3Y5?SPi
@4=0>ULh>S`n?chm>dPd5C/I7aQ7=SPk>cPa:B@b>CTb<S/k=2le6Rh`83di<R/d
<24_?2Lc;BLV:Bd]:cTb:bT/;bl^:Bhc<bdX9bP^82X^8B`l;bl/9b<R8bHXnBMo
:bTV8b4P8B4P824R8]5PN6I]GVABGEUEDeMPJW5RJ7nGUGa]L8=oLFMeSY62NFmT
HFI/Kfm/P8Z2OhN5NZn5WJb<ZL67KF9aNfidOVmTJVm^JfefOg9mNf]RIfi^Kgma
WI1dY8ZaT:f[LX^dRJnBI8JHNg]STg]^KfMSQ[NcZ;AoaZj1P:>VTk>i_kb=T9:S
]l6m^;Ji^JbY][nm^kf[[;K0^jfY/:S=^iV>L7>`TM;/a:c0a[3:`[N^[;6j`;Ve
][o8`jjKYjBSYZfd^;Vc^Ko0^kRg^J_1fNS^hl6N/:FNYK>j]:ZUZJbZY:2PXH^L
XIJBW9jERH>8UifFTYF<UGeoKhVDRXf8PWmlKEeNJVEUN9FNS7inN8ROXH9TL91/
JVehQ8MoMHR4Ng5[JVmcMGAdMWE_I5]GE5QQGE5?EUE?DEQEB4=7?c]>DCPgA3]E
ASTnCUMAATa<BD<n?TE<ADa3=CiAAb]>CD4e?D]3;He;6b<l@dUDGTDe?di@C4X]
=SIT;cM8B3Y5?SPi@4=0>SPj?3ho?SdkB3@E>aTO64Lf>3/k>34Y938i>C8b>c/d
;cDJ;S0P?CTb:c@`8Bll9c<]9bHY;Bd[>C8[:B`_;bhY;S<c;BPW:2hP:RhQ;3`_
;b`W8b8S9RSi9gl[:BHS8B0Q8B0P8B8RdF1hIVeNI59MFEECEf1ZLF9XOiNEO6e`
PgmaIgF>TH9iKfAQIVa_Kfb0RX9oQhEj[hFM[8bY`HM]HW5kKWAnKfAZKfi[KGIo
LWekJf9WKVi_Og6MT7BTR[6@[J]bRkB9[i9TQYQkNf>CNfi_If>6]k>X]7o6[X60
XjJC/kVo_8f@TZ>g`Kfh][Vi[:Vf_kfk_J^/]/2k[JV`Z<fkVHi`Lk2Ad^c4[<36
/<[2]jj//K[0^KFf_lS3[Y^WY:>V[KBh^K>i_l2k^;NiZl7Ij>kS`Ij`YIjU/kZd
ZZFY[:ZTX:2QRibQUY:LWYF9PhRGWIJBUHbEOGm_RIB:SHR2Oga]GEiZIFEhUIj<
OWihR9nQPVA`T6aZKGR4QgmeR8AkLF]ZKg=eM7AfMFmTFeMDF65MDDmFEDmAF5E8
@dLo>diA>3M4>eE6>Ci>Ee56C4a9@chnADa5C4<e?U57:di=@CDmBd<]SD/K8ca3
BEANACDoCU1<BRdf=V@_=dQ8>TDn>3U0@d0j>3Xl?Sln?C]8=1Dk6AlHAcHh>c/h
<BTT<STi<S8k>c@_=AX^<20m>C8[=30Q;c`W<bdW9RT];B/i<R/Y;2l_;RT^<c<]
:2LX;R0Z;R4/?2l_;2LS8R<V:?TW32/Y9R<Q824Q820Q8R85cWoJIGMMHEEUFeEE
Ee]PHV5OJF9KG69[Kg6<P6ULK8=oJ5eRHV5[N7EXMgAdN7n2PGioRHf8R8j;PI9d
HFYeM7InH723RH1aI5maKG9mNfeUIg^8T8nBVIF:SHB[SgJHWJ:UU8Z;P6]UKIbJ
VIfQXI^E[:bg_ZR9RJ2SQ:FjaknHZWn[/kZh/Jnf_/Fh];fo^;Bg^;Fg`<[9_;2^
bKZLWYfAU6nEeLBjck_3^kfm^kZmaLbo^[6YYZZc^jJa^;2RXK73YZba[:>QZK:b
`^Kbi>KI[Yfe_k6UZJfXXZ^`ZI^DVJ:@SYRSVXV<WHfHXZ2FTYVRWIYlLHJ7NX:5
IG6ATHMgFgmOJgb:Shj:R8Z6RiJFS8N;T8MoP8AoKUm@N7mdNGAYLUb5V81[K6]N
D5ILGEQDDeAFDdU1Ae=@@da:B4A0>cPf>d15ATA4Ad]7:eDPIbiA;dE8BD@m>CXm
Bd90A44f<cY5>c@iAeAGE5aIDde8A490DDHl>T14@C/e<cDnB4a7?c`o?3Xl@TA1
?SQ5CTLf;cQ5=T0X?48`>AhZ<Sa0?cdm?RdZ9R@V;3<g:S8k?S`h=cPb=S/o?CPa
;3Pe<Rh[oRX>;2/[:RTX9bL`:R@S9b//oB/1;2cn;Gl/<SPh<bl^;bTX9bDS8R0O
9bDT8R;JIGMMHEEUFeEEEe]PHV5OJF9KG69[Kg6<P6ULK8=oJ5eRHV5[N7EXMgAd
N7n2PGioRHf8R8j;PI9dHFYeM7InH723RH1aI5maKG9mNfeUIg^8T8nBVIF:SHB[
SgJHWJ:UU8Z;P6]UKIbJVGnMXJ6KUJb/]kjXRHVPXhBU^/NoV:Z[/kZh/Jnf_/Fh
];fo^;Bg^;Fg`<[9_;2^bKZLWYfAU6nEeLBjck_3^kfm^kZmaLbo^[6YYZZc^jJa
^;2RXK73YZba[:>QZK:b`^Kbi>KI[Yfe_k6UZJfXXZ^`ZI^DVJ:@SYRSVXV<WHfH
XWnPUY:IXYfJO766QgZ2QFEaTI67Me]OJgb:Shj:R8Z6RiJFS8N;T8MoP8AoKUm@
N7mdNGAYLUb5V81[K6]ND5ILGEQDDeAFDdU1Ae=@@da:B4A0>cPf>d15ATA4Ad]7
:eDPIbiA;dE8BD@m>CXmBd90A44f<cY5>c@iAeAGE5aIDe5=B4A2@556?3Y0A44k
=C<e?TQ<Aclo?3Xl@TA1?SQ5CTLf;cQ5=T0X?48`>AhZ<Sa0?cdm?RdZ9R@V;3<g
:S8k?S`h=cPb=S/o?CPa;3Pe<Rh[oRX>;2/[:RTX9bL`:R@S9b//oB/1;2cn;Gl/
<SPh<bl^;bTX9bDS8R0O9bDT8R;JIGMMHEEUFeEEEe]PHV5OJF9KG69[Kg6<P6UL
K8=oJ5eRHV5[N7EXMgAdN7n2PGioRHf8R8j;PI9dHFYeM7InH723RH1aI5maKG9m
NfeUIg^8T8nBVIF:SHB[SgJHWJ:UU8Z;P6]UKIbJVGnMXJ6KUJb/]kjXRHVPXhBU
^/NoV:Z[/kZh/Jnf_/Fh];fo^;Bg^;Fg`<[9_;2^bKZLWYfAU6nEeLBjck_3^kfm
^kZmaLbo^[6YYZZc^jJa^;2RXK73YZba[:>QZK:b`^Kbi>KI[Yfe_k6UZJfXXZ^`
ZI^DVJ:@SYRSVXV<WHfHXWnPUY:IXYfJO766QgZ2QFEaTI67Me]OJgb:Shj:R8Z6
RiJFS8N;T8MoP8AoKUm@N7mdNGAYLUb5V81[K6]ND5ILGEQDDeAFDdU1Ae=@@da:
B4A0>cPf>d15ATA4Ad]7:eDPIbiA;dE8BD@m>CXmBd90A44f<cY5>c@iAeAGE5aI
De5=B4A2@556?3Y0A44k=C<e?TQ<Aclo?3Xl@TA1?SQ5CTLf;cQ5=T0X?48`>AhZ
<Sa0?cdm?RdZ9R@V;3<g:S8k?S`h=cPb=S/o?CPa;3Pe<Rh[oRX>;2/[:RTX9bL`
:R@S9b//oB/1;2cn;A@/<SPh<bl^;bTX9bDS8R0O9bDT8R85b7o/MH5OFTI?@FAI
DEMVKVUPJF9MGFA[Kfn:PW=[NH^4KWaiKfUbNW1MMW=aMWn5QhJAVYbDTYJAQg9W
Ig9eKg>0GVamR8Z:S8mlLFieNW^5Tgb6RhV=VI^DQh2YSW:DWjjbY9jQVX^9TK>_
Zjb`/[2][jbd^J>4QIbWS[?8d<:@VT:X/KVi/k:i`[ba[kVn^KNl^;>c^/?4^[2c
a;BMVHb5VJEm[=cVb:SI_kfk^[^l_Kf^XYFCVZ2PW8VGYjf][kS2]K:^oZ]oZJNa
_nCdjNcS_:2e_[:WZZjZXjbc[ZBOYJjWW9fYZYjIWXZGYJNQWZB/SIB3P9F;LG6A
N8:@OG9eJeicRiBASI:JUhj<TXn6QHbAQGUjQY2ASFAnOgUmKF5dHVUfOGIWHFAC
F5eMF5ADEEYGCDA:EE12BDM4@T51@T=5@Cdl?dA/BTeQBWA3OdU/DDM9BTHo>c`n
BD4oA48g=S`i>SXk?TI@EcPk@4E7AdI4?cXf=ca1A4@j=cHlADQ5?clj=cPm@D0m
>D57@SLb=Sdd@bdo@Bdj928V:R/[;C<i<C0^;Rlb=SPT:c<f<Rh];CDf=o`h3TY7
@3Tc;R/Z;Bd/:bXZ:OhX1BLV9BHX:_hXObTZ:R/[8RTb=SDe>3/Z:BLV928Q82DT
8b8Rk7F1GeY6Cd5TFE5GIViYH6URGEeTJfm_RX9cJgV;Q6ilNFmYLWY`GGIcLGIo
QHN6TIZLU9:FTHMbIfMbMFmcP5i/OHR:RXb?O75^MGYkQI=lQX^9SIVKU8N0ZHib
U9n^/ZBNXIZ;G8VA/jn[[;2b/:f_[;BiXhB5W:N>/lS@`Y2JZ;6i^K>b^L:l/Jni
_[Vg_;Rc/k[3a;Z`/lBdWIV<QIVUOJcLi/RXfKnm^kZk_;fm[Z:ETiZPX9b9UjN]
[Jnh`[Fb[_j[OjVW/KoTm>W/hkbP]KjbYjZ^ZZ>//jjTWjF^YibMZJZNVIj:UjFW
XIjT[8fDPh2ERg5aTGR2T7ebMF]NLh^DTHfBVYN>S9:?QXF<THEiNXJ@THeTOWmi
OFeQM69YMWefIf5TDeQMGEQDE5EJEde4BUE@@TU7A491@D93AD4m?3m4K4Y=HDYd
@gm9K557BDY6?c/l?TU1?dA2=cHl>CXj>ci6D5Lh>d15AdM6A3lj=SLl@DA4>SLf
?4E8AClo>SLh?D50?CU1Ad8g<SHm=4<]?d4]>R@R9RX[:bdc>C4`;Rh_<SHh92/c
=S8^;Bde=SOl>0i:Ad0i<bh[:Rd];2/Z:RWn:0DW9RDV:2[n:7lY:RX[:b8Y<SHe
=CPk:RTW9R@R8B0U92<R8^aePEmJATm1I5UAEfI^JF1YHUeMI6]_KhZ2Lf]iRhA^
O7U_JG9jL5efLg5fOhF7QY6JW9BBUY67LVMWLWE_Lh1NK7f8RXZ<SgaaKWEjNhFC
O8J;RHfIViB7P:V>LYBO[[:TWZ6JReb9TK>_Zjb`/[2][jbd^J>4QIbWS[?8d<:@
VZRa^KVc/[W2_;6_^Kji]kbh/k>j`lBj/;?4]9fIS8FIYGf/g>K8Z=Vo_K^j^kbm
_JjRUI>JX:2LRINW[Jf_^<:e/ZknZgnYYk6oi?CYk>>lX;Fn/ZNZ[ZZS[;>^Y9nU
[ZNLWJVZWYVNRYNUYj6NY:b=U8>0UH]aLI5hPY1mLWE[GW>;U96=TYZGSXbBShJ5
S965NGZ6T96=I7ioNGe]HGARJGImMVMQI5=HGEeHE5AEFUM=A4YED499AdA2@D52
@dE1?C`oA6a:CF5:M4=oBFaAAdU:ASlk?3i9@Cm4@SLf?3Tj>S/nAU1G>3]0ADM7
AT@o>SHg?454A3Xg=Sa5B4Do?cXg>3e1@3di@DM2=c8f?CA3;Cm1;CXT8RHZ:b/]
<cTa<2h^;c8f>2@[<cHb;Rd]=CHgo3P>BTM0>C<^:bX];B`[:RXYoRP59bHU9RPZ
oRPI:BXZ:b/R:C8f=CDh>bXY9bHT8R4P9B@S8R85dgoYMHQ_LfIdJGMRD5=WMFmT
JVAOH6I/KFf5PginRYB9MWYgKFM`O7ETQH1kOHB:SHf>UIB:QXR4NEeVMh9nM7^:
WYjJT8=iMGF9OGMjNWMnRWMmO7IlS9FCQh6/TG2?Xkjo]kBi^;:c^/G0^[^o`/6o
^K:e^JB9Rj>XUKk@e<25QWnV/;Zk][Fla;Z_[k_3`;o4^[>^/[bo^[:j_:bOTg=c
XKehTLWYeJgDc/S2a<W9`KRcY9RKZ:jVVX^GZK[4aL?0`kR^[[BeZj2_^]oekO7/
bjNf_KB[[:n^Z;2g]Jj//k^hZ:6[/ZbPVhNDXZFPVYZNT9R8Q9J;LgBDQI2>K6In
QWmPNI>HSXVDXj>GT9:=Q8F>Vi23P8>4OWM`N7AkPVUQQ7iYKXV8Jf1_EeaPGeUE
EUQMFe17C5E??dM4@3i0ADa@CT4d<ca7C4`o<UT_Fb]<>TU<CDQ1?Ci1AclnA4<j
>D0`>3lm=cY8ETe?DE1:@CPa>S`l>STl@dU8@cdl?Shl>Gm1>cDe>cm1@3hn?chl
>CHe;d<b@C`W>b//;Rh];C<oB3Df>3Tj>STh9bdc<blZ:BXo?3Pd<cDh>T4n>38/
:2HU<2l_;Rd/:b/U;C@b:bL[<BDU9RLX:BXZ61lW:b//<3@Z:RPV92<Q8B<R8B4S
jGF8Kg=VM6UgHU1CIgE_I6YTGgmPIVa]KHF3OWj:U8UfNWM]Ig1lMFB5P7]mQ8Z=
SHjEU8Z6R8AiGFIgPWidNhZNWYZ@PgUeMHUmMgYjMgj:MgelMWb<UI>7PJbAL8nS
_[ng];Vh/[>jaL2j^ko2`Kni/[FiY8V;XjRE_]3D`8F6Y[2j^kJe_<Bj[jnk`l2o
a;Zc[Wnb_;nj/[Zl[9nCLg>Q_GRAbNWE[MC>b<;4bLW1^;>TV9^X[ZJJRiNY^/C5
`l33^:j^];F[X:njgoG]lNc;YkJm]:^/[jjX/;Ne[Zbc^kRXXJ^b[:2KQiBRYJ2J
VYj@V8R4UX]cM9B5T8i/IWj6H7VCV8j9U:>SUi2BSHB5SY^@Pgn0PhAnMg1hM7^2
JF64OVU^RHQ[H6mGG61OFEEFF5eKD4M<EDloAdA0?T15C51>@C@c?4M<C3lbFBmK
:d`jBDa=B44m?T57?ci4@cXi@30h?cdg>TQFCDmAD4Y1>34j?3`j>Ca3BDQ3?C`n
?S`i@C/e=C/o@D0n?Sln?3Tf=Bm3<Wm1?2Lk:b`^;Rd]<cm8=CHh>CXj>CPW;C<c
;bXY:Sll>3@c=CPj@Chh<R`X9RD`;bl^;B`[:bD]=38[9b/a9BDV9bPY:RXH7bL[
:b``=2XZ:2HT8b4Q8b8Q8B?YMHQ_LfIdJGMRD5=WMFmTJVAOH6I/KFf5PginRYB9
MWYgKFM`O7meI8F0Ngf4RXf=SYFDRXJ8Q7UMIWN2OWAkRYjNVY23NGEeRGegNWYg
OXYgOGafO8bEThN1[95`Sj>n_kNd^KRb/k[5`;Zk_l;1_kVb]KVTRH^SZ9Fnd=C0
QHJV/;Zk][Fla;Z_[k_3`;o4^[>^/[bo^[:j_:bOTg=cXKehTLWYeGn]e<k8`/C9
bL6h/jBHVjR^YYZ;UjVja<G3`<>h[Zjd]J^P[k[OmNgak<^W][fdZjb_[ZR`]kF^
[;>k^:RQZk:/X9^7U::UX9ZJWY2HR8BFRg=dU8F@SVaVOXIPNI>HSXVDXj>GT9:=
Q8F>Vi23P8>4OWM`N7AkPVUQQ7iYKXV8JgmPKeMLH5mIEEIHGE]@AdaECcm7A40n
@4E<D4i1=3<lAda<?c9I;e/[C3Y9C4e8@Cdn@DLo?TA3>SU0<3Po?CLjB5I=Ce5@
BT4h<CXl?3Xi?4=9B4<m?3hn?3U1>cDe>cm1@3hn?chl>CHe;d<b@C`W>b//;Rh]
;C<oB3Df>3Tj>THi>2L]<c<_:RTZ?c`h=3<e>3Y1?SPb;2PV9C0_;bh];2/[9Bdd
<R/W:c4U9BHW:2TZ:QPO9b/[;30d:RXX9R@S8B4S8R4Q8`G;?mm`Rgf:QYZCPg1L
Ef1[KFY_JF9QIVY[JWYmPh^EUX]nI6a_K7>5ShjITXZ8S96BTHB:R7ijOWYaKWV7
Sh^7RiCnSGn;QhB3Q7ejP8f=PGYmP8=mLWF7Ti>=QK2EKHNPa<?0_l73`lK:`Knn
`LK5`;_2^;Vn[iRL]:RH_l_>_hF2ZKBn_kVf^l72]kK1b<C2aknf[[2i_kfh`;JU
XY1RJ:^ST9V9/>W>^]S?bLoIfL^mb<:n`LS:`kbf^<3<e]C7^l6k]Wnf^KN`Z:nd
f?7ZkN_@[kNk]Zn^/K>`][Zi];>h_KJ]YjRZYYjIV::][ZFJTi2UYXanSX^1SXj4
T8e_M96HKGf=TH^8SiRTVYNKV8f:TIJEUYJAPFUHK6MRMXEYIiF8OX29P6UQJUeP
Hf1JEeQKGE]AB4aCBcY8A3hk?4=<DDlo<T8c@De<ASdiFcYE;dY2Bdi>BT<o@495
?Se5A3`l@c@i?C`j?4E>HemHCd@i<2]4B4Q1=cDlAE1;@S`h=cHfAT0i>Ci3oTEL
@3doA4<j<BU1<Slf83P^<SHi>SXoB50e>Ce0@3`g=38g?3Xe<2laA44m>3@a<2l]
:bTX9bPY:S4a<30_;Rd]:CM4@SD^<c`V9RLY:b`];R@X;2/W9BL[:bXY9bDToR;n
8D0Sgg2;OHZ6VY>3L5aGH6]]JVmYHV5VJV]ZNWf3RiFFRgiTK6m/LhF?SYVBRXR<
TI:AQ8Z8OWYnNW5^NHN?RhN;U?j=Oh^7Q8>4OGZ0SHf1NWf0PgebMHNCThf5/9E]
Qj34`l2o`L?3a/[1_kk1a/G0^l:h^Kj_V9bdZ9RobljoQH:Y];jo^KJk`L:g]/78
a<;7_kJ^/;Vo_KS0]ZFRT69XZj>@VHV`jLjjf<o9cmWIbkg8`[k1b<[3_;Jh`<cF
e<Nk`K^fOkJi]k2X[kCHlN[]jm2_]k^f[jja/k2f^[Vd/kRm]ZfWZ:ZVWYVHXZf^
YIZCT:FVS7j>Rh6>SXB@SFmdTIQ]OHfARhR?V:BJUi^HSHZAUYFFUY61JEQ/If9f
QFUWUHQnP8V0JF5ZGF1SH5YGF5]MFe58C5=;>TQ4?S/l@daACclb@S=1CDa6?CUK
>UD_BT9;CTi:@cm0@TDn?DE4?3a3=3Tm?3XlADiSGeQ?A3T`:dA8B44g=Ca5D4]2
?3Pg=SI6@3Ti?T?nAEa0?Cm4@cXa:D4b?cHP>2hb=STj>Sm8D3Di?D10?3Ld<SLl
>SD`;c54@Cdh=34`;bd[:BPW:2TZ<C4`<2l^;BdY=dA2=Bhc?2HV9bT[;2d^92P/
:bLU9b/[:RTW9BCn8_hQ@2?OL8]mRXJJTh=`G5MPJfeZKfURHFIZJfYjOH>;UIJ;
OVA/KfacQHn>VI::R8bATY64RXQnNWijLFiiQhn;Qh^DoXeoRhN4PhAmNX2=SH5j
OH23OG9eQi>CSHF`UFf7X<C3`;o1`l?6b/6o_/76aL2k`[Ri_ZnHW;BXV;o;c[n5
PZVd_[ni][_1`[Nf`LS4`/No]Zj`^Knm^<2fYJ:@HVR[Xi2IRK3Yc[[HclW?fMW;
_LS2_/78b/>l][S0c=KDak_1^kIo][Vg/:R_]=Saj^g[d:ng^kJ_[[6c/;Jj^KBc
^;ff[JNXZZJNVIRR[JjUVY>@YJJ<OXj;PHj>Q92=KgBAV6emSI6;R8nHY9ZGViR=
RY6FUIJFTH5YF6aWHWJ5JFNER7j0RH1YHFYMH6=PFUMHFeeKDDQ<Dd/jB4@n>ca3
C55??c92<d5=C4Hm>E/jEBm:@T]>CTY3?d12AChmAD@l?4<d>Cdl>Sa5CV=OF4m4
>C0[A4Q8@CLe?4E@Bd8l>3Lf=TI0>CTn@oi5G40m?dA3>S4Y@C8o=R0h;S8f>CXj
?dQ@=CTm@40l=c@b=c`j=C0_<DA1?CPd<C0_;B/Y:2LX:BXa<C0`;bh];BTgA48e
;S<l9RHW:B//;BhT:2`[9bDW:b/Z:BLU9?hRoR408`G8OnAdSWb5Nh^1QWi_H5QM
JGAkLFIQHVEWIfmdP8jETHV5IW^5NgF3VjVCSHV:TIJHUhbBT8J4RhZ2SY2?SHnC
U9>=SY6ASXIkM6QYMhbFTi>JTiF<OWj<UIB@PZ^BIgV@]kfo_KZk`<;1^;Zoal_7
^k70];Fn]J6V_;2P`LG:aiJECjjia<Bl][Rmb;bh`<>l^;c5^[6b^l;1_L>dXZBD
HV^dVJ6SJhKPfl;;`[g5dM;6^<38d=39a<O<clS4b<o>`KFd^/2o^KBe^Jj/cNWR
h^??oKQo]K6c^;Rk_;Zf]KJh[kBdZj2MWZ2^]Kjo^JjTWj^_V8VHUHjNTXNATX6:
VHf8QhR=TI:?Ri^GWJRVUhnAQXbEWZ2GRGi[He]_P6IST6Z3RgAPHFAPHfEVHUaH
FUiJFE18C599=de8@3Xj?TE:BChg?D]BBd53AEe9ESe>Bd]>CTY6@cm0@TLo?TI5
?Ce5?cXf>T97AT96@CTe=Sa5Bd14ACdc<CU2@T4n>cTk@4A;AT51AT];BT]4@DE=
Bclc9Cd]>C4M=bhT;3Gn>A/l?cDi?T4o>S8^>Ce0?CPd=CLe=c/m>cH`;2l^oR`X
;S0b<C4`<2l^;Bd[>4E3=Rld?BTZ:bd`<S<d<3<e<Rd[;C4/;2XX9RGn8ohROb?T
M8ilQG^;PHInKf1HGFUdNg5VHF9UIfM_M82>UI69QFIkQG]ePi^YThf9RY6FV9N<
TY26Q8^:PXj@Shf?TiBCSHjATHj6NgAXJGN<UY>CVY>ES7inS9FDT8:[TVMiT;Nm
_kfj^l32`KRj_lO;ak^a`;Be_[FQY[b`X<75b/NFD9F^^LC4_;Jh_LRl^<33_;Rl
aKZa/[_2`Kg3]::TU69[]9VQXf^6h=_2bl:maM7Ba[S0b=3@bLC7c<o8a<S?c/6e
];[0_kVd]KV^[<gYh^;ScofhOkFa/kRh^kbj][Ff^:nd]:^PWIjP[[Fn_kV^Y9n[
[iR9V9F>WY:7TI:1RYV=R8N8SI6BSh^KUifXYYN?THJ<UIjPUhUnJf=KKh1VHi1Z
Ph]dH65TH6=UIV9LF5YNFUU@B4aBBCM=B40j>Si5BTTn=ce;DT]1@dEMBEHmCT];
CTi:AT<o@497?ci6ACdmAClj=SY2AdI2AT4i=CHlAD]0A4Dm<c4i@T91?S/i>d14
BdI1@DI;BdY;A455CD/o<bDm;CTa7CL^92`eoSTK?3le>Ci1?cXb;STm@3dh=3Dg
=CLk?C/f<2`_;_h/:2h`<S4a<30_;Rd]:cQ5@cH_=3dY:R/]<38c=30c=C8]:bda
;2`Z:2HUoR?n8WlSi7B>O8EkRh66OVmPF5eYM7]aIV5RIFMWKgB0SYFARHEVNhEk
MH>KZI>=RHZAUYRGS9:@QXB;RX:>T8n=Si>DThf>TI6>QW]dJ6UgS9JCTiZCUHan
OXbEU922Zi9WNI2g_Knm^[_0`/6h^[o7blNk/L2d]KjeXJJl/:31aL[7UU2E[[W4
a;bf^;g8_;S0`kbh_<Fj/K:k`/6m`kBRY9ARJkBIXJ=[Q^3K`/_2_LGAd/Jh`<S@
d<W4alc?b<C8clk1]KBj`;ni];Fi[Zc=jN;Rhlom^7ne/K>h^;^l^[Je][R_];B[
X9fNX:je_[ni[ZBOZjnHRIRESYjBQi6BPHZISHR7R8fATXn;ViNMZ:JGSi66S9FN
X9N9OV]SFfn0IV>@JX>;M61QI61SIFIRG5QJGUYID4Q<DTTgCDQ0>SXnADY9?SLm
Be9;@D=5GDUF?Di;Bdi>BTI3?d12AclnATDm?DDo>SHj@TM6@TI1>CDf?4E;@4A5
?C<a>D92@Chk>C]0A4]6@D56Bd]:BdA1ADe;?c<U?Bdi<Adg;R@/=Ohi6c`o=CTn
@Clj<Rhi?D0m>3@e=cDg>cdk=S0/;bkn;2P^<38a<C0`;bh];B/hAD<f;c@m:BX[
;C0b<c@`<cDb;B/]<B`/:RPV9OhSoR808`GAOnIhTh:<PY66R8ElJU]NL8::O6YN
FemSI6Q/NX^>R8VAN8V=NFM_QIAnOH28Ti^MViBJUhb;TY><WijDQhJ?TH^SXj6N
U85ZFWI/JW=iNhJESY:<Ogf7RXF@NZ6>IgB4ZKRn_;>c^kbg^[c2b/k9_[Bi[Jnk
]:6R]KRYa/G=eJ^[OjjiaLO0^[^obKbf_;bb[:k5^k:d_LC2_L>fYJJMMGbk^IbP
R96i`N>e/:b`^;Zd[:6`_;V[YZjk_KJa];^n^[B^^/G4^K>g_ZZS`^;LfmoA`KVf
^kVc];bm_Kbk^KRg]k2n`;2QXJNZYJZb]kNc[JRM[JFQ[jBCWIfAVI^?VIQiOifC
S92KWiV@U9BMZjZISHb>S8Z9RXfAU75_HfYhIE]jF82<KEUYMW1YJVUTGEYMHEQH
DTa@Ed`jDDe6@3ho@TE6@T16Ce9=ACdoBdA9?T90BDa=B44m?T5:@D57ASdl@d<j
=3U5BT<j@S`d<CQ8FFDd=CHd<SDm@bdb>3/nA4eD?4]8ATU>D4i:BdM6Be1=@SHY
?2Pf<R8j;B@/=c/j=cLh>3/n?cdg<2/d>3Xh<c4d=b8X<CTm>SDa<S0/:BOn9Wl`
;bl^;B`[:bP`=cD^:Rhc:R/];c8e=cPT9bTW92@Z<2d/:bTW9R@S9bHT8R;VN9>2
S8:AQXR5O6YKGW22RWaZGU]OHfAXK7Z;SXR9TGR9SGUWKhFDOWf0R9>KWI^DVYN<
Ri:CS9nNU8N6Si6;Xj>QWYB1JUYfK6YcNG^6UHjBS7moOHN:QI1jXHiWM8BY^;jl
/k>k_;Nj_<;:c/Vn];V][k^dXJ:e^:W6aLgEZj^^^LG7`;Zk_lVl][bl/Zb^aK^b
];g4`[g3]ZFVWGEl^kVLX8RA^L7S]K2//;Rj]:bQ/;biZjJ^^kff/KBk_[Zd[[[5
a;Vc]kjZXl;Rg=_OdL6i]Wnk^K>d_;fm_;^i^;Ng/;k0/:6QYjZUZ[:g]k>]Z9f]
YJ6_Y9>MWI6IVhnIV7VMThb@VinIT9BDWJ^ZVHf<SXb:RHZ=TIAaKf=ZN6EKNUR0
S6eIJGI`JFYYI5eJGF5HF59<D5M<>U5=AT0n?d95AT90ATmBCDDm?d]4BCi2@4U<
CFU8@Cdn@DY1@DM6?Ca3@cXd>DE:@cY2?3@a>4QIIC@e=S@b=Ce3;C8h>ci4CEA;
B4I9CU1>BT]7AT]@CD8f:C`X=S8R>RdT;3Lk>SLg>3Pk?Slm=c0[=3Pj>3<a=3LR
:34i?CXe<C8`;2TWoRIo<2l_;Rd/:b/X<3Le;RX^<bX[;Blb=CLh92LY9b@T:S0]
;2/Y9bHT8bLV928RiWRCPXb2THJ8QGaZFei`PXYlJUiKGf=TJ6ajRhj8RI5hRHei
Ifn5U7imP8RCVifKU9ZGS8^BThbOWYB7QXnARj>SXIjDPFYJMVaZLgUkQYF>TXao
Ogf7RXF@NZ6>IgB4ZKRn_;>c^kbg^[c2b/k9_[Bi[Jnk]:6R]KRYa/G=eJ^[[[W5
al2j^ko9_;Jl_;:/[/Fk/[Bma<:m`kJUYYeeO;^iW:28TKW1hkF`[;2h^[B/XK2l
^J^V[[^m][6d^kjj]:jjaLBi/kNnZZ?2h]cKgm71^KIo^kVc];bm_Kbk^KRg]k2n
`;2QXJNZYJZb]kNc[JRM[JFQ[jBCWIfAVI^?VIQiWI><T9^OVI2DU9f[ZYV=S8j<
RXV:SI6DLFmSJWQUFgYHP8a]FFUfL6UZJFAMFUeQF5QBC51GC3YACDI0?Sm2ADI2
@4I?DTe5?Cm;A4Tn@T19C4eYB44m?T5:@D57ASdl@d<j=3U5BT<j@S`d<CQ8FFDd
=CHd<SDm@bdb>3/nA4eDBdQ6BDi@CTY;AdI;D4e2=RTl:3Hb8SX]92`g>cXg=cPh
>cho?CL`:c@h>SPc<C@g8RPa>Cdj=C4b<2`Y9ohV;30_;bh];2/[:30g=BhZ;S<Z
:bd_<SDg>2@W:BLT92X`;B`[:BLV92<W9R@R8PG>OnYnWYBTWk6XRhIkL6acPhnI
QVeJEEUOHfMXMHF7PH^NQXZ2LFaiQh^1PhRAVijKUYZOVHb8Shn8VJFSSX25S8Yc
Mh6AWZ2GSX]nMGEbJfmkQ8b=QHB:R7nGNj6GN8:<[K[3`KJf`L>ja<70`/K7`kjm
/;:o]j2KZK>Xal?<ejjZOjFc`/S4`<?8cL2j_kne[[70^;6d_L:o^<2kZJNXSi6o
eIfTZ:BPXN>h][:`[jn^[YnW[J^TXZVaZ:RZ/;Nk_;Zg^l31_[Rd/ZBI^MgKfn?L
akVe_;fe]/2m_;^l_l30_[No_:bV[[2XVI^NXjJUXIjI[:NT/ZRJYYbFXJ2DWiil
>iRDTI>IWj2OUi>HXIj=PhBKUXb2NWUlP6iiKFMfKV5]JGIkLVU/MWe]KF]UGU]O
HeYLEe9HGeE3De5=B_i824U;BDM8BTiADoiHL5eOGeQCAdU:ASlk?3i>AD=8AS`j
@CXi>C/m?S`iCdU2?T=>Ff@n>CDe>d13@bde?T50@4I<ATI8CU=BC4E5AdY>CTTo
>3<o9SHj;44`=3Tn?S/j?40n?d0o>cH`;C4d=S@a<CDj9bX^<C<b<2l^;2TVoREo
9Rd];2/Z:RTX;Bd/:RTZ;2hW:2X]<C<f=bHW9b8M724W;Rd/:RPV9B@[:BHS8NYn
WYBTWk6XRhIkL6acPhnIQVeJEEUOHfMXMHF7PH^NQXZ2LFaiQh^1PhRAVijKUYZO
VHb8Shn8VJFSSX25S8YcMh6AWZ2GSX]nMGEbJfmkQ8aoSHF4RXQoUg^QUgR2S:fj
`l6f]/73^/C1`<;6al>n_K2b_kNPVjVcZ<O3c=N^ZZFc`/S4`<?8cL2j_kne[[70
^;6d_L:o^<2kZJNXSi6oeIfTZ:BPXN>h][:`[jn^[YnW[J^TXZVaZ:RZ/;Nk_;Zg
^l31_[Rd/ZBI^MgKfn?LakUY]Kbm]KK0_Kbk_;o0`;jg_kb/YZj`Z9VKWZ>VYJ6N
VJbWY;:XVZJLUZ6PU9nNO9RDTI>IWj2OUi>HXIj=PhBKUXb2NWUlP6iiKFMfKV5]
JGIkLVU/MWe]KF]UGU]OHeYLEe9HGeE3De5=B_i824U;BDM8BTiADoiHL5eOGeQC
AdU:ASlk?3i>AD=8AS`j@CXi>C/m?S`iCdU2?T=>Ff@n>CDe>d13@bde?T50@4I<
ATI8CU=BC4E5AdY>CTTo>3<o9SHj;44`=3Tn?S/j?40n?d0o>cH`;C4d=S@a<CDj
9bX^<C<b<2l^;2TVoREo9Rd];2/Z:RTX;Bd/:RTZ;2hW:2X]<C<f=bHW9b8M724W
;Rd/:RPV9B@[:BHS8NYnWYBTWk6XRhIkL6acPhnIQVeJEEUOHfMXMHF7PH^NQXZ2
LFaiQh^1PhRAVijKUYZOVHb8Shn8VJFSSX25S8YcMh6AWZ2GSX]nMGEbJfmkQ8ao
SHF4RXQoUg^QUgR2S:fj`l6f]/73^/C1`<;6al>n_K2b_kNPVjVcZ<O3c=N^ZZFc
`/S4`<?8cL2j_kne[[70^;6d_L:o^<2kZJNXSi6oeIfTZ:BPXN>h][:`[jn^[YnW
[J^TXZVaZ:RZ/;Nk_;Zg^l31_[Rd/ZBI^MgKfn?LakUY]Kbm]KK0_Kbk_;o0`;jg
_kb/YZj`Z9VKWZ>VYJ6NVJbWY;:XVZJLUZ6PU9nNO9RDTI>IWj2OUi>HXIj=PhBK
UXb2NWUlP6iiKFMfKV5]JGIkLVU/MWe]KF]UGU]OHeYLEe9HGeE3De5=B_i824U;
BDM8BTiADoiHL5eOGeQCAdU:ASlk?3i>AD=8AS`j@CXi>C/m?S`iCdU2?T=>Ff@n
>CDe>d13@bde?T50@4I<ATI8CU=BC4E5AdY>CTTo>3<o9SHj;44`=3Tn?S/j?40n
?d0o>cH`;C4d=S@a<CDj9bX^<C<b<2l^;2TVoRD]9Rd];2/Z:RTX;Bd/:RTZ;2hW
:2X]<C<f=bHW9b8M724W;Rd/:RPV9B@[:BHS8@G@OoR;Zij[Y;>XT8=eLWb:U9RR
SFiHD5EMHVUXLh:3OXfWU8enN8VS[JNGV9^QY:2ES:R[Xi>=TY69SjZdVX61S961
P8::TY:8OXR5RiNFRX>6S9RNVibQW92RPJRUS9RM^ko:bKfnc<k4bl>i][[1a<G8
^[c7_Z>IXjRQ`[k6dJFM?If]_lS7a/[@e<S2b<Vo^[bj/jnc_<2j/kjo[JN_XJ31
eZVbZjBPULC;b/Jn][Bg_;Re/[>f^[blYJ^e_<72o/<b_KVm`[j`XijB]=cMg^[V
bkZd_Knf]l:k^[Zna<S9akZk[j:X]k:OY::PXJ6PViNT[inDoZ9o^HnBXj6BXZZ>
QhbATI2EX:ZMU9:FT85kOY>FVIN?QX1mHgU`IGQlKg1kI5m^KEYLL6m_KFENG61U
GEmLF5mWG4YCDe9BDE1@Ce5?BdI4BUIPEUA=FEYQDda5B4U4?CTj?E17ADU6>cPo
;SLo?C@`=3/j>CTl@diIH5I<@D16BDIo@3e4BdPn=SDg@D=7CeAAB40oAD]>BT<l
=ca39SQ0=TPb?3`j=S4c>T93@d8o>cLc<38e=cHd=CY0>cLa:bHT8b<`;c0a=3Pl
?R`[:bXY:2LW=S0Y:2``<C0T9BLZ;S4c=D=2?C@Y92HY;Rh/:RTW9BD^:bPT8OR;
Zij[Y;>XT8=oMG9lRYBHXXe^F51EGF9YJ7>2Pgj=YiB=OWR9XjfWUiRKXJBPUHbX
Zj>CSI:ARHnZ]9Z1PHbAPH22RY:BR7j8QH^GUXZ3QXbHWY^LXIb@XX6XYHbHWK^o
b/Vm_/c>a<_3^KJj`LC5b;ZlakjSVJ>XXL:na]6UWIf]_lS7a/[@e<Pc`/S9_kZl
^[>_/kc0^[>n_jfW[j6P`MJY/Z^TX9G4bl[6_[Jd]kbh]K:c][Zl_:F[]Kc1`_k3
<[fi_L:n/:>NT[CLgMkZi/^j];fo][O2^kZj_/C8bLNj^jnRZ;NbWjBRX:6QX9^G
Y:nOU?jROkV?TZ>QTZ:ZSXN<TI6@UJ2ZWIBBUY21NgjCUYVGShJ0OF=iL6EhO6m`
NfAOKVeJG71_KfeUGUaPIEeOG5QOIea:De=BDU5@D4mACd]6A4YFH5IDCEUJHE=<
ADQ9A3di>Se@AdE9AS/h?bhg?cdd<3@k>STi?4=>FF1FC450ATU6Od0mA4]8?SHe
=d53AdmDDDQ0?dE;CTY3?3Ll@bHh@3I8<S`l>SHa<cY2@d=2?c/g<c0b=CLf=3Dj
@3/g<B/V92<S<2l`<C@h?3h/:b/Z:BPW9cH`:BP/<34`92DW:Rha<cE3@Sdd:B@V
:Bh^;2XY9bDU;R/X927hRj^NZjBcZ923OgEbO8ZDV::=KUQ@EEeRJFQcPX=nSJND
SGihRJ>]YiNHVj6TX9F<Z:^SThfBTHV?Z[BJPH6<TH60PXZBTXQnR8F;UiJ:PhJ<
V9jKW:6LT::1Z:F<V9fk_l[9_Kk<c/C;`kVf^/74aLRj_<NnXiVSZ:72_/KAYIfM
[Ko8alK:d=C8<l;8bKnj_;Zc[k>l`;Zc_[n]YjnQX<7FZK:[Y:2Ea<_:a[jf];Nl
^;Fb/kJj_;bUZkFl`L;n`c:m^Kg2_[2SWY:dg=gNj^K;^[Bm_kJg`[^j^[k4b<W7
^[^_XZRg/YnTXZ2QXJ2KUjB_WiCnXWniSi:SXI:RZXj7S96AT9FPZYfDTYJ@PG]n
TiJIUhn6P7eSNG1UN7a_L7]TGfi]FUa`Kfm]IEiLH6EMGeaHGfMLBU=CDU9AD51?
DDm;ATA:EV1FE4eIFV5CC4E8BD@m>CXmD4M5BDHk>3l^=clm=30d>cXi>Ca3CUUP
ETa1@4I9AWE0?DA;B3hf=CM1@dM?E558@3m5Bdi:@c`g?4<V>40fB38l?3Xf<C<j
@T=3@Slk=c<`<SDg=S@e>T0k=c4[9R@S8c0_<34d>3`n;2/[:RTX9bLf<2TX;30a
<2@U9bX^<C<e@d8m=2TT9RT^;R`Z:BLU9Bh[:2@Q1LYohhZKXhN>RHbERHF=ShR4
QiN9PX5eHV=bJ9BQPWREYY^ATi:=R8bJYZ29LG6;YJFH];JRVYn9NHbGVHN2UHml
OXR=TiB?R89nQH:2R9:KWinBYJNCRYJLUH>>W8agT::8`MC4/K^k/[Zn_Kfl_;fo
`LVd]<S7ZY^SWIO4b/FjSYMoXkS8aL32`KcFe<o7_kbn`L6n^;Bd^;k1_kFe^:NB
W;W9aK6ca;>P[lgFbJbV^;faYkJn^k^gWGbQZkW2a<C6b;Zo`l6k][Ff_:^[a=_V
looJ`KK2blBm`<S2b=GCalWI`/G7al>l]:no[[BeXJB]WjF]/J^OV9fTWj:SX9ZG
VIaoV9jLUIVTYIf=TIJIVINEU92@XZ:>TiMnQFAGJWEZIgAOJgAaI5]MI6]XHUUD
Ef5ZG5MFH6]ZF4M9Cda3A4mDCeMFD4@j>TEAHUQ?CeIJEU5>D4Pi=T15@TQ1>ce6
CDm=Ad0j>Ci4ATEXCdiBBUMTEDTmBDdj?TXnDdHhAUI3@VYWDT]5Adi>ASe8@4IG
FDY6CcPn@Sdf=3a5=SLh>3Xj>ca1@3hn@DE:CS8g?Cdj>3Xm7SI:BD8n=bh`;bh]
;Bla<RT^<BdW9B`c7R@V9c0i<B4S;c8[;SXg9bTY:R/];Rl`;3Pj;RDX:2?l:WoS
RY^SQhj9S9F9QHf?R8B7UhV2PGERHg9XU:62N9FVVi6CTXf8S9ZVX8UaLH^UYIRd
]Z:JWhUiS9NIQh:ESganR8fCU8n8PWj5PX:8TY^OWi:UYi>:UYbEPhjLS7N@XXS1
e<Ba^k^b^[jm_Kbl_Ko1bKBdb<NZVj>MUlC:aKZ>UgnS^<S5`<;1_=KDclNo_;k1
`Kjh];Bh_/6o]KFhYi:L^LW5/K?4/j2_cMK9[:Jh_K6W][jk^kNMO:6[^L;4a<K8
^[o3`K^f]KJlZj_4fnKcom[1]/;;a;g0b<;8eM?7bMW2aLO7`kbd[kn^];FQY:fO
YJfaZinHWJBOXZ>PVYNIW7nHWYbEVJBUWHfAUYVIUiFDT92RXXjCUgj5I5MZMFYW
M5m[M75TFeeTJfQRFEAGHFYLEeIPJfYHAdU?C4=4CeA?EeI@A3XjAE5RF4m?EUYF
DDi@B3Tf@4E2B44k?DI=Cde7@3Xi?TA6AFQ?CU9:EfAEBCe9CCXnBSiCASQ6ET=2
JVMBBdE7CTi6?DQ0AUMIBTI?>3i2?CHd?4Df=cPh>SXk?450?Si1ADY><SLm?CXh
>SdN=TY9@Shg;S0_;Rd];c4b:Bha;BLU;3<N92HW<3Ta8B<_<R/^>SLW:BTZ:bd^
;c0/>3X^9BPX8o`ZOn>:Vj>7SXV<UHV5SHn8Q8NGRH:1MF9SLVRDXH9hUJJKTI>B
SHR<VZJPRG5aRjFUV;BfXYZORGV<UiV7PYF?O7j8SI>DShR2OXF2PXRBVinOTZFW
ThZFW9F3SYb<Mi2RR<7Da;6k^k:j_[fm_;bm_l79];C8ajZKXifGa<[5^XjGOj>h
b<G0`/6le]C?aknl_/71_[Rd];Rn`Kne]KRWTYbibLFa/lBcX:o=e/V/Y[Rm/JNf
_[^k]ielXJ^i`/C4a/Rj_l?1^kJe][b[ZlCKi_?of/6f`/_4_L38`/SEdlO9fL;5
alO3_;B__jjd]J6T[InU[K6[WiRMY9nRXj2JUiVLOiRNW9FIY:FMSI6FVIVGUIB@
T::RSY>GOXETEfYeJVMdGf]dLFAKGFA[J69IE5MQJUaGEV1[JUQ7BDm<@dA?E4mG
EU14>SY5DF9HCdmFFUIACU18>CI0AD98@C/mATe?CDM0>STnA4I5J4m>DTYGI5E9
?DU=>Si:?U=6>4IF@d9ZIe9;ADM>CTHmB416EeU:ATlh?T8m=S@lACHg>3Pj>S/l
@D0n?T55BThb=cdm>SPj?AhfBTU2?SL^<2l^;Bd_<C8Y;S4]9bD/<ahT9RL`>C4Q
8blb:bhj=bLY:BX[;Bh_<2`h>RhU:2PSo2X5_goRQiJMPhf;T9:6PX^?RHJ;VI2>
Sh=_K7ISNH1dNYBOUiFGUHj6QHbCUWeRHGVCV96c/IZ@VXf6Wj6ESi2CUiF<OWn7
UJ:SVHf?T8n>S8^<SHV<Shn;Ri>ML7nCRGZHZhnM/jNFXZBLYZ^RVZ2^]kB^Y:c2
bZb6S:fHT/7:blBJY0F`]k>VXjkn]Wnh^;Ja[J^[Z:FRX:2RYJRn]kg6^JJbc/o@
]jk2_:RZ^LoH`jZW];ni`;jd/kBUS[2f_L30`LG:_<C>dLc4_kfk[:k8gnGUj^W?
_/C<bLS>cLS<eM;5amG6b<[;b<:l]lNe^[RQXJRGYjfa[:6KWZ>;T9BDT8j@Ti^W
Z9ZAV:6SZGnUWiVDSHF0ViBLUX:>VXJOOFajQ7f1TFA`Ng]aJVecJVe^JV=PHVEb
IUUFFEaIE4M?CdQ:EEQCCDe9@CXmB59FEEEHFe]FDU5CC3dkA4Q3DTHk?DU@C4A3
@3e0ADM5@V59BDa2CUY;EDI@Dd56E4QLFTdg;c`j9UABDE1>AS/bA0dnA5=DB4=:
<CDh>CPh>oPoOdI5@d=6BTiA=3Xo?c/h>SdU=Cll>Shk<Rl^;2/[;Bl`:Rh`;2LV
;38_;bLO9C4a9b@f?S<[<C@`:BXZ;2d^;blU<CHa;c<_9RXZ:BTXhXNFWH>=Ri2B
QX:;ShV6RiV@SXn3KfafHgV0M7ZDWiNEUiF>QXF<TiImHV5iTiRA/k6JDY2JSHJO
XIF?T9>GUHanOhNEXZ>ISHn@Shj<Rhb=RHb?Sh^;Tie`Oi>9NYR[SifcYiJRY9bV
Zj:JX:jg]:jT[<;:[8J<[IRB`L[;a9ZT/;NcYZ>^o[Io^;Rf/Jf[ZjRUXZ2PXZFX
_[Nma[VV//k?d;N^`[bXZ[W?f<>ZYkBo^L2n];>dYHj`][g0`<75b[c4c]7<a;nm
^jb^b=oUiN[Yckk4c<W8c/g8c=GBaLOEa/S:blS2_;O7]KZhXJ6XUjN]/JbQVijS
Ri2DU92>T9>KYjRJTIRQXjUoYInIU8f5P9^DW9J2SYZ6Wge/NXAmPI5TL7]kLFY]
LfY]KVYSH69ULVIIEUULFEA7Cdm8BUEHDde=BD4j?DQBEUEEF5]KEU9ADd`m>dA8
@e96>ce9D4a4@d0m@4E7AD9QBDU<@TiJBeE6D5=1AUA8G5Y==bll>RIDDU5@CTHk
<T@=?TACE4Q3BS4e>3Th>3_h?gm6AD=3ATY>DC@j?clk>3Xm9CDo?3Xn>c8_;R`[
:bd_<2X^<2`W9R`b;blW7bDa<BLT=Shc:c4d<2TZ:R`];Rl_9C4f<Blc;bHZ:RTY
:>:7UYf3SH^@TXJ2Rhn9QX^IT8j?Pfm/MV=iP7AjU9nGUINESXJ5S9>FOF9QNI>H
TK>aVU:@VXf6Wj6ESi2CUiF<OWn7UJ:SVHf?T8n>S8^<SHV<Shn;Ri>ML7nCRGZH
ZhnM/jNFXZBLYZ^RVZ2^]kB^Y:c2bZb6S:fHT/7:blBJY;2g/jJS[_jfOkRh][6]
Zj^XYJ:PX::UZ;jg_LJiY[;>cm2g[/:lZ:ZicmS3ZZNd_kW0_[Bc]:F>/;Jm`<31
aLZla<kAc<Bo_K^/[/SOiNGZjLnna<c9b<k=b<cEd/G7eLK8b/_8`[bgakFj^:6Q
Z9NW[K6/XI^NXh^@U9B@SY2CVjNXVY6HXJ>YOjFOVIB=QH2KU9bFPXjJQYmmK7Z4
OH6AI71kNg5ZKG=ZKFiZHf1RIG9VFEIIG5UDAdm?B4YEF5==CDU1>Se8DUIEEEQK
FeIBDE=<?C]4B4=BAS/mBE1<A4=0?D15AdE2HDU9C49>FT]EAU1C@DIDB5aJCCL_
?3XVE59AD4i6>c943Ci4DeA8@dXa=CPi>3Pkn3m<ATE3@dI:CU4d>Slo>cPj?BDe
?c`j?S/b;bh/:b/];c0Z;S0/9bH/<Rl_9alU<C4W93Hn<b/a=30Y:RX/;Bh_;bDa
=S4_<blV:RXY:BP5cWoJOHV?MXB7T8UmNX>9QXJ<U9>HW99oMg]cKfmjS9^RXiZK
VI67P7j0[I=kNhnU[JfWZYVEX925W:Z9U9^3TJJ=NWMlTJR_XY:?UIVDRH:3Qh1j
OXV<RI>UQ9>SSgR>TfamUi22SY2:UJ>@PHNLZ:2CX:o7cJj;T[:MU/;;c/RNYa6l
^ZjPXJfaZj2TZZbYX9F=TI7mT7nATHj=VZZSTYbhbmBeWKK2[InW`moM^IfYb<_:
`;Fg`<2h_L32`KjoaL^la];EcL6f/KV^]=7]ln[Rilnk^Kk0a<_Ac/oBc<;3c<S:
cLo>b/G2aKBk^jFU[9bZ[Jn/YZ6OXHV@V9^IUiRJUjR]WI6J[;Nn/jNSYJFPVJRI
UXYhRQjMSIInMXF=Q8:;L7Z3PWQ`Kg9YLGQhLFMPGWA^I5YEoU8EAU1CCU1IFE53
A48m>ci8D4YBFemNF_iHOeaEAT58B49GBShoBDi9@D=1@DE:BdM2Ie5CEDQBGU1L
BDi@@4QGC4Q?EcLXJGTZ>dEBEeA;@Si1?TA?D4I2ACLh?4=:CDY6@d91@3hl>cY4
@d93A4M;CCHk?chj=cLj;C8b;S<o?S@];2XY:BX[;BX];B/W9b/`=3D]8R4X9AXZ
Oce6>2PX<3DZ:R//;Bd^;RL`=34d>30Q:RXY:2KJOHV?MXB7T8UmNX>9QXJ<U9>H
W99oMg]cKfmjS9^RXiZKVI67P7j0[I=kNhnU[JfWZYVEX925W:Z9U9^3TJJ=NWMl
TJR_XY:?UIVDRH:3Qh1jOXV<RI>UQ9>SSgR>TfamUi22;Hj@RYFST867W:RPTj2_
alf^Ri:bWIK2blk8WZNl^ZjPXJfaZj2TZZbYX9F=TI7mT7nATHj=VZZSTYbhbmBe
WKK2[InW`moM^IfYb<_:`;Fg`<2h_L32`KjoaL^la];EcL6f/KV^]=7]ln[Rilnk
^Kk0a<_Ac/oBc<;3c<S:cLo>b/G2aKBk^jFU[9bZ[Jn/YZ6OXHV@V9^IUiRJUjR]
WI6J[;Nn/jNSYJFPVJRIUXYhRQjMSIInMXF=Q8:;L7Z3PWQ`Kg9YLGQhLFMPGWA^
I5YEoU8EAU1CCU1IFE53A48m>ci8D4YBFemNF_iHOeaEAT58B49GBShoBDi9@D=1
@DE:BdM2Ie5CEDQBGU1LBDi@@4QGC4Q?EcLXJGTZ>dEBEeA;@Si1?TA?D4I2ACLh
?4=:CDY6@d91@3hl>cY4@d93A4M;CCHk?chj=cLj;C8b;S<o?S@];2XY:BX[;BX]
;B/W9b/`=3D]8R4X9AXZOce6>2PX<3DZ:R//;Bd^;RL`=34d>30Q:RXY:2KJOHV?
MXB7T8UmNX>9QXJ<U9>HW99oMg]cKfmjS9^RXiZKVI67P7j0[I=kNhnU[JfWZYVE
X925W:Z9U9^3TJJ=NWMlTJR_XY:?UIVDRH:3Qh1jOXV<RI>UQ9>SSgR>TfamUi22
;Hj@RYFST867W:RPTj2_alf^Ri:bWIK2blk8WZNl^ZjPXJfaZj2TZZbYX9F=TI7m
T7nATHj=VZZSTYbhbmBeWKK2[InW`moM^IfYb<_:`;Fg`<2h_L32`KjoaL^la];E
cL6f/KV^]=7]ln[Rilnk^Kk0a<_Ac/oBc<;3c<S:cLo>b/G2aKBk^jFU[9bZ[Jn/
YZ6OXHV@V9^IUiRJUjR]WI6J[;Nn/jNSYJFPVJRIUXYhRQjMSIInMXF=Q8:;L7Z3
PWQ`Kg9YLGQhLFMPGWA^I5YEoU8EAU1CCU1IFE53A48m>ci8D4YBFemNF_iHOeaE
AT58B49GBShoBDi9@D=1@DE:BdM2Ie5CEDQBGU1LBDi@@4QGC4Q?EcLXJGTZ>dEB
EeA;@Si1?TA?D4I2ACLh?4=:CDY6@d91@3hl>cY4@d93A4M;CCHk?chj=cLj;C8b
;S<o?S@];2XY:BX[;BX];B/W9b/`=3D]8R4X9AXZ6ce6>2PX<3DZ:R//;Bd^;RL`
=34d>30Q:RXY:2H5b7oALWb0JG^2SX9fLgj6QHR?QhnLXif?QXB9MWB8UI>JZi^L
ViJ>QWmlUX9eO8bFVijDWiZNZI5jR:ioU9]XNIahP7j0RYNLUi22SiZHS8J<UG^2
Pgn4TifNTjBaUW^>RUMgUI>5Shn8Tj:BPX>?U8b0[jbe`kn[X:>ZW/G:blBGW72]
[jZTZ[2VUInT[;6^XHenSHn@TY:@Shf:S9jc[I^T_[g<ZHRU`K2IZKC@i=2/Z;o2
_kRc]l;<ckg1aLG2`/G9c=?HeLZm];2^YZ[6j?O`i>7@_kVj_L33d<o>bl>l_L;7
bLc>c/g:bKZ/]kf//;VY[_j]OjbXXYfEWJFWY:6PXINSYYfO/lO@cl2_ZJf`[JN[
VYJ<O8nPSH1hOI2EQGMeNh:7PWIYHEmYL7MfKF=LFEiUJfUODTM3B59FDE5FDTQ0
?chl>ci2ATMAFeaGEUaSHVIPD4Q:ASe<BTM4@dE9C4U5@D=8BdY8IeAHFTYBGe9H
@T=4:cI1DDDg<Di5>8b[CC52EUeFBT=1@D=8Cdm9A4<h=SY6DeM@AT50?S/g=38a
oS/G?3do@44c>3`k=S8c=Bd^:RPc@3d_;B`YoRLJ:BX[:bXY9bP[;BXb<b`Y:b<E
=cdm<bPU:Rh[oBcn;Gla=30Y;3<]7b/Z:BLUdG9lP6UkPXj2MW=nQXF8ShN?W:>M
ShJ4RGIdR9FCVZ^KW9^FSXIoO9J2MGb<UY^NU9nJWZVANXR^OiBKJ7VLN81nP8ZG
W9N@PXnJV8b6S9EkPX=oQ9>MWY>T/IIkSXYGMiFCQHn?R9>RTX:3SiB<P:n/]Gg3
_j^PXjZNaL[;a9NL[JnZY:Z`YYFOY:ba[Z6=OXf?T9:BT8n=RXbN/jfKY;jmc:V8
YL6`VJVdd>C@[:Ro`[nh/kO2c<nm`LG5`/;5bLcCf=G:_KB`[ZJZa^Sgl>CQd;ni
^[g0`m3?c/_3_;g2alW<c/k=b/Vj[;Nm[;2iZJkn[Gn/Z::MUIfUYjBQX:6GXjJM
Wk?7d<o0[jV]/:fWZiZFS7b?X8f0N7f@UHEgMG^2Qh9fJF5OJG1gMVeSG5UNIF]Y
Ge97@dQBEU5AEU98@3ln?3/n@TI7DE]LEeILHf9VH518BTHmC4Y7A4=5BDa9AD53
B4]:B6MDF5Y:DUmBF493A2/f@E55=c5>ACR<Zdda@UIMETY3@D53B4m?BDA3>3Hj
AU=GD4I1@3hk=c@b<Ohk5c`m?d11<cPl>cHb<cD];RXX<d0m;bd/:OhW6RTZ:b/Z
:BLX:bdZ<S</:B/S5CLm?C<X9BX^:od/oReo<C@`:B`c;Al[:RTW9M5bO81YNh:>
PWIcOXJ5R8n7SibSWHn6Q8UfM8RETiZ[VibKUXj6OgbFPWElS9JKWYBOVYjYTGZ8
[WnDVfQiW7R0OX2:UibGT8:?VYR<QXbENh:3OhBCWIjCY;6FNhj:EgNEThF?ShRC
XY:2PhnDS82_[;Em`kn[X:>ZW/G:blBGW:f_ZZBZ/:JEWjB//JjQSGj=Si2BTY2?
SHZ<W[>]VjBn_LbYR:G1/9VY]=3Td:bX_l:o^;>g`/c?_L75aL;2aLW<dmSEb[fd
/:jVZ/KXmo3ThM2o^KZm`<?@clk;`kbm`/O9c<k>cL[9^Zbg_Jb`^JV^oZeo[:RR
WIFMYJNTXJ2QUj>VWIncam3?`:nY[K2]Yj^JUXalSj2=P7QmT9F5MgEkPXN2MVUQ
GfU`MgI]HeaIGVE[JEmBAd=8DUIADEIBB40o?S`k?T96Ae5KG5MFG6=RIV1@B4Y6
?Da:AdA3ADU<BDE1@dQ;BTQWE5QJBU9ODUQ2@d@[=T5AACLaCTDhS:]=<D9FGEI:
@d51@dQ?CdU4@cPf>TICEe16@D0n>cLd<S7n>aLl?Cm0@C<h?3/f<S<e;BhZ:3=0
?Bl];2Wn9aXY:R/[:RTW:2/]:S8c;2T[8aDg?Cdc:2DZ;R_m;?h]334d<2T/<bdO
:bXY9bD5`WoBLgb0JGb6ThQlN8><SI:KPi:QYjFPVYBBOgf<RGZ4X9RHVY^JUHj9
RWj0TYfGUIZ<UHfAWhinTK65ViYMIXYYQh^>RhJ9Tij0SIVHSX^DWgN?RVicUij7
NI:WU8NYZWAlWYnAV9>:UXn;QhF5Q85oWjBa_;NXWYj/W;o5b<>EVF>LW9F?UYnI
RYNLYK2cZIB4TY>EUYJETi:=T::f[ibR^kK6Xh6N_kFV^:Zeen;:/jnc/;2a/[Bi
`;>k`lK5`lC6fmgMelo:b/f/YJ>bcnGWgN;Mdl[7bLO3b/g:`KVh^[c5a/S9o/Yo
bK^_^l6a];^[/Zj[[[:_Y9ZPYJ^ZYJ2OX:NVX:2bc][FhM2hYinITX^VVIfKSijT
RY2:RY6AR861O866Q7]^I5iZK6eWGeUHFUALI6EMDDU5C5EFCda>B3e1?cdl?Cdl
>TeBE55=DEm[J6eXF4m=ACTiADi8>cY9Fdm7?ce2BDdkCEI6CU4oAE=7ESdl?S<o
CCi::TA?>VZ1>3i<FeeB@cXgA4Y?D51>BD<[:RdhADQ1=d91?S/g=34`>3Pio3/_
;C8f=S4^;c8Y;B`/=T0i:2h]:RPV9bLX;2XW9RPY:RXV;RdW;3e8B4Dg:RLY:2@R
oRgm;7l[;2hX7b8`=2dZ:RTX9]9cO81YO8JCR7ahPhb=TY^3TZ6WYJ2JU99oOHb9
NXBPV9RJViZESXV:OX2BWINEVXbESI6OSWjA/HFKVUeVRVV7Rhj;QXVCWX2=VIR>
RiBOMhn:KW>GWXMiTZNDQjVZM7bNWi6HThZFSh^7QHF4PGnOY76a_;NXWYj/W;o5
b<>EVIbLUHnFWiV:UibU/;>YU8BBTiFFUYFCTXf@X[J_W::k]/JSPIjo]JJhZ[GG
h/Zc[k>`/;6b];W0/k_3a/G3a<KKgMgGcl[:cJbUXk;?iNOMh]gCb/O9al?:cL[1
^KRj_<G6b<WnbWo9^jnk`K6d^j^b[Z^^/ZnTVZ2UZjZUX9nPYjJPX;;>f]KQd;RW
WiVBRjJIWI^?WZB:T8Z:TI68PH5lPHJ4NfiTGVY/KFMOFEQJE5aTIEeABDE<EEI?
C4i8?D4o?C`m?C`jCE9DDDeAGf]XKFQHCde5>CU5CTPk>TUKCdLo?D99CC]=ETI>
DCm5DdMF?C`n<cm=?TXZA4ljJX4h?TaKGE93>SM4BTm@D4i9@b/Z;CQ5B44g@T4n
>cLd<C0h>3Wl>bl]<SHf<Bh_<RT];2`f@3TX;RdZ:2HW9bP/:RLV:2TZ:RH^;BL/
?DQ8ACLZ9bTX92;n;Od/Ob//;RPO8S0d;BXZ:BPVdW=lP6UlQY>8O7R3S8fBVh>B
XJNUX9ZDTWmmS8UjQ:2HV9ZKVYF>RHYnP9:MUiFJS9F=TIn>OY6aQI^JGFJ:JHN;
SX^6RI>NP8fIV8j;U9mgShY^LiNNQgVBYiB7ZJYdO9jOTIRCRYJ?RhN5QHB1OinT
LK6l]jRNWZbL_lG8`iFIW9bESiJOVHZGW:F`/jVDQ9:CUIJFUI>BSI2R]ZnLX[^f
aZ>1W[neY[RZ]MORb[>_/k2`/K:d^L2c^l?6aL?4a]_MgMO?b/[=[:FS//oUimgR
gM?:alW7`l[=b/6i^;ZlaLK8bOk:OlVk[k_1/KBkZk:^Zjjb[jBJX:F[ZZFPWj2W
YZ2P//kJe^7@^:NOVI:;YYVMVhnNY8Z@RXZATHR1PGb1QXAkKVANJVa]IemIF5YD
G6AUGE59ADaEETm<CTPm@Clm?3dm?3Y=DUAACE5OJfQ]J5Q?CDDi>DE>B3/jBE]?
Aclm@TU=>deFATiA?dECAeHm?3hc?ddnBRY4CcYZPCPnC5]MDT<j=dA:Ce1@CTU3
:bX]>4E8@CM2@Chk=c@a<3Ph>O`k;bdb=SHa;Rlb:Bd/;3I0>BP^;BXX9RLW:2`Z
9bHX:BXZ9Rh]9b`mB4Q5=bXW:BPT8_h]oB`=:b`^:1lR<3@]:RXY:2H5d7oKO8F:
LXF=VI:4P8ZCUIbURi^WYZFXYZ2MT8b@R7^6WY>CUYbSY:2KTH^G/KNVX:VATGml
Sh^=ZjjHYYi/K8AeR9:IThR9Vjf<TIFARXVAVGf<PVM/RXmiMI6UTHZe^7aeVj2D
Ui27Tg=iP8B4Ph:2Pj_AcZbEXKZUTkK0b/ZNX`nYXXmmOY6MWHB7T9nZZIZ;oY81
TI7nTTV<SIj`Yi>I/[k8Z8ZQ^;Rk`:bYa>3M`Zbm^[k3_K6`^;6g_Kjm_<33b<[:
b<O:d][3`;Vga]cTgm_Nf<[4a/:j`l[8^kFj_kk5aOk6OlO8b<VkaLRc/;>P]jjY
[kRfYYJa];FaZjRZ[KN`YZJmem[=fm71/::JV9RQVJJ]YK2^RjRKRGahO8N@MGb5
RXZ3NWAZJVIOEeEIGf=NEe9ADUAFCUIEBdM;Aca1?S`n@D0j=59@BdM7CeeXHFUX
G5EDBcha@4]5=cE7Fda5?Ca1OdM:BTi2CU8oA5=:F3ln@cY6D3eI=TAD@T]A:cDn
BU5ACde=A4mCD4mABd0`<3<i?Slk=dM6A40m>SPf>S`n?cln?3/Y;S@d<C0b=BXa
<bld>cHY<S0]:RPW:2T]:2@T:2/Z9bh^91PUC7>7CS<N82TX8Ql^;Rd];2/Z:QdW
:B4R134m@2TYoRYofgb5RW:5SIVBQ82:TiFLYH^KYjJUZ:JPWI2<T8QkQYjCTiJL
XjBPVi6;Uk6gYZ2YTI5oO8n;SJ^^V:JNK6b4MHRBVI>8RI^]S96ETHZ9TIUmS89W
K8Z?NGFAYI6:]KQlMI^PU9N@Qi=cNH24Q8>2PX>[dLj/UJ6jYI>f`<[:WZ<?ZJ:?
OGjAWIf4Qi2OZZVJRojB0I6AoY99S8fN/:NCVK:nb:R:XKRh^l2/ZLCPgL:/_KZn
`kfa/;Ra]kfn_Kc0`lS:b/S7b];J`l2i]lKLi=oKg]S:a<K2^/?:b;^e^[nnaLGn
aWo7b<S9^lG8/k2cX;N^ZJnh]ZJF/KBe/J^XZZfg/:JV_MOJcM_A`K2RVYRHXIVV
[JF`[X^XVhUlN7b7T7ElQHZ:PgYdJVYVGeMEFEmSGUMBDE9DETiFED]7BdLl@Chl
?T50>SABD4]7AdmMJ65YJ5aEE4/n<D1;ACLeAe]<ACdl@Gm7BTY>@TiB?dACBUPo
?T<jAU0mFCI4E49;DB/e?TYADDm=CDA?De1?DD]0<30c>Cho>cM7ATA0?CXh=SXl
?Slo?S`k:Bhd=34`<SDZ<C<_=3/f:C8`;BXX9bPY;BPT92P[:RL^;R@H9DacQdhc
7R0Y:28O;Rh];B`[:RXM9bTQ8P@a?D0Y:OhZOm]lQHYbQHfITXB0RY>EW:F;VjNV
YJRVX9f@S928NhJNTi>FW:>TX9^ARiNa]jJPZI6AOgb?Rhf[[YRVWVa/Q7F8TYVC
R8VK[HbAUI6:RI6IOHb2Ifb:SgUeTJFAR[FhO7FKX9BGT8NCLgV0Q8B3PX:3Zm7>
[9FQ^ZFC]/3:bYjS3jVRSgenTIfMQ8N@WjZYVX_nTP6ATOjBBHb=W[2WTiVb_/RX
RZ6h^;_0[:W4h=g2[;fj_/>m/K2h/KNm_[fl`<?8b/[8al[Bf/?0^KO6g>COfmkH
b/C6`[[3b/Rk]KZo_/G5o/IoalS8bK_5b;>`/j2g[ZV_^;JVU[6d]K6[Z:Z]]k2V
Y[gGf/gKdL6`XYZHV:6IYZfU/:j;Z9^9O7QlQi1eO8F:RX=jM6YZIUmGEEUOHeiG
DU5BE5I>EUE;Ad]7?44n?3i1@3XdDU1;AdM?GFQQJFQLEEA;?S50BdDg=DMKC4Dm
?45oAdY:CT9>DSm4DdYH?ci3>TI@?ETfA5A2Be4[=Ci:DE5?CDe4Ce=@Ce5;@30`
<cTn?c/gAdI4@3dj>3Hj?3ho?chl>bT^=3@a<38e:S4c;c@k=RTb<2dZ:2LX:BdX
92@X:bXW;RhT62E<LhM><ahP:BPR7bh^;Bd/:bXZ7BLY8B84<Ce0:BWn:PGAOm]m
RHieQX^ESh5kQ8f?UZ2BX:BHU9bNV:2DRHR<TINLTHnAVJF/ZjMnN8JRXhj;ViJI
RXRGS8JOW:B[X8MoRYF9TIVITi6GWY6>R8>2QhfBU7a`N7agNXN:Xjj?PZ^YIf>=
V8jBRh>AL79iQHn>PgV0[]KA[YZX_jZF]l7=cZ:VH[2]Vh9kRY^QPGj0RiRJSX6A
Sh^9RH^?TJFT/l>jYk3:b/^[U:2U[<Nf]kFjb]S?_Kbj`L[4]KK3_;Ze[ZZ^^L:c
^;bl^[_0aLK=bl34f>CRf]kD_kJm_kO0b/Vj]l?:al[9aok6OlO8cL3:c;Fa/Yjj
[jR`_K^XU;Nh][6/[KBk[Zn/[KkDf<o>d<^lZj>X/J:K[;Re`;ZCXi^:N6mcO85d
NhF?Thn6OfY[JVENG61UKV=GE5ULFUE>E598Adm@BC/i>Sm6ASlgDD]5A4YBEeUA
G65LFeiGBc/n?S/h>T99?choA4U9Od@nBD1@ED57F51H?d17@D]@>TU8Bda;C4@c
?3/m@deEF5Q1Ce=<BU19>c`o@Cll>S/nADA2@3dk>CPh>Sdn?S`i=bT_=SPf=STm
<S/j;RXa=S<e<c0/:RTZ:RhW8B8X;2TU;BlW6R=7K81>=28T9b<S:Rl_;Rd/:RXY
6S0n=B/_OcPl:2TZ;2kKOHV>MHJ;UHn1NhB=SiJPTZ2TV9BLWYRPU8V8S96GW96?
TIVU[:^WOWR6XZ>>Ri^FVHZ8Uhb6WibTZj27OhZERI6IVI>AUijASXR3PXN=TYAl
L7QlMgZ7RZ>^Sh:[ZFMSSIR>TX^3TG1bNHF?SX=iP:kFdJjJZ;nZJIJg`Lg>XZJ`
[I^2NhZKXH5nP8^HVXj1THn;RHV;Si6UY;?3^ZN`b/[;ZiBPYJc7][Ne^/[Hckfl
^/7:a;Ff`kbj]JjZ[[W2/kRl_;Zk`<G6cL_0a=STh][Ne;nf_Kng`<[9^[O3b/O:
bLOnaWo7b<g0b/be/K:N^ZnX/;fkZ9Bg^;Ja[:fd^jj_[:fne=S?c]3;_:^SZ;6R
Vjbh]L2jTj>KRWQ_Lgb1M7^5Si>?QWmZJfYUGUaPIFiSEeAIG5YECUABB4M?D4Tk
>CXoATHo=e5;ADA:DUMIDEaQG5]NEd/k?Shk>3Y2BCln?dA9BGm4?TU0D5E1AeQ@
F3m0Ad5;D3Y9B4]<Bda4<c`k?D==EEQH@DmCC4Y@BC/l?d4o?3Xk?TE4@T0m>cTh
>3Xm?Shl>CLY;cHh=SHi?C8k>RhZ<CHc=C<`;2XY:RX^9b4R:2`Y9Bd_9aXSAfb0
CS@R92LS8bX_;bh];2XZ:AX`?SD[;glh?2PY:R`^fgf9SWF6RiF?PG^4SHnFX9:P
Y9RDW9jHX9B9R8bAUibASi6IYJb[YgihQZ:SSX^KUYV:R9N<QYnLY:^PQgn:UHVA
VIVCTINNTHj8Ph:7SI:DO71hO7MjQhZS[Xn2ZjUWHhfHSY:;Pi5`LWV5Shj3NH2^
e]6^VZRoZVVF]l7=cZ:V/:fKPW^:Vj61OX2;V9Z>PI6?RhV9RhnAYJBc`kZW/<[:
bj^DX:F/akJg]K[:f<nm_;[1b/Be]/>l^[F^ZZji`[>h_;bj^l35a/g;`<CHi>;J
g]Bo][fo]l3:bKZg`l[7b/W7o/IoalS=`<[<]K6bW[Z_Z;2m^jRD]kRf/Jb]];^^
[jb]_]CHclk@bkb[XjRaXY^/^;G0^Y>SVhYhKg=lPGAkQHnCShIoJV]ZIEiLH6E^
HeMDFEaJEDiDDTQ7Ce19>cTj?dI6?cMABdE4BU9GFE5LHEaKGUM;>chn>cPj@TTo
?Sm4BDUoA3i9@51E@DMHD5Po@4M1Be0jBDQ;C4]<A3<l>ce3CEEHF45?Dda:D4Tk
?3m1?c`j>ci5A490?C/i>3Pj?Chn?3Tg:Blf>3Hf>Cdb>cX^:S4f<cDc<2`Z:BXZ
;RLQ8RP/:BD];bLJ8dM/P4hd8R@W8b<Z;bl^;B`Z:RTJ<3he:bl6>3`X:BX/;PGA
OmEgQ8YaOh>;Q7I_Mh22RI>CWY^8P8Z>R963LW64VIZ>THf=UZB][ZZBRIF_[YZK
/YJTXZN^Sg5iR:FXWIV=T:f;SiFJVY>8Ohb3NGMnR92D[G1RSYA/Kin;Xjb9OJVW
HeF2T8Z?RH>BPGYkRYbJPVZ5W;:f/:VSW[VS_lG>cIjOOi^SWhYlOXB5ShIoPh^:
OW6BShV5QHV?TY2>W:bTTificlVZUiZBW<JX`LRg]L[FdJ:OZKVg[KG8bL2`X9ZQ
/l:j`<K5_[Nc/ZRj_kFgb]SIjNcM`;K2b/Joc<^l^/[Cd<k<b/S7alS8a[[7c;Vg
^JJk[jN`_kjYTZRWY9nMXZfgOiRU[[6ld=cLdmSE_j2?TYbUWZnm_<W3W9FKVY24
OGA]NGj7T9>=PGQZKW5_JVIWJVYSH6M_JUI4CE=@B4UFFeHf=3M0BTa4?4e6@DI@
EE5;@U1JFemUHEI9?C8c?44m=S<h@TaAC3hb>C94BSLmCdQC>ce6@DY<=3QIDS]4
Ac<W:VQJBT93@chg?TeAB4I=AcHi?T0i;RX`>3hm?3Xh=SDd<C<f>3Pe<Bl[<CWn
?0i0A3]3?BXP:SLm=cDb;Rcn:gl^9b0Q:2`Y928_<RTX=dI<BSL/:bDL9CP`;bh]
:bXY:B=1ET/d:RX[:2T[;S7EMhB:LGn3RhAfKgN0PXVCTijKR82:SXRAPg9aQ9VJ
SY6=SIJT[JjZTXVE[jjJVk:FY::W[XmaNHRUZ9fISI2]RhnEVYZCR7n<PgUgOXR@
U:e`HWn>U6a_Wh^S[8UmZJMSEH:@RXn9Pi:1NW^:W9Z2JXFL/[J`ZJ>N^J>oaLk=
WYnKXin:O7j4QHn6Oh>;RWiaTXn9QHF9Si:@SYb/Y9>M^Lo9ZYNJTYc6Z<78]kG:
e]6RWjVi]jfeb<W0/:2JXK?2^/36aKjg/k:X^[ne]l[HfNW/gGo0]/;:a[o<bkbj
b]?@c/c:b<O7b<S6^/O<^KNiY[^_Yk2o_ZVBZ:NTWifR[KNHYJja_=3Lg=?HeKnP
Si:LYIj__Kc9`ibEViZ@Q7edKGUnQi2CSH5hJViaKfYVIfYZHf1WKfYFA4eCD4Q9
EU]F=S@g@4Y<A3a=AT56D5EABd9@FUMKGfEQETTm<S<l@Cdf<cQ2C55<?S8i<TA:
=ce?B5<k?DI1BT`d>5UB>dA7<bMXFTY2@d<n=ci=DDQ6CDLf>Ci0>BhZ<3Pn?C`j
>3He=34c=SPh=C4_:c4ioS`>@4@k@cdZ82Xg?CLe<Rh/oR]o;RLP8BP/:B@R;c8Y
:3M6C4Xg;2/U72Dh<2l^;B/Z:BTS@EI;=2XZ:bPY:bhaeGN4RW5oPh^4MVmgP8:9
Ti>NVhR0RXj8TH=bLHBIVXjASHfFY:f^ZY:9UJn^VY^bUZBRYjj?LGV8YJRMVHf@
[H^?UIZJThQoS8=iMgj8T9B]L69oSYA/Kin;Xjb9OJVWHeF2T8Z?RH>BPGYkRYbJ
PVZ5W;:f/:VSW[VS_lG>cIjOVj>ORWanQ8F?QWn3RhYnLI:?RHF5RHnBT8jL[:BC
WKW?bJZGVY:LaZS1b;Neb]KAXYnY^KN]]LS9`;2PVZ6c`[[0a/Fn]k>bZ;Zo]KO:
f=WYk=eo`;K2b/Joc<^l^/[Cd<k<b/S7alS8a[[7c;Vg^JJk[jN`_kjYTZRWY9nM
XZfgV:F^/Kc@g=cCf=FoX8nBW:FN[kflbL>LUI^JT8AmM6eiOXN@Thf1N6Y^LFmZ
IVMZJV=PIfmZETA=De18BEIKESHd=d1:C4@lCDI1AU1EDD]2D5YGFemUHEI9?C8c
?44m=S<h@TaAC3hb>C94BSLmCdQC>ce6@DY<=3QIDS]4Ac<WJ5Y:@T=3?SLnCE58
ATe7=STn@3T^:S0h?Sdl>SPf=C@a<cHh>3Da;b/a>Ohl3T14>d<m:R0Z=cdg=C8^
;?h[;2hW824X;2TT8Rlb:BPgATa:=b`[9A`U>30_;Rd[:RTY8d5FBc@Z:R/X:B/^
<@GCOlajOH9kPGZFQY>?OhFHSg9kSY>4Nh63Ni5oI5Q/RiJ@Qh22T9^OZKJBRI2Y
^[>QUZRLTI6IW9B:TI6>S8nBRWj6Rh^8SYF=OYEoJfn6VIbFZYR>S81_LH28OI><
IgZ7Ee9YP8N2Ng9[RHJ;UI60MGInYko3^IB8Z;NY_L;C_7fBOk>OShf<RHfFViF>
R8F4PX5eKG^DT79ZNGb1TjJVWZ[1clZNPI:LTiJ[[/FS_K3@b<jWX<?A^Znm[kJd
Zj^d][2c^[nk/Zjc^/6m`<S:b]OZfN;J`[W2b<?4a<G7b/gAdm;@c/g<cLk?_/72
_KB]Zj^]/;>d/J^SWYZPYZJUZkO3Olb_Z;g1]lcddmCKg<:OUJ6>Ul>laMN]X:2J
T89gLgEiL7]oNWb;UYMjPEaBMFMCMEQPJ6ILDe5B;41<B4UBD4=FFU91>dQEFC`n
@454C5QRHe=KNX5UBTA@ET<lC4@`=ST/<da@>Rlg:C`i>Tm<@U1DCTM5AdQ6@cm5
A3i0AC`]Odi:CeQGCU1IBD4h>3i3@Ce0=C4nCT`b63Pj?Chm>SHc=T12?3]0?34X
<STd:RPb?S8a<2l^;B`/;R0M:SHd<C8S92LX:BPW9BPW9bT]<cXn<3/f8ad[=C4W
9BTb=BhV8c5EPg@h9S4X8B0P9Bc<NWf2Nh5jUXJCSgn5V8mbNhjCOhAkPH=kTGmT
F6b;UY27P8:@VinY]Y:9T:Vj/j6FZ9bATIVLU8ZATHj<Si::OXJ;RhR>UHenUGm[
KhJIW9JZV8j<P6maP8QmThaWNXMGDVV0Qh9kLV^9QX^ETH1eMWjW_l>iU8RX]jVm
`]>lOI:cWhn=S8V=UY^ESXR5Q8:1MFekOiB@LVYiO86CYZJNZ/7?bYj1TYbCUZ^^
aJ>m/=38cZNP`m6j[kf_][B[ZkBf/;>j_k^b[[>j`Kg0b<[:en[Ih][2^L;8`lC4
aLO:cM7Cd]3>cLc=c/nn`L:m]:f[Zjf`/kBaZj>NVZ2VYZF[]l?<[jRm`KO<m=?D
fmc2WiFQSYO3Okc5ejfPX9Z@PWMcMGU`NgmjO8^FUgZ1G59eIe=eF61XIUaCDE8/
@4a8BE9@@eIJDT4kB5EI?3i0@DA<F69SDe]jPFE:A51F@ca<A30f>B`cC50j;cLY
?3TjCda2D5A>AdE7B4I3?dE4?T15?2e>BTmHEdi@FDU1>3Pn@d4m@3DaOci>C38H
>3Xm?Sdj=S<f@48l>d0l<BPb>C@Z:38n<S4`;bh];2`^81dZ=S@a<R<T9bPY:2LU
:2LW:Bdc>Sh`>cHS7B/e<BLU:C8e;RHS<EF3M3PV<BPQ820U;<ajOH9kPGZFQY>?
OhFHSg9kSY>4Nh63Ni5oI5Q/RiJ@Qh22T9^OOjVfTXV@ZKZcXIJXW96AVIbDRY6A
SXb?TXYnQX^;R8jESGjEOf]_QYVLUZZHSXb0Kg60R7fCS6MjQeMBJH27PW]bJhV6
RiFAP7EfOZNo`kVDR:RgZKg2dkamT[>OShf<RHfFViF>R8F4PX5eKG^DT79ZNGb1
TjJVWZ[1clZNPI:LOi>FZjk5Xkf`d<S>Yj33dKZ__Jnf]:^[];J`/kZo^k:^/k[1
_L38b/[Gj]WRf/:i`/S3a<C5al[=dM?Bd<k=c<g>ckk1`[fd[J^[[K2c];6[XijJ
X:JVYJ^g`lb_Z;g1]lcddmCKg<:OUJ6>Ul>laMN]X:2JT89gLgEiL7]oNWb;OiJG
NX5LDWEWDgEHH6QVG5=ADRa0C4Q9DU13EUYB@C]8EETl?T11A4aHHV=CFgZ1IDY4
D5I3?4a4<3Hi;3=<D3X_=bTl>CY?C49@E4i7ADM8AT<oAD@n@4Dl;Di:CeQGCU1I
BD4h>3i3@Ce0=C4nCT`b63Pj?Chm>SHc=T12?3]0AS`a:38i=2XX<Shb<C0_;Rd/
;2hP7BXf=34b8b@W:2TX9bDX9bLY;C<j?S0k=R<M:cDa9bDY<SD^9R<aEH=d>2Ha
:24P82D/1LYogI2FVX^8MHJ0TI61P8b1IgF6RgmhOX1jRhQhHf5bPXJ7PXJAU96H
YI^LYJjUSX20YYbCU9bMUH^6RHjBUiRARH^BU8j@UY>8UHEhOi:OW9:4OH6?TH^?
W7iiUI1/QJ5mNGb2S9RQWiZARHZASX9nPXR/_lC0Wi>`/jJk`=:lOiARZY^DVj2M
WZFIX:>KS85nP8N>SXAlNg]hRhjO/k6RZKk4b:ZEY:25O:R^c:o;^mK:gLJb/KZl
]Jfh_[bc/kbn]k:f^[Zi^Kg1clC2b/o?e^7Khm_6^l;6`/K5a<C7c=7Df=ODo]9o
e=G=d=3;`[^i^kNh^[Zh/jj[[:na[:BQYJ^fYZ2WY9ncd];Aem_8ZinVVIc0];K4
V8fZYYjBQ7UbKg5lOWIePHZ:LH1^LHmiFg1MHfMTG5IGFT=CFE=AF5A8BdPn=3a=
D4U>BTE3AT]AE5aKIWZ0LV5JCEA2?4m:>dA4>ce<EU5KBdXiBTE4Ee97E5U?AD55
Be1AC55>AdQ?BC/n>d1;Bd91BDa5?Ce2ATA0=2la?dmA@C0b=3Hh>3Db<3Dn@3Xi
?SX`;cPn>S4_>48d=38`;R`Z:C0V92hb;2/`;2cn:ohZoRQo:Rhd>Cdb=c8[<Cdi
:B0U<3/m=Rl/945SEc<i@2@V92H[<mf@UYZ;R7F6P96APH2<PFMeQX]oN7j0NX^8
N6=QLX:6Qh:6TIBAV:FKW:F^YHj0P:JLTiBLWIF;QXV>TYNHTHV;TYB>T9JCR9F5
N7nBWibBQ7f1Si6;SianNIF@K8EoXGeiO8:<V:6OVY69RY6>PWj2R:boa<2OTk2c
Y[_0d[aoU:ZKU9^PWIjUVJ2SVhb1OX27SXj4O7]kN8^>Wk>aXZVna<RZUJBPQGbX
[/b_bk_Fb]g6/[6j_;F]^;jl/k>l_[Nb][Zj^KVm`Lo4`/[?cmKQfn?Ka[_2a/;6
aLC4al`4dMCHemCndWoDeLg@d<_2^kVk]kRj^[Rc[Z^/[k6/Y:6UZkJVX:NTWk?B
d]7GflR[WjJIW<2d]/BHSJZVWY:4NG9_LGanMWF1RXYaP6iaSgUKL5eSIfALEUMJ
@e=IDe5HE4Q;B3hd?4e@BDi:AD=6Be5DG5]VNX1bHEY=E48lCdXkA4@k?DaFDE];
BSU:ADAGDTMDFDm5@DE;D55<DDi7B4m9>chk@4];@T59C4Dm?D96A40d;c4oCe51
<38d=SPh=C8`=Ci0>STn>S0_>3hj<Blh@S@d<S0^;2XY<2HT;S8/:c0/;?h[oR[n
:7lZ;S@i?C8g<R/a?CTY82D`>cdf;b`T@F=G<cU092HT9R/cgI2FVX^8MHJ0TI61
P8b1IgF6RgmhOX1jRhQhHf5bPXJ7PXJAU96HYI^LYJjUSX20YYbCU9bMUH^6RHjB
UiRARH^BU8j@UY>8UHEhOi:OW9:4OH6?TH^?W7iiUI1/QGnQOGUlPXbHXInJTHV:
THj2OX:8[;o4`9nC/;>V^l3B_7nDZY^DVj2MWZFIX:>KS85nP8N>SXAlNg]hRhjO
/k6RZKk4b:ZEY:25O:R^c:o;^mK:gLJb/KZl]Jfh_[bc/kbn]k:f^[Zi^Kg1clC2
b/o?e^7Khm_6^l;6`/K5a<C7c0CAe=SGe?kBOmCEcM3@bl:k^K^g^;Zj^;>^Zjb_
/JbTXJF[]ZJPYjBO/m;BdMOKb:^OYYVL`;Bfa9R=ZZJNTXAiLVmaO7ifMH6:RW60
KW6?NE]`GF=WI5aFEeY3DeUCDEQDB4]8?S@lCE19CTY5@dI;DEALFfIjP79QFTeD
@Sa?BS]4A3/mC5IAFd]:>DY5A5MBAeAICdE1AD]@DDaACTM8CdTk?S]0Bd]2@DU<
ACdm@TI4@3@_<Cm?DD4`<S@f>3Pe<S0e?T0j>Chj<2lh?SXa;cQ2=3@b<2h/:RT`
9R@^<R`[<2`/oR_n:_hX8BX^=3Tm<SLb:c4m>BTP9C0k?CH_;2A1HeLc>D0T9R@V
:c<5dgoSW:RYUhiaNG:6S7igOGMWKGUnN7EjNgN3THmcFeibP8F5S9:;P8>AP96X
/In:S9b]YZ2SZJZRVH:7T9RKVINET9^MU96HVYFBRH>;VIjERXZ7SIVKThjBN7RI
UgFD^IekJf1[PiFIUIB;R8f<QHJ>VK>l`;nQTZZ^X[Nod[j1UgnXWI^TZJ>PY96Q
[:F?OG^0NYFIOgV;RWBDTZ>k]Z2P/loF^ZFbZHQkXjc@^=BncKWHdkZLVk2cXjRb
]K>jb]7=]KBe^/77alKJcLS@e=;Dg>7Vh<k3a<G3b<K2`LC;d]OIf=GCd];Ce<S:
b/Bk]KBf/k:b/:n][:^OY:Z/ZZV/[gn`/ZnTV9^^`=?@e=W@^jf[Xj31][_;YZ:X
YZ:JSh9fKgR1P7EaNH1nLXB8VJjCL7MYJFMQFeUMHEQOGeMDEe=9CTPn?DiPFTQQ
ETa;DeYJEdeOJfYXJ69HAThn>4a:@Di=BD92DfETET5ABDIGDTIDCD8f<SU4CE9B
EDm6B55>@gm2?dECEDa8C4U4?Se0@T0n;c0e?TI7@CXj>ci0@3ln?3Dn?cPg?3X`
<3Ln>c@b>D4d=38`;R/Z:C4/;C8^92D_=34/:2LX:R`Y:BX/;c@i?30^:RloBCXS
82/h?clk=C4W?595?F5V=RXY:c8khibXZIN>LGUbQXanMgegIfeiOWmhMGYkMh>A
Sg=KGW:0QHF<TX^0Pi60TJRaWhZ<W:fVX:>YZZ:IPXN@V9^IUiF@VifDTIRJUI:9
Ph^IWYF:RXN=VI^CSY9hN9VGMIBiWG][H6^3UIVEU8^8SHb5QXjI/kc0_j6BZZjR
]koB_X6GZ9fKY:VSX:BAXJbUSgekP7ZEVGmoNH^:M9BBXk^fX:2ccmJjYK:YR7^S
[=2he;k=^MSC^YbK/;>SZ;:e/k[:dLfe];Fj`LO7a][=b=3Dd]CLhNKPc/?4aL?8
a/;1a<_BemWHeM?Bd]?Db<[:a;^e];Jc/[:`[jf/ZinTZZbZZJb_/;:_Y9RK[/3C
d=CId;^]Zj>P`Gnf^l^VXZRVXYZ?PWI_N860MG5iP7ibQ8RI[Y=`MfUYIf5KFEeQ
F5mOEeAGDdU>B3hmCV1JB65FC4]CFUYGCEm[JVQXHUQ6CShhC4Y1CTe9@T9CIFAF
@E59AUMBAUA=@SHb>DA=DU9ECdI8DDi3@Sm5DeE<B4a9A3hm@490?Rl`=GlnATM1
>SXk?T10?chl=Cho>3Ll>S0`=chk=38i@C@d<S0^:bXY<B`]<RhT9Bld<B`X9bPZ
;2TY:R`_=3Tl<2hZ;cm9>R<P:cPo?c/e<BLlDTDmHFHf:RT[<S_SW:RYUhiaNG:6
S7igOGMWKGUnN7EjNgN3THmcFeibP8F5S9:;P7n3TH2AZ;6ORXbL[JJPXjVZXYV2
Qi2HViVGUI2KWIBAV9ZETXV3RiVNUHZ:QhfIVi>>TWQhVIMeU;VMNf]PJh>EVIFD
RhR=S8F6SYVc_<2oXI:Z[Z:g_m:nPINXWI^TZJ>PY96Q[:F?OG^0NYFIOgV;RWBD
TZ>k]Z2P/loF^ZFbZGn8Nj>/d;SD_/fif=>jW9^`/j>X/[Fc^/[AcKFd]K[1alO6
f/g8d=CBe=cQi^3>`lC5`lS6`/74bm;GfMSEdm;BdmC8b/[4^kFd][>b/[2_[Jb[
WjBZ[:ZY[:n`/ZnTV9^^`=?@e=W@^jf[Xj31][_;YZ:XYZ:JSh9fKgR1P7EaNGn0
OW:4R9V^Tg1gJFUWHE]IGF5HGemGE5MCBDi8?Se>H5Y8HEI<Be=JFUM=Gf]ZJ6QR
F4I>?SQ<BT5>CDU2@U=UI5I1DDU6Ee96E4e2=S8iA4eBDUE?ATQACT=2?dECEDa8
C4U4?Se0@T0n;c0e?TI7@CXj>ci0@3ln?3Dn?cPg?4Hj<30g?S/d<SU1=3@b<2h[
:RTa;2db;R@U;c@a;2PW:2X/:BTZ;2ld>C``;RX_?dTj8b0[>3lo>cDa9caBACeQ
ISHZ:B/b>`FoOmbJYJ>BSW9eJGYoLVU`MG9WKG5bLgEfMGjBV7mVIgV7LgIoQ7UZ
JgQaQ:6aZIfW_:NUY:V^[JBLTY:GVYF>TYbBWZ6FTIRLVXn:Qh^AThb5X9bKW9ZA
Qh:3OYbMP9jjU8IdJgR<UIJES8F6SXj6QXjT]kRi^Ib8WJZO]KkC`8BKOkJVWInN
U8nBRI:IUhf4PXAJN8n@T9F;N8j7V;FcV9>Wfm^fVjRVShVHXlRddKJmX/g?a:fM
X[2iZk>e/KK3bLBk]K>ja/k;aMCAe=WDc=CTj>[Vf/k9b<O:al?1a<_DfMGCd<g<
blc<`L?1^[6/[Jnb/:f[ZZZ[[9RMYJ^^[Zn_Ojjn_ZVJXkBme]?Ef=G8]jfeZ/Fk
_lb[[j:NVIFBS8AoQ8b:O7EkP7f2RiNZ/ij9RW]eJUmHF5eQG5YFDE1ACDM?D4e<
FFAMBeU<@4ADGeiHCFYdH59IFTi3CCdeAdDnCe1@@C=5IFMA>DQ0?Dm;@U16?cPh
@4YBE4Y;A3XmAdLn6d]6C5aQF59D@Sll>c/j>CLi?D0o>SDb<Cdm?d3m@@li@D4h
=chl=2/b=cLb<3@hnBl>;2`a=2`P9C@g<R/U8R@WoRYo;2hb=CPj;BTW;C]2>Rh]
=c`g=3Db;2LjBCPjK7M2:RT/=3gLVZFSTXibMFUjOg9YL7EbIfeaLW=eMWEnTYQo
IVMiQg=fOhAiJV]hLHBQ/JVMYkbWYJBY[ZfTW9:BUiZESY:LTYjQUY6HW9Z?RXN;
TI><QJ2LVibJTHN2PgjLWH1oW[ZDQWA[N8bEUYF<QHJ>SXJ6SZBg^;ViW8RMZYne
_]?0Q9^fYYfOWYB?TXVBVIN=Q8:4FWR?T92ERgR>QiRe/iRCYm_K]Y^XYXn9V:?8
]=6f_J;=clB]WJ:`^J^c]K6f`lW4^kFc^/K>blGDdMCIe<cDi>SZi][>bLS7b/O3
`LAobmCIeM?@cLc;c<c1`l6j/Jb][k:`[J^ZZZ^/V9fUZjj^[jn^_[jYVZ>d_MKC
eMSEb;N]]J[5^ko<ZjnRWYVETXb4OhB<RWaeNh1mPX^GZ[>NRHYkMFYOF5QMHEaJ
EU5@DDe7Ce1=C5UTGD]IC414E5mNF4eZM61BFEY>@ddm=DLnACi?D511<dEUIe4i
B40mCd]2D4Ho>3Q0BU9DBT]4>Se7Aci;ATaLHEQBE48o?3/k>STg>Ce0?cXe<S4m
?Cm0oD4?>D51>3Ln?3@[<SLg<S0d>?T_3R`/<C@/82Dd=c8[9B8T9ohZOb`^<SDh
>RdY9bdk@SX^;CLl=c@e<R`W>TTh>Vag@RXY;3@mg9ZUXi:>LWEYNWmbJG1eLVM]
LG9cMGIeOY:HOfIWNHMcMWn4NFY[N764XK6YWJNlYjFTZJj]Y9bBTYNJUHjBW9:N
XIJAV9bJShZ7Ri6CS8FPW9^LVY67PX=nW9f0OijjU8IdJgR<UIJES8F6SXj6QXjT
]kRi^Ib8WJZO]KkC`8BK]ZJMWijDSi:9TYVGSHB2Q5YhSi2@UH]hSXNH]K>HTjOK
fkJKZ:J?RIRSb;CA][fRcLo4[IfR/;V[/kFa]/?9a;^e/k[6c/_5e=7DfMC<e>CX
j^KJc/W8al[7`l74Ol_DfMGCd<g<blc<`L?1^[6/[Jnb/:f[ZZZ[[9RMYJ^^[Zn_
[[jnZIZS];gFdmGHeLRg[KFZaK^oc:^_XYjIUI:<Q7n4S8YlMG^0OH:;UjZcWXV:
NgEZGeQHGF5LFUIAD55=Adm@CDaII5e;FDa0A5AOGUQ=JWAPDUUJCT==?CE7?TDn
Ce1@@C=5IFMA>DQ0?Dm;@U16?cPh@4YBE4Y;A3XmAdLnBdI<G65HDUA2?c`k>cXi
=cTm@3lj=C8a?Cdo@?e13cU1@CPg?S`d:c8g=c8`=3Si;`h/;34d;20U=3Lb:bDR
92On:R8/;S8e>3X]:BL]>d8j;Rdg?3Ld=C8/9cY9>3Y/Md8Z:B`d?@G=OnBQYIV5
RG9dLgYgIeaRKG=WIVU_M7=bLgZ;THAjPY2FIfQ`Mg1SHfj:Sij/ZYfLYINIWjFX
YIfFZjBOVXUkQYfAVijETiVJUIBASHb<SHf<UiBATINMViBCQYjOQ9^WLfeVKH>>
RHN=P7f4TY:7PHBN/kJi_J:AYZ^P]l3E`hROLl>^WIRCRhZ@RXB1QY6IV9AXK8:N
XHj6ShQkRk2bUI2Vblf[U:BTSXR5S[FVbkS3Z=3<eMVjV:G?b<c6]k6e/ZZm]k>j
aL_7`LG>g=k?`m?]jn_ZiM[?blk<b/O6bLoFf]KDdLg;b/_;cLg:`kZe]k^m^kRe
o[@0]Of/OjZUWYVS/[BRV:6^/mCGf=SFckna`Jg2][FkVJ6`YIVCTiBASHjFU8Io
QHZ7THJ?ViF@UIR;P6iOEeIIG5UAC4mCDDa9A55GDU1CCdI<?S<gAU9ABe=aNV=B
FV1IBUM9?d]6?TmDE4<`>eQKAc50>3M;BTADDDi?E5aQHEm3A3dc7CM2@cU4?3m?
F59;C4=4A48o?3Xj@TQ;Acde<S8c<ohbOc<d=3e4@STh@40h;C4g>3Hd=CHW:2X]
<3<e=RPX;S@/8bTh>cL_:BLX;2l[;2la=3Hg>3@`;Rla=T19@4<j:RPb<BDG9cDR
74QJ<RHV:30ji:6UVHF9LWAcNWMWG69]LfMVJFmdLg9cNX^AQ7Z2T9IWJ71gL6=S
KXZ?WZbZWIbUOiNIWjFXYIfFZjBOVXUkQYfAVijETiVJUIBASHb<SHf<UiBATINM
ViBCQYjOQ9^WLfeVKH>>RHN=P7f4TY:7PHBN/kJi_J:AYZ^P]l3E`hRO`jjMV9>;
RY2:Q866TIVHU6Q/PYjQSXJ?R7^;/;:ET:K;cJ^DY:B>R8F>]JK;^<>X@m3<eMVj
V:G?b<c6]k6e/ZZm]k>jaL_7`LG>g=k?`m?]jn_ZiM[?blk<b/O6bLoFf]KDdLg;
b/_;cLg:`kZe]k^m^kReo[@0]Of/OjZUWYVS/[BRV:6^/mCGf=SFckna`Jg2][Fk
VJ6`YIVCTiBASHjFU8IoQHZ7THJ?ViF@UIR;P6iOEeIIG5UAC4mCDDa9A55GDU1C
CdI<?S<gAU9ABe=aNV=BFV1IBUM9?d]6?TmDE4<`>eQKAc50>3M;BTADDDi?E5aQ
HEm3A3dc7CM2@cU4?3m?F59;C4=4A48o?3Xj@TQ;Acde<S8c<ohbOc<d=3e4@STh
@40h;C4g>3Hd=CHW:2X]<3<e=RPX;S@/8bTh>cL_:BLX;2l[;2la=3Hg>3@`;Rla
=T19@4<j:RPb<BDG9cDR74QJ<RHV:30ji:6UVHF9LWAcNWMWG69]LfMVJFmdLg9c
NX^AQ7Z2T9IWJ71gL6=SKXZ?WZbZWIbUOiNIWjFXYIfFZjBOVXUkQYfAVijETiVJ
UIBASHb<SHf<UiBATINMViBCQYjOQ9^WLfeVKH>>RHN=P7f4TY:7PHBN/kJi_J:A
YZ^P]l3E`hRO`jjMV9>;RY2:Q866TIVHU6Q/PYjQSXJ?R7^;/;:ET:K;cJ^DY:B>
R8F>]JK;^<>X@m3<eMVjV:G?b<c6]k6e/ZZm]k>jaL_7`LG>g=k?`m?]jn_ZiM[?
blk<b/O6bLoFf]KDdLg;b/_;cLg:`kZe]k^m^kReo[@0]Of/OjZUWYVS/[BRV:6^
/mCGf=SFckna`Jg2][FkVJ6`YIVCTiBASHjFU8IoQHZ7THJ?ViF@UIR;P6iOEeII
G5UAC4mCDDa9A55GDU1CCdI<?S<gAU9ABe=aNV=BFV1IBUM9?d]6?TmDE4<`>eQK
Ac50>3M;BTADDDi?E5aQHEm3A3dc7CM2@cU4?3m?F59;C4=4A48o?3Xj@TQ;Acde
<S8c<ohbCc<d=3e4@STh@40h;C4g>3Hd=CHW:2X]<3<e=RPX;S@/8bTh>cL_:BLX
;2l[;2la=3Hg>3@`;Rla=T19@4<j:RPb<BDG9cDR74QJ<RHV:30j1M1omK:_V868
Lg>2OW=UG5eTJVeUIG5gLg1cMH67PHBCWj60NWb6Qh1oQI6;SifOThZ:UYfW[k6/
Y9jcZJFNQFikVi6GV9FIX9V:V9ZJUY6@TiNBTHb9Tj6NTiJ9X9ajSYYXETmMO8R0
P8amNhFCU8InOi2]^/?8/:Bo/:Bka=W6Rj5Ta:jMVYREVJ:AQ7b5VZVXX9^6R9bH
PHJRSWV6/;JHU:o0bkR[_KNFRG9gVi73_mO3bl7AiLJ@T;W3b<Fj^<30^KFc/kNn
`/?1`<[Hflc0c^OVi>OYh<o;d<c<cLoBeMWKgM_Gdm7ncaOBdLg4_;Rk`;bk^KJc
/:j/YZBSYZZ[Yj;nZGnWY:F[//ODfmSEd/Rk[YVd/k_5Z[[2/j2GUYNCSXfFUXZ6
SYFCTgQoQW9hTYBAPVeNEeMHF5]>BUEMF51>AeQQFE9BDDYEBd10B4i?C4MJIE]A
E5]MDV=ICUI<@E5EDdPl?DU;ACA3>cU>Cd]MDe=EFf9SGUQ5B4<l@4Y8?TLj>7m7
De5<CDiBEE9<ATE6@4M>D4a6@d4j>3Hc<S8d=3e3@3He?Slh=3Ll?d0n>cTV9bX]
<C@f>2XV:C4_9bXf?CXe<S0a<cD[;C4d=SLf=T<j=38_<TIMBDLf9c55@2TK7bXO
3bTl9B@S9B`dmK:_V868Lg>2OW=UG5eTJVeUIG5gLgm`LgF1Qh64TinQP7YlQXN0
OhFARhnMWi>:RYJMYjna[:BN/jVUWXE^Ni^AUiREVJ2IRYRJVYJAT9>GTY6<RI>Q
WY>FRJ2LNXjJJ5I?GGb8P82<OG^5TiB6OWn@[K[3b;2T_k2T^lCIaX^Qa:jMVYRE
VJ:AQ7b5VZVXX9^6R9bHPDj6XXiiQ[2fV9B_`<^hZkfgUXUbMi^A`koG`l_1dNG6
T92i`lS5^[S0`;Ve/k>g_/;3`L3:f=_<`<kWi^CWjN3?bm3<c<g?d]GIfmgKem?A
o/lGd]7=a;bh^l2l^kVf/k2^[:JTXjJZZjNRoZUoYjBUZk;7e=_HeM;8^jjI];>k
aJZj`[>PUiJGThj=UYJ:QXjETi=hOhIbN9:DTH9]GUMGF5QKCTYEGEQ@CTMHHEUB
DU5:ED]0@4Q>Cda7FVEKDEAKGE9SFDiFC45AEE=8?3e9BdDd@c/iCTm;GE=CEE]R
HeiHADQ3?41:B3i7>SQoAe=AC4e>DUEBC4I5AT17CU1<AT=1>SPf<c8b=3@m@d0f
=Cho>3@g?3m0?S/i9RLZ;C4d=SPZ9RTa;bLZ=Sdj=C8`<C<e:bda=3Hg=SI3>S@b
;c96GDU7=RLaAD0Y6alZ7`lY?2DT8bD/=?Fb[iR1R7=cPWicIEaMI6Y]IFEaMg=o
L7=ePHN1Q9>OXH1jO8J7P7n5TH^?WInCRXZFWJN_/JbTW[>YYIj5KW^KTINHUIVP
VHZHVYZFTI2CUi:AS8VCXIjCUXVPW7Z>VVQFCeelR820S7ekQI>DQWioT:fj`lR`
Y;n`Y;_4fLJ;XLB^WIZHUIVRTHAlQIZYZ:2KQXRLV85>QZ:>NHJ`]YRD[l3;^:^m
]iJ9LWNKTL>oel?;`M7UaY2@^L?8aKZh`<2i]K>c]kk2`l70b]SKc<3>inKTinWP
cl_@c<c=cm;EfM_MfmOCdOk?5m;AcLBl^;_0_;^i][>`[ZbVY:>VZZ^WX_jYOjNT
YJ^bamCKf=GBb;^^VKBc^lFZ^/:cX9NFUi>>SIJFRXJ>UI>CN7n6LWRBU962KEiG
EeQHFdi:EEeHD4i7F65IDU9ABUE;@418CTm<AeYUFe5DFeeBHeU>ETa1DEECB3`m
BD]5=4<k>Di?BeeCDeEKHV=NF4E8@ca0BTPnAcXhJDMCDDa=CU9EDTa6ADI0Adi@
C4I3@CXh=S<b<S@d?D=0=SDn?cPd=c`o@3hk>BHW:Rda=3Hh:RHY<BlW:SHm>SDb
<34c=B/]<C@f=cHf@cXd<RlbAUe9AcHW<DE0:A/O:Ql?:C`U92<U;3@5bWo`/[6H
PhihM7YbJf]/JVQXMFMVMGaeL7A/O8=lNhVIX9b;Q8nIUi>DRHB8Ti:6OX2CWJ^d
]JnWXZ>OYJN<KGVKU9FDUjB[VX2>V:6QVI:BUHnBSXZDWYAnQXBQU6ElWhB8KFR6
W9^MZXN2QY6@QH25RJk3blZ]Xl6fZ/38g<V=XfnlZj2RXinPYi2:R92LXYnHZ:6J
U8Z3Qi:HNh>^]YJD//SB_:k0^ibAKFZ5Mjjef<c3_/KDbjjLW[Fl_;JiaLW3Y:V`
];Jk`LK;a/WAc/C5cmcHg^ONblK>c<oDf=_Lfm_Ng=SDdLo>c/g<akje/[Jko[Mo
]K2ZXinJUYFMZ[>f];jZYKBh[:Ze/l_Kem;Fe<bPRjZb_lV`aKNYVYFHUhj4PH^=
QHFAVYZAL7j8J6n?RhYkJ5aJFe]IGDe;FfAIC4U<EEUEF5iIC5=?BTQ;D5IIADI>
EU16B5A:Ge]CFD`nCT]6ATQ1=cY6?4Xo>dm?BUaDD4hXCe=DDDa8CDa7C5A@@e91
>TQFF5IHEE]PG5A<Bddh?DI?Ddm7@4U5@Ccn>B4j>3hj<2lh>S@e=c]0@d4l=b`]
;Bh_<34a=2TV;c4Z9b`boS7m<7l/;c<f>3Lf=4Te9b/_<T1C@D0e<Ti]H3Xf8RL[
72<_8RDS92Xal;:aV8>>N7AjLV][K6YXJ7EWIWElMG1dK7b3O7^9VJ2LRhB?VINC
U8V4R9>BQWj0Tif[];F_Yj:SWjFWS6eiViBEU9NTZiZ0SYRQXIVBTYF?TXj:U9jD
OXJ4XGnDIGbOQ8Q]J8JLVifZQh:6TI25P8F9[/?;bZfS`KJZ`<SLbHfS_:^PXZ>O
X:N@RXR@W::OV:RQVYB:PhNBV7^3[[JFU;;8d[b^`;^LTFeZQGN^]MS<`kk6e<^^
W9je_;bf^LG9`jBY/;Bf^l76blK9dLk4aLoLf=kWg/_6c/c?e1CHfmcKfmkLf=CA
clk>cLc7_[Fb][_n]gne/:ZSWiZFUIfZ/kJd_ZZU];R/Z[Fcbm_Gd]KDc:2;Z[:o
bK35]jVJUIRGSXB1Rhf5QI6JVY5`OXQXKhn;RW]XG5YKFeUMCD]KI5U<BDaEFEEH
GUU<Ddm:B4]@EUU5ATiFD4I8E4YOFe=IC3i>BdI6B44g>THlBSlkCdm:G5A@CRQ?
DeAAC4Q=C4M<E513DT4jB5IHEUQEFf1LE4a;CCPmATmCCdM0BDE1??hi8CXh?SX`
;cPj=3Dg>d13@C`g;2d];Rl`<C4d:BH_<BXW;3;n<Od`Ob`_<cHh=cHdBCDW:blb
@5=1@3DbCVeP>SHR9b/L8blR9B<T:S7`/[6HPhihM7YbJf]/JVQXMFMVMGaeL7A/
O8=lNhVIX9b;Q8nIUi>DRHB8Ti:6OX2CWJ^d]JnWXZ>OYJN<KGVKU9FDUjB[VX2>
V:6QVI:BUHnBSXZDWYAnQXBQOiAUO9n4R6eXQYbKWJZ7PXJAT8F0QHV^`l_:[J?1
]Z[0b=c9SJ>lZj2RXinPYi2:R92LXYnHZ:6JU8Z3Qi:HNh>^]YJD//SB_:k0^ibA
KFZ5Mjjef<c3_/KDbjjLW[Fl_;JiaLW3Y:V`];Jk`LK;a/WAc/C5cmcHg^ONblK>
c<oD5=SKg=_Kg]cHe=7?c/k=c<Nn]K:f^ojgOkF`ZZ>OVYJEWJZc][BnZZFd^:bZ
]K?;fmOBe]C<X8^Z/[o9/<FgZIZEV9N>Q86;SHF5TIZJTG1nR6Q_Sh^:NfQLFU]K
FEe=Be]TFDa9C5EIEEQNFDaCCdY8Be1FFDE6CUI@ATQDBUmKDeU<?Ti;ATI8@CLj
ASa:?c]?CdYLE51>:4mCE55<B4e<AdaDD4=B@CY8EUQFF5EKH5aDC4]=>3e6Ce=?
Ad19AD4loSTQ>SPn>S0_>3Xd=CLk@4=1?3L/;Bd^;c0a<C@Y9Rla:RL/<_haoC0T
;2lc=SPg=SA9=BL[;c90Dd50=C9>KF0j=R8W:a`S;b8U8b@Z<@GCOmZSZIJ5U7mi
I5iQL7emMW5jJVMhP7I`MFIjQ7M]N8fJVH5cOXf>QhBGU9JGR79YKWn;VjFUWYJA
Si6S[iEbNYfGUI:I[;BLNgj?XJFKShZ;MX66RYZXVX1dOZ:>E72[Yim/CfJ3RHbG
TXV8SXf5QHf:/l[>`ijA/;Z^`l_NbXjTOkJYXZNXWYVLQhfEV9J@RhR>YZVAQXj8
LYekOjZ`T8f]cLbWSInSTY5bJ7UTV:;9_lS;b/cLi<RRal[4]:f_[:>FXJba/[K2
cMS5_<OAb[jhd/kFh]_6`L[<dMSNhN3Mf]WGd/k;bLS8dLo:`;Ne^Ko0`L?1^k:X
XZbSW9bTZZZWOlNTV[FmYij/Xl?Ie]7HgMV_U:b[[:R5UY^BRhjFUXUlMH24Oh6@
VibALHRGLGFBQX9dHe]LH5mMG4]8Ff=D@cm3@Si0D5eC?SHh>S/nAU9LFTeAHE]4
@50jDe=>EDHgASdf?da0:2a4@4a0>D]9@eERFU5=Ce9BDDQ?D4eAF594Oe<o=D5A
EEEHDeYPGE=;BT`b=Ce8CTXm<DM3?CLc<S8c=3Te:RTb=Bl`<CDk?Sdf<C<c<C0^
;2/Z?RhV;S8[8b8R92HX:BPV9B`_=3Li>3DdAbPE7bha=3`f>CDoJXmjBTHN72hV
8BDK9bDU:S7JXjVFQIAoNFANHG1mOGIaNVYWOgR0MW1eIWZ4MfehSIZIPG=nSHj7
Q9NDUYN8LVU^Oh^KYJFNUY6?TJ>_UG9jWINETYV/]9akOXnQYI^?RX]fPHJ:VZRJ
P7AnXXiDL:^WWfa?IX>9S9NBRHR>SHF5SHZcb/k3WY6`^Zk3bmk:SZBfZJ:WZ9jI
W8N=UIRFT8^8SZJYOi66SXQbWG]oZ[2@SJg=c:N=Wj>BTG9XNFBHX/Vob<_:c=cT
b:;7b/Bd[Jn/XiJQ[;6b]/;=f<Flam7:_[SBc]KRflK1b/cAf=kQh=gJfMOBc/_9
b<SAcl[0]kFi_l31`l6k/ZRR[:>LW:BZZZO7Y9Ze_JNN[:?3fMKAf=gI[iB/Oj^/
Z8FFVi:;SYJFRGaeP8AoPI2KW95aR9MaMI:6PWASFeaPGeeLBdQKHeA3?d=2?T1@
GE<n=SPj>ci6DUaJCE5QFdA0D3YCDdiEASM6?CHoC40X;4A0C40iBdU3EF9JDDe?
DU9AB4m@CE5HDTAC?cE1DEEEF5=JH5eCBdY<<SDmOdQ>BSdaAd<m=c<b<S<d>CDZ
:C8e;c0a=C/n?CHa<c<a<2h/:bXn;RH^<R/S8R8T9RPY:2HU;2ld=cTh=CA7:1DO
;S4d?3Hi=CmZSgY:AQhL;RHQ9A/W9BDZ<MZSZIJ5U7miI5iQL7emMW5jJVMhP7I`
MFIjQ7M]N8fJVH5cOXf>OhN4UiBFUhQbJFioRi^UYIjFTHnAXjnELWZMUiFBVJbd
W7]nSj6UVhn:RgJ1QXZJZ9Z0M7jRSUA`ZjNOK4mVPhV<Ui:9R8j=QHF=R[?:c/>N
TK2j[/?;g/Z>Y;JYXZNXWYVLQhfEV9J@RhR>YZVAQXj8LYekOjZ`T8f]cLbWSInS
Oi:ALVQiI9RRbKo8bl[<g>C8X/O:a;B][jbSUZ6//K:f`/gHaKc7dLZn^=;>e^;K
a/7:c=7Hg^7PgM[Iem;>blW8b=7?b/2g]KVo`<73`K^bZ::/XibLY:ZZYlNTV[Fm
Yij/Xl?Ie]7HgMV_U:b[[:R5UY^BRhjFUXUlMH24Oh6@Oi^LTG68Ug5eTXJ2M6=K
G61OGEa;B5]SE4<o@d8n@51MDchf>3Xk?TIBG5Y=DF5KA41@>U=CCUE6=dHm=Sm<
@2P/A41<@3U;BD=EHUYACDmBDU58Ce1=DEQBA5<o=D5AEEEHDeYPGE=;BT`b=Ce8
CTXm<DM3?CLc<S8c=3Te:RTbASD_<34e>chm=S4c<c4`;R`[:Sh^9Rhb:b<R8R@V
:2TX9RD/;c@g>CPe=4LX5Al^<C@l=STe?fZ?NTY67Q`^9R4U6bLU9BXa1LYoj9>^
UZ:4PXEYLgE_M7]]E6=RJGfATh5]JW9hMW9hRY^VWXn5SifJS8ZDX:JRVHn9PGUg
QI^YYYj>Q8:=UI26PHnEWjFUWYB>TYJ8R9F8OYEoPXN;SHb:R7Z4WIQkPIB:OVQH
GW>7UYn3Thf=WiAnPi2m`lWK[hJQa:c<eMC4UZ=T[Z:KWIfJXJjIV8j6SYjRVWjR
TX>HQFn?QX^:W[BPU;3:`[N_[ZJ@NVYmLF5^Q:kWYmfefj;KnJBDWl6jXlkX][Zh
_LG1]kW3`LS>cl_7b<[De]WKf]ODdMCEf=_Lg=_KemC@c<SnaUnia=3Cc;nd[Yjb
_KBYZ:VV/:VRX:B[/;>MXjNQUiRU/jbZ^m[Wg]OK`JRbal2eWGFFNG6=XYnJXXQi
MXFDUYFHJGj4MGB3PW2=FGUcFgM^FfiNCDYAE4a1BE=FDE5FDdWmCOi<Od]A@DAI
GU=IKEY>@dE>CdDhCD];CDe8?SE<@3HjBUIHECM4E5mPGEYIEEEFFEaJE4i<AT11
BE5FEeUFF6=_KUi>DE9;A4aNI5mCDDi9A40l>dQ2>c/oA4E4Ad8n?D10?3M1@3hm
?Ci0@BLT:34`:B`g:S8k?3Th?D=0>cLh>SXgOc8`ACHQ:bh/>cPg=3Q>IfYO>S@/
:2LV8Qh[;2d]:NRC[YJRQ8:5JG=eKgAkKEASHVUmTI>1KFYbN7IbN8ZKYYj?QHnM
VXb:U:2VXYV?RH5iMhFKZJJNSXB2SIF@QX6?UInUYIjDSY:FR8RER7jEOh:7Rhf<
RXQjQ9fHNh6DRWiXOeQNLhNFWh>CSHfOU7j3T;g3bM^_QZ74[<cEe<BFXjjRVifM
VZ6^VIR>QXjNXYYnXY:3V8E_ShJ;RYjdX9B`b/:g[jjVT7YZOG5QKXB^ijOM]M^R
foVTU9o1^Z?>j;Jj^;g5`KNi`l78c/o;alS:e=KIfm[Ge=7DeMSKg=cKfmOD0]3<
b?k6GkW4d=?<_kB^W[:m]:VXZJJ`ZJ:PY:^`/ifSYj6GV:Fc[:Zkf^ONem_1Z;;7
`;FMMIIiLHfRWiZRR7UfQIBFUIQYOXAeM8>2L8eING=KMfiKKUi=BU5DC459DeIA
DEICBOe=oTaoBe51A5UNDeU]FTi3ADi?ACQ=Bd]=CDPn=Da0=SY:EUQE=dADGf1M
FUUEEEIIG5YDCTa6@459DEIGFEIHHfm^GTiADT]4C5iTGe=ACTU4@3`kB48k>cm4
ADA7@Shm@40l=d50?Sdm?T119b@X<C0Y;3LZ<S/l>CPm@d0k=cPj>SMo<S15=R4[
;R`k>3Ld>4iWJUlj=2`X9bHR7R//;BdYj9>^UZ:4PXEYLgE_M7]]E6=RJGfATh5]
JW9hMW9hRY^VWXn5SifJS8ZDX:JRVHn9PGUgQI^YYYj>Q8:=UI26PHnEWjFUWYB>
TYJ8R9F8OYEoPXN;SHb:R7Z4WIQkPIB:OVQoF5icQiJOPi>=SInDOX>@_L?9fjn6
XLB/c=GDa9JS[Z:KWIfJXJjIV8j6SYjRVWjRTX>HQFn?QX^:W[BPU;3:`[N_[ZJ@
NVYmLF5^Q:kWYmfefj;KnJBDWl6jXlkX][Zh_LG1]kW3`LS>cl_7b<[De]WKf]OD
dMCEf=_Lg=_Kem@2d<c8o/IO^LC@dlbo]:jN/[fdZJRYY[2YXZ2TZk2cWJ>WXINH
YK>/Z[_JimkGfl6X//O0]IeeUWUaSJ:OVZ:8NGJ5U9JEV6UnQ7EdPh9`SEUiLe]g
KU]^GTe:DEA<@DUCEU5AEU=9oDgnC7m;DD54FEiCFFeJCT=5CTm5>4e;Bde=B3he
C40f>TYFF5DgA5AOH5eJFEEEEUULFUA>C4I0@DUAEUMIEUQSKfiNCU5BBdA<GVAO
De5>BDA0?3]8@S/k?dA5A4M2?Se0@3`g@D0n?Cdn@44W92Pa<2T/=bXb>c`i>3e3
@3/g>3Xj=adb<4Df8B/^;3/h=c@hCVMZGcXd;2PW9R8N:b`];BT5dE7JQZ:9U7A_
L5iSH5UNJ69ALG5gQY6;M5mQJG1^IfQdP9>IUXZ5RXR0S9NU[ZbQU8acM7MnQH^=
SF]gQiRY/k6YUIVOXjBRWY^KWi:?VXQjSX^<oXeoS8Z8PhfWY8R?XIF?NVMVM8B?
U8FBQh6BTHbOQk2j`m>_Sj^mYLKAdL:EX[JZXjBQVI^UQI6FShfEV9A_TXYlRGET
PX66QIZbXYVhc/JgZZFNRWAgPfiII7BC`k;@^mjgfM_2Y9fX[jVf`[Jb/;K0_kNj
aLg:bLoFf=7:d=?Hfm]oem;?e=KIfmcLfm_Ge=3;b<K5aLK7al6k^;^o[KFg]K_2
^jbNWj6U[;6c/kNg/jbUYZjf[ZNac=_Fcm75/[c3[Z6DMXA`HVUeNgn5Og^1SY>B
VJN:S8^:TibCPh1HJf9RNVENLFMKEUQGCdQ1C55>DEUHCdY9AdM8BTe?Edi;D51o
BdiGCTHo@4E6?cM?B44o@DA3@Da2>3M0C5AGA4aDF5MFF5YCCdiCFEU@B4e7@TA<
E5QIF5AEGVUYG4i:CTe8D5eNEE9@C4Q3@3hl>C@`<CHi>3I0?3Xj?3Xc;CHe=3<d
=SPi;bd`=BhU:cXe?4=3?ce0ADI2?Sm2@ShjE6aM?cL=:A`V=3Tk@E=TH4lj<b_n
9ePS81hR:2ldfXJRRIAdKg1NHf1IGVQRDG5aMhJARgAOHFU`KVMXM82CVIJ:QHZ8
P8bGYJj/XIB<LgAgOXF;SHe[MhNHZK>aZIFIWj>TXYjKVinBSiZ8NXj;S?j=Ohb:
R8>=YjB8Sj6ESgYWIWB4SiB5TXN1TY6<WhN`^/?C[hn[_JG6dM72UJ:fZZ>TXIVK
YHFAUXn=UIRDKi::O8UeI8:1QXFJ/Z:I^<k6]jZUWXYdMh=^FFAdTl>bd;_N]mWK
`ZBMZ:nY]/:f/[2f`;ng^/G=b/W?e]SAb]3Cf=_KOmOBcmCFfM_Lg=_KemC@blS6
aLG6alO1^kRk_jfe]kFk`[^/WYnQYJba/k>g]k>/YJJ^]ZjW/LcKe/oAaK:l`jjQ
U7J4L69YMG]oQGmkPHjCTYVWRXb;RY>LTh>0F6]RHWYUGW5WFeIHEdm8@DaACU5I
F4m:BDM7B4Y=CeM>Be1@Od]>Edi6?d15ASlgCdQ1?d54@d5<@SPg@4aDEdA<E5QG
EUQJDdm>DeUID4Q=Ad94C5AHFEQDEEiYJEa>BTi=B51MGUEBD4a8@d0n?3Td<34f
>CPf@3`j>S`j<bdf=C@c=3Hh>Bl]<3D^9B/j=Ca3@clm@4E6@Sho@T8n>UA/GClg
3BTL9S@i>d5CI61?>S<[oRMH8b0N8RP_==Z6XXVDM6m`GV=PFEiXHU5aLGN6TH]d
Gf5YL6iWJ7B0TiVFRXF:R82<UjF^[:6DS7=dMgj5Rhf=JgN7V:Vc/JVEVInSY::N
Vi^OTXnJR7Z>RhcnSGn<RXR3SJNTR8nQUHmjIfIdQ8nDQI:7PI:AS9n7/;[3djn?
ZkfUa]7A`YFR]ZZSY:6IVjF5TIJ?SIFHU6nBRWb9MFB2PHJ5V[:RVKS>a[NZYIj:
M7N3KUUTM9?3/]2kg[OIfl:TWJR_ZKK2][:`]/2o]k[5cL[9cmKHdL[@dmSKfgoG
d/oDe]WKg=cKfmODd<_8a/G5a/O7`K^h^kn]]KNe^l:k[9jOXJF//K>c]kNc[:FV
[[J^Yk7<fmK?dLFb_<>^XIAfQ71RJGEkOhEoNh6>Ti:IYhZ<RhZCW9>3P5Q[HV9j
IEiaIe]FF5M?B45<DDiAFEQ?BTU7AdQ:CDmGCT]@D7m;CUM>ASm0ADHo=dm8@Cm1
A4=1C48h=d1<E5M4C5AHEeIHFU=?CU=IFE18CDM2A4aDF5UHE5ENJFULCTY>CDQ@
GEiEDU1<B4=0?S`i=30a=STh=T0l>SXl>S<]=SDd<c@f>3T_;C0e;RD[>SDl@d<o
?D15AT8n?d92?SYDK5do=`dY72Hd>C]1DfAPCcXc:ohW1R<P7R8X;c@5cT?QSJZA
VGI^KFMXHU]PJfaUJVabO85iIE=`MW]gKfadO8:EWY63PH>1SYNT[JjUV8mbNX61
OG]oQ86JZ:2JW91kWj2SY_jW3JJJXINIYI:1TiVGU96?oXioRI6WXX>5TH6<O6US
K7b5QgZ?RX>>RHNNTK2nb<ndY;jjXlKBe<RLZ[J[YZRQThnDO9>SWYJFV9E/SY><
Sh1jUHj@S9fcXi^jcLViYj:TUh=oPfYFI6elW[W3b]W>g;STa[JR[;nc[<F`[kK1
`KZnb]76`<WJh=K8dMKMh^;Me]9oe]SJg=gLfm[Ge=3;alC3`l;3`[fh]kc1]k>/
/LGDajfQYZje^;Nd/[R_Y9nQYZV[]ZVY_M7Dclg3^<?2YI^IPV9VHeaPKG=`LGF1
S8V4T:FMS8JFYJ:ESH]kP6n5UW:4O7I]I5iIEeEBFeiIFV9PF5YGDe5CEeiRF5]D
AdE>DTiHEUABD4i<BDM7@d13B4a:B4m=Ad50AeAODEAEDe1@EEYGCd]BGEmDAdi9
ADQ@F5aMEU5@Ef1QF4m5Bda:D5YGBeABCTU6A4=3?C/k?TA5@Ce9AdM9BT@j<CWn
>7`i?3m0=cLj>RhT;T<k@DQ;BTY=DD]7A4E8BDE1LI26HThe8bhk@dQ<EUe@?3Xc
:RHW9bDR7R<Z<c_QSJZAVGI^KFMXHU]PJfaUJVabO85iIE=`MW]gKfadO8:EWY63
PH>1SYNT[JjUV8mbNX61OG]oQ86JZ:2JW91kWj2SY_jW3JJJXINIYI:1TiVGU96?
oXioRI6WXX>5TH6<O6USK7b5QgZ?RX>>RHNNTK2nb<ndY;jjXlKBe<RLZ[J[YZRQ
ThnDO9>SWYJFV9E/SY><Sh1jUHj@S9fcXi^jcLViYj:TUh=oPfYFI6elW[W3b]W>
g;STa[JR[;nc[<F`[kK1`KZnb]76`<WJh=K8dMKMh^;Me]9oe]SJg=gLfm[Ge=3;
alC3`l;3`[fh]kc1]k>//LGDajfQYZje^;Nd/[R_Y9nQYZV[]ZVY_M7Dclg3^<?2
YI^IPV9VHeaPKG=`LGF1S8V4T:FMS8JFYJ:ESH]kP6n5UW:4O7I]I5iIEeEBFeiI
FV9PF5YGDe5CEeiRF5]DAdE>DTiHEUABD4i<BDM7@d13B4a:B4m=Ad50AeAODEAE
De1@EEYGCd]BGEmDAdi9ADQ@F5aMEU5@Ef1QF4m5Bda:D5YGBeABCTU6A4=3?C/k
?TA5@Ce9AdM9BT@j<CWn>7`i?3m0=cLj>RhT;T<k@DQ;BTY=DD]7A4E8BDE1LI26
HThe8bhk@dQ<EUe@?3Xc:RHW9bDR7R<Z<c_QSJZAVGI^KFMXHU]PJfaUJVabO85i
IE=`MW]gKfadO8:EWY63PH>1SYNT[JjUV8mbNX61OG]oQ86JZ:2JW91kWj2SY_jW
3JJJXINIYI:1TiVGU96?oXioRI6WXX>5TH6<O6USK7b5QgZ?RX>>RHNNTK2nb<nd
Y;jjXlKBe<RLZ[J[YZRQThnDO9>SWYJFV9E/SY><Sh1jUHj@S9fcXi^jcLViYj:T
Uh=oPfYFI6elW[W3b]W>g;STa[JR[;nc[<F`[kK1`KZnb]76`<WJh=K8dMKMh^;M
e]9oe]SJg=gLfm[Ge=3;alC3`l;3`[fh]kc1]k>//LGDajfQYZje^;Nd/[R_Y9nQ
YZV[]ZVY_M7Dclg3^<?2YI^IPV9VHeaPKG=`LGF1S8V4T:FMS8JFYJ:ESH]kP6n5
UW:4O7I]I5iIEeEBFeiIFV9PF5YGDe5CEeiRF5]DAdE>DTiHEUABD4i<BDM7@d13
B4a:B4m=Ad50AeAODEAEDe1@EEYGCd]BGEmDAdi9ADQ@F5aMEU5@Ef1QF4m5Bda:
D5YGBeABCTU6A4=3?C/k?TA5@Ce9AdM9BT@j<CWn>3Pi?3m0=cLj>RhT;T<k@DQ;
BTY=DD]7A4E8BDE1LI26HThe8bhk@dQ<EUe@?3Xc:RHW9bDR7R<Z<c/5dGo[V;>I
X7Y`KFi_KF]_MGQgI6EZL7EeKfZ0PGmhLWAmQX6BVi:;T9JFTiJKXJFSW9J:SI6C
THn=SFJ:WI:AXJ:BYZR/[Zj[YjBAW9RO/:2AY9nLV9BCU9NIWj6`Y81lPFf8PG=Z
LhNCTgbMYjBWTX>CXkG3b;nYZ;jlY/_IgM:W]Wn^YJ>WWhn6RGn?V9FDV9J>L8bM
WIRAVJjRXYVU]Z6F]<S:_JRW];2OOX=_IGMjMhV]_]k6e^J/lMCF[:78`Zk:^;Jm
alFm_l_7`;c3dMOBb]?Ih^SYi=cGfM[LgMkMfm[HeM3:a/?1`Jjha<S4_;Fc/ZjX
Z[c;`:Vi_/?3_kVf]GnaXYBCWZNVXKZ/Y[?:f=WE^k?1`Zj^ZHY<JWU_Kgn2MFQX
L7YiLWR6SWYiT9R8P8RDXJ:5WJ5jZH^5NVYNFf5WJ6m]HUeQGE=ZIEiHF5eTJEER
G4I6G69EJ6UXHUQBD58m?dMAFEQABE9IGUQ>CEUUDUEGEE5?DeMNE4mGIFQLCC1?
BdU<E5]NGE9>CE5GFEA?B4]8@dUEETaGE4m:AdI7B4E5AdeBDde8CTi@De=<?cDj
oSUo>ci1@cPj?clb:CM>?dA:D5EHFee7@d11ADM4@6R>RfeMCDQLDUMFD51A@bln
=R`W9bPX9Rl`<S@fjiRcVJ1jL6e^Kfe[KgEhMfAUJW1eMFmZP85oN79dOHJ1TY^B
Ri2FUY>FVj6UXibFRXfATi6?SHeVRYfBTJ6RTZJX[:j^ZjMoY96LV9n`X96TWibH
U9>DUiVOXK2TP7b1KHR1LfYcQi>CO9fWY:NBPi>S]L?8_jVX_[bVbmWMdZNf[ZFS
Yin?QXUoSiREU9RFSW2<WIfHTIV^XZ:IYKJQU[C8b[fXYkB`Wgj3KfEgNWN9[KkN
a]KV[?7DeZbQb<:^b[Rf_LO5_KmoblO0_<?Aem;:dmWRj>WTg=OIf]cMg]gKf]SE
d<[6`l71[[S4b<Bl]K>b[ZRZ_<_0ZKVn`l>o^KJe/J:DTijWYZ6j[:Jcb]SIeK^c
`L:^[ZV:C6YiKfmoPWEXJ71jNG9hQXijNI2HR828U:6RQIfQNZV;QGYZGU]QIfQ_
KF9MHEeYDfYUGUQHGFAYEF9LATILHUEXJFQRF59@DSdoAe5IF559DUUNF4i=FFEB
EEMEDDmCEeiDCeMUJ5a=Cd]9C5AKGUeBCTeAEeUDCdQ;B4=9EEI<EeA?BTM6AdQ5
ADM=DU==B4i>D5=CC3le>_hiOc/n@D<h>Slo<RTgCSm4BU1EF5]MAd=0@DE7A41X
SX]]GDe8G59GEU1@DD<_?SH/9bLX:2H_<38d=^^H/iVPNW1]KVm]JfmeN7MTIFY`
MGE_JX21OgQbM7f6PI:KTX^@UYJCUY^QYJ>LUXZ=TI>AShf=IXZMTY6QXY:VZ:b^
[Z^WOjBAW9RO/:2AY9nLV9BCU9NIWj6`Y81lPFf8PG=ZLhNCTgbMYjBWTX>CXkG3
b;nYZ;jlY/_IgM:W]ZjUXjNOShJ9OhnHUIBHUXi`S9fMV96I[Z:RVJFfXIJdb<Zm
Z:Nd/9mnPfmUMgYgRJfng/KFiZcae=J/XLS2[/Zh][g7aKfoOl_7`;c3dMOBb]?I
h^SYi=cGfM[LgMkMfm[HeM3:a/?1`Jjha<S4_;Fc/ZjXZ[c;`:Vi_/?3_kVf]K6R
U9>NYjJQ^ZbV/l[HfMFk/l72[ZjYRTaZNFm_Oh9eJ6Q`NWUbN8J>NWV@V8R0R9BQ
XXFMXGZYRhEjJUiKHFMXKfeRGF5MJE=ZIEiHF5eTJEERG4I6G69EJ6UXHUQBD58m
?dMAFEQABE9IGUQ>CEUUDUEGEE5?DeMNE4mGIFQLCDm;BDaDFeiMDTi=DEMIE4m8
BdQ3BEEFC5MDCdY7ATM8ADE7CE9CCDQ>CU1CDd`o=C[n>CPk?T53>3Xo?c8Y=dho
A4Y@EEQKGDM3@455AdA0J8j;KEe=B5aBEeI@D553;chf;2LW:2PV;c0b=3H5dgoT
SZR<TFaRH69SJFm`KVmbM7EdLgAjQ8aiM6]RHFUhQ8:9RXJ?XZb[X9ZEUinUYZBR
W9ZR[:jSUg2:V8n@XZfXZZjc][>[XYbGXIfT]JFFZInLVYRIWJ:U_;W3]I>AUX2H
VHj0QifZYi6b^kNiYYRX][O3`J>AWk2iY<WHgM>Z^GnZXjBZY9B<ShZ7OW^9V9>3
N8>GVHN6UIfLWIJS]9nC/<O@`jRT]KFRQ8j0O8j6M7ZF^NJ`d>ZkiLSS^YBjc[Zk
_[_0al:g^<;0`lK8bLcAe<oDg>7Sgm[EfmcNgmkMfm[HeLo9a<6o_Zff`<Bo^;>a
Z;6b[:jf]Jc0a<K2^[Nk`7o3/j>S[K>[X;6XXJRmdm_H]jjj`;RmZWMONXAdKh6;
Q6eQGfY`J65RMVmhRX=^L8J1WJV2Qh9VXiJ=O6YNGVQbKG=^HUeQGUE[IEaDDEAI
GEYWHTa;GV=EM7A`IUU?C4a5@T55CUAFEDaLJFMIDUMQCE=JFeIACe1IDTmGHfIL
D7mACTa@EeaLFTe<C4mCE55=CTe3>CmBFEEDD4U3?cm0@S`l?TA;C4I1ATI8Bda6
>Rl`;bh^<38e=SDg?D8k=45FCdmAE5MHEU@m>CHh?3hl>4Q^KUMDDeejJFQLBT92
>bi7?C4Z:BXZ:3Tg=30/i8jXS95/HV1RHfU_L6i_LWAeM7mcM7Z4S7UdJf9QJGR4
PXV:QXnR[:^PVYFGWjFVY::LVZ:/[Z>GL8ZHSi2R[JRZ[[>f/j^RW9NQWJBeYIJY
WibJV9VMXZFl^L>eTi6FP9RISX27WJZWTK:k]kVVV:Rf]l?1Xi6O/;VTbMSMdjZi
ZZ>TZZBDS8n:QgikRIRCPgR3UgnIQhJEWIbMUZ>dWi>`am33Z:Be]J:4SX1lSXId
NYJii[3@j[_Ub>>jU;[>^[^n^l37`[Nh`/33a/S9c=7DcmCLhN?Of]GKg=kOg]gK
f]SEclW4`Knn[KK0a;nh/k6X/K:/[[Je[<34a/:j]k_0`k>SXjfcZj2aZ:6X_M?K
f;N^^Wo0^;fZMemjQ7A_PH^4KF5OJW1XHF9fKgR:Pfi`QX6MZH:7PVJSUXelJUiN
J79]LfiRGF5NEF]UG5AAE5UMFVMRC4]NHeEdM71VFDm<C4E2@DE>E5IEC5aYIeUB
Ef5=DeYKEU5?D5UBCeMSIUa@DDi<D5MLG5Y=C4a?DeAACDi=@gli?e9IEEA@BD<o
?d12?3`nA4]<AT56ATQ;C4Hj;c0_;Rh`<SDf=CLm@S/d@EI?Ce5DEeQFE3di=SPl
?S`hB6i^EeACGGYYJ5a:@T8k;TLm<BXY:RXX>CLd<2cTSZR<TFaRH69SJFm`KVmb
M7EdLgAjQ8aiM6]RHFUhQ8:9RXJ?XWn/Zj2JUINOYJJTXYbJXZb^XiM`RYR?T::]
Z:Z^/kJcZj:LUj6MY;FUUZVOW9ZHVIfRYKbi`kFCTIJ0V9V>P8NMZZNA/[^g^JJH
Z;Jg`l6STIn`^JC9f=gCZ[VZXjBZY9B<ShZ7OW^9V9>3N8>GVHN6UIfLWIJS]9nC
/<O@`jRT]GneXXB>P7b>QWAjU[WV/=3Z^nG8hkZD^/jj^kjk`<O2]kS2`<?6b<W<
dMC?e=cQhmoJeM_Lg]oNgM_Jf=G?bLC1_kj]]/34_kRc/JRa/Zb^][F/`<C6`[Zg
^l33/j>S[K>[X;6XXJRmdm_H]jjj`;RmZWMONXAdKh6;Q6eQGfY`J7mQHWI_N8Z3
KW26PIfYPXN2IZ>FSGaZGUiXLVecKV9MHEiEJfELE55DFEeJIf9<BeiSEGAdL6II
Cda<AD91ADiDEUE<G6UWFE9GHDeCFU]FDDm@FE9?Ef=VG51ACTa@EeaLFTe<C4mC
E55=CTe3>CmBFEEDD4U3?cm0@S`l?TA;C4I6@DI6B4]<ASX_<2l^;S0b=CHe=ce2
>cA1ETm?DEAGF5ID?CTf>3`n?3Q8KViGE5=MNVUXG4Y2@S/^Acda:RTZ:RPi=c@`
;0GAOn>;XX>8IEiNGemWLG1WJ75iNWI]IVUhQW5ZH5ULIgEoOX:0OHZP[JbUVi:E
X:^]ZjJMVJ>c]JJFR8^=RhZ=TYN[[[2a[jVRWJV`YZNcX92RWIbLWInRYJNn]kjc
VJ6]VYFMTgn1V:>MV:^RVJBQXkg>`<c5Uh^X]K:L`M3Fc:>bOjjWZ:jZW9JIXI>0
O92VXXn?Pi6@M7N9PGn5QY^bXIJcbmS:YIVXY8f=VXf6TX=[L8BWdjO;f]G@bnWB
ZKWGc[Jn^kk4_[6a^lK<d<o;c=CLb<_?dmGDdm7Mg]oPgmgKfMSEclW3_kfl_[bg
/:^]]KfT][jbZ:be]jbd^[Vd]Ko9Olk1]K>f/jJHXZ>OWJ_3dM:j/[^l][bQHhF7
O6ELJWf6Lf=MJ6mUF59ZLh66NF]bQ7R8Xh1^KF2AThQhJfAUJFecNGM^KGIhLG5/
IEmMGV5SJViYG5MJF524P7Q_IUeED5a;=bheAeYUB5ITI5UAE5]BFEiNETi9B4Y:
C59GF5=>HeAACe5FFEICAdY>DU=ACTa@C40d?E=OGU=>AC`g=SPj>STi?TE8AT98
AdQ<CT]1>CDd<S4`<C<d=C<iA4E0AU=QG5MDDTe4?CDa;c4f>CHc<55=>Ci4CfY/
J5Ln<cLh<U=7>2on;7l[=S<`;B_SRj:3R6ENGUmOIg5`IfQaNGYfKFIYN8IaJV1I
G6MeOgj2P7f:X:f/YI^BUJ2[[J^VWIVS/kFVUXR;SH^:SI:GZjj`/JnYXYfY/:JW
/j2@XYfLW9fOXZFW_[Nn/iVQ[IZEWI=oPIRSWIR[XYVTXJ>mc/3<aIN;Z;FbW7o1
d=K<Xk:^YjR^ZYbFVJ6CP7b@YZ:?Sh>AT7AgRH5oQHJK/Z6F/l_HbZFIZ:B=SIZ=
QY:3Jg24Ym>Wbm[Ed<_YdZVieljf_[^na;ja/K_6c=3?blcDg<S;cm?Ee=?AgMkO
h=oMfmWHeLo9`knm_;jl]k2[[KFmY;Jn/ZR/]KN/]7nj^KBe_lW>`KFc][>VV::S
Wif[`m7B^[:k_;JlXF>5QgaUG6YmQW=SGFQ_IEQBJW>1QWU[LXAhR:>0KVePTI>8
N6]TIFU]LgUgKVefN75aK6EOGEiQHfY^JEaGFUQ@Q81hKfIMEE1LBcL^=DMJIDQF
I6AIDEAKDUUNGUI>BDQ:BVU<DUMHDdiDDDmAEUUFDdM:CU9CDDi<D4a0=3eCGeiC
CTDl=cHh>SXi>Ci5B4I2B4M8C4i;@CTe=38a<34c=3Dc>DA5@4ICHEaGE59=A3de
<Bla=STf<c1ACCTnA4mZK6QG?S<g>39CAcP_oRao:cHc<2d[hh^RPhQUGUiOGfMa
L6MXLGUjMVeVJGR6LFYPFEaWMGmnPX1mRZ2][:FKTYFPZjf[YYfIXk>eYYJ8Rhf;
RXfBUj^^/;6_ZJ:MZK2VYk>PT::MW9bMWj:UYkjg_[>IXJfJUIfCOh6HXifHZj:I
Y:6S_Lk0c<FGRjRe/Yao`M3Fc:>b[ZNX[ZZLUYVQTh1lT:JRShn3TI1dMhV1OhF6
Vk:QU[?;f<ZUVJRTSHfJSHJBPf]`Q:OCYl_JeM3;jM:Y^MO>][jk_/Bn/K6ka/c@
cl_<e=c8bloCeMCCdMgNgn3OgM_If=G?bL>o_Kbn_;N`Zjfe_JBf_[:X[;Fg[;Ao
^[Vd]Ko9c/6e/kJcYYRRXinMZl?Ad[Zb^kbf_:5SQHMlIEaZOHIcHeeXKfEHDVYc
PHIiJg:4N8RSP6i]H96CR7Q[I6EYKG=iMfi]MWQaLFaUGeeNHF=ZKVULEeYHD8B0
N6mVGEE@G4/g;SE7FVE8EVATFE5DFe9IGUiFCTU8BTYYC59GF5=>E55?DEIIEU=7
BTiBDe5>C51<@3@mDemNDdi5?3Lf>3Xj>CTnADQ6@TQ7B4a>Bd4i=C@b<C0a<c@e
<cU4AD16Df5LEeABCD@m=C4_<CHi=S<`DDdi?TA?JVaXEchc=cPbDdLh;oh/1B/f
<c0]:`GAD^^AXh:8IfEXJFAWKf]RJGYVKFmVF5EQKViYIFAWKG9dNXV@R8F@W:2F
SXZBX:RTWIZIVZ6VXiR>K5iXR9VFW:j/Z:BQXJFY[K6eZ:F`WY2TWj2RoZ=oXZ6c
ZJbQS9Z/W7N5P6Y]R9J>UIj=PiFHVJo=]/K0RHNc_[2J_lkCbIn^/:NUZJBFTYNU
WHn8UZVZWIalQ8IYMHagLgf3W[VWVkK;g]6WUjBNPXJCQ7R0MFUgPXNZ/M6hil?N
g=oB`LgA]l6o`l[5^[[4dLg:b/gAe=C;blc>d=9oeMKOh>7Qh=gKfMWEclS2_[^j
`;fg[JNX/KVO/KZ`Yjji_In/^[fg]Kc4_KVf^;VdYYZNZJVNX;G6b[fmal2a^jYd
T85eKfUTKWiYHF9[JEaCEF5bO7E^LGAbR7VNRVekN8Z3Ng=aLViSFGUoO7=cOH1k
M7=aL71bM7EjLg9gLVEoGf:;PGMbLFeRF6EF@cTnC5]SDEMLFUADFV9UIV=JCDA1
@T18D5=@CTmBEU=@DUEDD4]2BE9GEU5<BTU9@CU3F6=PHEY?A3dl?Cm2?S`oATa=
Bde;BTeADDa7?S`i=SDd=CDj<SI6CTU3AEmHDDm>B3he=C8`<SPj>3DYASl^=SMY
=dQGETPb:C4g=UmB@3@_;Rd/=S@b<C;[TJ>2R6MUJ6UTIfm[HVUjIVe_IUQEHFi^
JFETIfebM7Z9T8R5T9bPUXj:TZ2XY9fJVIZQYZ>HSVaNJ8RIUYb^[:RTXJ6UZJfa
]JRU/9j@Y9nPX_jSOj:Q/jV/XHbJ[9agQH1ZKHRFSYFNSH>EV9V_cKK6`8V7/kj`
V[o>dlVO[[2WYJVTUY:GYIf?R9JYZYfLO8B6JGF<Mg=mPijiYi^fbmkAYiNTWX:6
ThAhP7EYMh:7Z[7A^>O3g]cOd/7=dKO1_l?:aKZja=7=b/[=dMCDbl_<c]3BOmGF
gn3QhN3MfmWIeLo8`[jk^/2m]jfWZ;6iWk6j/:N^^KfO[;Zm]kFla;fi][Ri]:JJ
WZVYWZ2ea/Zm_LO0/K^ZM921MFmYI6inJF5RJfULDeEQLWaeKW5dLXQiWXY]NgR:
Pg]cLG9^HeUiOgacLgf0NgAcLG1`LWAeNW=bMg9UOemRRh5gLW5]HUQUET<i?TaK
He5GG5YDE5YRIFISFTe4@D90B51CD4i?DUICD59EE51;@TUBEeIAC4Y9BD4i@eQS
H65JCd@m?3do@Shl?dI<CD]=BdY=DE5<Achl>CHe=3De>S8fATi9@dEOF55?CTPn
=CDb<38h>SPe:DHo;SHgJCM8EeI8<RTa=cIODT0d;bh];3Hd<S4bji6SPXQWIFQY
I6M_Jf9YNVI]KfIHEF5^KVUUI6M]LWAjRI28QI2LX9J>RY:PZ:BMVYVJXJJSV8i/
GVR8VIJL[ZbXY:6QYJV]/KFXYK2NT:BOX:;nXgnRXK>Y[:6<VZbLMhF0JVf8UXjE
WXf3UIRI[lffa/29Qk>n/9Zoc]?9Wjj`YjFYY9JBUjFMShRFZJZMW7b4QVUeS7Mc
OH>N^JNK]/_NdJNGY9j2QY>4N81eJGN2QjZadKSW`mkLgm;1cM6g`Ko3b/Fj^/CA
cL[:cM7De<_;c<k@dWoEe]oPhN7PgM_IfMG?b<:n^k[0_KN]YjRa^Ina^[2W[[Vm
Wjbj_KNe_<Bm^KJh^KBVVYjYZIjP]LK:_Kg7`;6kZWB@PGE_JFA^OVUQHV]YG5=E
HG9lMFiaM7:8NIj:KG]hRX=kLg5bKV=INGmlLg=mP7]dLg5`L79dMGYcLWMbIGmO
HX^1Mg9aKF9HIEI3>Ci<Ff=AEeaJE5AJHVEVHeY=A452@4Q@De1>Ce9FDe1BEEA@
Bd99DUMFDDa:BDU1>D=HHf1QFTm4?C`m?d8n?3m6C4e;CD]:CE5AC4Ln?3Tf=C@e
=CXb=TI>BD=5GeQACdi8?SDe<S0b>3Xh=BU6?bhf=aHgB5MFB38Y<CLfGe90=2l^
;B`f=38a<PG@OnV=WG^1HfAYJf1NHUaDHWYHIG5/GeQPJf=SI6Q[JVEPNiNWVXF3
SYJ0OGn=W:2ER92HX:6IT8^9YHF3Y:R7N8N/Y9VBUZ:b_:b`XZ:_XYR_XZBVYjFQ
W9ViZZRJQ9BVUf1dM69YRifFW:NJUJNQTY^bUj^XKgBZ]KJOa=?Gc::aF:bRWIjH
RXJ;SI6<Q8RFVYB>IFadG7:?M7b7Sj[2[Ibea]kF[If]Yh]ePG5SKF]]QhM^R;oJ
W>nohl3Ei[b`_Jc8a/_DdLS:eMK8_;o<e<k5eM?AdM?Hg^7Po^5oh=gKfMWEclS2
_KZi/[Rm_;B/YjJIYjfWY[6k_::ca/[0]kJiZZnf`<G1^;2T][RVWk33b;c5e<Nb
`L6HPGAiSXefK7IHFfE[H51?FeMYK5mRLViIUfbESg6<SHAeL6mhOWINB75fL6=Q
J6USIfU[KW9eMgR1M7V=SGQcP7iaIFAHJf]NDF1LFU]OGe]FHEiIE5=JIVmgLVID
A3/k?cm<FEUACE9KF5AADU=ABdDoBEAJFE9<B495@d1;GVANLf]NDTY8BT]0>cHh
@4M:BTA0?T15B4I3>3Hb;R_n:Gm0=3E7Dd`o>51:ATQ<C4@l>CDc=S`o?CXZAT0b
>cP]=D14?2`V<3PgIUQ5=c4`;R`m>cTg>>V=WG^1HfAYJf1NHUaDHWYHIG5/GeQP
Jf=SI6Q[JVEPNiNWVXF3SYJ0OGn=W:2ER92HX:6IT8^9YHF3Y:R7N8N/Y9VBUZ:b
_:b`XWnR[j:H[j:TYZNUXIbI^JZXVXBDYYMPM7ARJH^MUYbWVYFWXI:K/YN[Z6md
Z[FfWlCCelbR/JbRWIjHRXJ;SI6<Q8RFVYB>IFadG7:?M7b7Sj[2[Ibea]kF[If]
Yh]ePG5SKF]]QhM^R;oJW>nohl3Ei[b`_Jc8a/_DdLS:eMK8_0foc=C>aMGCdM7C
f=kQh?kQOn3MfmWIeLo8`[fj^K:h_Kbd[:NVVJN]YjJa^kbR/lK:`;Nf^JZ_]/35
`KR`Y;JhYYn``lRlaMC7//71V85dNHj=MVafF5]UJf1@Ce]GJFaOHW9^FIM/UHma
S8f4MG1_N7ifGTQaMW1SHFQYHfMYJfibMGMhPGAiSHehLh1nLFETF6][GU5PG5YK
GemKEV5NFEACFVI_Mg9VE4@k>cloC5UIDDeBFeQDDE9CDD]5?dUDFUUBC4Q2AD=0
BeiTGW=[GU9:B4Y;@3/f>417BTY4@3i0ADQ6@cPf<Rh[oRUo@3@eAe=<?cQ@BTI8
C4a4?3Te<cHl?cdj:TI0<S/h;CE0A3`/9S0h=fIHACLa<2h/?C/i=cSYSIekPF=T
JF]PGV9LE69jF6EaK5mHH6]SHfAXJfYUH7^GYiZ5PhjFP7eoSIbPUHR@V:2QVI2;
RJF5PjBXQgR7[:BITYJR/[b//:9oXZnRV:nRY:JWYJ6LVKVZZ9Z4U:JGH7AdHVV;
WIJLYiZEYj6BVk:GZjQ_M:Ze]Yo4dmO<X[6/XYfNV8Z6RhfAS8B8UYZDSVE/M5ab
SgAlQhnZ`ZfL]LKNeZfM[JN;MH5aHfe[KHN7KXRofYc__n?0eNJl/;f/b<K;e=78
b]GFb;`=_lcDc/GEdm7AdmSNhN3nhGoPgM_IfMG?b<:m^[Vb^;fl]:bWYYVW[JNV
/K^lX[?6b/2g][VZ[kK0aL6h/:Bf^:JO/<?8_<GDak;1`IR1M7V>SGI/MUQKIF]P
D4mKEfU/Gf9bKUVGK9F?LHb=Q7E`KgQnMUi8LGI`Hf5XJF=WJF]^LWEgN85dNHf=
N7>0OW5UI5Q[JeiAH5aJFemOFeIQGUUDDeYVKgMbIUA4>c/o?daIFE5=DU]HE55B
De5;ACm9E5YIDTa8@TE3@4]NI5icJeiBBTQ:Bd0k=SQ0AdY:A40n@4E8AT<h=S8^
:ohY=40d=DMCC3lhD4Y6B4a<A3`i=C<f?3lm>RY6@38k>2de@4@l;2H`>3MVF4Dg
<C0^;3dk>CLh1M=okYV9Lf=aJ7EXGE1:Ce]XL4Y?EE]OH5mNKG1bKfUUIVV3SY>6
M7F=YibQVi:K[ZnRWiJHY:2=QHb;Ri^[WXJ?[IB5TIR6S:BUXYjMXZNUVY2KVi>9
SjFc]KZGXgiVRXnFQWa]IW:7TiBFU9NHRWQfPJNVSVQONi^XUK31eN?8ZkIoVh2@
Ph6<O9RFTHR0OH27SIZ;U:J@J6nHWiVIWYjQ/l[O`<bl/JV3TX61P7agM7AfKgQ_
JYSIhKkYa>;9d>Ve`l75b<C0`/cFf]?4^L3?d<G4b]7EemcSjMcNgn7QgmkLeM??
b/G0_;[D`:ZQYJRRVJbKW[:eZKKCVjRf^kNd]keo/k2a^L;3^:jc/[2_/KJk_kJi
aLo3ZYjRO8J5M6=RJFiZKg9[GeIEF6]gNgMlPG1FOG]gLVYRFUIPJg5]KW=^HfYV
Ge]KH6M/R61YHfenLHi[MXF?SX5aIG:6U8U[EUIPJfQVIfQTFeAbD4AJIEQCGGY^
FdU0@4E;CT]AETTg?E9oCE9BB3`kBEQHGEmHC4M=ED56Bde:BD]>MViTG5I>A3`i
A4i9>c@j@e=6@4M:A456>3DlBDLh;S0g=SPm@d@n>DA5@c/d=T9==3<a;b`Y9bH]
;Rlb=CPk?2<f?C0V<TQDFDXi;bh^:bM3@3doA>jIRG=SLFQeJ5e@BTmKJ71:CeEo
FemPGei]L79_JFEVJH>>ThIdMHfWW:6KTY^^[j:OUYRTX8f5S8^;Vj^NQXn]U8FA
V8J<Y:FRWYfRYjFJT9^KThV?YK>e^YNSOVJ:SiJ6O6eVLXNCU9JDUiR:N7J1YjJ>
J5mkVjRE/<7EhlR[]Y^0T8>1S7bHUY68P7f0QhfJRiAoYY1XKiROVIVNWZ6cb]o0
c;baZH>BPH60O7MdM7I_N6mZV=WQ_^W4h/W@jKG3`LG8a<32c=KJdlBi`<o@aLC:
dMGGg>?Yg=kOhN7Og]cEdlo:aL2l^]C0ZZ6UZ::I[9^N/[FY]]>KZ;Jk]kBg_K>`
/KW2`kR^/k:`[k6f^knf^LEocl>ZWZ9lQXEdHf9YKVY_LV]OEUEHJgMkMgb1L5Im
NgMbJV9JEV1[LFe^LfiSJVIOFe]PIfb8H6USKGiaSV]fQHn>PG5ULXJDRF]FEV1[
J6IWJ6AKE79@A5YUF5=MNViKBD10AD]>Be5FBCLmDTeBDTPl>dUHF5eOF4a7CEE1
AT]oCDY9BdifKVALETi4?3U4CTTk=3Y3DdI0AdY4@DHh=Ca9AcP^<3Lf>3e3A3hi
A4E3>c@f@Tdd<c4_;2TW9Rd^;c8e>3/l8cHm<2HbB5AIBST_;Rh[9d=0?Cm4kYV9
Lf=aJ7EXGE1:Ce]XL4Y?EE]OH5mNKG1bKfUUIVV3SY>6M7EoSJNLXI^BVjj_XYnF
V:BPSHF<Rh^KZij6SjfDQI6HQXbTYJ:NWJ:WYIZ@Vi^CRHnU/kFjUj=nIXZ?UXIl
KFIbQi>DUYBGV8YhMX6WYXiXGg^KZ9F``MGSb:^fVh2@Ph6<O9RFTHR0OH27SIZ;
U:J@J6nHWiVIWYjQ/l[O`<bl/JUoPi:1PH1lMgAdMVmhKfZHfN6njLCRbM3Y]L?1
aLS4`<;<e][Ca;W0cm35a<[AeMOLhnWLg]oQhMoNg=GCcl[5`;bje<2ZXJFXXYV/
Vijb]JVfdi^X][^g];Nm/k2a^L;3^:jc/[2_/KJk_kJiaLo3ZYjRO8J5M6=RJFiZ
Kg9[GeIoEEQ[Mg]gO85`EWekMg9ZHUYFH6]aKFicKV=ZIUmKFf1WK8QPJF=]OW6>
JgJ5Shj1LFEbQYB9JeIFH6]XIVMXI5]DLU14FVEHDeejKU]9@415Bdi;DEI9=ceB
CE9BB3`kBEQHGEmHC4M=ED56Bde:BD]>MViTG5I>A3`iA4i9>cA6>T=CAT17BTA1
ASPe?4U7>2h`=cHh?D=4?SU4AD<k=3I2CC@c<Bl/:BLV;Bh_<SDh>c`S=Sd`9S98
E5U:>Bl^;R/W@d0m?d@5dGoXVI1oKWERJ6APFeYNHfQZGf5UJFe_L71XJFQSFeMI
G71mS9:@Si:HQ8AoOY6XZIZ:PhJCTXF1R:ZVZ:^RTHbBGFF;VhB3UIFWXj2QXinD
RXfDThZ;VJ:RZXNELeakMgMmLVAOJh2?U8Z1P8F2N7ElTHmoIEefX;jQ]/3Bh/JU
Zgn_SiZ?TYb5VY><Ph25SIFJQX29UhejQ:6OUYJNXj>[^N?7bjfTZXJ;OG=ZJg=i
N7>GX9R9VL;Jf>;8i<WUfLRl`LG7`kfl`/W>e]G:alk@blkEg>3Oh>?Wg=gOh>3O
gMcCdLg8`knk^L6g[:RZZJ6I[9bN[ZnS[LRNYJba/[:e^7nc/[>g^[Vc[[Bb[jbX
YZFT`kni][Nf/ZfBS8=hKFM^N6ebM6mUGemRG6M]KWR2NVMeM71[He]EDEiYKFQX
K6MLMVmUGE]OIV^9IFmUIg1JLG9jQhn>QGQ_HfaeLfYRHVERH65UJFUSGTXb<4]K
EUYZN6mPDda=DUI9Ada?@c@jCAA3BDa4>CI0Bda8AD=4ATE4?3i2B4gnD7mLEe1=
CDY3?Ci5BdU1?416>c0_?4E4AD`l<c4f<RLT:S8b=3]3AT<n:Bhd=SU2D5`h=cDb
;b/X9Slk=C4`=3Tm;CTi:B0Y=S]3>B`V9RLS7Rl^;cM2j9V@OfieHVQTH5]JGV=X
JUmQIFU]Kg1`J6UXHe]GFEa`OHbBT8nBV8B4OgmnTJRYVXZ3QY>BQH68ZZJXZj:A
S99MIH^KQ8>EUJNSX:6SWiB:SIBCRX^IXZ:ZQiEcG7]gMgebI5m[P8nDRX60QH9h
MGbASgmUGGJP_Z6f`=;RaZF[[hnJSi:LQIZCS8>0QHfEVXJ0RIN=NXBQWiJFWZ>S
ZkWSal^]Y:Z6RgecJWm[LgUhLiNPV8VI`][Hh/STbNGIb;c1aLO3_Kc2bLkFeL[7
c]3;c]GLh=oPhnOLgMoPh=oMg=?AcLS3_k^i`KN/Z:ZYXIV/W9j^[j>]b9jU[;6b
/[Fh/k:c]kZi/jjd/Zn/Z:JUY<>o^KJg][:]TXb3N6eWKWQ]LWA_IEmOHUaWKFU^
N89jIgEdL6]SFeEAGVU]J6Q/IeafKfEMFemVJhUUKfEWL5YaLWZ7Shj5N6mSK7Ec
JV9RIF9PHFEYJF=NBS8`Be]FFVYhKf1CC4eBETU7C4m3=3Y=@dU<A3Tf@4]<B4E3
A4I5A3`n@TQ=oU1oG5M@CDe:@cdnAD]9@Ca0AS/`;ca5A4E<?3<a=S8W92Xb<S@k
@dI3?RT^=3Hi@U1L>3Le<Rl[:2Ho>cDa<3@i?Bdi>BTP:CHk@cT/9RHW8ah_;Rlg
@^RIT7m^MF9XI61KFUiSJ6YOHFEYKFm`L6QYJ6=KEeULL7f<TY2?TYR4Q7moOY6X
ZIZ:PhJCTXF1R:ZVZ:^RTHbBGFF;VhB3UIFWXj2QXinDRXfDThZ;VJ:RZXNELeak
MgMmLVAOJh2?U8Z1P8F2N7ElTHmoIEefX;jQ]/3Bh/JUZjn?VXnBW8FJThb3P8F=
UIZ6P8VGSGZ4XInFUYjSXj^ihlO;[JBZQX]mLfYoJg=iN7>GX9R9VL;Jf>;8i<WU
fLRl`LG7`kfl`/W>e]G:alk@blkEg>3Oh>?Wg=gOh>3OgMcCdLg8`knk^L6g[:RZ
ZJ6I[9bN[ZnS[LRNYJba/[:e^;>b/kNj^K>^];:_[:RVYJC3_kVf]kJb[I:<PgQ]
IfihKG9dKfEOGf9LIfeYKWR2NVMeM71[He]EDEiYKFQXK6MLMVmUGE]OIV^9IFmU
Ig1JLG9jQhn>QGQ_HfaeLfYRHVERH65UJFUSGTXb<4]KEUYZN6mPDda=DUI9Ada?
@c@jCD=9C4@i=T1;C4Q5@dA6AD@l?T98COi@E5aGD4e=BT<m?TE;BD4l@4Hk<2ll
ADA5C3`c<CHb9b@Z<S8d>d=6@chY;S@f>D9@G3Pg=C8_:bPV?c/e<C0d>Cd]>CTY
82Tf>d<i;2HV9b<N;bh_=d85cPoUW9^?O7]MG5=GGF5QGUUFoV<6IFM[KW1bMOig
Og^4S6adPiFQYJ6LT8j9Rif`[j:FT96HUhf:SjJYYZ>W[J>CHgJR[Y2=XZ:UXZ2Q
Xj:LUY2OY9ZDVInNWgj@MF>2NGF7NFUSJWV9TjJ?PXR@RGmkQh9kLV]fWLB]^K_;
glBNW[>BWYFIY8^MPWYdN8B?TY1dO8F9RXfDVY66R9b/BJj]/>7<bYnL]I>8RWY[
KW^3OG=mQh^1Nhnni]WGfM?bbmjka<O8aKjk_;o2e^3Fbl_?c/oGh>?QgMcMf]_M
g]kMfm[@c/_7`[jjo[Qo^KRf/:ZU/JFV/k6W[lFUXj:U[;:d/k6d][Fa[k6c]kRi
^;B_ZJJh`;^a^LRlXIImKG1]HVEdJfi^JV=NGf5XK6]VJFmYGFQWI5mIDT]8DeiS
HF=[JF1hKf5FDUELHWmTM6UXK4mON7f4R8N1NG=NGEiQIVQXIUeLGVE]LG1/EDDh
@e5CAdUHIV5HD4a<CU5;BTe>A3Y0CT17C4Pn>3]0E4U1AE1FDTY0?Ci8EUeKEEIA
C4]<BdI1=cPioSYF>ca2>CY9De9DFUQ9?cdi<CE0?Si0Ae1EE513BeIOJ79nQVEU
Hf1LEe9?Bd@i<2da>Ch_<bdO72HZ9RhZ9B@V9B4M8b8U;S[UW9^?O7]MG5=GGF5Q
GUUFoV<6IFM[KW1bMOigOg^4S6adPiFQYJ6LT8j9Rif`[j:FT96HUhf:SjJYYZ>W
[J>CHgJR[Y2=XZ:UXZ2QXj:LUY2OY9ZDVInNWgj@MF>2NGF7NFUSJWV9TjJ?PXR@
RGmkQh9kLV]fWLB]^K_;glBNW[>BWYFIY8^MPWYdN8B?TY1dO8F9RXfDVY66R9b/
BJj]/>7<bYnL]I>8RWY[KW^3OG=mQh^1Nhnni]WGfM?bbmjka<O8aKjk_;o2e^3F
bl_?c/oGh>?QgMcMf]_Mg]kMfm[@c/_7`[jjo[Qo^KRf/:ZU/JFV/k6W[lFUXj:U
[;:d/k6d][Fa[k6c]kRi^;B_ZJJh`;^a^LRlXIImKG1]HVEdJfi^JV=NGf5XK6]V
JFmYGFQWI5mIDT]8DeiSHF=[JF1hKf5FDUELHWmTM6UXK4mON7f4R8N1NG=NGEiQ
IVQXIUeLGVE]LG1/EDDh@e5CAdUHIV5HD4a<CU5;BTe>A3Y0CT17C4Pn>3]0E4U1
AE1FDTY0?Ci8EUeKEEIAC4]<BdI1=cPioSYF>ca2>CY9De9DFUQ9?cdi<CE0?Si0
Ae1EE513BeIOJ79nQVEUHf1LEe9?Bd@i<2da>Ch_<bdO72HZ9RhZ9B@V9B4M8b8U
;S[UW9^?O7]MG5=GGF5QGUUFoV<6IFM[KW1bMOigOg^4S6adPiFQYJ6LT8j9Rif`
[j:FT96HUhf:SjJYYZ>W[J>CHgJR[Y2=XZ:UXZ2QXj:LUY2OY9ZDVInNWgj@MF>2
NGF7NFUSJWV9TjJ?PXR@RGmkQh9kLV]fWLB]^K_;glBNW[>BWYFIY8^MPWYdN8B?
TY1dO8F9RXfDVY66R9b/BJj]/>7<bYnL]I>8RWY[KW^3OG=mQh^1Nhnni]WGfM?b
bmjka<O8aKjk_;o2e^3Fbl_?c/oGh>?QgMcMf]_Mg]kMfm[@c/_7`[jjo[Qo^KRf
/:ZU/JFV/k6W[lFUXj:U[;:d/k6d][Fa[k6c]kRi^;B_ZJJh`;^a^LRlXIImKG1]
HVEdJfi^JV=NGf5XK6]VJFmYGFQWI5mIDT]8DeiSHF=[JF1hKf5FDUELHWmTM6UX
K4mON7f4R8N1NG=NGEiQIVQXIUeLGVE]LG1/EDDh@e5CAdUHIV5HD4a<CU5;BTe>
A3Y0CT17C4Pn>3]0E4U1AE1FDTY0?Ci8EUeKEEIAC4]<BdI1=cPioSY6>ca2>CY9
De9DFUQ9?cdi<CE0?Si0Ae1EE513BeIOJ79nQVEUHf1LEe9?Bd@i<2da>Ch_<bdO
72HZ9RhZ9B@V9B4M8b8U;SX5d1WUWIjCP7aLFE1GH6=OF59?GeeJFE]OI6MRI?iV
OfafOg=hP8^GXZV^ZJ^[YjJXZJN^ZJBQViB@TINWZ9bQ/ZbDTIJ[YHR?YjB;Rhb?
U9RJVY^Y[Z2EV9jOV7V=MFR>S8b@OVaUI6UfQ:n@OY2[/JBHY9bLXj2HY;Z]];30
f<6JV::9W8n;Th6LUI6AVZJYX9EfS9NBUjBPSWmcNIReOkfg/]K=cIbL_iQoRH9k
NgekL6N6RYFGQhNgl]?__nSQcnO8blc<blO4`l?0cmG=al[<al3:eM_Ie=7@f=WK
g=cKfMS>c<W5`Kjk^KNj_KVbZjRYYj6T[ZfW[l2`YYjQ[;Fg]:jd^KJ_[kO0[;6j
`<?0^kRF^lo6aL^_PH][GW5iFVYTKfa[If9LF5MGKFaXI6AWJ6IRHEmLEU1:AdYF
GEeTL79[NW1SF5AIHVUWF7=[Jg=EHGMhN7MdKfYWI69NG5eOHF=OGEiUKG=bL75W
HfAHATA?H5aGDTi;BT[nEWmDCDU?F4I>EEA;@ShmFE=>D5MLFeM>AT==GfMPEVAO
F5EEDT]6EU=@DUQKFeQICdeHG5IBEFEGCTi:A4UDATA4BE5EE54j?dQ?E5QJG51A
D4i9@c`i?c/e<S8f>cl[:R4I7bd/8BDV:2/];2TU:BHT:2oUWIjCP7aLFE1GH6=O
F0]BCemMFUUKGfAWHVCnIWm/MWmcN82;Uj:Y[ZV[ZjNVZ:VW[ZVTXI^DT96GYjRL
XK:/U96FZjF8SjNTRh^<SiBHVYZKZJjPUIRNWiQiSGEXSXb<T7i/IFAYMXB_T7j@
Zk6TV:BLW:>PV:Bj[KB``=S1VYRRRIb?Ri>1W9FATIZVZJ2EMXbGTYNTX8ioLgVH
]Gnm]k;FcLfLW;nHOhV2Ng]mNg1WQXZEUhN7]o;CkkoXhLoWb<_<c<_7a<?3`<oE
cLO:c<O0b]GKfMCAd=SIfmcLfmWHc/c9aL6n^kVg^[fi/Z^XZJNQY:j]Yjo0/:JN
XJbe]kB^];Vf[jng`:ba^/33`;^hU[_?a/G;[h6;JeiaNEYZI6m/JfMRG5QGEfe/
J6ATIfQVHV5OG5I@BTM:EUeMI71bJgY`HeQDFF9YIeQcJf]cEF5gN7QgM6mZIfAR
GUaMGf5SGeeNIFecLW1aIf=TF4I4Cf1LEe9>BdY:oUIoE4e9CeQ6CUEDBd8n?EUC
CU1GG5]GCTI3CEmWH5ITGeQEEE9;AUICD59HFe]HFDm=F5aFDUEUEdi>BTA9E4I4
A4UAEEAA>Sm8CeAHFUa@DE1>BD<l>Clk=C8b=S/o:bXQ6Al];24U9RP[;B`Y9BTV
92P_iIfNTh1lG5U@Ef1SGeP;DTmOGEYIFemTIf9ToVIoK7IoLgR0RiNRZJjYZj^W
YZRYYjjYY:6KU92AUjNXW:6b[9BAUZ^UR8nWY8^;S8nDV9ZJVjV^X9FHWYnHNHee
J8j<S91nK6ETJGJ4[i1nT:^aY9RTW9bSX9RT^Zfd/<3H`IZHXXVLSh^CPIbETI6J
YZVPUGJ<Ui:GY:2>Og=iV;Eo_KNbe/g=W9boV7n9PW]kOG]`IhJ:UIN7QkObdnno
j>7?ilS;c<c;alC3`l3?eLg7b/c7`<[EfmWDdM3HfM_Lg=_If<k<bLG1_[^i]kZm
^K:[Z:VWXJB^[JN_`;2VWZ6/]KNd[[Bi]Zn_]l2//K[0`l2k^9JkclK5bjn1Rf]N
LGUJJVA_K6]WHUaHEeM]K6QTI6MXIV9QGeaFD4Y7BUIMGFA`LV]jL6=HE5URJFMH
Lf][LeEQMgQhMgA_JVMTHUiLGEmQHemMGVE]Lg9`LFMSI5Q6A4mPG5MBCT]:B_iF
LEA=BDmHATiEE4]2?SeIDdi@EeaKEdi6@deOIf1FI5mHEEEBBdIFDe1BF5]KF5U?
CEQLEU9EIEM>CTY4BEA6A4A9DEEDDCXoB4mDF5YLD55@CTU3?3To>cDb<SHk?b/Z
8ATO;B`Q9BHX:bd/:BDY9R@X;`G>An6GUXUgMeYJG69XIUiFE5IPGU]HFEaPHVIW
IV1KFUiTJ7F3RX^@W:NMZ;2YUHR?WJNUWYF@T8n=VJnbWI>LV8NLTiJ:MhZJQoek
Ogb1Qh^NYjBCRY6JW9enT75OQi2HRWMYIV9NJWfEMVZ=`=K=_/2k`<oBa;>]YZ^V
]m:nW9fKRZ29MWQ_UH>5S9JJT7a[M9:SWJ2]XHJ4MGRH]kng/<o;dZ:K/hAVKGV4
Q7U[I6>JTiRNS7VB_m3lZ_S4h>;Ldm7@d=7BdM35a/2iOko;bKjf`<gDe=7?cmKG
fM[JfMOFcLc:a/>o_K^j^[J]Y9nPXiBDVZ>UY:bh^JjTYK2i_;Z]];Zi]KO1bj2W
/[c1`;^hQ[_KbkVbV7>0JVV3TXEfM7iiLFYUHEiMHF1SJW=mRIA/K6YXHeiJEeEO
Hf1TKg5ZNG9XHV9YLg]FD71TOf=`E5e_KFYUH5aHEU]PHEY@D5UTGe]IFf5THf5M
G5mSGeMIHFe[IV1KEU=BGEmLEE9EFei=De]LEDU0>TM<Cde8B4mFETe7CeeQF4eP
FUECDe5<AU9=BD]@E5EDDdU6Ce56?d59@D17AShoAclk=cTm@3hk<C<f>S`j=C4c
=3DdJ30Y8QhV:Ble>Sdn?c4]8a`T<B`M82D[;c0^:bX[9b<U:>6GUXUgMeYJG69X
IUiFE5IPGU]HFEaPHVIWIV1KFUiTJ7F3RX^@W:NMZ;2YUHR?WJNUWYF@T8n=VJnb
WI>LV8NLTiJ:MhZJQoekOgb1Qh^NYjBCRY6JW9enT75OQi2HRWMYIV9NJWfEMVZ=
`=K=_/2k`<oBa;>]YZ^V]m:nW9fKRZ29MWQ_UH>5S9JJT7a[M9:SWJ2]XHJ4MGRH
]kng/<o;dZ:K/hAVKGV4Q7U[I6>JTiRNS7VB_m3lZ_S4h>;Ldm7@d=7BdM35a/2i
Oko;bKjf`<gDe=7?cmKGfM[JfMOFcLc:a/>o_K^j^[J]Y9nPXiBDVZ>UY:bh^JjT
YK2i_;Z]];Zi]KO1bj2W/[c1`;^hQ[_KbkVbV7>0JVV3TXEfM7iiLFYUHEiMHF1S
JW=mRIA/K6YXHeiJEeEOHf1TKg5ZNG9XHV9YLg]FD71TOf=`E5e_KFYUH5aHEU]P
HEY@D5UTGe]IFf5THf5MG5mSGeMIHFe[IV1KEU=BGEmLEE9EFei=De]LEDU0>TM<
Cde8B4mFETe7CeeQF4ePFUECDe5<AU9=BD]@E5EDDdU6Ce56?d59@D17AShoAclk
=cTm@3hk<C<f>S`j=C4c=3DdJ30Y8QhV:Ble>Sdn?c4]8a`T<B`M82D[;c0^:bX[
9b<U:>6GUXUgMeYJG69XIUiFE5IPGU]HFEaPHVIWIV1KFUiTJ7F3RX^@W:NMZ;2Y
UHR?WJNUWYF@T8n=VJnbWI>LV8NLTiJ:MhZJQoekOgb1Qh^NYjBCRY6JW9enT75O
Qi2HRWMYIV9NJWfEMVZ=`=K=_/2k`<oBa;>]YZ^V]m:nW9fKRZ29MWQ_UH>5S9JJ
T7a[M9:SWJ2]XHJ4MGRH]kng/<o;dZ:K/hAVKGV4Q7U[I6>JTiRNS7VB_m3lZ_S4
h>;Ldm7@d=7BdM35a/2iOko;bKjf`<gDe=7?cmKGfM[JfMOFcLc:a/>o_K^j^[J]
Y9nPXiBDVZ>UY:bh^JjTYK2i_;Z]];Zi]KO1bj2W/[c1`;^hQ[_KbkVbV7>0JVV3
TXEfM7iiLFYUHEiMHF1SJW=mRIA/K6YXHeiJEeEOHf1TKg5ZNG9XHV9YLg]FD71T
Of=`E5e_KFYUH5aHEU]PHEY@D5UTGe]IFf5THf5MG5mSGeMIHFe[IV1KEU=BGEmL
EE9EFei=De]LEDU0>TM<Cde8B4mFETe7CeeQF4ePFUECDe5<AU9=BD]@E5EDDdU6
Ce56?d59@D17AShoAclk=cTm@3hk<C<f>S`j=C4c=3Dd830Y8QhV:Ble>Sdn?c4]
8a`T<B`M82D[;c0^:bX[9b<U:0GCOmfBTHIfNV9TG6=WHUE=CU9KFEMFEEEFEeeS
JVi_LWQnFW2;UiB>SI6>V:FTT828WI^NV8j>VInLRi^TWYVLWY^QVIfES:F`T9^I
U8^4PhV?ZJ^SUYFQYj>cVJb2HH:?X9>2Nh1jKWR?XH1dVLcOck^_^;bk_[f]V::[
Z;K?_J:YOjF@Wh=^LV^DL7R3R89dHeMYQIJBT9J?Oij;Qibb]JjYc/SF[9ZPKei[
P9FHRh20QXj7RiF>P8ZRcnfflKoZfNGKe<k=dMKGelO3^;>ncLZk_<G@e]KDeMOD
eMOHf=OEe<o>blW6`l6oblFm]K2]Zj^IWjN][k>k`[Zd[Zjc^[k0Ok2d^Kbl_/?7
[kBl`L:n]k>G^/ZaU8^6OFa[Lh>BT7e[THUoN7IeLVmaKG1iOH2>WgUiN7IcKf]X
J6m^I6=YJ61VHUiLGfM_MEQELEYDHdU@IVERGe]HEUA;E5YFCe1MJUiHDU5CEE=@
CdmBEe]KFUY_K6IPFeMEEF1SGE=BGF9OOe=HGEiHCD0h?4I>C4E5DEeFD4]>EEE=
ADQ4@D=8BTM3@T4n?3`o@dM7?Sm;CdI0@CHb=T93>CHk@cdh=cXl>cQ3@T=8C4a6
@C/n@T=0>S8^7R@^=cdo?C/l>S0U9RdV5a`R:B/X9BDW8b0N8RSMTY66MWYRI5aS
If9ECDiBFeUGOeIEEEIGGF=ZKVmbN7iJL8^GU8j=THjHYJB@P8RMVijHSXjIWib;
VjBNVIbNVj6IWIF<YK2@ViVDRhB3RHnYZj>FUJ6WXk>I[89QPXnPTh9kP7Y^N8nQ
P7BIc=o?^jnh_;^n_JfHXZ^X]/nmXZVUT9n3KW9[U71hPhR2M6=GJHFFOi:@UXmo
WX^7W;:e[ZW>b=J/VZ1_GV^0UIR;P826SXN;UHj0RZ;?kKKa_n[IiM_Dc/gAe]OG
al>h/kk=b[^laM3Fe]CEemCEemSHemGDclk;bLK3`Ko;aKfe/:f[ZiVOYjf_/k_2
^[B^[[>j_/2`];Vl_;k3ajnd_<72_[NcUk[:Ok6DRhImK6]cPi:@OF^ARGmhMWEb
Kg5]L7UmP8jONGUhMW=_JfQXKfiTHfUXH6IRGUaOIfmeF5EaFUASBE1VIF9OFeQF
E4]DFUI?D5eZGUQBDE=EDe1?Ce9GFe]JFVm/IV1KEeEEH6=MDe9MHUmCF5eNF4e0
>3a6CTa5AE5MEU1;OdiEEDe5B4A1@dQ:Ad=2@Chl?3m3AdLn?d]?AT11=S8f@T<i
=S]3?CPg>S`k>4=2@dQ<C4I1>ci2@d0j<RhN92hg?Clm>c`j<2DV;BHG728Y:bPU
9BLS81hR:=fBTHIfNV9TG6=WHUE=CU9KFEMFEEEFEeeSJVi_LWQnFW2;UiB>OhfA
SYRUY920R9fKWYR>SYVOW8^KY9jIW9jKXIVMUHbU/92KVIB;Q8>9SjV[XiJEXJNS
/iV/PV62Sj2CPW^0NVihSj60M9W<glnk[kRl^kjm[IRRZjRfckfRZJF@Wh=^LV^D
L7R3R89dHeMYQIJBT9J?Oij;Qibb]JjYc/SF[9ZPOfmNJh2EV8^0P8J>Qh^ESX2:
X/o]]_6oj]WUfmC>cM7FemO7`kRc_/g:^kc5d=KFe=GGe=GGf=SGeMC?c/_9a/?1
_l_5_KF`[J^[VInW[Jnc^l:j]:j^/kZn`;2d^Kbl_/?7[kBl`L:n]k>G^/ZaU8^6
OFa[Lh>BT7e[THUoN7IeOg9_LFe`NGf0SYmiNGQfLfm[J6Q_KVASJFQPIV9NG5mW
KgEHEG5JE6=9D6IUHUmKF5IDBeAJETm@GFYNF59ADeECD4m?DUMKFeYJKfaVH5]G
EEEPHeeCDUeRGe=HGEiHCD0h?4I>C4E5DEeFD4]>EEE=ADQ4@D=8BTM3@T4n?3`o
AT=7AchoBdm6@44f<SI2@cTf>d<m>3Lj?3/h@d93B4a<AT4k?T93@3Xb;QhT;SLm
?cdk?3X`9BH]9QLL8RT[:2DU9b<P7R8X1LP@hibPVXjBNW]RKGE_H5=AEEcnGGmL
FEMEBeITKgEjP8AdOi2NYJBNVIfIWjVTUYJRX:FOTYBU[ZZ9QHfQ[k6b]kB_[ib?
//fh_[^cYYZGWZJ_[ZJR[;VeYkFW`iMXP8jUZiZEVhifN8jSQ7VMbmJoYini]8en
U9jBYkBd_/nlYkJROhAbM8R1XibW/K2UW9^OTYnWWWn?RXjD/YjCWZ^^[Jo<`MFi
YZ:0RI6LZ:^VXjJ[ZJba]KFf`<_<a>3EgN?Gh>3Eal;6cLo?`<O8a<O@cL?8c]GF
e=?FfM?De]OGe]CCdM3>c<W7aLC<aKno`/2f[J>/];Jg_<74]KNg]KBf_L>g][Rl
`<2j]K^n`L;0^kB`Z:fYUR]oLgR1HgMoNX:?P669OgEaMGQgM7]dM7YeK7F7MGIf
MG9_JfUXKfeSHVUZH_iJ45]NHfU/IV=jFTmRCEIRHfEWoVPhIeEFF5]OIFU/IUmG
E5EFE55LFUMJHFAKD6YVH5YHF5YLIf]TEUQXKFIQHVATH5E8?Se1ATaBFF9Xo5IX
De1=AdA1@TI8AD5MH61JDU9KIDY2AE=HD4U:AT13C4a2?dE:A3ln@dM7AC`h=ca4
Ad<m;c<i?3/f;bX`<SDh>CTg=SPk=BTW;2LL82H[:B8O8BDQ7QhR:^>LX9Z>TWYk
HVeeKf1CDEELoUeoG5UGED]FI6meNX24M7n@WZFTWYVMVInYY9JFXZ2UWi:DYJjZ
RHF=XJna/[Nd[jnLSk;=^;jk/jJJUijV[jjVXZbi]JNeYl>GJ82>YJ^JUI^>MWR>
XhAiWL_F_jNO^KB=OYBNTZNd];k?_:NfXWn4LWB8PJ>LYk6`YIbKWi:OYiioShZ>
U;:NTij[[Zf_c<7E^JJRP8VAW:R[YZ>VZjV//KFe]/3;c<CPeMgSen3PeLO2a/g?
cl37b<C7d<g3b<kEe]CCe]WCe=KGemKDdm7@c/c9alG4c<Fo_l;0]ZfS[;Bf]kc1
a;Fg]kFd][g3]kJh_<30^[Fk_/72`;^d/:R]ZIH[Og=hPF=gOgZ2Sh1QRGmeLGEh
MgAkM7AjMFaeQgEfMWEbKf]YJ6m]Hf9YJV;nFQ1KGV=YK6ISNUY?HTeFHV=UIoiX
>6MEEUQKGfEYK6IOEeAEEUAAG5YGFV5TFe1ZIV1JF5QJG6M[I5IHJ6eVHF9TI61E
B3hm@DI<DUURJ?aFJ5=@CDM4@D96B4E1GF1PFU9BFfE:@TECF519BTI0@da<@Sm5
BT@o?T=7AdDl>3LlA4M3?Blc>C`k=RlZ<38e>3Ti=cHh>cDY9b`W720V:bTR7b4U
8AhN8R[SW:2JSY9jNf9]MFmPDe5EG?iMOeaIEeE;EVA_MGZ0Q7AoT9jUY9jIWIVO
ZJBFUZ:PYInBU:F^ZXV5SJ6_/K:g]:n_W8nbcKRn^k>VVYNNYZn^YZ:/^KFW]JO3
UfR0SZF[VYFKSWIhSZ>4NIg;e[nWWkVdSGjDWY:W];BnckbW]Z9oQ79dR86SW:Na
/:FLVinBWjNNOhn:SYBbWY>NZjj][lc1eKVVXX29TIbXZjJSYZ^Y[;6e]KK0blc4
h=GMhmOPh=G7`/K=clo0alS4am3=`lS>eMKDdmKIdmCFemOFe=?Ad<k<bLO5a<c5
_ko2`;J]Xjbd][Nl`LBe]kNe];Jm`kNf^;c0`;Ze^kk1`/2k];2X[JVF:gmcN85S
MgmjPXn0HHUoMG5eN7MdNgAdNWE/MHMeMWIeLVm[JFQ_KF=RJFYRoUX@FeiSJFaV
HgYJCf9=EV9SIFOnJ3QWEEIHFemUJFaVGeMDEEIDDEaJEeYQI5]@JVIPFUQHFUaW
JfAFF6Q]IV5RI6APEDPn?D56C59IHVSlEUMCD4e7A452ATQ5@EePH5YBDU]UBT95
DeQ@BDY6@4=<C48oADY4?ci3AdM5?3Pg?4A7@cd_<cTl>cH_:S0b=CPi>CLf>3/e
:BL/9a`P9R/Y8QlQ9B4N7R8Z1LiokZbf]J^_Ti9iQiB@OfmYJVmaLgAbKVUUSIFN
X9^CSXfQUi6K[[bm]k>PVj^cYY^JYZ^RT8nPYj6YSX^Y_kN/[kVbY7aTT/K5_[bf
ZIjMYk:RXIfP/KjaVIZF_YISMXFN]J6KWHIRFfmaFEV7_LnmZ;3EaGaIOJ:S[ko0
a]6lZ[e;Tf=RGg^RW;JP[;B^XJ2``MgMf<N/W:Rn]Z:GWZV^];k9^MC6][BR`k>_
ZZV[[[2`_<G4]Zb_^;c:X_nko]OHe^?C`KRk`LC4]lgMfOkAOlc?dmKCclg@e=;C
eMKFeM?Bdm;@c/_9alJe[Zff`;j/VY^U[:ZY[K6`[kJl^K:b^/>l^;Jk`;faYJj`
/[>b[ZZWZYbBSX5_KGMaT9AmOiN=J75WGUiVKFi[H5YPJfURKH=YJFYYIfAQGeYR
HeiRKgA_J6U[KG1bM7E`KX=OEFiO<6YQIF]aMgYkO6iUGfIdNWAZLVYRGf1RH5iQ
GUaSM7ieIG1/If9RIVa_LGI^GV9dNG3nKe5^JV1CBCTd=49FIVYXFemSHeiKFeeM
F59?Cda6@4YAE4Xl>TMECTE7DeM<A4AICdeBD4I6CD8m>3U0ATQ7CDM2ATeACDPi
?TE:BTDn>DM4?SPdoS9o:C8b:BP_<2TX;C0/8ahR:2PT8RDZkZbf]J^_Ti9iQiB@
OfmYJVmaLgAbKVUUSIFNX9^CSXfQUi6K[[bm]k>PVj^cYY^JYZ^RT8nPYj6YSX^Y
_kN/[kVbY7aTT/K5_[bfZIjMYk:RXIfP/KjaVIZF_YISMXFN]J6KWHIRFfmaFEUP
Qkg?_JR`eLElFGfRXjno`<KA_:ZmTf=RGg^RW;JP[;B^XJ2``MgMf<N/W:Rn]Z:G
WZV^];k9^MC6][BR`k>_ZZV[[[2`_<G4]Zb_^;c:X_nko]OHe^?C`KRk`LC4]lgM
fOkAOlc?dmKCclg@e=;CeMKFeM?Bdm;@c/_9alJe[Zff`;j/VY^U[:ZY[K6`[kJl
^K:b^/>l^;Jk`;faYJj`/[>b[ZZWZYbBSX5_KGMaT9AmOiN=J75WGUiVKFi[H5YP
JfURKH=YJFYYIfAQGeYRHeiRKgA_J6U[KG1bM7E`KX=OEFiO<6YQIF]aMgYkO6iU
GfIdNWAZLVYRGf1RH5iQGUaSM7ieIG1/If9RIVa_LGI^GV9dNG3nKe5^JV1CBCTd
=49FIVYXFemSHeiKFeeMF59?Cda6@4YAE4Xl>TMECTE7DeM<A4AICdeBD4I6CD8m
>3U0ATQ7CDM2ATeACDPi?TE:BTDn>DM4?SPdoS9o:C8b:BP_<2TX;C0/8ahR:2PT
8RDZkZbf]J^_Ti9iQiB@OfmYJVmaLgAbKVUUSIFNX9^CSXfQUi6K[[bm]k>PVj^c
YY^JYZ^RT8nPYj6YSX^Y_kN/[kVbY7aTT/K5_[bfZIjMYk:RXIfP/KjaVIZF_YIS
MXFN]J6KWHIRFfmaFEUPQkg?_JR`eLElFGfRXjno`<KA_:ZmTf=RGg^RW;JP[;B^
XJ2``MgMf<N/W:Rn]Z:GWZV^];k9^MC6][BR`k>_ZZV[[[2`_<G4]Zb_^;c:X_nk
o]OHe^?C`KRk`LC4]lgMfOkAOlc?dmKCclg@e=;CeMKFeM?Bdm;@c/_9alJe[Zff
`;j/VY^U[:ZY[K6`[kJl^K:b^/>l^;Jk`;faYJj`/[>b[ZZWZYbBSX5_KGMaT9Am
OiN=J75WGUiVKFi[H5YPJfURKH=YJFYYIfAQGeYRHeiRKgA_J6U[KG1bM7E`KX=O
EFiO<6YQIF]aMgYkO6iUGfIdNWAZLVYRGf1RH5iQGUaSM7ieIG1/If9RIVa_LGI^
GV9dNG3nKe5^JV1CBCTd=49FIVYXFemSHeiKFeeMF59?Cda6@4YAE4Xl>TMECTE7
DeM<A4AICdeBD4I6CD8m>3U0ATQ7CDM2ATeACDPi?TE:BTDn>DM4?SPdoS8D:C8b
:BP_<2TX;C0/8ahR:2PT8RDZ1LioiKVdakb_[9nFXjj/XIfU[i>CTY>FVIfPXj^_
YiVCVjFWZJjb][Ri^JR]/kRg/Z^V[jZFP86AT86;PhFM_<RhXj>gX6a^Y/2]][Na
Z:^d/ZNJUZ2c]Z:;P7UiOGYUFW>IZIn:L5aII75ZHVJ3[/c@b;?9ah]ST/2`]ZC5
bL_;[;moYgAGIW9dT;fTZ:f[YZ>SY/S:c<_5^k6ZZk:^XIn]^K_0b<Ji[jZNShfD
Ui^X]k>VXjnf/[2bZIb/`][SgMCDfNcGalS9`l;6^;W0cmkTgmO9g>cXe/S:d]?D
e=GGemSIem?<aL2n_[nm_[nm^:nUX9jUZZNOVYbP^kBYXZ:Y];/A][6^/[Vh[J>b
^kbc/;:]XHV8oXH?R8Z;PhnOX8UcN8aeN7j3Qoj97X><Rh1lPX=nPWAmPG1cO6f?
Pf]GFVefLVj2QW5RIfknK@5^Koe`OgAiL5iOL7M_HUi]KUiYKeMNHf=PIFiXFFI/
LFiWIFY`HV]ZGEUSKFmkKEmKH6ETH6IXJFQRFDm8Eda:FVifLfm>EV9UFDeBGf=E
DeeLDE9NDe=BDeEHFee@EEUHDdm@DU1GDe]RB41SACa2DD`oCFaEGfMUFe=EFT<o
>3<a<cLjOca4C4To=C8c;Qh/?CY2A2/Q8RH/<BhU72`X9RP]iKVdakb_[9nFXjj/
XIfU[i>CTY>FVIfPXj^_YiVCVjFWZJjb][Ri^JR]/kRg/Z^V[jZFP86AT86;PhFM
_<RhXj>gX6a^Y/2]][NaZ:^d/ZNJUZ2c]Z:;P7UiOGYUFW>IZIn:Og1LFFAaJV9V
Pjk<d<RcbLN;Hi;0/;JTaLW;bjboYgAGIW9dT;fTZ:f[YZ>SY/S:c<_5^k6ZZk:^
XIn]^K_0b<Ji[jZNShfDUi^X]k>VXjnf/[2bZIb/`][SgMCDfNcGalS9`l;6^;W0
cmkTgmO9g>cXe/S:d]?De=GGemSIem?<;/G0_[jo_Kjo_KR_YJ2NYJZWWiZLX;^d
ZJ:RZKBk][6^/[Vh[J>b^kbc/;:]XHV8oXH?R8Z;PhnOX8UcN8aeN7j3Qoj97X><
Rh1lPX=nPWAmPG1cO6f?Pf]GFVefLVj2QW5RIfknK@5^Koe`OgAiL5iOL7M_HUi]
KUiYKeMNHf=PIFiXFFI/LFiWIFY`HV]ZGEUSKFmkKEmKH6ETH6IXJFQRFDm8Eda:
FVifLfm>EV9UFDeBGf=EDeeLDE9NDe=BDeEHFee@EEUHDdm@DU1GDe]RB41SACa2
DD`oCFaEGfMUFe=EFT<o>3<a<cLjOca4C4To=C8c;Qh/?CY2A2/Q8RH/<BhU72`X
9RP]iKVdakb_[9nFXjj/XIfU[i>CTY>FVIfPXj^_YiVCVjFWZJjb][Ri^JR]/kRg
/Z^V[jZFP86AT86;PhFM_<RhXj>gX6a^Y/2]][NaZ:^d/ZNJUZ2c]Z:;P7UiOGYU
FW>IZIn:Og1LFFAaJV9VPjk<d<RcbLN;Hi;0/;JTaLW;bjboYgAGIW9dT;fTZ:f[
YZ>SY/S:c<_5^k6ZZk:^XIn]^K_0b<Ji[jZNShfDUi^X]k>VXjnf/[2bZIb/`][S
gMCDfNcGalS9`l;6^;W0cmkTgmO9g>cXe/S:d]?De=GGemSIem?<;/G0_[jo_Kjo
_KR_YJ2NYJZWWiZLX;^dZJ:RZKBk][6^/[Vh[J>b^kbc/;:]XHV8oXH?R8Z;PhnO
X8UcN8aeN7j3Qoj97X><Rh1lPX=nPWAmPG1cO6f?Pf]GFVefLVj2QW5RIfknK@5^
Koe`OgAiL5iOL7M_HUi]KUiYKeMNHf=PIFiXFFI/LFiWIFY`HV]ZGEUSKFmkKEmK
H6ETH6IXJFQRFDm8Eda:FVifLfm>EV9UFDeBGf=EDeeLDE9NDe=BDeEHFee@EEUH
Ddm@DU1GDe]RB41SACa2DD`oCFaEGfMUFe=EFT<o>3<a<cLj73a4C4To=C8c;Qh/
?CY2A2/Q8RH/<BhU72`X9RP]1L]ol;jb_kB^/Z^X[kB`YZ2QYZ:RXjBVYjVZ[K>e
[:2KXjj][k:e]kRh]j>X[[:b[JNRZjbPSHV?RWfBRh^M]KjbXj2]W7QjXKFZ/kNd
[[:k^:bXV96JXZ>V[LVXPfYHCe]`Q7mcHUECG6IVGemaS9jNUkc0]hIPQK6Y^j;4
d=;8Z<<?ReDhD6]eS:jZ[kFf/k:d]ofd@k>b/:nd]JbNX:jg]<O>cL:m_[R/ZJj^
Zk:l]ZNR[kNg_<C2^K?1dm_Ie]KIe]kB]jfe/J2j^;[3d=SHeM[QinORfmOGo]P1
fMWnfWoHe<o9a/C4aLO8bLO2^[6/[[Bj^;:^[k?0^[:][K:j`<:o_/33`[ji]Kfn
]K:e/:F?SXf<S8f?TI:GXJ>CP8BDTYFHVIF>QX6?UI>8QY2ETI^9SHafMWi^R8Z4
OH6:QGQWMgeaK7N0Og=gOH61OGMcMH:4NG=gM6ZISY64JFa^E5mcN7E^LWj1NVY`
MWA^JfibJW5_IFA^Lfn4OG=^Kg9cLfebMW9SCc/`BS`hCFYfKEiKHfQTGEUGEF=G
EEeKDE5KFEQGEUMJGV1LH6=PFUEDEVQUA3UJIU9;A4UDF4m7DfSnG7mMGU]EDE=?
BDE3ADU;AD]ACdQ3@dI1:Rdd:S4d7BHV:S0e<b/T71TH72?`_[:o]:jbZjR_];2V
X:6VXZ:SY:JWZJZ]/kF/X9^S[Zf_/[Fg^;RgXjR^/[:]Yj:[[:2=RHn:OI:;Rife
_[:SX:fLN7ZQ]JZc]kB^/[^h[:RHTIZRXcVV[LVXPfYHCe]`Q7mcHUECG6IVGema
S9jNUkc0]hIPQK6Y^j;4d=;8Z<>;ECQ@JgF<[ZZ_]KJc/[BgoKA3/k:`[kBe[9jP
[[Ndalk=`[fn^:bY[Zj[/[bfYj:_]kNla<:i/l7CfmWFe]WFg]:g[KFaX;Zh^/?@
f=SEf^7Win;KemOnf07IfOkJOmSDclW6a<C5alS9al:j/Jb^];Zh/Zj_/l2j/Zf]
/[[0`[nn`<?2_[Ve_Kje/[F`YHn>SHb<SHnATYNQXi>0Q9BBUIRIUHj6PHnEThR6
T9FAVhV=S7IfOVj8RXAmPHZ5N6MgOG5/Mh1oLgMmPH5mMg=ePXAiLgMdJYV>THAY
K6iDGg=hMFibOX5jJW1fM6i[KW9ZLFmUI6icKhAmLfi_LW=cKG9fLV=?>c1:?3Q=
JWI]GU]SJ6AMFEMEHeMEGE]ADE]IF5MFEeYNH5aPHf1JEEAFJ6E4>EYVDT]4BEAH
CdMCJ?iLOeeNFeEADdm9AD=5BD]5Be5?B4=3AT4Z;C@Z<C@M9RHZ<3Dc:b@L6APL
8o2n/[nd[[:[Z:nd/:JPXJJRXZ>TYZNYZZfc]JbPVj>^[Jnb]KNh^;NSZ:jb/ZfW
XZ^/X8f9ShYmTX^;WKFn/Z>P[IahNZ6eZ[>g]:jb^kR/Z9RAVZ:S>JJ]bJR3JUQ?
Fg24Og=REE=LIVIOGg6<WYjG_<2gQV25/JVkX/C@d/RX`h]E>51[MHb^ZZne][>b
];Om]4>c/[2_];F/WZ2^]kC7c/g2_Kjh[:V^[Z^b_;JWXZng]kc4`[Vc`M?KfMKF
fMKNd[N]]K6P^[Rj`m3Hf=GJhNOWh]_GeokH0MWIo]Yof=C?bLK4a<G7b<W7`[Za
[:jd^[Rb[Znc`;Zb[Jfb^/32_kk0`l:n^KFm_[Fb]K2UShj=S8b=Si6BUj6STh24
U9:EV9VESXJ1SiFCR8J@UI6KRHf<MWInKXR:Q7f1RXEhIgMmLFagP7mcMgf1PGeg
LgF2Q7UcMgAZVHjAQ6U/KUAOLgQeKW9nPGYZL7IdKV]^LVYaKfETKW=_Q7ecKVmb
Lg=]LWIbHdlk<4Xl>4eZMVeNFf=XI5eIEeESEeEMFe5AFeUHEeIGFUiPG61SH5YE
E5IXID@iFVIBBdA9E5Q?Ae=XoU`YGEiKEE5CCdU5@dE9BdE;DDm8@d=6@BX]=2Xa
=1dV9RX`=C<[91`I61`S1M5oo<Fb^Jn^^kVf]kNe/JbYYkBe]kVi^;Ne^kjl/jRV
[kVb];Ni^[Zi^JR//KFe/ZbY[[JdYYZGTXVTWijV/kVcZj>VWiBFYJj]YZf^Zjng
/JBTTXR?VjJgan6oXIjPTGISJF]ZIF1OHfQXIVM^N7moOH5dL5m;JiRM_9Vkdm>m
Vl1GZG9@I7n3RYb//[Vk^[Zn`L[8aL?4alc?aL6dZJjk^Zo<dLg0_<2n]/76a;k1
b<:eZ;>i^;k:c<Fk`<O>dmOIfk_Mg[V]a/Zc`[jk_/O?e=GRg]_OiNKOf?kN0MgM
o]aoemCAc/c;blc;c<g;al2i]K6f^kbi][Rja<6m^[Zm`LBm_l6o_;g1aKW1`KRe
^KF[XZ6OWYjOX::UXJ>WWi>EWjb][ZbUVi2:WZ6JSi2MYJ:GQhjBPh^ISVmoS92E
Th5[R92CSiBQYjF9T9VOWYR>R7J3QgadN7alUhZ;OfQbOFQoLWQeJFUfPH9^M7Yk
Mg=bLfebKfQ[M79WN7MeKfYZKgEaNGmjId/a8Sla;3iNL6EBEfQ[GUaVHU9UGE]P
GEECFEaJEeEFF5aOF5eQH5]GF5YYLd`ZAV5A?T1HIUe>CUIKFe9;CUMGCD5IEU9?
CU1CETmADe1=C55E@BT[<bloBcYo;2/]<SPh<R``;blf?oc5/[V_[[^i][Ng]K6/
ZJNd]KNi^KRg]K^n_;>XYZni/[Bg^KZj^KVX[;6e]K:/ZJjf]:JJUi:9Y9nNY[>i
/j^SYYnDUZF^[JJ][Z^_]k6TY9:8Si^V]lOQ_j6NX95fHfU[JVEPGf=XJ6IWKWQo
Ogf1M71TGd][V9flVK_CdkfK`:UbD6AoPhZL[;:i^kZj_/7:b<G3a<O<clG1]:V^
^kZ_c=7=`;c0_[K1a/Bn`LS2]JRc^KRnb/c5^l37c]?GfM^kgMji[LK:/l:n^kk7
cmCEh]kKgnGVgmSngP7MgOkLOmODdLk<bl_<blc=blO0^KFa][^l^KJh^/C1_KZj
_L74_Ko1_kbm`LFi`L6h]KVeZj:QWijNWj2RYJ6SYinCUIn/[Jj/YI^@RYjQVXn@
WJFRUhN>TX>;VHi_Ohb@UI>1JhR@ThnDXJNURI2IWijHSXQfPhMlM7QlO9N:RgmX
LWeXOg9hMFUYMX62KWAjNgMcLW=]LVmXJgAbIgQgMFmZJVmeLGUoNVM;<B8o<B`n
GW1UDUMXJeiLIV9BIEeKH5eEDeULFUMEEUQLGeQMHF1KEeQJJG=<:TIQDCi0F6IM
CTiFFe]BBdiGEde1FEIBCdi@DeI?DE=@CDaAED4Y:c<_?d/jOb`[;C8h>38/<2l_
=SolaK:i[jjk^KJg]kFa[:VW];Fg^KVh]kFk_[bcZ:J_^K:d]kVj^[ViZ:ba]KFb
[:V^][BVVYNBRJBOWZJc^K>[XjJOU9JU[ZfV[Jj[[kNaY:BBR8nKY[O7hKnQWZ2A
MV=YJfYUH5mSJ6QVIfihOgmmPGA`I5m;JiRM_9Vkdm>mVl2YLU1TOh>:W:bb^K^j
^[k1b/S5`lC7c<o5`KBY[[^j[lcAcL2l`;jf`LK4_/78`[FX/kVh_/[<aK_0alkC
emWK^mgN^Jg6b[?2_[^naloDeN;NfmoUi]oHo]h1gMgng7oGe=7>c<_;c<_<cL_7
`;Ve/KJk_;Vf^;[4`Kfj^[g1a;fo`Knl_L75^L71^;Fi]J^RXInNWYnPXZFQXjNO
TiFO[:f^[:FKT8ZNXIZ?T9fUXYN7SY:3RiV>Kgn<T9FCPF^8T9>?U:6WYHV@VInN
V8j8MX>7O7AhO7bGRX]oJ79mJ7mbN7EYJGJ1PVidNW]gLg9cKG9_J6]dLVMhMgE_
JVY_MG5iOgYWBc4R?c4/?Ui`IE9GJ6]NG6IRDVEMFf1MEE=IG5YGEEIHG5mHGF5P
FeMHFVUcC2Y6HE4n@5QVGDi>EU]KDT]>EeM=@EUFDTm>D5=FCe5CD4e<DEE1:B/c
;cm;>P`/:bdb>3Pb;30_;cHo1LhTolRf_[Bd`Kni]kJi_Kjj]Kk0`/?3`;fkaLG1
^:n_]knd][Zm`?k1K;Nj_/;3`;fj^/;5^jjXZJbm^;>d^K^i]ZbWZ[>e[jnfYjna
[[:g[YjQVYf/]KFka/jgYk;3_9YkL7EkOgmmNWUhO823QHN<T91kPi27V;_6^Y2b
cLfaSkS7WHB@WYVJYJ^a]kRf][Rl`;jl^KSn]dC3`;Ja^L2cWLg?aK>[/:nX]kjn
^;W2`;Nd^kbd]Kfm]/:n_L;<e]_Ma=kSbKS2c/g6aLG7bloBdmOCdM?Ig=[Gh^7Q
h=ongP?BdM3?o/h0cok7OlK2_KRe]KRl_[nn_ko4`l?2`/?3a;Vn`Kff]l;<_LC3
^[Nm^[6ZZJNUY:FVYk>WXZRYXZ6W/k:`[JVVY::ZZInATj2UX9R8T9B7TZ>HJgf<
T92<NVF0OgenQ8b>RWIjOh>3OgUeNGYdJ6=`RIb7NgeeIGN9NFM`L6=OJ75bKg=h
Og]jMW=aJfm/IVYaJeaYKg=_IVAZLWMjOGY[E3`]@Shh>TaPHeY7IFmMF6Q[GFUW
IVISGU]KGEYEDU9FFUi>E5YLFUULH5UeJD]4>SA5@F=bGDeCEdmNF5=CEUI?B59A
Cde>D5=DF5IBCD]=DUM1:Rlk>D]HB2l];30e=c<_8B0R9RXeolRf_[Bd`Kni]kJi
_Kjj]Kk0`/?3`;fkaLG1^:n_]knd][Zm`?k1K;Nj_/;3`;fj^/;5^jjXZJbm^;>d
^K^i]ZbWZ[>e[jnfYjna[[:g[YjQVYf/]KFka/jgYk;3_9YkL7EkOgmmNWUhO823
QHN<T91kPi27V;_6^Y2bcLfaSkS7WHB@WYVJYJ^a]kRf][Rl`;jl^KSn]dC3`;Ja
^L2cWLg?aK>[/:nX]kjn^;W2`;Nd^kbd]Kfm]/:n_L;<e]_Ma=kSbKS2c/g6aLG7
bloBdmOCdM?Ig=[Gh^7Qh=ongP?BdM3?o/h0cok7OlK2_KRe]KRl_[nn_ko4`l?2
`/?3a;Vn`Kff]l;<_LC3^[Nm^[6ZZJNUY:FVYk>WXZRYXZ6W/k:`[JVVY::ZZInA
Tj2UX9R8T9B7TZ>HJgf<T92<NVF0OgenQ8b>RWIjOh>3OgUeNGYdJ6=`RIb7Ngee
IGN9NFM`L6=OJ75bKg=hOg]jMW=aJfm/IVYaJeaYKg=_IVAZLWMjOGY[E3`]@Shh
>TaPHeY7IFmMF6Q[GFUWIVISGU]KGEYEDU9FFUi>E5YLFUULH5UeJD]4>SA5@F=b
GDeCEdmNF5=CEUI?B59ACde>D5=DF5IBCD]=DUM1:Rlk>D]HB2l];30e=c<_8B0R
9RXeolRf_[Bd`Kni]kJi_Kjj]Kk0`/?3`;fkaLG1^:n_]knd][Zm`?k1K;Nj_/;3
`;fj^/;5^jjXZJbm^;>d^K^i]ZbWZ[>e[jnfYjna[[:g[YjQVYf/]KFka/jgYk;3
_9YkL7EkOgmmNWUhO823QHN<T91kPi27V;_6^Y2bcLfaSkS7WHB@WYVJYJ^a]kRf
][Rl`;jl^KSn]dC3`;Ja^L2cWLg?aK>[/:nX]kjn^;W2`;Nd^kbd]Kfm]/:n_L;<
e]_Ma=kSbKS2c/g6aLG7bloBdmOCdM?Ig=[Gh^7Qh=ongP?BdM3?o/h0cok7OlK2
_KRe]KRl_[nn_ko4`l?2`/?3a;Vn`Kff]l;<_LC3^[Nm^[6ZZJNUY:FVYk>WXZRY
XZ6W/k:`[JVVY::ZZInATj2UX9R8T9B7TZ>HJgf<T92<NVF0OgenQ8b>RWIjOh>3
OgUeNGYdJ6=`RIb7NgeeIGN9NFM`L6=OJ75bKg=hOg]jMW=aJfm/IVYaJeaYKg=_
IVAZLWMjOGY[E3`]@Shh>TaPHeY7IFmMF6Q[GFUWIVISGU]KGEYEDU9FFUi>E5YL
FUULH5UeJD]4>SA5@F=bGDeCEdmNF5=CEUI?B59ACde>D5=DF5IBCD]=DUM1:Rlk
>D]HB2l];30e=c<_8B0R0BXe1LEonlVmbl6ma;k2_kk1a<C0^l31`L;1`;jmb/S3
_;Jf^[nd]kc2a/W:b/33al[;b/S7`/C5`KRe_l_9`k^i^kfj]jnX/<;4][6h]K^l
^;Vm/j:`[K>o`;Rg_/ZaTXB;V9VCPhN=TiB@R8:<TYNHUIFJX8QfRIn@RYVJ`IVh
c<ZcTkUG/9nKYjZRZ;R_];Vh];6b];Rk_l;0_;Jb]KNe];bnZXo=c/>aZk6c[Jfe
]:ZX[ZnX^Knm/k6f]Jc2_;Nia=;Kh>;Kf]BeUYjl_L?:c/o<b/S9c];BcloDfOgO
oMh1cLknc`;>cLgnaWo4`[nl^l?4a/W<c<_9`<72`l?2`L30a/W4_[o9e;o5a;Zh
_kjgZ:NTXZ2PXJ:dYZ2X[JVWZkRbZJ>QYJb`[jjSUYNOW92_VijJPhB<OH^GViB?
T8UnOgUfNX22PX>0OgimOX23QH5kLfaYLXVNXiFCQFmjQW9]MgU`Jg1_J6m`LUae
MWA`KFidLVYZKfYNL7V0OgMdNGn7P7QeLF=<>TmJET8lCfI`CFemJeaRJfY[Kg1]
JfUUH6APFUMHG6=WHVM/K6MTIFQWL79iKCLTC5I`Mf5DGEiCIf]/IUeIFf3nE7mE
EUQKG6IOETm>D5=DECi2BCm5B30b;BTZ;S0_;28Q8b/fnlVmbl6ma;k2_kk1a<C0
^l31`L;1`;jmb/S3_;Jf^[nd]kc2a/W:b/33al[;b/S7`/C5`KRe_l_9`k^i^kfj
]jnX/<;4][6h]K^l^;Vm/j:`[K>o`;Rg_/ZaTXB;V7VITh>7SI>DT8R2S9:GV9FE
VZ28MXVOT8ZIV/6I^<c:/i>i/9nKYjZRZ;R_];Vh];6b];Rk_l;0_;Jb]KNe];bn
ZXo=c/>aZk6c[Jfe]:ZX[ZnX^Knm/k6f]Jc2_;Nia=;Kh>;Kf]BeUYjl_L?:c/o<
b/S9c];BcloDfOgOoMh1cLknc`;>cLgnaWo4`[nl^l?4a/W<c<_9`<72`l?2`L30
a/W4_[o9e;o5a;Zh_kjgZ:NTXZ2PXJ:dYZ2X[JVWZkRbZJ>QYJb`[jjSUYNOW92_
VijJPhB<OH^GViB?T8UnOgUfNX22PX>0OgimOX23QH5kLfaYLXVNXiFCQFmjQW9]
MgU`Jg1_J6m`LUaeMWA`KFidLVYZKfYNL7V0OgMdNGn7P7QeLF=<>TmJET8lCfI`
CFemJeaRJfY[Kg1]JfUUH6APFUMHG6=WHVM/K6MTIFQWL79iKCLTC5I`Mf5DGEiC
If]/IUeIFf3nE7mEEUQKG6IOETm>D5=DECi2BCm5B30b;BTZ;S0_;28Q8b/fnlVm
bl6ma;k2_kk1a<C0^l31`L;1`;jmb/S3_;Jf^[nd]kc2a/W:b/33al[;b/S7`/C5
`KRe_l_9`k^i^kfj]jnX/<;4][6h]K^l^;Vm/j:`[K>o`;Rg_/ZaTXB;V7VITh>7
SI>DT8R2S9:GV9FEVZ28MXVOT8ZIV/6I^<c:/i>i/9nKYjZRZ;R_];Vh];6b];Rk
_l;0_;Jb]KNe];bnZXo=c/>aZk6c[Jfe]:ZX[ZnX^Knm/k6f]Jc2_;Nia=;Kh>;K
f]BeUYjl_L?:c/o<b/S9c];BcloDfOgOoMh1cLknc`;>cLgnaWo4`[nl^l?4a/W<
c<_9`<72`l?2`L30a/W4_[o9e;o5a;Zh_kjgZ:NTXZ2PXJ:dYZ2X[JVWZkRbZJ>Q
YJb`[jjSUYNOW92_VijJPhB<OH^GViB?T8UnOgUfNX22PX>0OgimOX23QH5kLfaY
LXVNXiFCQFmjQW9]MgU`Jg1_J6m`LUaeMWA`KFidLVYZKfYNL7V0OgMdNGn7P7Qe
LF=<>TmJET8lCfI`CFemJeaRJfY[Kg1]JfUUH6APFUMHG6=WHVM/K6MTIFQWL79i
KCLTC5I`Mf5DGEiCIf]/IUeIFf3nE25EEUQKG6IOETm>D5=DECi2BCm5B30b;BTZ
;S0_;28Q8b/f1KhLnL[3eLc5ako>clk:aKnj^<6o_Kbl_/72blW6`[on_@^k_L;7
b/g>c/32aLSnbWo9`kbk_kjla]C8_[Bd^[bf[ZVY/[o0]k6c/[Nf/K>h/::f[JRX
XibT/k6bZinNZ:fZTY6BUIJBR82IVibJUI:CUJBUbN7@bM;<d;?<cL[4Z<>f/kNl
/Z6PZkJk_kfh];Bg_<;;d]GBcLS0a/S7c<noZLkBc;nnb<g8`l_7]jf_/4RZ/kbn
^;Ro_K>l^[Ng_/_Ji=c:cmk4Ti>i/K_6blW4`;o9d=SHdm7Df]OHfM[Kg=gMcLo@
dM7?cL_=cLc:bLS7alG3`/G:blO2n;mo`L;1_[k3ako5`[Rg_l2j^KNd/Jn^[k2^
Y:>]/:ZX[KngZj6MWjFZ];F_YjRZVhJWUijORHZ@Oj2XYYN?U9JBShV:TI:?TibA
SX^9S9>KX9:9Qh^9PGn4X9JKTGZ2R75dNGQcMW]cI79^Jfa`LVm/MH20M6]^Kf]d
Nh:5Ph60PIIoPW1aNW=G?5M_KdhiC6anIGB0Nf]QIVmXLGA_KW9]I6aXHUmQJ75f
Q8N8PgYbL72;L6J;Vf4iEWIhLF=OIVMQHVU/HeE?EUmNGf5SIVQZJfmWG5IFEeME
HDaAFU5GFD4g<2LU9bTY9c<a<SQ2nL[3eLc5ako>clk:aKnj^<6o_K`8_;k1`/_9
a/:oo[d;^kg2al[=c/k0`/G8o/YobL>l^knn_<KDb;jd];Zl]ZjYZK:o`;Na/k:g
][6c^;2R]ZfXZ:>LY;>a/Z^OWZR]ZY:ATYFFTXR0VI^LVYFBTiFTYLWQd<WBc=2c
c<g:a:S3][>g_;:QX:^f^knm^;Bd]kc2bm;Ed/g8`<K8alc?_jW>d/bo_/S=b<?;
akN][k18Z[>l_[Rh_kfc_;Zg]kk;f^CLb/oNa9>C^K6ka/_9a<2obM3Hf=?Ae=[G
f=WJfmcMgLg?d=7Aclg;cLg<b/W8alO5`l;5b/_7`_RoOl72`Kjn`lNoaL:h]ko0
^[Vg];6_[Zn`[ZBS[K2ZZ:fo]j^QWInUZ[Be[jNXZY^6YiNNWhV:T7nPZ:JGSiBF
TXn9RY6BSi>LTHj;RHbCVj2BRHN;RH5oQ:2FVi5jPXQaM7UhLgIkLfAbKV]/L79_
K7F0P7A[KVm[M7^2QH>1P86FOh9`LGYcEcaGKfm>>Da/OVEdP7][HFI_J75dKfib
KFA/J69OHFQaMXB7R8=jLW1`Rg1VRi]Q>EIfN75SGfIWHF9YK6=ECeIOGUmQHfIX
JV]_IeaFEUMGEF5<DEYAEeU1=c0W9BLY:BLc<C8h@_W:`mG<aLNoc/o>b/Fo^[S1
_kfl2;bn`L;;bLK2_ojm2k^m`/O:cLk>`<;5b?k:OlW3_;^o_[c6e<Rn];Bj_;J^
ZJVb_l2g/K>b]kJa/kR`X[J]Z:RSW:Bc/K:[WijX[JZBTI:EUY:8P9VKW9ZETY>E
Y:G9hM39d/c@/lc=b/BX`kJc]kbbXJ2[][^o_KRd];Nl`/_BeM;=b<36b<O<cknY
c];<_kk8cLS3blNg[Jn`B:Zc_;jh^;nm/kbj]kNnbm[Tg<[?g/BCTkVa^lK;bLC0
_lW@f=SCdMCJemSIf]_LgMg=cm3AdLo=blg=c<[9b<O7aL?2aL[;al;h_go1`/6n
_/?7_lG2^;No`;Zi]kBa[jj_/:jTXjf`ZZR]_kN[XIfOYJZd]JnWZ:ZKQZNGWYn9
RY1oX:RVUhnDUY:?RHZATXnCW96>RhV<Ti^PTXV7RhV1OhBPUY^ANX:8LGAiN7=f
Ng=TLVi[K71bKfaeP81dJfi_JgAkPXF3PH21UV^2L75jLeLlEfm_CSU<K7iUM81k
Jf5VKfQaM6m^LVeTK6QRGf5XLGJ4QhR3NW9`L8]`IX^KHCUFMWQaHemVIf5RJFaS
EDmFGeiOHF=VJ6Y[KfMLEUIGEeEQC55JDEMI@CL`9bDW:BTW<c4b>485d2;mc/KF
c/S=aLgCem34^k^naL6l^K_1b<g=c<_;b/K0_<O8b_k<Ol[9`<73a/S:b/_6^[[7
cLK5cLNh[;6o`kNWZK:h^;Zm^[:`]K>^];jl/K>ZYJ>LUj:eXkoEfMOFb[VSWING
VIN?R9bJUiFETi2>Ni30d/77elcIbMg8aM>kb=G@d=75[ijI/kVn_[Zh^[b_/[Ji
^kZi]m?If=3Af]_Cd]ODbLWCA=G@bm?@_k>e^;F]^Knl_L>o];Bh^[Ri`mOW_<7F
j=ReZ;>c^l?5`Ko2a]3@dmSMfmC=c/oAdmKIfmcBe=KGeM;>c=;Acok>Olo?aL6n
`LK6`;W0_kfk^kfo`;jl^kfo_k^f_/C0][Fn`K_7aL6n_;^k_:NTZKBdZjZa_;Vc
[:NTXj>i_l;2a/>ZSYR=WJNIW:BCVjR/XIVKW9R;QXN;PGAiRWQhNGb1QhfAYiB=
Ui^=P7j4PY:DQ8fBMg]fKF]jR81]N71WIVaaOg9`MXJ9MVAUKgAaLgR0QXEoNHY`
Gff8RFDmDg1dEDAGL7U_GV5gNfYVLUm/LVa/M71SJ6AOG61YM7^0PhJ2NgEcMHQj
JWjCMEmhSG9KFV5SIFUVI61IDe1BE5YLH6AWJF][J61GEEQJF5ASBdeED5aVDche
:R<S9BDT8AhM8BOm8Lk6e/k8cLG=dmO@a;^k_/G1_;Vk`LS=cLc;bl[6`;c7b<[n
c7o:bL31`lK8b/[;a[Zjalg6aLg7^:ba_l>gYjVb^;Rj_KZb/;Fc[[Bn_;6cZZFS
W9NR]J>oeMWGe/ZiXifGUiVGShRLVYNEUI>@SW^@`=;1amO<fLWMb<GC^lSEd=3A
aJnNVK>i_[jj^;Zl[k:f^K^j^KOCfMS@dM[Kdm;Ge<W9ddCEd<_Cd;nc]KRe[KVo
_;g3_kBd^;Zh^L?Gikc1e^SH]JRc/k_3aL6o`/K@d=?HgM_DcLk?dM?FfM_Ld]CF
emGBc/cBdLoncWo?clG1_/76a/2i`;nm^k^m_l2n_;^m_knk][k4`;Je_/6kalG1
_[bk^kbWY:Vd]:^Z/Kbi/jbWY:>S^Ko2`/K3ZXjHSIfWVIbTTi^X[:6IVibHRhJ7
Rh5dNHYhN7UlPHN=TJNDSINKSH1nQ8:BU8B=TWMkMVe[NXR0KGQ`IfI/LGmbL7J6
RGITIFmdLG=hP8J5OgV:L5m]R8UU?E=`M5E4Eg1iKeiQMg]ZIW9OK79/K7A`HfQT
GeaPJGAkP8>6PW]eLgF8NVYnTgEON8ebFeYQHfEYIVAPFE=@DUAJG61TIfU[JfQP
EeEHFUQDHd]=EE1LIU<n=BXS8bDU924N7B4WoB7>a]K>b<g5cM?Gd<Bk^kk5`Kbi
^l78cLg<bl_:a/2lalS:o/aob/W0`L?6b<[:blJj^/O=a/G=akR//Ko3]jNY/[Rh
^[fj/[2e/jjd_[ba/jZUXibGX[FS_mGIemK:^J>MUiNIUhn8W9ZGUIFCT8ikT<3B
`LOGc=W9gLS5dk_8eM3@dLF_WYVc^Kjn^[Rj_:nb][Vk^[VgdmWHd=7Jfm?BemC9
bM=4eM3;dm2o/kFh]Jfi_kbm`knd];Rj^;W3enNl`MKXf;FX/k>k`lG1_l;6d=3C
f=gKe<g>cm7Ce]WKg=;De]OEd/k<d]7?o/ioclo5`Kk1a/K0^L2o_K^k_Ko0_[bk
_Kno^kJna<2f]Kk1^lO5`Kjl^k^lYjBY];B[Z[6l^K>/YjBSXkVo`/;6`jZ>V8fM
YiVLY9>KZ:bQVI^LV8^6Qh^1M7V:N7QiO867SI6WU8fGVhf0OXB2TYB4SI9gNgI]
JgZ8P6ehL6MVK75nLW1fQXUfI6E_M75cN826QGmiRW1OKHR9ICeCL7AEA5M`NFmN
HGMkJVIbGfabK6adL6=XI5mLH6UdNh23QX9kMG=eR7YZOY=eGgR=LU]JHF=UJFIT
H5UCD59DFUaPI6MYJf]XH5MEF5YHE6=;CEE@G6IC?SDZ8b<U9B@Q7QdQ9`G>7ooA
a]C<bM7<`LgGd/Bm`lc:aKjj_<G@elo?d=;BcL>lo]5od<g9aL?3a<K8blg>clfo
`=CMdLK7b[V/]LS>_JR^_L6h^/O5]l35`l39f=[B^KRna;je^/S5eMS:`lS4]kF[
XInRXYfGViJCUY^NViJA[mcN`lcMc]SBh[nlel;5clS8d]K8/J6Z/KNi^;Rk_]7>
bLC1`<72d]K@`/3?g^;DfMEab<C9b<2`^k^]Y:Za/Jbh_kbk_KFX[[Jm^[JoeNV^
cNSYf<2QQkg2a/>o`L[Ce<_7d^;Rd;g7b<_?dmKIfmSIfmcJeM7=d<o>c<c>cm3C
cLW;dM79`L?0_;Zj_<33c<O4b<o>`kVm`knd];g1^kjl^;Fco[9oXjF_^kN[ZkBa
];Nh]K2YY;k8dMONfK^JYif/]:6NWh^GZkVd[JbXXJfWYjF?Mg^?Ri2GWjFYZj^f
UH29U92<SXZ:WZ6@U99dRWi]K8>KUhAnLVMTJg=eM764RG5JFVUeMgEhPhj?Q7Uc
FDeZUYecA4]XKeM?I79]I3`hIh=dJGEdEfM^IfUcL65NFUECF6=_Mf5WKW1_KW5e
J8B0KVaXMj6DIDA<FUUKIga`I61UIf5IC4iCF5]NGemJDTa=E5QDCf]<@Sh`>D<b
ACX/92<T92<a;B/]<_oAa]C<bM7<`LgGd/Bm`lc:aKjj_<G@elo?d=;BcL>lo]5o
d<g9aL?3a<K8blg>clfo`=CMdLK7b[V/]LS>_JR^_L6h^/O5]l35`l39f=[B^KRn
a;je^/S5eMS:`lS4]kF[XInRXYfGViJCUY^NViJA[mcN`lcMc]SBh[nlel;5clS8
d]K8/J6Z/KNi^;Rk_]7>bLC1`<72d]K@`/3?g^;DfMEab<C9b<2`^k^]Y:Za/Jbh
_kbk_KFX[[Jm^[JoeNV^cNSYf<2QQkg2a/>o`L[Ce<_7d^;Rd;g7b<_?dmKIfmSI
fmcJeM7=d<o>c<c>cm3CcLW;dM79`L?0_;Zj_<33c<O4b<o>`kVm`knd];g1^kjl
^;Fco[9oXjF_^kN[ZkBa];Nh]K2YY;k8dMONfK^JYif/]:6NWh^GZkVd[JbXXJfW
YjF?Mg^?Ri2GWjFYZj^fUH29U92<SXZ:WZ6@U99dRWi]K8>KUhAnLVMTJg=eM764
RG5JFVUeMgEhPhj?Q7UcFDeZUYecA4]XKeM?I79]I3`hIh=dJGEdEfM^IfUcL65N
FUECF6=_Mf5WKW1_KW5eJ8B0KVaXMj6DIDA<FUUKIga`I61UIf5IC4iCF5]NGemJ
DTa=E5QDCf]<@Sh`>D<bACX/92<T92<a;B/]<_oAa]C<bM7<`LgGd/Bm`lc:aKjj
_<G@elo?d=;BcL>lo]5od<g9aL?3a<K8blg>clfo`=CMdLK7b[V/]LS>_JR^_L6h
^/O5]l35`l39f=[B^KRna;je^/S5eMS:`lS4]kF[XInRXYfGViJCUY^NViJA[mcN
`lcMc]SBh[nlel;5clS8d]K8/J6Z/KNi^;Rk_]7>bLC1`<72d]K@`/3?g^;DfMEa
b<C9b<2`^k^]Y:Za/Jbh_kbk_KFX[[Jm^[JoeNV^cNSYf<2QQkg2a/>o`L[Ce<_7
d^;Rd;g7b<_?dmKIfmSIfmcJeM7=d<o>c<c>cm3CcLW;dM79`L?0_;Zj_<33c<O4
b<o>`kVm`knd];g1^kjl^;Fco[9oXjF_^kN[ZkBa];Nh]K2YY;k8dMONfK^JYif/
]:6NWh^GZkVd[JbXXJfWYjF?Mg^?Ri2GWjFYZj^fUH29U92<SXZ:WZ6@U99dRWi]
K8>KUhAnLVMTJg=eM764RG5JFVUeMgEhPhj?Q7UcFDeZUYecA4]XKeM?I79]I3`h
Ih=dJGEDEfM^IfUcL65NFUECF6=_Mf5WKW1_KW5eJ8B0KVaXMj6DIDA<FUUKIga`
I61UIf5IC4iCF5]NGemJDTa=E5QDCf]<@Sh`>D<bACX/92<T92<a;B/]<PFk@__E
e>3=a=7DcLO2`LK:b/W2`lC6b/kBe<k9aLK:cLc:aLC6bm7Ac<K?cm3Ad]CEe[K2
cL_0^[o7alK2^[>b^;k0_[cn^P2lo[eE_lC;c<O2^kNc]KZn_K^Y/k>//[faVK6[
YjV^[:6FZ:FQX:>VYjFW^loBbLC=fN7Jd/g:a[jg`LNh/[RTV:nT[;W5bl_7`jG0
a[6^_[VPfLo7bMCMgmcnbRo;c<g>clC@]M:Za:Nb`[Ng`/6f]lFl_[nl^K_2bK_Q
d<;YhjnOa<gDe<o<d=G8b/cncPg<blO8b<W:bl_<g=cJfOkH8=WFd]7Df]kLfLkD
d/O6cLk7a/G3`/?5alRoaLgCe<o7`O[5OlBn`[Z^/[feX;:`[J^ZZjb][;W2^jZM
WJ>c/k:`[jj][9ZMXZBSWiVEY9ZJYZbVXjJWXiZ@RHV@UXn=S8nDUI:>UYFCSXbA
WJJOS8ZLW8AiP7]YKHJ:MFilR9RKRGQgOH2;Oi=kKWMSMgn>Wj>KTi6DPY=GIGVf
KT9CGei4;39BEfmG<beGMW1[MFYcMG9dNG9TIUI<EFakN6ieIV=cO7=YIWMbLgM`
I6E`P6aCBUY]K5mUIVUaMG1SEeYJFemTIVAQGUmOFU=@DUIJGUeA@3@c=ca2AClc
:b[n;_h_@__Ee>3=a=7DcLO2`LK:b/W2`lC6b/kBe<k9aLK:cLc:aLC6bm7Ac<K?
cm3Ad]CEe[K2cL_0^[o7alK2^[>b^;k0_[cn^P2lo[eE_lC;c<O2^kNc]KZn_K^Y
/k>//[faVK6[YjV^[:6FZ:FQX:>VYjFW^loBbLC=fN7Jd/g:a[jg`LNh/[RTV:nT
[;W5bl_7`jG0a[6^_[VPfLo7bMCMgmcnbRo;c<g>clC@]M:Za:Nb`[Ng`/6f]lFl
_[nl^K_2bK_Qd<;YhjnOa<gDe<o<d=G8b/cncPg<blO8b<W:bl_<g=cJfOkH8=WF
d]7Df]kLfLkDd/O6cLk7a/G3`/?5alRoaLgCe<o7`O[5OlBn`[Z^/[feX;:`[J^Z
Zjb][;W2^jZMWJ>c/k:`[jj][9ZMXZBSWiVEY9ZJYZbVXjJWXiZ@RHV@UXn=S8nD
UI:>UYFCSXbAWJJOS8ZLW8AiP7]YKHJ:MFilR9RKRGQgOH2;Oi=kKWMSMgn>Wj>K
Ti6DPY=GIGVfKT9CGei4;39BEfmG<beGMW1[MFYcMG9dNG9TIUI<EFakN6ieIV=c
O7=YIWMbLgM`I6E`P6aCBUY]K5mUIVUaMG1SEeYJFemTIVAQGUmOFU=@DUIJGUeA
@3@c=ca2AClc:b[n;_h_@__Ee>3=a=7DcLO2`LK:b/W2`lC6b/kBe<k9aLK:cLc:
aLC6bm7Ac<K?cm3Ad]CEe[K2cL_0^[o7alK2^[>b^;k0_[cn^P2lo[eE_lC;c<O2
^kNc]KZn_K^Y/k>//[faVK6[YjV^[:6FZ:FQX:>VYjFW^loBbLC=fN7Jd/g:a[jg
`LNh/[RTV:nT[;W5bl_7`jG0a[6^_[VPfLo7bMCMgmcnbRo;c<g>clC@]M:Za:Nb
`[Ng`/6f]lFl_[nl^K_2bK_Qd<;YhjnOa<gDe<o<d=G8b/cncPg<blO8b<W:bl_<
g=cJfOkH8=WFd]7Df]kLfLkDd/O6cLk7a/G3`/?5alRoaLgCe<o7`O[5OlBn`[Z^
/[feX;:`[J^ZZjb][;W2^jZMWJ>c/k:`[jj][9ZMXZBSWiVEY9ZJYZbVXjJWXiZ@
RHV@UXn=S8nDUI:>UYFCSXbAWJJOS8ZLW8AiP7]YKHJ:MFilR9RKRGQgOH2;Oi=k
KWMSMgn>Wj>KTi6DPY=GIGVfKT9CGei4;39BEfmG<beGMW1[MFYcMG9dNG9TIUI<
EFakN6ieIV=cO7=YIWMbLgM`I6E`P6aCBUY]K5mUIVUaMG1SEeYJFemTIVAQGUmO
FU=@DUIJGUeA@3@c=ca2AClc:b[n;_h_1LhZo=GBg/_2cLo2`L76c<c8`/;3a<K8
b/c=cl_7b<c?cL[7a/O<d]?>bL_=c_k@:<o?`<O;aKbja<nm_[fi][W1b<[9alK6
b<[;`l2n_l6n][30^kJg^[bjo[Mj];>i_kV^[:ZWYjJQVI:QVIJIUXf8RHFL]Kjg
/[Jo_l?4_KB^/KFmakjnak:P/[jo_kjk][2]aJ^ZaljfZkJo_[o3b<W5`LK6aL?0
_KVga/jfc[7?_/b`YJNe^k>b^[:d]K>a/k[0e>;@`MOSbkO8cmKEd<c>d/k@e=OJ
o]]oc<_:bLS6aLG4a/[=c/c:b<S5`lO=d<k;cMCAalK<c<Fo_[fl_;fo`L32aLO8
alG3bl[8aL;0_Kbg^kJZZkFdYjb/ZjZYZ:NW^;VfZj2OZ;:c/k:a[jj][JVSViBC
V9nT]:NQYZFITI:JV9B@T9BLXXnBUiZKVYVHUYJBRX>2QheoMgf<VYN:R8n?NGN<
TX5iPgn:RGQ/KWAcQg^AO79kIg]bO8N;QGmmOVfDMEE=K5iOAeEKCC/jC5eT?cQM
MfaTKGElNW1/Jf9CMFEDDf1[K6QiLV]ZK6QMDV9QJG=bJVagMFEFDeMLH6=`J61R
JFeYHV=QGemPHF5PIfMTGEICEe/oHf=MDD0a:2D`=CPc:B<S9Rl^;Rd/o=GBg/_2
cLo2`L76c<c8`/;3a<K8b/c=cl_7b<c?cL[7a/O<d]?>bL_=c_k@:<o?`<O;aKbj
a<nm_[fi][W1b<[9alK6b<[;`l2n_l6n][30^kJg^[bjo[Mj];>i_kV^[:ZWYjJQ
VI:QVIJIUXf8RHFL]Kjg/[Jo_l?4_KB^/KFmakjnak:P/[jo_kjk][2]aJ^Zaljf
ZkJo_[o3b<W5`LK6aL?0_KVga/jfc[7?_/b`YJNe^k>b^[:d]K>a/k[0e>;@`MOS
bkO8cmKEd<c>d/k@e=OJo]]oc<_:bLS6aLG4a/[=c/c:b<S5`lO=d<k;cMCAalK<
c<Fo_[fl_;fo`L32aLO8alG3bl[8aL;0_Kbg^kJZZkFdYjb/ZjZYZ:NW^;VfZj2O
Z;:c/k:a[jj][JVSViBCV9nT]:NQYZFITI:JV9B@T9BLXXnBUiZKVYVHUYJBRX>2
QheoMgf<VYN:R8n?NGN<TX5iPgn:RGQ/KWAcQg^AO79kIg]bO8N;QGmmOVfDMEE=
K5iOAeEKCC/jC5eT?cQMMfaTKGElNW1/Jf9CMFEDDf1[K6QiLV]ZK6QMDV9QJG=b
JVagMFEFDeMLH6=`J61RJFeYHV=QGemPHF5PIfMTGEICEe/oHf=MDD0a:2D`=CPc
:B<S9Rl^;Rd/o=GBg/_2cLo2`L76c<c8`/;3a<K8b/c=cl_7b<c?cL[7a/O<d]?>
bL_=c_k@:<o?`<O;aKbja<nm_[fi][W1b<[9alK6b<[;`l2n_l6n][30^kJg^[bj
o[Mj];>i_kV^[:ZWYjJQVI:QVIJIUXf8RHFL]Kjg/[Jo_l?4_KB^/KFmakjnak:P
/[jo_kjk][2]aJ^ZaljfZkJo_[o3b<W5`LK6aL?0_KVga/jfc[7?_/b`YJNe^k>b
^[:d]K>a/k[0e>;@`MOSbkO8cmKEd<c>d/k@e=OJo]]oc<_:bLS6aLG4a/[=c/c:
b<S5`lO=d<k;cMCAalK<c<Fo_[fl_;fo`L32aLO8alG3bl[8aL;0_Kbg^kJZZkFd
Yjb/ZjZYZ:NW^;VfZj2OZ;:c/k:a[jj][JVSViBCV9nT]:NQYZFITI:JV9B@T9BL
XXnBUiZKVYVHUYJBRX>2QheoMgf<VYN:R8n?NGN<TX5iPgn:RGQ/KWAcQg^AO79k
Ig]bO8N;QGmmOVfDMEE=K5iOAeEKCC/jC5eT?cQMMfaTKGElNW1/Jf9CMFEDDf1[
K6QiLV]ZK6QMDV9QJG=bJVagMFEFDeMLH6=`J61RJFeYHV=QGemPHF5PIfMTGEIC
Ee/DHf=MDD0a:2D`=CPc:B<S9Rl^;Rd/1M5oo]G@flVobLRg^Ko8clk6_/73aLO8
bLS8cl_8bLg?c<S7aLK;dM?@blO9c<k>blO4al[8`;Rjam?5a/K3`<;9d<_;b/[<
cm;Df=CAd=7>al32_KVi^k^g/lBh/;>c[:R[XjJWXibETi>VWJ6b]JVZ]ifcc=C=
`l;6dmkTfl[3c=X<_/Nn_L>VRiJ/[:^ZZ_jYOl>UY<SKbko6am3Jg]WAbLG@dM;B
cl[4`KNjY[FS_;O4]:NS[[Jc[Zji^kfk^;Rn`mcEeLg;hMnhaLcBe=7>c/nn`LK;
c]7Bd/W:blc=c/o?a<W@eMODd<g?c<[>e=OFd/cCdLS5bl[2_kfk^[Zk_Kk5a<?2
`lK8b]3>blG0^kNeOk2f/ZFQZJn^YZR[[:^XY:6c/Jj[ZZ^_/[>c/[:a/:n_/ZbQ
V9>BUIR`Y9jUYYbGVYnKUY6?Si2BOXVEV9>?TIF;SHb6OGQhNVQoSXR1RYVRV7eb
P8UmM7QnPW]/J71cKWY^QgI`O6IgK6mcMG=_K6YKQHQ>DTiOId1=FUiGD55FOf0n
>5ecIemXHVa^JFU`KfIXGUADGfijP7AoNfa]NgMTI6E_NgMZIfi`HEiYJF5YOWQU
DTiJIf]ZIfAPGEeQIf]_KFQOEUAIGe]JFEUGD4@l@dA2>c4Y9bPb<C0_;OkEd=_9
_lW8]kVob<o>a[k1`lG7b<W8b<o;b<W=clc8alG6JL_Adm3;alW<c/k;alC7b/S0
^;[7dlG6a/?0`/W@bl_:b/c?d]CHe=7@dLk7`<:m^KVk^kNca;R`/k>/Z:^SYZNS
W9FCTjJMXK:eZJZgWK?<e<g3`/KCg^CKb/?<f[k7_[g3YX^F[:b[ZZ[nZGo3YJC8
fl^oa/O@f]kIdLW5d=7Bd/o:a<6g^ZJeXkbga;BWXjjf/jj^^K^m^kRh_/?LeMG=
bn7O^<G<d]CAc/k?_/76blkAd];9b/_<cLk?clC9d=GGe=3=clc:c]CGe];<dm78
aL_:`[nm^kZj^kfnaLC3`/?6b<[@c/_5`;^g]Gn`][:UXJV_[ZJXZjb[Z:BQ/k6^
ZjZ[[k:c/k:b/K2_[k:/XIRCTYFH/:BNYJJLUiZOViJAShn@TWj9UIRCSi6ERhf<
QWehN7YXOhj8PHZIXYQmLX29OGAhOX9kK6Q`LfijKXMfL7aVMfa_LgEcKfaZFhF8
CU9>GfM0CEYNEe1AEWmP?SQMLfMOJ69/KVUYL6mVJ5iDE5m^NX1dOg]/KG]gI6AU
Kg]gJVM^L65NJFUQJGihIE9>FVM[JVMTH5eMHFM[KfeXGeIDFEmKFUUIEe14?4=4
@S/a:BLX<S4`;bgneM3KbKo9b;Ni_lS?c/Jn`L?5alS9b<S?blS9cLo<b<O5aVW;
dM?@blO9c<k>blO4al[8`;Rjam?5a/K3`<;9d<_;b/[<cm;Df=CAd=7>al32_KVi
^k^g/lBh/;>c[:R[XjJWXibETi>VWJ6b]JVZ]ifcc=C=`l;6dmkTfl[3c=Znakjm
`jJ;UZb/ZjZZoZUo`jFTb=_;_lK7d=[NfM79aM3Ad];?b/C1]kZV]J>l]lBdYj>^
][>^[[Vk_K^h^;k3g=GEcL_QgkS5c=;DdLk>ckk1a/_>dM;BbL[;c<g>clo4bM3E
emC@cLo<b/kDemKBc=?Ab<G;b/:o_K^j^[^m_/G4`l;3a/S:d<k;aL2k]kEo/;Jb
YJ6Y[jjVZ:^/ZjRTXK>a[Z^ZZjnb/k>b/[6`[jnb[:6HTi:EV;2TWZFVW9NJWi^F
THn?T99nRIFHThnAUH^=S8ImN7QjJ7n>R86:VJ:HOG:0RGedN7j2NfaXL7=^NVj7
MW1lIWM/Kg=eLfm/JU^5R4iBCUmW@4eJGUM@DEILH3hhGG=WGfQRK6iYJG1_IVQN
E5AOKWZ0M7mkK6ekMfATIFmkMfYWKW1QGVUYHFUnN6EBCUYWJfYWI61MGF5WJfm]
J5mFE5UOFeYIFEM@A3a3A48k<BTW:38a<2l]1KioomC=fLRnaL:f]k_3blc7`Kk2
b<g?clg;c<W6b<_<al;4`/76cM3>blG7blc;a/6ma<K5_kZka<g:blW3_;Vm`L70
`<;4b<_=`;fk_L73_k^m^[Ni_;bg//2d]/K;`lGAcMCIeL_6bM3OeMW[k^C[om?Q
k^kSf=GHkO?djmkIh>YDdMO=c][3ZkNk_l?8b/W8aYN_][72h]o2bmORhMK;alS=
dMKJfmWEd]GEc<o7clkCimO9b<g?blK8bl_8`[o1aM74fn3:gMjQ^/38c]3@cljd
]kZn`?k18/33b<kEg>7SemWKgMgLf]WIe]GHg^7PgLcDdl[7blVoaL?1o[l7`<77
b<[<cLkncak=b/G0_;Rf/[JbYI^MZ;6WZZnb/JbVXZ6W/[g3_[2Uo[Gl]1:a/[>_
YIJ7OZNJUIbOV9JJWiVBoXlcSHafQYNIT8Z>UXjDV9N@RhV:PiB>Lff9XZNNPW1g
OgQ_KXR8OW5cOh5jO72;OWf9L7icLoibJg1/JUidR5fBN7=D@TUJK75YI6IF=cMN
MFYTL5]WK6MYMG]hJ6ITIVegPXQKN7e[LI6IQGinQhj3K61RJEAEKGI/LHI_G4M2
CEaSI6QUHEeMI71jOGYdJF5OIF]THF9XKf]MD5EBBd4f;BPV<?daOooDcMW8_/G2
][Nk`l_<al6n`/S=clo=blc9a/S;c<O2a<;1a/g@c/_5al_<blK1_LC6aKnj^lC=
b/_9`kbi_L71`<32a<S;cL2m^kg1`knk_KZg^Kbl]k;0];K6bl?5dLgDfMG;a/W@
gmGIjnkTjooChNk^hmSEf>gcm>_NfN3ZE=7GcLkJ`j^g^ko3b<[9b<JG[kJa`^;O
`/_Gh^7FblO8cM7Ff]_IeM;EeLc?alo>dnOGbLS=cl_6b<_;b<:o`LGAa=_Pb]gN
XK[0b<k@d<o>];Nj_/3n`B;0`lS>eMcQhmOIfmgMg=[IfMKEf=kQh=g<e=?:al_9
_lG3`Ojo1l31alS:c<g>o/lNcL[5`;bh][:f/ZFKWJRaYjZ_/[6/YZ:QYk:m`kj`
YOjeo;@B/K:c[jFFQgjWVYFLWiRFVYnIT_j?<hf<MXJGVI2:SYJ>U9RGT8^9RX>D
SW=]RJ:WWX9`MgmhKfj8R7iaLgn1NWa`RgimRG1nLg?nLV]`K6YNM8QMTWQcE499
FVaaJFAVESLgGWEZI71KIfaWJGEkN6QVI6I]Mh:8FgQmJg6AVHEnOXN>PfaPHVUD
EFefK766Kea7@TeLHfAXIF5MGFA`NWejM6UQGfE[I65RJ6m[GE1EDT]1=RdX9S3m
<Gooe<gIb;k5`[Jg^l?;c<O1_/;8cLo?cL_<bLK8blc7`/C2`LK=d<k;aLO;c<_6
`Kg4a/Fo^[_4cL[;bL>l^Kg1`L30`/C8blg0_K^m`L>o^kfj]kVl_;Nb`;Bfa/_3
aM7=e=WEblK9d=oEfN_^i>_odn7^k^?HeMS]loC[g]WPjUCAelg>f/>[]k^o`lS:
bLS6Ujnf/L;Rgl;;en;Qe/_7b<gAe][KfMGBeMG<clO?c]?WelW8cLo;a/S;blS2
_l75dLCKh<[MgZ6j`<S>d=3?c[Bg^[k0o/4R`<?8c]GLhN?GfM_MgMcJfMWFeMSN
hN3Mc=CCb/O;bKo5`l7n_`O0`LO8b/c=c_k?7/g:aL2l^;Jb][:UVifX/JNZ[k:a
[:JRXJNb_L>n/:Gn]Obd4[6b/jnUUXMnYiZEW9nHUYZOVI;nSc>=S7J6UiV@RXjF
SYBHUi2;RHZ3U8icKHVRYij2L7MoN6m^R8QnLG=oPGYlL8]nOHU`OW=coW9[L6aZ
GWB8GI9hLeA2BEY/LFUTIUHg=eieJVA`FfM/IfUeNgQXIVAVKGN2R5]hOF]aTIV5
OWj7SX=/H69YE5E]MVaaQVmLAd9=G6=TJ6EQGEeTL7YmNWAYHEmUJfAQHVQ_Jee@
EE9;@CH]:2H`oC45WF3oe<_GbL76`;fj^;c4bL[9_<;<eMWHeM;8a/C6bLS2_<6n
_<38cLg;a/S:blW6`Knl`<?3`;jo`K^m_KRa[Jnc^[Vi^[g1a<K3_kbn`lK4`KFc
/kNk^kJ`ZjnoenO/mOoho_l1no[ko`;kloOko`3koOl2o?[mo_l9l??Wkoooloob
n?ko5OGWg/7Um^SYooofl?KilnSRi^cfnOcno`7mnoSoM_k^i>SbmO?jo?ghknWY
j]K9g]o5f=bT[;6kaloBd<k4aLK7alG3`K^n`l[AemcOfmSEdM3@d]?Ac/c@e]WH
eLkFe/g:cLVnalK3`Kno`<6oaLgDe]?>b/[9b<K4`/70_;Zf[:2KYK:_/[Nj^KB^
ZZF[]/;8a;N[oKWm^Wn`];Nf[j6CRZZLUYbNV9JKY9bDU9ZOWif7UjFVW9JLY:BY
[jjWX9bLTYZ>MgZFXYVXTWmnPGigM8f=QWb0S8j6RgnKTI:NP8YiNgelNGEdM7:0
TW:^SG]CA4=BK7QcLg]VBdecQWQbOgAnOFmXKWAcPX>2PGehLVmALgiZJXJ@P7n4
Qi6KTWa`LFI;@eY[IUmSFe15@TM?DeA`KVQNF5aYMGmnNG1XIV]`Mg5/JfUNBSY2
?3@]9b<O7BHW:B/^omC;elW1a/2m^[Rla<W:bKc2c=GIf=GBb<K4a/W8`[c1_[c0
b<g=blK8b/_9a/6o_<33`l2n_l6k_Kfh/Jf_/kZi^Afj_L74a/>o_;k3a/C1]K>c
]k^k][2[[koGinceooSno`7kn__o0__cmo_o0?_mo`;ln_gno`W`lnO_ooocoo;h
o_lEmNON`NGfj>WoooK`m_Wcj>;Vk?Kio?ko0Ogkn?mfo^kTj?;elo[loOS_jNWZ
e/WNglGHg:B//K_7cm;@c/C5a/O7aL?1^kk3b]7Gg=oKf=GAd=3Bdm7>c=3FfMSE
c]KFcL[=bKk7a/?1_ko0`Ko5cMCFdlk:b/W8a/C2`L2l^[J/X9^U/Znb]kZi]:jZ
YJ^f`/S4]j_m^OfjOk2d]kJ_XI>:ZYbFW9jHUY^TW9BDVYnOWHNGYJJLUYbTY:V_
[ZNPW9bBVXigNYJRVJRBOgj1OWMdSHf6O82<SXJ;Oi^ATYj0RWUkOGaiMGAdLX2B
LZj=Ne=4@e9/N7=cNfI;CG>6N79oM7imKfQ^M7>2Ph:1OGQbKe5cOVYZQY20OhB7
TI^BO71aIT]3FV]VGf=KD4E2AdmCE71^J5iHG6UeOgiiL6QVJg1gLFa[JEi:>T8l
=2dW8alM9RLY:bkoe<_GbL76`;fj^;c4bL[9_<;<eMWHeM;8a/C6bLS2_<6n_<38
cLg;a/S:blW6`Knl`<?3`;jo`K^m_KRa[Jnc^[Vi7KZm`LC6`knl_/?6a<6e/k>g
^k^f/:^__mOWk?Gon?ko0O_jnol2no?gnol0nogo0_cjoOko2O3cinoooo?ol_Sn
oaGeimk1iOKXjOoom_3fnO?Xh^K/m_Wlo_l1oO_hogKnk^CXl_Gcn_cmn>oYjN[F
bMkOaMSLY:ba^lO?d]3>a<G6alO5`l6k_/?:dMOLgm_HeM7@d=;CdLk<d=KIf=G>
e]K=b/g9_/O6`l6o_l31_lG=e=KCc/[:bLS6a<;1`;bj]ZbPVjFb[k:g^[Vd[ZZU
ZkK2b<BgZofioKYo/;Bg]ZnQThZZW9JLWYRFVjBLU9BJWinMQiNUYYbFW:BTZJn^
Yj2LW9:JSWMjUZ:IZ99oOX5nMgB=SHIlP8b>QX]oVi6BWX2:NG]mO7UeM7AbP99b
[XekDdA3DVahLg=kIT]=LhIhLWmdOWe_J6idLh:3PX5mN79_DG=nJVZ6T80lQ8NA
Vi9lL75VBd=JJfIOHe]@AD97Ce=DL6iXGUQLJGEoOWU`J6I[L7MaK6]YGTXj@S`d
;BLS7adV9bT[;PG4:ooCbMO=a/[2a;nj^l;8bl^naM7KgmcFdLS6a/S;b<2i`Kfk
_lO=clk<bl[:oLT@_L33a/K3_kfh_<2o_;bo`kon_Wo0`/G7dL_5`lK7aL:b/;6d
]kJ^Z9^Y/Jn`^l2m_Ko1_kjoaL[Bj?3Oe]kPf=cMgMWHgNSahmcFfnOcnOWbkm_L
lNGEi=3Jio3_i=C9g=OVo>k?eOC_k^WSg^3Wk_Kdl^o/jNSWe]G/ho[Vkn?Lh=gE
fNSbl][Mh=gEclk?h]gIb0bneMo4Z:bgaM7EdL_<o/dWblS4`l31`/?4aLK6eM?A
clk>cm3@cL_?eMSFdm7Jfm??dL^oa/C1__jl2;ff_/WBe=39a?g8oLUoa[fh]ZnW
[;Nh^[fn_KZf/kjm^kVj_L75_[jo_l31`/:h]K:_[Zna/jZOX:nm`l_Ee<>_Y::Q
W9JGWjJUWibPYZR/[ZVNU8n>Qhb=SINQVhjQUXV0O7UfM8>;Rh>4SY6;RWfHSi6J
N7eeP8V8OgQjOhVPXGb8L6UYA3i;Ig9/LhAoP6IWRIAoMX=eP85bJgB0PgenP8J:
QGU^KhZCOg1dMFeaMXJFUXR3R7APCU5PIEM6B4]<BD=1ADUfM6eMCT]EH69THeiG
E5MJGUaJFEI>@ST]9b0N8RDV9AhO8B<Vom?9elg6b/;4_kZk`/S;bkk5dM_Og=KA
b<K6b<_8`;W1_K/8_lO=clk<bl[:oLT@_L33a/K3_kfh_<2o_;bo`kon_Wo0`/G7
dL_5`lK7aL:b/;6d]kJ^Z9^Y/Jn`^l2m_Ko1_kjoaL[Bj?3Oe]kPf=cMgMWHgNSa
hmcFfnOcnOWbkm_LlNGEi=3Jio3_i=C9g=OVo>k?eOC_k^WSg^3Wk_Kdl^o/jNSW
e]G/ho[Vkn?Lh=gEfNSbl][Mh=gEclk?h]gIb0bneMo4Z:bgaM7EdL_<o/dWblS4
`l31`/?4aLK6eM?Aclk>cm3@cL_?eMSFdm7Jfm??dL^oa/C1__jl2;ff_/WBe=39
a?g8oLUoa[fh]ZnW[;Nh^[fn_KZf/kjm^kVj_L75_[jo_l31`/:h]K:_[Zna/jZO
X:nm`l_Ee<>_Y::QW9JGWjJUWibPYZR/[ZVNU8n>Qhb=SINQVhjQUXV0O7UfM8>;
Rh>4SY6;RWfHSi6JN7eeP8V8OgQjOhVPXGb8L6UYA3i;Ig9/LhAoP6IWRIAoMX=e
P85bJgB0PgenP8J:QGU^KhZCOg1dMFeaMXJFUXR3R7APCU5PIEM6B4]<BD=1ADUf
M6eMCT]EH69THeiGE5MJGUaJFEI>@ST]9b0N8RDV9AhO8B<Vom?9elg6b/;4_kZk
`/S;bkk5dM_Og=KAb<K6b<_8`;W1_K/8_lO=clk<bl[:oLT@_L33a/K3_kfh_<2o
_;bo`kon_Wo0`/G7dL_5`lK7aL:b/;6d]kJ^Z9^Y/Jn`^l2m_Ko1_kjoaL[Bj?3O
e]kPf=cMgMWHgNSahmcFfnOcnOWbkm_LlNGEi=3Jio3_i=C9g=OVo>k?eOC_k^WS
g^3Wk_Kdl^o/jNSWe]G/ho[Vkn?Lh=gEfNSbl][Mh=gEclk?h]gIb0bneMo4Z:bg
aM7EdL_<o/dWblS4`l31`/?4aLK6eM?Aclk>cm3@cL_?eMSFdm7Jfm??dL^oa/C1
__jl2;ff_/WBe=39a?g8oLUoa[fh]ZnW[;Nh^[fn_KZf/kjm^kVj_L75_[jo_l31
`/:h]K:_[Zna/jZOX:nm`l_Ee<>_Y::QW9JGWjJUWibPYZR/[ZVNU8n>Qhb=SINQ
VhjQUXV0O7UfM8>;Rh>4SY6;RWfHSi6JN7eeP8V8OgQjOhVPXGb8L6UYA3i;Ig9/
LhALP6IWRIAoMX=eP85bJgB0PgenP8J:QGU^KhZCOg1dMFeaMXJFUXR3R7APCU5P
IEM6B4]<BD=1ADUfM6eMCT]EH69THeiGE5MJGUaJFEI>@ST]9b0N8RDV9AhO8B<V
1L9Aom?8f=7<clK4`/34bL_9aL?;e]kOelg5cLc<cm7=a;c6`[o3bm;EeM;?blW:
cM;EbLO5aLO8b<O0aLW:a/G8blO6aLC4aLO9^kF_[[:f][Bf/ojbOjbQV9b`XWER
LWAQMW5[JF]^KVaf[lZe/L_6Y7EgNGYmPh^BRXZ8QhVAW:Bo^Z>Q/9^0QhVAWJJX
XIN@SX:<XIQjNI:LUHj=TYRLWJ:NV9:?Si:DRH:LQjJ;WY6C[;fj^<;9af]aMgQe
LW=ecn;?]lKHemNa];c:eMS@alO8bL[9</O5`lK5a<?2`L2o`lWAf=_HdloGe=;F
g=oNf]GOh=SDeLg1b/S4`Knn_[nk`<O=d=3=bog<oLeob[^g`<>k^/:o_[jm_;^j
^/S:b<2h^<?>`l?4aLO8bLVo_K^j^[^l_ZjUZ;c>fNGbl=VkZ::OV96WYZ>PWYnR
Y:>VYZ2GShf>S8R;Ti>>TI^GVIB6NGEfMgJ7TH^6Ri2>RW^ES8fCK6a`QIRGQgb2
SIN_TWiWJ5Q_BTABKG5TK8AGLe]NOhM`IgA]NWeaK7Z<U6]VIgF7SXEiOi6NUGi[
JFi/KWZ8QGMbN71cI51EJ698@U1IDClf?T]TIV9DAD1:EDiCF5MBCDe>A4Y?DE1?
D5<d:b8Q9R/[:OdWDRKodlSHdLc?a/C2`<C9blW5`l_Fg]oGcLG=c<c?dLg4_<K2
_l?;d]GEd/o;bL[=d]G9alG5alS8al35bL[6aLS;alK5a<C5alVk]Jn^/[Jf];Jc
o[9o[:6HW;2RMF9bM65fLF]YJfi^K7J_b[FablJTMGMiNWf3Ri::RXR7RI6LY;nj
Xj6`Vh27RI6MYZRQUi2>PXbQV7YiTYbESXfBV9bMXYjHTXn?TYB9PYb7YX^NTI>/
_KZh`/W7Jg5gN7EbLgG?h/nga]SGek6d_<[Ef=37alS9b/TbalG3a/G4`l;1`;o3
bM7HfmSCcmODd]KLgmkJeMoPf=CEcL7:b<C1_kjn_k_0alg@d<g;oLcmcGo:^kO0
`k^j`[nn_[fl^kZjb<[8`;Rh`lk3`lC5alS9bKnm^kZj^kbn[ZFX_<kIiO;`fK^X
XYnHTJNVXj2NWj:TXjJVX9N?SHj<R8^CThjAViNIU8IiMGIgMXNARhJ;T8j:NiF<
SI=/K725V9N7O8:=UjnBOVMXF6m:A59]LFA/Q5McFeioQg1WM6ejOG5/NXbDJfIW
MHN>QGUoTIjEOV]YKVa^NXR5Mg9hL7=TD5EXHTQ2D5UA?cHnBfAVHUA5@4YECU=H
Ee9=CDi4BTmAD4m@Dc@[8R4V:b/YoBMB9_oCb=SAc<o6a<;0a<W;bLG3bmKNgmO=
aLg<c<oAcLBla/:o`l_BeMGBcl_9b/gBeLW7aLG7b<S7`<G9b/K5b<_7a/G4a<G7
bK^e[jjb][Jd][?n/Wn/XIRL/:9eHW9dHGIaJfU[KVi/MZo:]K7;aZAeMgUjOH>;
TXZ:R8N9TIbT_kZSXK2KP8N9TIfVZ:6GT8j2S:6HNWVBW9F>SI:HW9fRWYRBShnB
U8V2W8NVRijATjbm^[S2bLM[LGMhMG9cMLoRckO6f=OG/KBlb]GHd<O7b<W:bC;7
aL?6aLC3`/70_l?9dMSKf=??emCBe]cOg][Egn3He=G=`L[8a<6o_[jo^l37cM3@
cL_mc?g=OlZk]l33^k[2_kjn_Kbk^[[8b/S0^;S3c/?3a<G7b<W9_kfk^[Zk_;j^
YJRlc]WUl_3I^jRRWiRAYjJSX9jOXZBSYZJPUhn=SXb8Ri>CSY6KUiVDQWUeMWMf
Qi6;QX^@SXYkUHb=Tfa/L8FHUhMlPXfG[i9nIfQHKdY4DVeaI6b4Eg=KGWn7L6Md
KGYmLFajS9A[IVMeQhj5NGnAWYEnJfU^K6ijR8EgLWQ`LfA@EFQRB49@FE4o=Si;
I6IRE4E0BUE>DeQGDTe=CTA:Ce5@Ce1C=2/R8BH[:bWm9`0V1M1oom;8fM?@dl[2
`/K=dLo6_LO?fMoLdL>id]7Ae=KBb<3;alC7cmOKfmOBc<W:dMWNe/o7`lK<d=:n
`/C1^[Fd]L[9alG4aLK7e=3=dM[Ri^Nk^;Bb[ZBGS:FnYfI@KgYROgAXIFU[IV1I
Ylb/Xkf[LWIiOH21PX>5PXR9OFi/Nh]lPX=hPIV8K768RHV6OW9WH7:;T865VYEj
OGI`M7n6QH6?RhF0PHN?UH1aQVB4Hg]^MYbj^K2a/:UOIg5fMgMjOZ[Gb;CFgLO@
_;g3cmWIc/?8bLc>d=3?c/O8b<W:bl_<Z;G8fMkIc/GEd]3CfMgKf=SQi=_Gelo2
d]3=bLOnaWo8b<[<cm?GfM7Ad<o?c/g=b[Rda]7:alc1`;fk^[Zk_Ko<f=C5^kg4
a/O8bL[<cLg0a/kBc/6cZL6cZk:g][W1e;jUVj:/[jfo]ZfYZjj_[jZ^/:fXYZV]
YI>9QgU_R;6NZ:VHQX24R6n7Ui:9S96BVX^TVY^OM79_RjJTSh6:VGnLZG=nJh=D
Ge=?H7YhHfR3CCPoHfmJDf>0RhQdIVelPgIXGVMiPGMYJWN<TgiTI7EjMgYmKeU?
DU9[IDA2HVQ?A5IREC`a?U59Ce9:?cm;FEYQJFaXHV1PF5iRGE=>DUU0=2HP8B8N
6CLf=34]om;8fM?@dl[2`/K=dLo6_LO?fGoOg=73^M;AdMCFd/S0blO4aloGfm_G
d/c9b]7Ig]K?al?6c=3B_/;4`KZe];G:bLO5a<G6amC@cM7Jh^KW^kRd/ZjTUhbU
_ZMVD6mjHWmdJ6EYJfIPFJO<[:>mZg9fNGf0PH:3QH:8RGe^K7^;PX=hPIV8K768
RHV6OW9WH7:;T6V1QIZENWefL7AoQXF1Sh^5P867SiF0LHITQ6=kKWJL^[V`/K2Y
GfMaMWMgNWjZelRde]g7d;bm`loIfLk3b<W<c]3@clk7b<S9b/_;c:Reb=WNfLk5
eM;@dmWMfmSHhNCKemO?`];@cLW7o/Iob<S:c<oCemWAdM3?clk=cLZh]<KAb/O<
`L2m^kZj^kfoc=SDaK^ma<K7b<W:c<g=`<K>d/k1/jW1/j^b]kJi`MBnYI^R[:n]
_kJ]ZJ^^[jnZ[[2]Z:JY[JFCRHMiKhRaWZRYV8J0Q8Q_QiNBRHbATYZ;Y9ZKWgAb
Kh^VY8n1RYUoW:UcOV^3E5mCCf1jN6=XPddh?f=_FU=SP8^8M6I]O8=fJ5iWNH5g
JFYgS9=nI6AeNWMjOFmICe9BJfE4@V9XCdAFHUDl<CiABDmBBSloBeUJHFU/J69P
H5QNHUeCCU9I@3@V824R7QTg=S@a;OoBb=WCd=?:`/;6cM7?a[g7cmUogmcA`kWB
dM7De];8`<_7a<O?em_Kem;<bL[AfMkFclO3a/c@d[k2a<6j]KBeb/W7aLC5a/OD
d<gAf^;Vik^h];:^Y9N<YKjWIU1_NV9oM6QUJF]VH5VWc:bS_J]bMWUmP862PhF2
R8UmKVakRh:3N86IR6aaR8V9QWibIf1bRi1YPHFJUGYmMW1dOhJ5PHn;QH21QhnE
P766I8ASNfifW;Zi/;6`ZEmWLGIgMgYnZ]O8]=KMam2l_L??fMW>`lS9c<k@d<o>
alS8bL[;blbX]LSIg]W>aMGBd=?IgM_Hf>7TfmOGcl;Bd<g9aok6OlS8b/c?dmOI
dM7@clo>cLg:^;C6dL[7c<70_K^j^[^m_lcHe<Fk_LC6alS9b/c=cL36c];>`K>Y
`K>[/[Nf^L7D_ZFKXZb_[Knf[JV[[Zn_ZZj`[JRVZJfUThV7NFn8/IjXZIR6P8B8
KhNGTXV<TI:JRjBJVimdLVn;YZB?PHZIK9bYLgi[PeAODdmPNWQSJ8==>3mSKeYC
Hh2;R7AVKGb3MVQNIgV1MfUZMhbCOVATMGYgNWe_FDmBDV]UA49RJ4m4EV9E?34n
DDU?DTXo?d]IFV5YK6QRH61HGV9MDdiBFD0d9R0Q8QhI=cHd<Bd5d1ckf]KOfN3T
cmCEe]CAblC1^lKCfMK>alBl`<S?eOkGOm?Ddlg6`/C8bL[<cm?Ff=Vk^kbm`LG9
bl?9clo;alK7bLcAeMKEd]39cM7BcL>g/:Vi]Z:PZ9AaQgITGV=WHUYiHei`MFUZ
NXbBVYbFR7M/J7R4OfiVKg^8OVQQP:NRPI65MG60RGIIUHn=RW]ZJG=dO8F=V9Ii
F4Y_O6ehW9j2BYN8NWV6TiRFQ7UdLfURMiJ5WI^EW8n6V5mXLWEcM7Z1S:K6e]KE
g>GHalGJiM_@d<34bL[7`l71alO6b<gDfmo4`l71a<S>dLS?e_kI3]gQfMOEemWF
c/OBcl_7`ok1OkboaLW:al?1f]7AdlNe^<Vc^;o2_kBWWkZg][c1_JnRZ;G2a/70
aln_/[:c_lJhXZjh^[:][JBF/JNOXZZ/XIFRYjfa/:ZSWYbPYk2e/jbUZ9^GXZRN
Ti1mR91hJi>TOHJ;MVYiMg20Lh25Ogj:TiB<Ogb6RGe_JXbKUh:4Ui=kOhV:PfiE
@cPb9UMiL65VJVERAbe7Kem7EhAnP8ImJfE/QV5KOHafKWjANWUgIVmkKVegPXN0
L5eABDI=F5A;EVeAFE=8EfmQ?UUIDT8a<d]SH6AVI61LFe]MJVE<?D11>R`U9BTV
8BThG510<bkkf]KOfN3TcmCEe]CAblC1^lKC2MWFc/O4_<38cmGnegoCe=?=a/;4
b<W:c<oCe]SI^k^l_L75bL_3bLo?blO6alW<dMGFeM;@bLgAd/g3]k2Y^KJRX:RD
LHMfI5iSIf9JNF=NL7EYJWZ<TYZLUXQgK6QhQ7m^IVmkR7iXHH2WXX6AQGEaP8Uf
FIF?SHYkJVUcM7b5SIRFNEQ:Kga]N9bNPTZGR7YiQY>HUXAiM7=YHWNFQIfKUIb?
QYQOJ79eLgAjPHbVa]KFeMcUf<O5f^GKd=30a<W:al?1`LO7a/S=e=_Oa<?1`LC8
c]78cmKnf@kMhMWGeMOIe/k7d/o;al?n`Gnl_lG9b/O3`M[AdM?7]KS9/kRo`[nd
Yinj]kJl`Kf_XZRe`/K1`<O?[k:b/ko6^::^^;Zb[JfTU[6WWj:Z[:6EXZN]/K2Z
XijLX:N`]K>/YJRKUj:XWY>@OHR@N6^CY7f6RgIZNGM`P7>0QGmnRY>DS7mlQXUm
KfZ<ViN2Q9NCNgn9RX=^ED<h<RIGNG1QIVYUHTL]AfmOAeN4OX26OF]UK8IQFgf<
MVinTGYiMfI_Nfi]Mh:7P71MDDU6CEQDBeI]DEUCB5M_HCiIFE92<C=;Hf1TIVAP
G5]KGFYUC3e0@CX/9BDY9R4Y>5a@@3<^nm[FgmWPi<oDeMKDdL_4`K_6d`WIe/k7
a;c0b<oEo]ModmCCcLK2a<S9b/c?dmKHfK^k_;g1aLW;`lW?cl_7a/O9c=7Ee]GB
d<W=dM;=`kN`ZKVfXZ2XU767MVANHfMRFWUSGW1eJFYjS9:JW9J8MfaXN8AoKVI_
NhQnJ660Yj:1THEeLH29MUVEShf:NfYYLgAlQHfHUWUHBVmlKGRLWX9:UhQjNHJC
V9J4NGAcJF9gUXFMViFLShJHGfQbMG=dNX6<Y/KFe]GLiMS7aM[Ufm3@`<C9b/O3
`L77alK8cMCKglC3`L74b<kAb<oFo]T>gN7IemGGfMK>am;?blO3o/5o_;o5bL[7
`l7JdM7CakFhbK>h_l:o]:NO^[Nf_<6m[j:X]L;6`L37cjnb/[>oa[RR[[Rj/Zf]
Y9JaYinRZZbQUJ:W[K6`ZZ>NW:2W/;Fc[:FXViNRZ9jCT7f8T7Q[TjAmQX]fJWUg
L81cP8EoOXZCU8aoO8J9OFmZS9^GPXBGTg]/RHZ3KUE3>38VEgU`HFIZIF97;DM_
GdMGQ7j0QWe[IFb6HE]mS7I^OY5jNGMVKg]^KGN2Qh1`GE59ATeHE4]FKE5IDdQG
Kf4nFEUB@S4cBf=PI6ITH5aKFeeZID`m@44j;2DU:BHQ:CQLD40c;PG29oWGdmkH
gN7>cm7De]KDdLoDe]KCd=7GgMgNh>;Sh^7PdMCEd/g=dMKlfOkJOmKDd<c9alK6
b/oDdlk9b<[>d=;De]KEe<G8c=3Ce=CCaM37/[2n]9YgJ5MAEUUECV]VIfi[HEiT
PhR>SXIgIeaPI6MWI6AXK8IgI65fRhMdRX^5OX24N6F:T9RDNf9SM7N6SXMoNViP
JGj5NGb<RWMYN8ZFUiBAT8F7T9F6L6ikC6b2P7j;Og1mOhF9QWmiNWefU;_Cf=KG
fmK2_<oPgm[J`<?7bLK3`;k8a/C3aLW>dMGCclc;c<g?c]CIf]SFfMcJemGGfMK?
b<o<b<C1o[mob/[9bL[<c/o5_l?9`[BgaK^l_knl]k2/]kNi_;fh[jNc_<C2^:n^
/;6h^kVn`kVXVZFZYZR^Zj6ZXYbOYjNLT8Z?VJ6VYZBRSY>LZ;Bk_[nPUI>LWYF@
ThnCX9J6VZ:1OhYlN8f?RYbCX:6DRXb?SIR>RXn;NFe[M8V>PHBHVXYBShemIeeG
@2A1BUETMgeWBV1E>3E<BDIOP8N:Q7UaL7:3H5UhQFmULX9/KFaKHg1TJVaaMWMc
JF9DAD=EHF1OIDa=BEAnX8aOEEQ?>cM7F5eLGf?mICeVEFM_HUA>@cDk:QhO8B<`
@61LDdLnnMOCg]SMhLk?dMCFe]CAcmCFe]?@dMOMgMkPh^?RhN3Ae=GBcLgAe_cI
o]Yoe]C@c<W7a/K:cmCCc/W8b/k@d]CFe]GDaLS<d=?De=?5d<Nb/;jdVWMXEe5F
FEE>JfIWKV]QGVB3R8j>QWMWG61TIfMTI6Q/QWMTHGJ;QgB:RhEnP8AhIHZ@V9Ak
HV=dMhJ>QgmjKV1YOXEiO8b:MfUhRYJGU96@QHN@UHI`KW]<K8:0OX]oL7eoQHV6
OgUjOGJD^m?He]OKe/:lcn3Of][0`lO9a/?0_/S6a<?5bLkAeM??c<_<cLo>e=WJ
f=KIg=[GeMOIe/o8clc8a<7n_go:b/W9b/c>clFo`lW2];O5^kbo_kbg/:bg]kVl
_KR_Yk>la<:h[jj`/KRk^Kk3^JRJYJZVZ:j[XJZRW9nWYib@RXnIXJJVY::>TibX
];^n_j2ETibNUI2CSi>PUXJJXX5oRWahSHn:W9>PXIB:S8n=V8j:Sh]iKF]dRHj1
Q9RJRU:?SGeWGEM0945:EFAgOFM:H5Dh=Da9AUn0QhZ4NG5`LX=PFGR5KfEbPVa]
K5]SL6AZK75fMg=YHUA5@eEQH5mUC4e9E7jPS5mEF4lk=dMHGEaOHoeU?FIEIfmR
E4i3=C/Z7QlQ8c10H5aCAckiem?Nf=gQc/oAe=KFe=7?e=KFdm3AemgMg^3Rhn;Q
h=7DeM;=cM7Fo=WnfWoFe=3<bLO6a/[?e=?>bLS:c]3Be=KFeMC5b<c@dmCDdlG@
ak:`_[BJMfQGDEIIEDi[IVM^Jf5NI8>8SXj6MfMLH6AWIfATJ6b6MfAQMX^7M8Z;
QGj0Q7QURY2HU7]RHgAgQXj7OgY^H6UnQGUlS8YgJGR:UYNDTI25Qi2EQW1^Nda/
PX1nRgm`OGn5RHIoNGYmMYBkdmSFem_F`[c?h=oJf/33alW6`l2nb<K4`lG9c]7E
dlo<blc=clkDfM[He]WLf]OEemWFclS?c<S4`OjoOl[:bLW:c<k?aKo3bL:d]lFk
_;no_;N`[;Ng^Kbm^:nW/kc4`[R_[[2a^;^i_/>iZ9ZUZZJX[Z^QZZ:LWjNWW92:
SiVQYZJTXXjCW:Rd^kjoX9FCW9jET9>?Tj2FQYZRPGn:O7R=ShZLTj2QU8Z<ShfH
SXZ?RgU]JgB9SX64V9Z:DXn=OFMMEd0T@DYEI7MmIdYPECPeC4U6Gh27RXAiLG1b
Pf1IN8E_IG:2K6e/Ff=`I6Y/LGIgLfURE4E3EF5PGfE<CDUDOZ2<GeEHCc/gAeQM
G5mSoFDEIUEWKf9DCT<e>bXN7b4S<41PG5=7?PGA?_SBc]gGf=c=bLcAe]_Mg]oL
g]oLfM_Qj=kLfmWHfM[KfmgMfM?BeM[Qh=kLfMKDdn7Nf=;=b/S7d]KIe]3:b_k;
Ol[9b/c>cmKDdLk=c/o?bLk2[Jk0`[B?PWA_LgEbKH>CVi65P7egS8nBTHQjJf5V
GeULIVi^K9F1M7QnO7UkO8N;PW]iLfQ^Oi>CMe]NLVj5SgaVHV]bIVYbNWn1PX9L
NY^VVXb;TXB:UY^>N6mdLh=mOY:;NH29S8j9PGYhN6V7Ok7?fMK@c]k8_<WKh=cH
`<;5a/G2_K[6a<2m_;k1`m_IemCCe=GFdmSMg=SEe]SJemGFfMOAblc:a/?0_kjo
d/k9alS<d]O2`LG;aKVg_[Vi^;Ne];Bc[;6f]K2[Z:ROZ;:g]:n[ZZ^i`;Vd]K6X
XJ^_[:nh^K6XXinSZJRNTi:G0YnW[?j_OjBSXjFY[[Bh[jVZ[j^SY[:FSJ2/W9^L
R7:3O7bATHbMPY6FRX66SXn:Qh^CSH1mQFJ0SHB3TIR@P8=eIG:3IcI;?dEWPWeO
Ae]]FD19D5AWIgn5Kf1XKFR>Jf1hPVmVL9>0Ph5^M89fOGI`Lg]oO7M[DdYPOH=g
JUM4<3mhY95QHd]JDCLkFfEDFEaQIfa_LG52Df1PGf5MEDlk;S8f<S0c?DI>Cd[h
d/kMemSLcLW<dMKKgMkOg=kOg=WKhNSNg=_If=WJfm_MgMWCd]GJhN3Ng=WFe=?Q
g]SBcL[8am;FfMK@b/[nbgo:bL[<c/oFe=7>cLk?clW>`Zf^`<:dSh9dKg=eLVf3
Ti^AQH1mMhb?TY68NV]QIUmIG6I^KVbEPGAhOWaiNgb7Rh9kNG=XKWnCTgMKGW9^
QHmlIV9[LVIZLWYoPH:2G7ZKYYZ<Ri:4RYJKSWQ_M7>3OGjBRgV0RHb>RH5jN7QY
QgnacmWFd<kNb;c9fn3Lf<32aLK5`[fja/C0_Kbn`L?KfMODdmCEe]?HgMcHeMKH
f]OEe]WGdL_<b/K3`;nn_m;>bLO8c=;G`/75blFi]kji^KRg]KBd/jba][F`ZjRX
WjRb]kB_ZjZ[^L2i];FaZ:6[[jb_^;VaZ:>OXjVXWY>BU`:OYjcn[gnTXj>UZJjd
^:nYZZn[XjJbUXfP[9bKW8QbPgalTI6<WH:AUXZ1QXj?RXN;Thf0OHEVP8f4Pi6H
T823MFEbPfLfBcm5Ih9mGdMKKEU0BE1DIfMoQFmPJ6eXSV]PN89_IW2CP8>1KWB2
MWefL7=kOgagJe=:H7f3MfYGA30oN:BAHF=;FU4g>e]UE5ULHFM/Kg5a@U=PH5mQ
GEE?>bhb=S8`<ce6CTm:n=;>gMOHg<g9c=7FfmgNgmcNgmcIfn7Xg]cKfMSIf]_K
gMgIdm;Ef^7Pg]cIe]CChMkHd/g:b<OBe]WFd<[:o/]ob/W:c<k?e]CAc/g>clo9
c/:][/32]8n2M6mcMG9]Pi>KTHF0OGN<Si:AR7Y[HFIOFEaVKVi/UH5dN7ilNG]l
Qh^2NgUcJ6ioTi=gFeibKXF?O6IRJg9VJW9jOh62PUajVjJJS8^BQ8ZFVhihKgAc
PgenTX]iP8V<SXV1NWQhJHMo/LoIe]3>g/RlbM_Pg=S0`/G6aL:m^/K4`;fl_/73
fmWGe=?DeMKCf=gLf=GFf=[GeMKIem7;c<[6`l2o_[oBc/W7b<cBel;1aL_5^KNn
^KVh]kFd];>//KJe/:^XZ9nX/[Nd[j^ZZkW0^KBe/JRQZjn/[kRi/JRSWj>YZ9jC
TYL2WjN/oZmoY:>SYJV^];R_ZJZ_Zj>V/YJ=X:bLVib8LX=lO96AS9f2TIJ:PHJ>
ShZ7Ri>=P7f5IX2=Q8>AV920PgEULX=W=T/oAFN2OEm7FfeI@4U@E6MWOhE_H6Q]
J8i[H7R2KfI`Th23PFidPWImMW1cNgmlMf]CBV1mPgMZEd@`?gRTTF4TBeYA=c]K
IEAIG65WK6maLD9CH61OHEeECc/^<SHb<3<mATi?BPG=OoO=bMcFdmO<alW=dmSL
gn7;e^C[jN;LfLo=bl[<d=GIjNWUgM;<c<oHemGCd<g;b];@c/c;blg=e=OHe<c7
alW>c<S6a/W=d<g=blS5`[nn^KjfZ:Zi_kVh[jBPXZBRWjW5c;BSZZfTYJNZZJ>I
SXN2NgAdNh:6QZnKUZ2KRHZLNhNBUXj:RH1cKgfBVhYcLWmgSYV:NG^:U7Q^M8Z@
QHNFQ9BRWXn8TIfEU9BASHfFXYJMSHbVYYRQSI2CTi:@ShmoU;;;eM;:`nSGbm;O
hMG:`l;2a<K3_;K1_[^h^;Zn`<g>d=?Ff]gOd]OLgMWGfMcLf=GEf=SDclk<bLKm
`go;bLO5a/W=d<[;c<c4]jj[Zjf_/K6`[Zfa^Knl/jja]iNLYJjc/JZTX;>m/ZFS
YJ>d^k^b/;JdZjbYYjZ_[JFMZjb][Zf/ZjZf/Z^SWZ2X[kZg^Kbe[KO9T7V<YYR;
ShYgRXF2ShQmS7J3QGE[M8>:Oh28ShMkOXa_R9J<PXJ;RWmmRh=bP9QnBC`hCG1g
HEEMAg1ZD5e/HEYIOHEVEfYdJ:J1KGV2MgF0Pg=gLe]MJUn9OW=dNgmjLWeZHWB@
VXajME4X9U5hK4Q5IfQ4@FA^EUaMH6Q`MGEcFUaKFEiYLgULCTeJG4L[6R8b@dU6
mlg9g=KCelc7bLgCf=cOhL_Fi7o[jN;LfLo=bl[<d=GIjNWUgM;<c<oHemGCd<g;
b];@c/c;blg=e=OHe<c7alW>c<S6a/W=d<g=blS5`[nn^KjfZ:Zi_kVh[jBPXZBR
WjW5c;BSZZfTYJNZZJ>ISXN2NgAdNh:6QZnKUZ2KRHZLQi:FSXZ9P7=_OI:KRW=b
OgN>VFR:NG^:U7Q^M8Z@QHNFQ9BRWXn8TIfEU9BASHfFXYJMSHbVYYRQSI2CTi:@
ShmoU;;;eM;:`nSGbm;OhMG:`l;2a<K3_;K1_[^h^;Zn`<g>d=?Ff]gOd]OLgMWG
fMcLf=GEf=SDclk<bLKm`go;bLO5a/W=d<[;c<c4]jj[Zjf_/K6`[Zfa^Knl/jja
]iNLYJjc/JZTX;>m/ZFSYJ>d^k^b/;JdZjbYYjZ_[JFMZjb][Zf/ZjZf/Z^SWZ2X
[kZg^Kbe[KO9T7V<YYR;ShYgRXF2ShQmS7J3QGE[M8>:Oh28ShMkOXa_R9J<PXJ;
RWmmRh=bP9QnBC`hCG1gHEEMAg1ZD5e/HEYIOHEVEfYdJ:J1KGV2MgF0Pg=gLe]M
JUn9OW=dNgmjLWeZHWB@VXajME4X9U5hK4Q5IfQ4@FA^EUaMH6Q`MGEcFUaKFEiY
LgULCTeJG4L[6R8b@dU6mlg9g=KCelc7bLgCf=cOhL_Fi7o[jN;LfLo=bl[<d=GI
jNWUgM;<c<oHemGCd<g;b];@c/c;blg=e=OHe<c7alW>c<S6a/W=d<g=blS5`[nn
^KjfZ:Zi_kVh[jBPXZBRWjW5c;BSZZfTYJNZZJ>ISXN2NgAdNh:6QZnKUZ2KRHZL
Qi:FSXZ9P7=_OI:KRW=bOgN>VFR:NG^:U7Q^M8Z@QHNFQ9BRWXn8TIfEU9BASHfF
XYJMSHbVYYRQSI2CTi:@ShmoU;;;eM;:`nSGbm;OhMG:`l;2a<K3_;K1_[^h^;Zn
`<g>d=?Ff]gOd]OLgMWGfMcLf=GEf=SDclk<bLKm`go;bLO5a/W=d<[;c<c4]jj[
Zjf_/K6`[Zfa^Knl/jja]iNLYJjc/JZTX;>m/ZFSYJ>d^k^b/;JdZjbYYjZ_[JFM
Zjb][Zf/ZjZf/Z^SWZ2X[kZg^Kbe[KO9T7V<YYR;ShYgRXF2ShQmS7J3QGE[M8>:
Oh28ShMkOXa_R9J<PXJ;RVamRh=bP9QnBC`hCG1gHEEMAg1ZD5e/HEYIOHEVEfYd
J:J1KGV2MgF0Pg=gLe]MJUn9OW=dNgmjLWeZHWB@VXajME4X9U5hK4Q5IfQ4@FA^
EUaMH6Q`MGEcFUaKFEiYLgULCTeJG4L[6R8b@dU61LPXnL[6gMS@e<g9bL_=cm?E
el7=fn?Qf]GBhMoKfMWLh>;Ti>7Hc/O7b/gmc?g;Ol[9b<W;c]3@d];=aL72aMCA
cL[:c=3BZk6k`lO7`l2a^;Ze][g0_Kjh/Zn_/:n^[LC6ZYbZ]kBc]KRi]k:]ZZ2P
WYRCUIjV]ZZ]^K2KWkF][j^W[;2SSYjMY[:]Vhn@VjZaZJFZ[ZbbWif_ZiBAXZNT
X9^JW:6U[jjXXZBb`lfaOk:ITZbb[Kb/[K2e^K^j^J^a^lO>cLFngM_Kh>OWf<O7
a<;4b<Fl];Vg][Ji_/C7`lG8cM7DemS=dm[Lfm_OhmgHe=GHfMOCdm7>blW9b/[3
a/[=c/c:b<S;b/K0^:fSXZVb^;Vd[:O2b<c8_kc3bjj[ZZf`ZY^?WK>m/:2NXjF_
OkNf[:RZYIZZZ:JWZJVVXjVWXijKV9NFZ:RVWi^OZkJTXJBVWiNQ/iUgP9N6Mh25
PiRDSIF7NhZAVi=gHVEeOh20Q8MlKG1mNXbHT8B3R8b4VIR2OXQeDChc?UeVETmH
?5mD?f1lJE5/SiQmLhR@PKF?LgInOX:>RG^1O5mMJEmeI71/KgEeKFEgLVmePhb6
Ng=I>cI<Ge@lBWf<IE5YMVMRGf1VKg=`JgQ_IV9RI6Y_H5ACHFA><1l^>TM:A?W:
a]gHd=C=bLW;cLoCeMO1cM_ShM[Ed^7OfmWIg>3Ri>CQf<k7al[=oLcmbgo:bLS9
blk@d=;BcLG1`/GDdLg:b/c@dZ^a^l?7al?0/KRj]KJm`;fn^;:_[k2_[Zg4aZZL
Z[Nd/kFh^KNb[JZPX9jHTiFNY[JZ[KV`Vine[Jn[Yjb`XhjNWJJb[I^?T9^Z/JVU
ZZj//YnM[j^DTJ:WY:2KVYbQYJn^Z::T//?=/GnbVI://Zfl[:f`]KVk^[V[/K_7
c/g5_]gKfn3WimS7alC2a<S5_;Bi]kJf^Kk4al?5b<gAe=OHcM?Jg=_Kgn?Mf=CE
f=WGdm?Ac/_9bL[:`lK:cLk<b/S8bl[6`;R]Xj:Y/[Ri]:bW`/S<b;nl`l^^ZjZ]
/:ZKSifc_K2PWZ>U[gng]ZbXZZFJZZRVYjVYYZ>YYj>NViRGUZRXYYnKWj^fY:6T
YYnGXK>IMh2GQWN0QH>HU8fEQg^:TI^CMf9UMGn0P8B7O6e`OGZ<V924PhR<Q9VH
PWj8ME4n<ciMIUI?F3aOE3mPO6UAK8nHOG>8T86eSg=fOWj2SXUkPGaOGFUOMFA`
K6meMFeUMg9_MH><QW]cFC/fC5mD?4YmS6EAJGIWHUmPIVmcL6]hKfIRHVAZKf1D
Df5TCS0O;SY7BTCib/KMf=3DcLW9blg?dmGG`LgKhn7JeM;Qgm_IfMcPh^CThMS>
alO:cOg<oL]ob/W8bL_>d=3Bd/g5`L;5e=7=b/[<d=:[/K_3alO3`;6h^[Ff_L2m
_[Rb[jn`[jj]a<JZW:Zg];>e^;Vg/ZfZX:2NV9>EWZJfZZfi/9^O]Jf_ZjN//:>>
WYfV/ZfKSi2KZ[6YYJZ^[;:OWJn[U96RYjBPViZLXJF_[ZRRY;;3cK5o/YVB[;:]
_:b]/;Fi^kZiZk6kalk=aKkMfm_PinOHalO4`/C8aKbd^KNf][Vna<O3aLS=dMCG
f<gCf]cKfmoSgMSDeMSIem?CdLk;bLW:b/?6b/g>c<[8b<_:a/2h[J>RZK:h^KB/
Yl;8c<Ro_<?;[Z^Z[K2ZVhnM/kf`X9jSYJmo]kJ/Z:ZUVZZXYZNYZJJSZJNSWY^H
UiJXZ:JOVin[]ZBQY:JOUj6cVGN0UhIgP8F3V9B=UHMkRY6KTgMRIGEoP824Qga]
L7ejS9R@Q8>8S8BIV89nR7EA?S<nGFIFCePlGe@oH7aYDFb?V7ecR921]HmcMWin
PXj9Nh5lGeeYGgDkL6a_MGE]IGMbKgF3S8IkLeTk=TaOE3a:OHaUDFUfIf9OH6I_
Lg1[N6mVHV9TJVmPE5=QI4h`7bhjAdY41L/do<S5h=[?d]3<blW8b<W;cLS;cLc:
cMGLmO;]in7Mfm[Be=C@b/W<dL[;c<g?d=7BemGAc/_mbPW<blJo_;o4`l6oo[d>
_[n_][o6a/2h/ZZb^K^io[Qo/k6^[:^[[:bX/:^KTif[/Jj_/K>d/k:b[k:c[JFT
Zk>YZ[6g/:FX];^i/:^b^ZnL_[6[/JjNSh^Z/K:][[>]WkNXZ;BcYJBaZjBPZ;Jj
/ZN^][Rd]l;5`<74Zinc^K[>a<?3a/_=bLG:`kk1bL_4_<?ChNGXj^7DcLO3a/_9
_[?n/PNd^L78c<K7b_k<Ol[9bm;IgMgNh^KNfMCDf=_IemGCd<k=cLk?aLW?e=GB
cLW=dLo9bL_3]JR`^l?3_;:Z_;fk]kBe^l6^YInV/K>WVJBf_k:VYZb]YK2e/:nb
[9nTXIfJVYfQXj>OVYJDUIRJZ:b/XiRDVj>DSXnDT8R<Ujf:RiAoMH62NY6>Qhf1
OgR:QIBCNfEXN8=]JW1kOGUoS7^4RhZ7R96HKh:=Qh20OWMR@2/nGVEB?e5M@35Q
R7aXNHjGSHfJVhj[Rg5aNh26SIV>VIAgMH9jJg5hOX1nNgU/L6eUIVm`JTQ2@4YI
G4`jDXFMP6E]NWQRGE]QJfmZHUA>DV1VH5]LHE15BD]2>cXj;38lAdolb<GPf/oB
d<c;bLS8bL_=b<_=c<[=eMcel^gWhMgKf];De=3:bLcAb/_<cLo@dM;GeM7>bog:
2Lc;a[nl_lC3`Kon_@jn_jnf_lK6`;RbZ[:i^kWn^7nc/Jj/Zj^/[:R`Zi^CWJ^a
[Zna/kBc/[:_/[>]YJB[/jVZ/KN`YJRd^kV`Zk:j[ibn/J^a[Yj?RjZa/Zf^/jfO
]jRX];>UY;6[Y:2X][ZbYjjf^;Bg`/G0`LB[Wk>i^/k4`l?6blg9aL[3_/79blBl
`m?QiNSZhMC=al?6blVn/ojb1kBi`LS<a/O:o/aob/W;d]WMgMkRi]kIe=CHfmWG
eM?@c/g=c/o5bLoDeM;=bLgAclW9bl>eZ;2k`l>l/ZZl_K^g];Fk`JjUWjJa/jNI
Y;Jo/ZJV[:fU/;F`[k:/WjBQWIZJWJ6SXinJUYBEV9ZX[:bSV9BKXiB>SiB@R8bG
[HZ;U7mePH9jTHj7SH5oN8Z5U9=kIFQhPfeZL7]mNGn<NhB;RXN8TIQ_PXf7P81n
Mf90:ciNIE8oDEe0<F68O6QiSYN=SIZKSZ^;LG5kP8J=VHjIU7MePWY[LGQnP7ik
NFa`KFEVKg1ZB490BUULC3YBQIf0IFejN69MFf5[KfYRE4iBH6IPFeaQD4E9Bd8k
>SX/<Sa7Coc8aN3Jcm;@c<_9b<S9blg8blg<b/gEg?GbkNOQgM_Jd]CDd<[9c=7:
blc=cm3Ad]OEdLk;oLX9c<_6_kboa<?1_ojm3[jo[kJoa/K0^;:Z/[Vk^OjhOk>a
[Zb[Zjb/Z;2[Vi>MZk6^[k6c];>b/Znb/jfUY:^cZJZa]k2UZ;Bk^K2[/[Z_W;ja
Zk6^WXn;Z[6b[Jjc[IngZ:Rd/jFT/J^TX:Rf^[:W[[Jh];O2aL31a:^O/kVjc/C3
`lK;cLW5b/>n`LW;a;c3dn7Uj>[Qe<g7`lK;bKjco[87];W1b<c6al[nc7o:bL_B
fMgMg^;Vg]WDe=SKfMOEdm3>cLg>clG9cmCEd/g9cM7?bLW;`kFX/;_3`kbbZ[bm
^kNd]K_1[ZFOY[6cYiVT][nbYZJ/[JF`]K2_/ZbOY:6MVYZMXJ>SWiZFU9FHVZR/
[:>HU9^SU8j?U928S9N]RX^DOgF1PWZASXN=PGmhRXFDTg]UJ7R3KFY`NgeiOhak
Q8^:QhRAV6n2SHN0P7igHT0[?UiUDSmAGD0aHHQlJ7V>Uhf=VY^>Zh]aLG^0QXfI
SYVDMgF2NV]aN7j0OW]iK71]IFI_L6Y8@T1:FEa<>U:5WH1UKGYhHUeKHF]_JV9D
CU9PIV1KG65@ADU;@PHj>R`b?4M?1LYXolS5i=k?d]C>blS5aLK8b/O:c<_:cMKM
j^WUh=[Cc<W<c/o<b<O<dLg=c/o@dM7BgM[Ed<_8a/K7b<O3_Kc1akBd]KFd/Jn]
`L;2`;ZaZJ>Y[[Fg/Zb^];:c];:`[k6c]JZUYjFQY[:]oJaZ[Jf^/k2][k>e/k2R
/;Nb[[:aZjnc[Z>PZ:RQ/ZJOWIF8QHbOYZFNWZJTVinMWjFYZjne]:bX/;c0]Z^S
[kB`]L2m/;g9^Zjj^KO>_k^j_/G7`[c:_kJkalc5^kOBi=oIg^7Ndl_5bLo>`KCn
[bRa][k5bLK8c<o@clg<d=KMg]gLgn;OfM?Cf=_Lf];Aclg<cLk?alW:c?k=OlcB
eLo3aLg6]K:f_<30^kF`/Z^SX:BY[JjUV92K/KfgZjJd^JnX[K6^X:ni^;Vj/J>U
X9RBT9JQZJ^VX9^JWZ>WXjbaZIR<RhnNTi6JW9>>TJ^EUiV5RIJ=MXf:P8AhLXMS
OXn3LG5kPViVJGV5R8fFOWalP8F:TiadMX:?SH>7OiJ:Kde2EFUPB5QJ?ce^Rgie
M7R0RiFFSXFEP79hQ8R6Q7A^OWiSHgE_OXVDU8f8SI=iNg1OGFUZH48h=D=DEd/o
C6n8P6iYKg=LEE9JIfeVGEI;C5iWH5YMIEE8A3hd=CdZ9RPfBoo8aNCNcm;Dc/_8
aLG6b<[7b/c;b/gFgN[YC^GPf]?<bLc>clc8alcAcLg>cm3AdM;Mf]G@blS6a/O8
al>m_<77];Be]KBa[jg1`/;0^[6YXjV^]KNb[:jd/[>d/[2_/K>eZZFWYJ6V/Zgm
[6Z][Jjc/:f_/kFc/::`]k:^/[6[[k>^Xj2XZ:6bYYnMUHR5S9nVYIjNYZBKWifO
YJV[[kFd[:R`_<2fZj>_];2e`;f`_LVj[[Zi]ljo^kZnaLO2_<Zo][_7c<Fk]m;T
gmWNhMkCblG9clk1]?j_:;6f_/G9a/S<cm3?cLc@e]gNgMcOh]oIdm?HfmcJd]7?
cLc=c/o7bL[<o/eoc=;Ecl?5cLJe/[Jl`<2k]K2bZj>PY:V][ZFHT9^a_KN[Y[Bi
[jR]/JjP[kVh^KZaXjFPV9:@UZ6YZjJPViZNXjNS[;6YV8b;SijCTIZLThjAZiFG
VHF9UXefSHZ0Q7QbQf=nSh=aLG^2KVIYNHF8SIInO7b0QHZCW7AfPXn=PhMoUXY_
CD9EJF18F5Xo?Fj;OWEdN82;UIJ>QIF0LWR4R8J4M6inOV=SMFmnRIBDSHR=TgUk
L5mMJFYP@SPe@eAGBcm<KhR0KVU_LeaEDUYWKFIMET]<GVMPFUeUEDQ4?S@e?BXV
:3I;olS5i=k?d]C>blS5aLK8b/O:c<_:cMKMj^U>iN3Jdlc9c<k?c<S7c=7=cLk?
d=7Ad]gJeM3;b<K6alS7`kfl`LNd];Fe];6_[L72`/2j/JVSZJje]k:/[[Bb/kBb
/:na/kFZYJNUXJJb[Of/JZf][[>`[Jnc]K>`X[2g/Zjb/J^_/jjSX:RXXK:VWifE
R8F<WjJUWYjVY9^OWInUZJ^_]KB/Z;2l`;J[Xjnd/;G0_K2mbKZ^^[Vgc[nk^[k5
al:lb[nf^lO<aK^gd^COfMkQg]?;aLW?c/6doZlX/KJnaLW6b<c?d<o=c=3FgMkM
g=oRgmWCdmSKg=[BdLo=c<g>clO9b/cncGo<d]G?`lG=a[Fb][c0`;^e/;:[Xj2T
ZJf^YIR@Vk6m]j^V];V_Z:fa[Z2_^KRi^[6SYJ2HTY2FXJV[YZ2KVYjSYj>//JVH
S8^?WY>AVYbCSY6[UINIQHVFSGJ=RX24N7:7Hgj?Pg5aNh9^IVUiQHR=UWilO825
RY>LM7J2Shf3QfFFRVm=@UEYH4QHFSlmKX]nMGAhP8^EUXj5UH1bN8B8QXAdKWin
Hf=eKgj9U9B=R8fCNG]`GeeYJV12>3E3E5M;?da_R81^JFmcG5EBFVM]IUeFBdaN
If1JGFEEB4@n=3Dm:RHX=T/5a2SobLGVh<oCe/k<b<G5al[=^LGEgMgGd]3GfM[J
e]7;am?Ddlg6`/G8cOc<1/_;e]??blSmaWo7al:n_/C:_;k1`/6m^;Fc/[6`/;6b
/kJh^k^d[K:m];Jh]kBc]KS2[:Ng^JRT/KBb/:j/[:f]]:RQZkg5^Z^X_/Be]<2l
ZJZh^JJIWJV_Wi^IUXZ1SZBHXjFLVjRb/jnc[jNTZJRSbKf`ZZfb/k6Y/[2X/<G:
`JRm]jjeZjJk]46a/;S3b<Fo_;:/]/O?a[Zjf>SHbLgHg=K=al[Bd<>e[jj][k>i
_l?0a<_Bf=[KfmKKh>3LfM_MgmWCdmOLgM_?c/cnbQ7<cLO4`;jo`lS<b/^n[:^c
ZYKm]Wne/k:a^ZjRX:Va/[2gY9BHZ[>ZWJ:]/:RU[:nZUjNb/[6_XY6[YI^BT9RV
/K:/Xi^HVYnRPi>TYinHVYnXVYNRYijBSiV?VI^?WZfMRJ2IRXYlMXe/SJBJPG9^
K9Z8OH>6OgQgQW]dN826SYFXTi6PV7]fRI^PRUm<GFe[@4PnBgmgP6USM6]bS9fE
Qh67NgN4TY>8Ofi[Oh=[Kh>0SIVQV8InQiBDSg]VJ7MeI6e?=3I8De9=@59XLV]Q
H6AECT]EIFaVG:J9Lg1[GeaTJF5MF4H^9BU3<R@W=_o9aNKPcm?Fc/c8aLG7b/fi
aMGMgMOBd=OIf][FdL_7dmCCcLK2a@78cOc<1/_;e]??blSmaWo7al:n_/C:_;k1
`/6m^;Fc/[6`/;6b/kJh^k^d[K:m];Jh]kBc]KS2[:Ng^JRT/KBb/:j/[:f]]:RQ
Zkg5^Z^X_/Be]<2lZJZh^JJIWJV_Wi^IUXZ1SZBHXjFLVjRb/jnc[jNTZJRSbKf`
ZZfb/k6Y/[2X/<G:`JRm]jjeZjJk]46a/;S3b<Fo_;:/]/O?a[Zjf>SHbLgHg=K=
al[Bd<>e[jj][k>i_l?0a<_Bf=[KfmKKh>3LfM_MgmWCdmOLgM_?c/cnbQ7<cLO4
`;jo`lS<b/^n[:^cZYKm]Wne/k:a^ZjRX:Va/[2gY9BHZ[>ZWJ:]/:RU[:nZUjNb
/[6_XY6[YI^BT9RV/K:/Xi^HVYnRPi>TYinHVYnXVYNRYijBSiV?VI^?WZfMRJ2I
RXYlMXe/SJBJPG9^K9Z8OH>6OgQgQW]dN826SYFXTi6PV7]fRI^PRUm<GFe[@4Pn
BgmgP6USM6]bS9fEQh67NgN4TY>8Ofi[Oh=[Kh>0SIVQV8InQiBDSg]VJ7MeI6e?
=3I8De9=@59XLV]QH6AECT]EIFaVG:J9Lg1[GeaTJF5MF4H^9BU3<R@W=_o9aNKP
cm?Fc/c8aLG7b/fiaMGMgMOBd=OIf][FdL_7dmCCcLK2a@78cOc<1/_;e]??blSm
aWo7al:n_/C:_;k1`/6m^;Fc/[6`/;6b/kJh^k^d[K:m];Jh]kBc]KS2[:Ng^JRT
/KBb/:j/[:f]]:RQZkg5^Z^X_/Be]<2lZJZh^JJIWJV_Wi^IUXZ1SZBHXjFLVjRb
/jnc[jNTZJRSbKf`ZZfb/k6Y/[2X/<G:`JRm]jjeZjJk]46a/;S3b<Fo_;:/]/O?
a[Zjf>SHbLgHg=K=al[Bd<>e[jj][k>i_l?0a<_Bf=[KfmKKh>3LfM_MgmWCdmOL
gM_?c/cnbQ7<cLO4`;jo`lS<b/^n[:^cZYKm]Wne/k:a^ZjRX:Va/[2gY9BHZ[>Z
WJ:]/:RU[:nZUjNb/[6_XY6[YI^BT9RV/K:/Xi^HVYnRPi>TYinHVYnXVYNRYijB
SiV?VI^?WZfMRJ2IRXYlMXe/SJBJPG9^K9Z8OH>6OgQgQW]dN826SYFXTi6PV7]f
RI^PRUm<GFe[@4PnBeQgP6USM6]bS9fEQh67NgN4TY>8Ofi[Oh=[Kh>0SIVQV8In
QiBDSg]VJ7MeI6e?=3I8De9=@59XLV]QH6AECT]EIFaVG:J9Lg1[GeaTJF5MF4H^
9BU3<R@W=PG46OZkb/g9elWCe;V/^l_;b/o2a/oJgm_?aM3@nm46f]K@b/C0__jm
Okbn`lW@e=G=a<32a<C3clW3_kjk]:jX^l[5/ZZfaljfZ:f`[;;0_Kjm^KJi`l[6
`lG4^K;1f<FZX[>dXIn`[ZZ_^k^a[;6d_/W>b/:l^[bn_KJ]Zk2f`LG4]ZFP[;ZV
XinMWZ>Z[[bdYI>=W;cE[jRY/[B^/;R[Z:BRY:V`]:NgEL[CdLk?d[C0c]?=_k6Y
/;Fk_;bna<Vg_<G<clc7a;RXeooZjO3BelK3dMG:a/bj^;Bb/KBg^/W1`/W4^lKM
em[Ngm_Cb/?>dM;AdMKPj=_FdLoAe=GEoLQobL_=c/;1_[Ra[Jj`][B_Yj:T[KFe
/:ZVYj^_/IjRYIb9OXNHYIREWj>HSHZ6U9jPXjBGQK6OSXbJYjZVYZFSXIjLViZI
X:FSViJHW:JPWjJ`[Yj?TYf`^jjFSYJCPXRQWW]UJ69fRX]lKfmfQXB3QXV7P7U`
KFARKgihIh1mP89oMVANIFaaMVeHBUEYC5e6BWahEEf@RGabMge_FGMfPiRQV8n?
QHR;SHf9QH:1O7YgKFMdRY:JV81PDf1cPWANBd=7DEY;BUa_H4=8IFM>CUA<EUa7
GEmZLVAEH7]PETLk=C8`;bH[<CHhn[_:cLWGbM?D^Jbkbl_:cl;6cm[Ofll2aM3@
nm46f]K@b/C0__jmOkbn`lW@e=G=a<32a<C3clW3_kjk]:jX^l[5/ZZfaljfZ:f`
[;;0_Kjm^KJi`l[6`lG4^K;1f<FZX[>dXIn`[ZZ_^k^a[;6d_/W>b/:l^[bn_KJ]
Zk2f`LG4]ZFP[;ZVXinMWZ>Z[[bdYI>=W;cE[jRY/[B^/;R[Z:BRY:V`]:NgEL[C
dLk?d[C0c]?=_k6Y/;Fk_;bna<Vg_<G<clc7a;RXeooZjO3BelK3dMG:a/bj^;Bb
/KBg^/W1`/W4^lKMem[Ngm_Cb/?>dM;AdMKPj=_FdLoAe=GEoLQobL_=c/;1_[Ra
[Jj`][B_Yj:T[KFe/:ZVYj^_/IjRYIb9OXNHYIREWj>HSHZ6U9jPXjBGQK6OSXbJ
YjZVYZFSXIjLViZIX:FSViJHW:JPWjJ`[Yj?TYf`^jjFSYJCPXRQWW]UJ69fRX]l
KfmfQXB3QXV7P7U`KFARKgihIh1mP89oMVANIFaaMVeHBUEYC5e6BWahEEf@RGab
Mge_FGMfPiRQV8n?QHR;SHf9QH:1O7YgKFMdRY:JV81PDf1cPWANBd=7DEY;BUa_
H4=8IFM>CUA<EUa7GEmZLVAEH7]PETLk=C8`;bH[<CHhn[_:cLWGbM?D^Jbkbl_:
cl;6cm[Ofll2aM3@nm46f]K@b/C0__jmOkbn`lW@e=G=a<32a<C3clW3_kjk]:jX
^l[5/ZZfaljfZ:f`[;;0_Kjm^KJi`l[6`lG4^K;1f<FZX[>dXIn`[ZZ_^k^a[;6d
_/W>b/:l^[bn_KJ]Zk2f`LG4]ZFP[;ZVXinMWZ>Z[[bdYI>=W;cE[jRY/[B^/;R[
Z:BRY:V`]:NgEL[CdLk?d[C0c]?=_k6Y/;Fk_;bna<Vg_<G<clc7a;RXeooZjO3B
elK3dMG:a/bj^;Bb/KBg^/W1`/W4^lKMem[Ngm_Cb/?>dM;AdMKPj=_FdLoAe=GE
oLQobL_=c/;1_[Ra[Jj`][B_Yj:T[KFe/:ZVYj^_/IjRYIb9OXNHYIREWj>HSHZ6
U9jPXjBGQK6OSXbJYjZVYZFSXIjLViZIX:FSViJHW:JPWjJ`[Yj?TYf`^jjFSYJC
PXRQWW]UJ69fRX]lKfmfQXB3QXV7P7U`KFARKgihIh1mP89XMVANIFaaMVeHBUEY
C5e6BWahEEf@RGabMge_FGMfPiRQV8n?QHR;SHf9QH:1O7YgKFMdRY:JV81PDf1c
PWANBd=7DEY;BUa_H4=8IFM>CUA<EUa7GEmZLVAEH7]PETLk=C8`;bH[<CHh1M=o
ol;<blKGcmbk/:nm`l33cmCFgNK]k>CLe]GDe=GHfmg@c/[7a<?3a<70_[k0aL[>
eM7>cm7Ac<KAc<K4a<:l]jnmb<Fh/[W4`[:]][Va[kJ`/K2/ZJbd_;bh]kBWWZVn
^:2J[K>XZ[be/;Bn_[>_/kO0blo:a;nn]kZi[j>PZ;9o_l2k/:FU[kZj]k>_[:b]
[Z2RZKK6eMoSbK^b/k:^]L:o_KZg][Ni^ZF__<G7alS9a/_;`KB`^L?4bLk>b/O8
b[jk^;Jf^Kbna;cHm>OFe]?@a/G=bKbkaJJYZjRVZ;6ibL;3b/O1cN7Og=SFfN3X
kMKJg=[FeMSLg][EdmCFemQob<_?d];?blSDdlo9a<71`Zn`[jZWZK6h];6/YJ2O
XjNVZJVNSXJ?WZnNU9RKUI:FYJf]YZFWX9>WWYFEVinLUYbKVIJDTi:AY:V]ZJ6L
WJ6`ZJ:TYYj;NXjBWJ>HQhREWXnD[:bAPHJ5Yjf;MWn2M8N3OginNG5ZEV=]MH6;
QGIoT8^?W9QmHEA4DemLE5IPJ4eHDU=UIf9^MW]kMgYkJUAZJWVBWIB7PgEnRiJJ
UXj8M6UTIfY^OiBDUHmnJ5YGFUaNH5mLEDm:C4I@GE8oC6f:JeiB?TmZJ6ASJW1U
EEUZJf1@@SXg=SH/<3Pn@_o2c<_6eloL^k2__L?0`loDe]eoi^g/i=cFeMCDeMSK
gM3>b/O4`l?4`L2n_/35b/kEdLk?dM7<a]7<a/C4`[bg[kg8aKRb^LC2/Zff^K6_
][2a/:bY[;Bl_;Rg]:NNZKjhX9Z]/jRZ_;F`];jn/jnc]l3;cl[4_kjg^[V_Xj2X
/[o0^k2UYJnj^[Nc[jb/[JjPXZUo]/KEgn?9^k:c/Zje`[nm^[Nf]kVjYJnlaLO7
b<W6bl_1];2i`lC9c/k:alS:_[^h][Ji_;k4_=SdimKFdm36aLg9_;_5YZV[Z:JX
/KW9`/?:al7=hMoLf=KIh>S]e][Lf]KEf=cNf]GCe=KGf<S;cm;Bcl_8e=??bLC1
`L:_/:moZZNY/KRd/JbUX9nSYjJYZIj>QXnN[ijDV9^ETYJU[JfVYJNPTjNNUIFK
WibFW9^IUYBCTY6TZJfYXIbMXK2YXZBVWX]jSY:MXiR7R9FNSiB/[961QXFW[H]f
Oh9dQh=oOWiiLFYFHfeePH^5MY2;SibHOF5DA5=OG5AFH6Q=F59oDfEWHVifNg]g
NW]ZE6YZNI:MU8N3MGj;UYZFSXQdJFAWJVioU9BESgiXFUMJG5iPGeaECdY<AU1M
DSm<KHY[GU8nCfYXI6=ZL6EEFFY[H512>SLf=R``>3i2ol;<blKGcmbk/:nm`l33
cmCFgNK]k>CLe]GDe=GHfmg@c/[7a<=o`lC1`;jn`<G:c]GAc/oAdLc6dLc6a<C2
_;N__LS5^;:ia<:b[KJi/Jnf/;6`[:V/];bl^;NdYijY_[RPVZfcZ:Zl]K2d_[jc
[k>g`<_?b/Bo_[Nj^JnSX:Rb_l2k/:FU[kZj]k>_[:b][Z2RZKK6eMoSbK^b/k:^
]L:o_KZg][Mo^KZU[kc5alO8bLK;bl6d/;W3a<W>c/[7b<Zn^kRf][Vl_/Blf?CW
e]KCd<K5cLVl^lFVZJ^XYZRa^LW2`l[7`LgQgmcHe]WPj>gFf]cJe]GHg=kJeM?D
e]OHb<_?d];?blSDdlo9a<71`Zn`[jZWZK6h];6/YJ2OXjNVZJVNSXIoSij_WYBH
ViFBUZF][JJUYj2CYijEUI^OW9JLViVFU9>BTJBY[JVQW9fQ/:VRY:JNRgZ>TYfS
V8N8UIj?U:b/TH66QJN]RgIoPWB7PgmnOWUaJUISKGF1RhEfT8^?W9QmHEA4DemL
E5IPJ4eHDU=UIf9^MW]kMgYkJUAZJWVBWIA6Qh=eOX^FVYJ>R7AYI6MZKWnDU9F?
OVQJEeYLGV1OG5E?BTa6D5eB?da]RV]NDSi?JVQTHfY`IEEIJV]PD48j=cHf;30h
?T85dGoo`LO3_M3:fKJg_/O4_lKDfMOGfmoOfmGBcl_9b/oEfLk=c<_<c]7CcL_7
a<?6bL_DdmKKgmcDc=;=bLW;blK2^l35a<2l_/6e/;>o`[R^Zjj_[jbXZ[6h_[Rd
/::FWJjiY9n^][6fa/2i^/;0][:h][k7bLFo_Kg1aL:eYZ>^_0Nj]JbUXjVb^?jl
Ok^j]kBcX9nV]/W>aKVlZYbIV9ZX^/K5a<:n^[JdZ:V]];g2`/2cbN?^imcHfL?;
dmGAc<[:a;Z]Y:B__LO9b<_Qjl^lelc6aLO0]KFm`l_>a[Vf`<g7`/;8bLWDi=oK
eM3?dMCGe=WLfmGAdM?HemCBd=7Bdl;7c]?BcLFoblW4Oknl^[Vh[;6d];:c]kbf
^;F[WiZOYZFXYYfEV:B_Z9jMYZNKTi>_]:nTXZ^^Z9jPY:RYZ:BQZZRUXj6PXJ6/
[ZjZXYfNX9^GUIZQWY:6QXF:T8b7TjJVUYJWYi:6Ri6k^8=aTIb4PgmmP8F7Q81L
JG5cNhN8P7=YKhNFRW1PA5MJOdPoAT@g@d9AD3]4HFUIJgYnOga[Ef=LHgR1Lf1F
E6=iS9BAQgm/JW>3RHF8TXf8OgIZFd]1C5AOIVIMDDUDBTU<@CI9JhU`I4h]?6=^
IF9WL75YIV]aJUmECD]<CR``=3Tkol77`kg@b]Vf]kk7a;o6e=WGem_Ogm_Ed/o;
bL[?JMGIc/g<blc>dM?=blO4`lK9bmCCe]_Og=C<d/g9bL_;a/:k`<G4`;bn`KF`
/ko2^:j[[Zn_[:RZ/KRn^;B`XYJM[[VTWjjf/KK6`;Vj`/2f/[Rf_/O9aKnm_L75
`[FVXjjl^[F/YJ>Y/[Sn_7nk^[Nd/j2OY[K9c/Fi_:ZLVIRJZ;[6aLC2_[Zf]:RY
[KBm`/;0/lWSk^OLf=W3bm?EdLc:b/Bj[JBT[kg7bLS;hN_;_=O<a/G7`;Fe_L?;
c/Ji]/3=al;2b<W9e>COfmG@cm7DemCIg=_EdM7Cf=ODd]3Ad]?2alkCd/g5_l_9
a7no_;Zi^:ba];Bb/kNl][ReZinJWjJUZ:JMUIRT[jRNWJJWVi>C[kB_Y::[[ZRN
X:BXZJRTXJZXYJ>QX:6Q[:j^ZZ:MWZ2KUiFJXIjBQXJ5RY2<Qi>VYYJFYjNBQX^A
^kR3LI6LQ8=oOH25QhB0G6UaLg^7R81cJFn7UXY`H4AGFWm8?dI4=d=2DE0kA65Y
FF]jOWmlJeMSG6=hPG=PEUASNHbDTHMoK6YcPhV5R9:=R7mfJU];@DaDGfIVGE59
E4Y9C44fBF^9L6A>;CaSKVERIg1aJFI[LFYOEDe;C4h/<3@i>oo1al>md<[I][Nn
alBoa]CIemOKgmoKeM;?blW:cfWEfLk=c<_<c]7CcL_7a<?6bL_DdmKKgmcDc=;=
bLW;blK2^l35a<2l_/6e/;>o`[R^Zjj_[jbXZ[6h_[Rd/::FWJjiY9n^][6fa/2i
^/;0][:h][k7bLFo_Kg1aL:eYZ>^_;Ze[:FSZK:ho[ao^kZg];>PWjJfbLk5^KbZ
W9VHVZRja/G4`[jj][BXZJfd_L;2`;?9hnkWg=SI`l_CeM7<b/[4^ZfTY:nmalW8
bn7[bkcGc<K5al2e]Kg3blk6^KK0cLO2`/S9bMCTgm_Ed<oAe=ODfMcKeM7AdmSG
e=;@dM;C`/O>dm;=aKo;bLAo_kbj^KR//KBd/[>g_;Jh]J^OVYnVYJRVWIFHY:nX
WYfVYi^CTjnd[jBRZjjXWZ2TZ:VXY:6ZZ:FSXJ2QXJb^[ZZRWIjPViNEVZ6NTXJ6
QHZ@S8NCYZJFUZNWTXJ;TK^hPg6AW8B3Ogf0QHN4P5aYLG=kQhR0LfU_QiJ:L614
EeYQB3m6A3M3@U5@>dAQJEU[NWioO6]GHeaSN85cH5IDHgV<U967OfaZLh>9QHRB
SHQoMVYKBd5<E5mVIUeABEA:BDa1=TU[RG1TCRdlHfiUHVM`LFUVJg5ZGeE=Bda>
;30d>C/5dgooaLg;a=?9e/g;c=3BeMcTgmSAc/o?cLWKeLg7a/[AeMSGe]KHf]gO
f]OAc<[:blcCd];Gfm_Fd<k:alW=clc8aLC3aLO6`[jc/[O0a;fbZkVl_;Ve][_1
b/:n^k2TZ;K5]:ff^kNjaL[1_lC1]kJm];[0`Kfi^K[5alBfYZ>__GncZInKX:V`
/jZ^]K^m_;Vg[jNNW:2RWi^OT8J8S96P/[Fg^[^h/Z^V/J^W[[_4`knmd^koooCO
dK>mb]3@c<[:bKn`YjVfb=C4aK?;m]Jce<k6`LC8aKfha/k?_::DW:W0_[k2a/gG
hLW?e]_Hd<Fmc]7Bd<_;cmC=c/k;alG6bGnk_/;6b<K3`K^f/:f][:ZW/;Jl_KZf
]kRh_KjeYj:X/9jRWiRJZKJkSY>V^k^SS8BDWZ6KWZbf]IfU[[Fh^l75^[Nc/:n`
/[>^[JZUWi^JVY2?TIRPXIZCQ8:9U9RKZ[faXIVNVXZ0PWnJVgefTZ:KS8N2PhN:
RXR<PVeMHgEmN7mMD51TMWUfMfahK4XmAd8]BcUBE2`iGeM?IW^0PX9jKUi>Bei^
JeiGC5U]OhR7P7YZP:>k/YF3PHR5P7M/H5I?H5mLFEEBCdiKD4Y7>c=4GVMNI5Da
>5YUGeeRLX66Ph1/KVm/IV9QHC@e=cLfolG=blCCbMK=blc@d]GLi=oHdGo>clo=
bM_EcLO6b]7Ef=OFe]SJgMoJem7<b/[;c=?Bd]OKfmK@c/[7bLg?c<S5a<?5alK2
_[>b]l34_K:[^Kbl^KFf^l7:`[jk/:BX]/Fd[KJk]k[5b/6oa<6g][fd^/31_KVi
^/G7a;JVXjnm/jVOVj2Y/;>Z[[Fk_Kbi]jnWWWnLX::OVin@QXR<TJ2b]KNj^kRb
ZjJaZjN^^lC3_kgBk_oom=oA/kg:d=3<b/[9_k2WZKK8e<C5/l_fe[?Dc/K1a<S5
_KS6c/nlXYBLZL2n_/;6cMOQbLoFfmS@aKg>dM;@bl_?e<g>c/_7aLK9^kk2a/S6
`l6k][2][JbZYk2f_7nm^[Jg^;Rm_[FWXZR`WZ:OV9ZY][^>TjJk^j><Q9BNXI^N
[;JeWJF^]KRk`LFj]k>`[k2b/jj]ZZFOViZJT8nAV:2QVY>4PXVDV9^Z_K6QVIjJ
RX22OiZKOGJBXY^<Qh:3QhZ:R8b2KEeSMGehGE1@I7IiMWM/N6a:?DM2;D/iDWmD
;3UOEdmVNh22PWY^GTi;GVi[GUM<FFeoR8N0NVZ0Xk^bUH>1R8F0MfaPETmPGeaI
EE9?CU]@BTLk<dANIeiTEC4hFVEOGF9bPHJ3P6a^KfaVHV5Q=3Dg=cKoaLg;a=?9
e/g;c=3BeMcTgmSAc/o?cLWKeLg7a/[AeMSGe]KHfWoMgm[GdLc:b/_<dm;Bem_K
e]3>b/O9cLo<b<G4`lG7a/:n/k:g`<Bm/Z^i_;bi]KJk`L[2_[^`Y:RfaKB]][^g
^/G:`Ko4`KNf_KBj`<6m^KVjaLO4]ZJS[kfcZInKX:V`/jZ^]K^m_;Vg[jNNW:2R
Wi^OT8J8S96P/[Fg^[^h/Wn[Y[6[Yjjka<>o_M;^ooodgm6c_L[@d<c:b/Vo/:NY
]/SDa<FcboKF/mC>a/74b<Fm^<K>ckbRU9bY`;jn`/K=en79cmKKf=35_LkAd]3;
bloDcLk>blO5a/Vk_/;6b<K3`K^f/:f][:ZW/;Jl_KZf]kRh_KjeYj:X/9jRWiRJ
ZGnf^hjCY[^kXhb4U9jQVij/][FMYJje^;_1aKZg/k2_/;:c[ZfZYInKVYZ@Si6H
X:6JThB2RIBHVjZm/J6IWYZ:P89oVY]mMY:RVhb7PX>7RXZ8S89]GF=eOGQMD51T
MWUfMfahK4XmAd8]BcUBE2`iGeM?IW^0PX9jKUi>Bei^JdINEdaIKGn8Qh1jJX2S
^k:EPh68QH1gK61FCf1OG5UEDTm>Fe1:Ac/cA5iWGVAE<CQJIEmMHW:1QX>0K6i_
K6IRHF4d=CLg=PGAHoo;f]gDgL_BfM38c>3do?[[i=_IgN;Ti?7Zh=OCeMWMg]gK
fMWJfmcKf=;<bLS9bmC>b<S=dM;@bLG3a/_>c<S;a/C6b/W3_;Vj^[c0`[bd_L32
_k^j_/;:`Kk0^[2c_[nd/;On_Go1c/>n`[ng^L6j_/70_;Zl`;Zi/jVOWZF][:FM
Vj2WZjbTZ[:i_K^g]:JXYZ6LWjZdZIjLXjJU[;VY[K>g]k>]Z;Zc[[?0bLW5hmK9
a/[:`[VobMCIem;?c]?;`;Ne^/?9al:U^_OW][g?aKk6fMo=]lS?cKRKRY2L^[Zh
^L7>egoI_lWHi>[XhMcFeM7:a<K>e/W=d<g5`<;6`;jm_/;8c];5_[Je^;Re/:ne
^kZd[JZY/KJi]Zj//KRRYZ2EVjjd[X68Vk2_VXZ6PI>OWZ2[/JnRYJRZ[[S5d;Ba
[:RXZZj`]K2ZYJ:PWYfUXj6QWiZCSI6?UZBYYZfj/jJMW9V@RWn:PX23RHAoR9ZI
T8AmO7ajN:bFLeiWNGQZIf9UKg1ZKWR5R7MJE6QbK6M;GF=3CVM@FF]hNh6=TXmW
CD1EMXN;S6M]MGj4QXF4HH:]_jMoKgJ0Q8AjK6I[LW1[HEE;@SdkCTY9Ad0mB5UB
C5]I?dUZLUiNHFf0SHZ1J71gMFYNF6UF>c`n@47obm[Me=g;d]W@b<cPm?cjjnCK
fMgRi>Caj^3GdmGIgMkMfmWIf]_LfmSBc<W8bL_Dc/S8cM7Bd<W5`lK;c/c8blK4
a/[9`kbi^[Zl`<:l];g0`[nk^[k2b/6n`;Z`/kjo];2go[eo`Lk3_/:o]kW1^[k1
`;bj_<2j^K>YWijU[JbUWI^PYj^/Y:Zb^Kfk]kBVZ:JQW9nZ]:VNW:>VYJbiZJfc
]kNc[JRj/jjc`<W9aN?FbLK:b/:i_lWDfMOBclkCbl2g]K[3bLO2YK[gikJmclFn
a]WOcKO8clfhVhZ@W;Zj^;W1c]MofKo9f>CZj>7Le]GAb/C6c]K9cM3=aL32a/2n
_Kk2b<kBaKjf]KRh]K2_]K^j]:fZZK6f^KJ^[;6hXZJPUI^^]:j1R9^`[iZ:QX6C
WijPZk6_XZFXZZjhaM2d/JbXZ:Z^/;F`ZZFRX9jMYJ>QXInJThfASiJTZJJ]^[>V
WIbIT8YoRX:0PhV4OhRJVI24OGalNWR/UW=NIgUhJVMRIFm`JVihQHQgFUAXLVaW
BeeS@diWD5U[N7^1SI:?Ide0EGJ7RhaWKGEnQ8J5Q662[KnWOfmfP8B4NVaVJg9`
Jf5EBd8m>di:BDM0?DQIDTaKFCm9JW9NGV5]P8f:PFQ`MgEZGUQYES/l?T11ol_J
gMCMbm;Id<S<h?Cln^_TfmWMh^CTlN[Pem?EfMgNgM_IfM[Kg=_Hd/c9b<W;e<k8
b<gAd]39aL?6blk<b<_6a<K:bL>l^KZj_<32_;Bm`<:o^kZn`/[1_/2j/;>n_kB`
]ojmOl7>`kk2_kNi`KZn`L2l^[c0^[VcZInNYJf/YIfKX:N[[:BZ/[Vm^kNdYZRV
XIbOZ[BYWYbSYZF/^JV]/kNg/jfX^[>^/l39bLGSe/W6b/[2^Ko9e=WGd/o>dl_0
]kFj`lW7`ZFjmnNf_Lo5_/KIglfgb<o=^9^:T9bj^[Ri`LkGOmVobMSTj^SQg=KE
dL[4a/kFbLg@cLG0`/K0_[fn`/S>d/Fn][Fh^;F`[kFk^[B]ZZVa][Vf[Zba^::V
X9FK[[B^PHRK/:nJRXJ1TinNX:^a[j:UZ:Z^^<G@];6/Z:RZ[[2e/:ZUXZ2NWJFS
XJ6OVY>=THnFY:VV[KZcYYfLVI2:OhZ2P8>9Q7n8VYV@Q7elO7Yh[9IcGVMiN6YW
HVE_L6Y^N8F8MeYDJ79/Id]MHd=>Ie1IJgQkPHfBSfM=@5EfQh^<IfeeOXB6QHAQ
PZfoYgm_MX24Q7Y/IV]bL6]QED]2?C]>BTU7@3e8FE9<FeToBFYbGUiQKH2=RX5X
L7MeJUiH1EHk?3i0@@G@8oc0d]G<d[^oc<Joa^?ooogSgM[Mio?io>oZh][EeMOI
f]SEdokAOm;DdLc7aLK8b]C<a<75b/c<a/?1a<W<b/O:b<O7bLO2_Ko2_k_0bLNm
^Kbo_KRe^;_1^;Fj^K6a^ZZY[;Jo`l:oc<2i_;Ze^LC3aLK3_ko4bKng[jb^[jfZ
Zj^ZZ:JVZ:V`/kRl_;Rb[j2]^[Z`ZJbc`;Rg_K^a[kF//KRm`;jk@kRj^;Jj`/S:
b[ne[[:m`l2iingaknKLemGMelk5_;Jc/]36Z[3OjlJYaLC4cN7Yd[C5blZmZZ6X
/[Rj]kBncmKBfm[Ho]Mof=SIfMG=alK=dlcDfMG:`lG:cl_7aLSAfn;?a[fm`lG0
^Jfb]K:ZXj2OZZ^/[[6c];B_/ZRGW:fXU8j8RY2@SIJVSj>a[JJWYZ2XXIRDVJFb
^k6]Z:BTYjf`_kN^ZZZ[ZZNRXjBUYJBRX:>NXZb/XIfRW9J@TIBETi6ORhZISW5o
KhN>QWmoQi6HVj:HQW^3SXA`F61dQXEhM7b>Q79PF6=iRW1KFE]DG65AIFe_KgfE
Y:F;I4QDM8R=SGakNGUjO822GW6:SgMNHGEZLWE^Hf5/N71bLfeNAc0R>ce1@T=7
DE]3=D19@eYjNfYZIVA]N7EYJg5dJUM6?ch^<3Dj@?`R`=;Ec=:k_lc6_lKSooom
hmgJgNOcnOc_j^;JeMGGfM[HeM?ndGoBe=7<alG6b<[Dc<C1aL[<c<K3`LC9c<[7
b/S7alW7`[fo`[nk`<W7_KVl_kfh]KRk`KRe^[Va/KZZZJbf_l?2_lc0^Kbj]KW4
`lG6`knoa<Vo]jn/[Zn]ZZ^[ZZRVYZRY/;>h_;bh/ZnP[KZj/:V//l2h]kfk/Jne
[;6h_L2n^d>h^[Rf^/;8b/Zo]Jjb_L?0^NO]lNoVg=OEgMO>aKbf/k;@aZZ`gn_6
ZLG4a<gQjM:daL_:_JZQZ;:h^[Nd_/oFd]_Jf?kGOmSHfMWEcLO6cM?<e=WEb/?5
b/o;alG8dM_RclJm_L?5`;V]/[FbZZ>PWjZ[[:ja/kBd[k:XUib]Z9B>R8Z@T8fF
YXnS/JfVYjJPZ:6HU9VU/[^a[JRTY:N]/;ng[ZZZZjZWXZ>TYJFTXZ2SWZ:/[:6M
XYbFT96DUI>AWh^:VHiaOfn7SXIoOhNAV9^RV8IkPhj4L5QPM8J5N7AlSXAbH5QS
NHY`FeUKE5aQDFE]KfmmUJBURfA8E7B8SHelNgUiNWb0PUiaRXmgGV5eJW9eKV=Q
K7Q`LW=]GTL`8S/m@D93Ae5K@cE0BD=JNW]ZJVITKGQeJF]aM6YGASln;S0e>T3l
8/3BeLcB^ko<a[o6hooooN?Mf]gWloWlkn[Rf]GEemWJf=GCo]5od]CAc<O5a/S:
e<c4`LG:c<c6`l74bLc:al[8alO9al:m_l:o^l39akfi_;nm^;Fh^l6h]KZi/K6j
ZZV/][o3`[o<`;Vl^[Fia<?5a/>o_lC9_kN_[:j_[JZ[ZjZXYZJXZK2c^;bl^;:_
X:fj^[2Y[;?0^;Nm^k6_]Jba^;g0_[]3^;Zh][[2b<[:_kF^/[g3`;WWkO7_i]cG
eMgGc/Fl][>bd<JZ/=o[aZW5a<C=hNWB]<G;b[fZXJRb^;Zg];k?e];Kf]SnegoH
f=WIeLg7a/gCc=CIeL[3aL[?blO5b=7Kh/o6_Kg3aL2i[K:e/ZZSX9nZZjb^/K>d
]:nbZ9NL[JRDSXR:T92=UZJ?Xk6]YZNVX:RQV9BIYK:k/JfXY:BW[K2o]jjZZZ^Z
Yj:SY:FUY::PXijR[:bQWJ:LUY2AU9FCTIn;RYV>LGi_Qhj6Ogn7TIRKXYR6Nh>>
Q71HH7B6QGQdO8j4LV1HHgV:L5]IFeALHE5UKFm_OIFTYH]TB5AdR8f=O7]iNGYl
P89NLHZ?MeiQMFYbMFiSHFahL79cKEi7<28k?D52@dMAFd<e@4U3FWYkJVYVI6eh
MFU[LGAZEdHo?Rh`=CY01M1on;[8b;k5/KO3blo@go;biM7=b/kIhnSZg]_HeM?B
dmCEdm7?c/k@dM?AcL_;c]7DeM3:b/c=b/K8aL;5b/c:a/O9b/W5`Knn_lO7`LOB
c[o1aLS6`Kfn`LJl^;nn][BjZ[2g`<S;a;_7^[:e];6ia/;3`[ji^l;8bKbb]lG9
_Jib/;Vo_;6YZ:^`/[Fh^;Jc/Jbb^K^f[JFP`KRf^[J[Z:j_/[Nk_Kfl^[6e^kfm
_lC8Y[?2cM7DfMkio?cejN3KfmkJdl_3_;Rfc<BhZ;KVik:_`m;Ff]W6[ZBVYJ2J
VZ2W_;nj/kkCf<oTgmO;_k>ZY[Nob?k<OlkAbmGMf<_3aL[Ie]?AdMGIg<c1]kS0
`kfd/[Jh]JjYZJ^`ZJJ/^;fg[jjeZi^S]ZZ<X9J?T96H[lZT]l6fYj:PVjbOTY2L
ZK6d]K6[YZJ[/[K0]jfZ[K2_[9JJX:JZ[[>f[:>RZJRNVYjAT8f=TYRFTJJMUiF;
OGb3R89oQ9BWOkFmSiNERHF=THiQHW:9U8f7R91kKFQGBV68JFQAB5UMFVMWIV5R
N9RXYj5dD5MdQ89mQ89mNGQhNW]eLgIiKf9ULV]^LGAeMGAdOXF>SWmSAS8l?Sdi
>D9;DC4P<TmNN8A_N7]aGeaUI5Q]KfQG@SPmARl`<SDin;[8b;k5/KO3Ol_?d=ob
l^GAcL[>fN?Xj]kKf=GCd]?DeM?Aclk>d=7CdLg;blkAe=G@b/[<cL[6b<G2aL[<
b/K7bL[9aL6o_[o7al77d/jo`LG8a/6m_/76_;Ro_[Jd^ZZ`]l38blBkakZb]KBa
^LK2`l:n^K_2b<Vl/[O5bKf^/;Vo_;6YZ:^`JK:e^;Rf/k6//[Vk]ZfUX<6h][Zf
ZjR^[k:g^kfm_;Za]K^m_Ko4b:Jc`/gAe=WNnOclmNWPfm_Nf]?;`kbh]/c4^:Rf
i^Nb[l?Be][IaZjTYZFPVYZPYkbo^[>ndmS?i=oGbkncZZJg_lSnc7o>dL_EgMS;
`lG:fMKCdM7EfMc<`KNh`<>m];:f^;F^ZJV[/:VV[;Rm]jn^]J^KXkJZS:2FSi2A
V:o:Y;O1]ZNRX9^/Wi:@W:Va];FaZjJVZk:f`;N]ZZf`[jbFVZ2VZZjc]ZbSXZVX
WYZNTI2=SI:HUY6VWINERgelPhR2OhBDYgne_HnGUHV5SI6>HF9bRIB=QhR@NfeX
EdYQR6UXDDQIGEYWIfIQHWRHZ:NQM51GM8B2OHB2OGUhN7YkMG=fNFmRIG9[KW5d
MGEdM7j5SXioHdHb?3hm>CU2Be4a839?GWR4KgQkLEmLIFAHKFmXEd8h?DH_<38e
>ORjb<RnaK6g`go;cm3Ol_;UdLg:c]WSj>[NfmSEdm;Ce=GCdLo>c]3Adm7=bl_>
dMCEd<[:c<g:a/S5`/G:c<[6alW:bLG1_kjoalO1am;>_l75b<K1_Kk1a[bh_kjf
];ZZ/;O0b<_4^lNj/[Fd/KW6`/?2_[Vk`/S9_;:gaLVm[[2i_kbaZJR[/6Vb]KRh
][>a[;:i^kJ]YJ31^;Jj]Z^X[Znb]k^m_Kbj/KFk_Kfoa<RV/l;=dMCIg_Wlo?GY
h=_Kg][Cbl>l^;K<a;RX]^KW/Zo3d]KJfLJ^Y:JUX9ZJX:Nl_kZc_]?HcnCOel^o
/jZV]ko8o/aoc]7;eMgHbl?5b]WFdm7AeMWLc<6g^<33_KBb][Re[ZVYZk2YYZbh
_KN_[[F[Vj>fZXbPUXn@TIR_bZBg`KJWXZ2K[9nBT9bY/KBe/J^VYZ^b]/2g[JZ]
/:n/UYZPYZZ^/kJ/Xj:YZ9jJWY6@SHfBV9JAYYfGUH]mO8>8PWn4U:Mf]Kf?UiF9
QHfASV5RLXVDSHN8T7]]J5M:HHQYJ558FEeJIfMVHF9hV:RWXGA@EgB4PWf4PWei
N7QjNgEcMWU_HVEbJfiaM7EeM7AnQHj>Of=6<S`n?CTi@T]A<B0bCeihQ6mhNg5O
G6ETF6e_J5M2>3e6;c0b=CT5dAcobM;>a<job<OMj^;LgMK7cl[5aL[?d<oJf]_L
gOkNOmCCd]7Be=KHf]SEe=KJgn;Edm?Fem?:`/_8aLO;cL_7a<W=b/:m_L2lbLg8
c]S@_M7EfMOBc/k@e/[6c<_2_/:l`l_@e=;4]L>f[[2`[kS6^[Zh/jna^L35]:Rc
bLnlYKK4d<bk[:Z_XZBY[[:e]kRd[:N/]kfi/kZ`[;6`ZJbeOjZ[[K2a/K2`Y[6k
_;Rf_<?QiMo8]KgRonoal>[Qfm_MfMKBc/_;c<bn_;nRUn;obYc2gmc>aKRY/k6^
[:f`];O1a;fe`=OKc/S=d];7/ij@RY^caLoAdM;6dM[EakfoaMWIf=OEd/o=bknd
][o3_;>l_l6o^[Rk_kb`ZK71b;f^Oj>]Yif/`kNDZ:>TZZb`a=b/_L>dXj2QWjnR
UYb_`<C2/:bUXJ6V[[>k/JJSZJj]ZZNZZjZVYJJXZj2LY:RTYJfTY:2MWj>OUY6N
VHB2UIbAW9:6PhVDWJ6<ViZ1KWVFZZ2;OhVEU8j;R71]NFU@JIm[O5U4HVESRf=N
EEUeUjFPJIE[Cf69X:2JTHn=RXN5Q8>EQh:<SX1aJXZ6Qi:OWi21V9fRX9AoJEY;
BCha;3@l?bTO@G>?Wi5TP8EiHEQQHe]]JUi:>Sa?HTQ6@d0oolWBc/C>_lS7gN[R
g=gFalo:aLG:cm3?f][Kg=gngWoDdm;Ad]CFf=[HeMCFf]oReM?Ce]OCb/;;b<G7
blg;alC9cL[2_Kg0_<W=b<kHd;gAeMWGd/k>d=K:a/c;`[k2_<?;d=CBa;G3]Zj`
/:nha[Zj^;>_/KW0aKBX/lW?_:Ffa=3<^jbZ[j:TZJjb]KNh]:bW[;Nm^K>j/:ba
/:V/]GnZZjf`/K6`/:Ja^kbh][c3hNGOb;Fmh_o_lO3ZhM_KgMWFd/k;blc<_[bo
XYORolZL`]oLc/FhZK>a[Zb]/;Bg`LBm]L3Gflk8cM;Bak>NT8ZK/lG?dM7Ba]7J
eLNm_lGIfMSGeM;?cL^o];Jo`kbc_;o1_kZh^knl/:Va`LRm[WnS[JNM[<>gU:RS
Y:Z//<CL[;g3]:>PXIn_XYJL[l34`[2/YJ6QYZjc^k6VXjV^[JZWZZ^ZYZFVZ:^P
W:BXY:F]Y:BPWInSWiJAWYV4PYFLTIbBQX>9U9fQS9^JPFiiUZZPRgn9UIB>RhQ`
KGUYD6VOJgaIA69UHh]SGUEIMINUX6VEJdmQRJ2PVY6?SHZ7QHB3UHN2S8j0LFZ:
QXNBWin@PIRMXZ2DOfUJBdTn<B`d?3lY7d5cSinAI825NF5HHF=KKFYNBSXlCf98
AT=0?oo9d/k4c[o8amgZh]cMe/O?b/G5b/o@cm[JfmcMo]ioe=?BdM;De]SJf=GD
e][Oh]GCdmKGdl[2blS5al_=blO4bLg:`[fm`;c9cLS>f=2mdMGIem;>c]3Fb/K<
bl:n`[c3bm3Dd/Be`kJ^/;2_^<Jj^[Rc[k6i`<FdZ;?9ckbU]/C@c;^/ZZnRY:V^
/[Fg^;B/Yjbg_KVc^[2//K2Y[;EoZZ^]/;6a/;2V/K^l^;Jl`n7UglRe_N;oko7`
j^7KfmgIe];>bl_<c;jl_j:Gh_o:W<;Og<k5^:Vc/Jj/[K2d]l74_KG0em_>b<gB
d/NcWY2:Vk?5cm7Ad/KAf]G7_Ko5fMWHemGBclg;_kBf_l>l/kbo`Knj^;^o_;2Y
/L78_JioXjfWWJc3]iBXXjBZ[;34g:bm`kBSX:6O[j:FW:o0a<:`[:FQXJJ^/k^a
YZ>Y[ZfZYjZ[ZZJUYZR[X9bTZ:BU[JBTX9fOXinFTIjIQ8:EW96LTXJ3RIBMXHbK
VX5^NIJZX8]oRIFDSX^8L6eiJE1YWf]lFDARIF>;HeiEFGFGYJ1<UF]?HHVPX9ZA
Shf:QhF4PiF7PXb>P75ZRXJ7TYnOT86HWJ:PU7mYFT]9?S4/=3`o:Am1LhnOTFB0
QGUQF65SFfeZGTXj?4mRB4I3@3l5`WolfmOJalC;`]_Mgn7Rh^7Pb<cBf=oZm_oo
il[<e=;AemSIem;<bm3Ed=;DeMKEdm;GeMCFf][FdMCFf=[He=3<c/[7bLg;`;O:
_[c9dlo:c<k>clo<b<C2alG3`/;3a<Je_LG6_kJ_[JR^^<33`Kfia<?2`L;4alS@
a[fk`<C2_BNo`/G7a;nh]:Ng_KFd^[>RZIFN[:Zf_JRc_[jbZjj^ZIjX]jF>[MGB
nOiooMg3c_;oonkll>7IfMgPh=;<a/C5aL:o[jnf^[>gh?o<]m7N_/?B];O>f<c3
alNoaIj7UZV^]lW4c/nkVX5lP/?0`<K?eMOEj/V[[lgQfLS2c=?Ad=GKg=K;_;Bd
^;^lY[6m_[F/Zjg2c/Vla]W9Y[Zl/j6IWIbDX9bLY[Fm^[AoP8jNYJ>NWInbYI:5
QYJZ^K2PVZBVX:Je[Yj@RXJ8W;>hZ;2aW:2[W[6OVZZaYYfPVZJQTIN][YajV9VD
Y9j8QhEcM7IfSIMlM7f0LV=XQ9n?VinJVYnNUWMWGf9QH7>>HGMaC3aEKgAjAEf6
Jf1oRWe[Ff9iS8j8SXf5MFMVLh1oO7b1RHV3OWmnQ8V9QH>6RW1YHf5RHEaGGE<l
:2Pc<bPf:2mAK6]RH6aSF55@D4i<DeABAC@bBVMHEEEHG_cKem[7a<_2fmgOhN;R
hN38c=;Hgn[foooWb/cDd]7Gf=WGd/c;d=G@d]CEe]GCd]OEe=KJf]KAe=KHf]SD
d<c>b/MTbLg;`;O:_[c9dlo:c<k>clo<b<C2alG3`/;3a<Je_LG6_kJ_[JR^^<33
`Kfia<?2`L;4alS@a[fk`<C2_Ko2aLO4_kRdYkNm]KBj/j:YUIj/Z[JmZ;>n_[:[
[ZjYWZRgYHj]eM;ioWomgL?>l_ook_c`hMWIgN3Pd/c6a<G5`[n_[kJj/kOPolbg
dMjn`m:d]lkHc<?7ako5WXNFZJjgbLC>ck^JPGb2`l30a/oEemGZbJ^_cN7Ib<;<
dm7@eM_Le/^l];Bh^kbV/Kfn]Jb[[L;>bKc6fLVV^[bcXIVMW9BPW9bV]Kfj]7n0
SYjUXijMWk:UTXF6UZZi/:2JY:JPY[F^WY2:QXRL/kRX/;6LX:^N/InJZ[6VWJ2J
YZ6AUjf^W7ZHVIBTWXR7QG=dMWJ=UgadOH1bHfR4WhnKWiZJWijFMfMOHV5PLhiQ
Mg5<?5E_M7Y5GHI[H7n:OF]KHWV<SXR>SHEeIfIcP7mlO869RH=nOgj4RHV5PhJ:
L6USHF9QG5MMDc`X:3<c:3HX;e5/Jf9PK6=HDE1@CTaCE595=39:IeQEEEQNo=_G
f/O4bl;KgMoQh^;Qh<S<d]SOj_KoonO:c=CBdMOHfMOBc<_@eM3Be=GFeM?BemGD
e][Je]7De]SJf=C@c<k:afC9cL_0]lZn_<WCcl[<c/k?clc8a<;7aL?2`/?4a[Fm
aLJo]Zn]Z:jh`<?1_KW4`l;1`/C7b=36_K_0a<:m_l;5alBo^;BW]kfe];ZcXZVE
WZbZ][fX/kjn/Z^^[ZVNZ;NUSZgEd_WnOogM`lkbooo^o?3QfMWMh>3Bc<K4aLG2
_jn_][Zc]n3oc;OAg[k3d[Bgc]S<`lO7_lFNQiJY[[O9a<k?^iZ1O8;3`<36cmGG
eN[9Zjo=hMW8`/cCdM3EfmcFbkbd];Rk_:Ja_Kje[:^]`/k9_<KIbJJj_;>QVIfL
U:2LW:Je_KZdOh2>WZFSWYfO/ZFBQHJFZ[V`X9ZTYZ2V]JjNT8Z6R9bc^:R`/IbP
ZijaWiZZ/JJMX9ZVXI6G[JjLNYRIU:BNR8N5LgAfMXfGO7AmP79SJ8BOSi^OVYZO
WYIgIemRHF1cSV5gLD`lEFmdNTEMQV]POhYmJe]RNHb>R8j=QGEWIW>0?7alPHV9
PgioOXB9RHF3QXY`JF=QHV5LEeeC?2PX<c<X=RP_DFa[HV1/HeQAD51>C5=DDTDd
<TYWF5EEF5h5`Woog]?FbLcFc<C6bL_=cLc<aLO:c]GOj_;oi=7Eg=_Nin;Uj>c]
jnOSgn3Qh=oLfMOFemSGe=3=c<k?d=3>c<[8dLc8b<_9`[[9^K2f^kNf^jV`^lG9
b<:n`L70`<;5b<Vb^L31_;Ne][k2b<k@d<g;_kjn_l73aLK2^kJf_;nm^2Nc]kg2
a<C2`:Zc/ZJU[jnUZ9bX[j:]_kJ_^KV/YJNXXZja_[Veh?ohnOioon[EgOOooo3_
iMSAdM;BdMK?b<C4`knk`L33`[NfeO_A^kVm^<;8^Lo>aKc4clF`e;>HVZN][:cB
a[:MTI>P[<c:bm;LhnGSb[FOW:o8fMoIf=GCeMcPh=oEb/C5b<W8^L38b/Jo^kVh
b<[1bmkE^[Zk/J:Q[kNf/Zn/ZZRRV95oWZF[ZZJUZ[2PXJ6RY:JXZJVPWjRWX:Je
Z9fDTHR0QiNFSj6[VYbTUIR=SYbQVIJMVYZCRhnIVY62WYfHZj^LWi^<T9>@Y:Z=
UiN@OfeUJG5jRYJHWJRZY95fGe]IDeIPHgE_D4AFI65==DESGeQQIge_HF=aO7ag
PWY`JfmhPXQoOWf1R8jAUYYmO7YgMgZ0Q8n;PWM]IfEVJf5<>3Dj=2D_7ahhD5MH
GEAACe5FF5EA@4A3=24O=4eJDdY6B?oNdmK9c=K<a<K9blg=c<c5al[>eMoZl_oT
dMGLfmkWh^GXk>g[in?Oh>7PgmcIemKGf=ODd<g<c/o@d<k<b/SAc<QTb<_9`[[9
^K2f^kNf^jV`^lG9b<:n`L70`<;5b<Vb^L31_;Ne][k2b<k@d<g;_kjn_l73aLK2
^kJf_;nm^;>g_L;4a<;0Z[>bYZF_[jFXW:R_XZfo]Zni^JbUYjRR[[6n^KGPooSi
oWooj]GMmoool>oUf=7Ad];Ae/o8a<C3_k_1`<?2]kKEnm6k^Kfh`/Riclk5_<C?
aK3D/iRJYjf/[=;6/YfATj2/c<[;d]cSiN?:]InL[lSIgmWHeM?Eg>3PgmG:a<G8
bLRi`<S:a[nk^KS8b/7;g]Fj^[^aXZ6_]kJb[jbZZ::HTGnNYJ^ZYZFZ/:2QXJ:T
YZRYZJ2OZ:NPY[FXWIBAR827UiJ?XJ^JW:BEV8f>W:6IUYfJVY>;SiVJTH:NWIR[
ZibOVhb@Ti2TZXfGUi1oKFEYLGZ:UYRMZ:ZTTGIOFeUCEV1SMFm@A5ITHDdeAF=O
F65WOFmQHg5lO7N2NW1[KgR2R7mnOH68SY6FVWelNWMgNX24Sh^2MfeWIFI[HD`h
=CXd9BlO7SQ@EeQME55?DEIHEE50A4<d8AldCEYCBTI8omkCe/W<e/c4a/W;cLg<
c<G7b/kEgn[bonCAeMcKg^ORiNS/kN_WhmoPhN3Og=WGe]OHemC@cLc>cm3@c/c:
b=7<b6C8blW2^/Vi/;Jk]kJkZK2kaLW8`[k1`L30`/G8bK:i`<6l]kFf_/;8c]3@
cL^o_[jo`L?5a/:k][Jl_kfh/kNm`/C4`/2Z/k:VYJn_YJRLZ:nR[Knf[kVi[:FW
Z::^/Kji]N3on?WnOooZeMggooo`knGHdM7Bd]7FclS4a<>o^l70`l:g]]GkdK^i
_KS2b;W?c/Fla<o5/=BcV9ZW[Jb/d/JbWI6CX:c<b/_Bg>?UhlZeWib_b=WOfMSE
dmGLh>3OeL[4aLS9b;W0b<[6_k^i^<S:`L_NeKZj^k6RXJng][:_[:ZXXYRAOijU
ZjZVYJZ`X:6QXZBVZ:VYX9nXYj2V]JRMU968P8NGUXnQZiZLY9FHSHjLXIVFWIZJ
Th^?VIZAPYjMV:^[W9nKS92CT:BZSINGT7m]IFUaNXZFV9fXZZBAMUmKFE=FH6=e
Ke14EVAQCCE5HemHHFMmKf5SLGalMh9jL6]_N8:8?7imPHR>TIJJOGajMgMjP8B?
Rh9gKFMUIV]QC3Pe>S@U;alN>51GF5eDDDmAEUQEDD14@c@Q7cA=FU=:ATP5_bOo
dKo4`<WDb<;4b<_>clo>blW8bLoHhNOIc/[?d];JiMWKh^kgmNKIo^I1i>7Nf]OI
h>CNdl_<d<o=blW8bL[:d/g7a/S9alCB`KNj_Kc0bNO^m_[eimO<alK4`l;4aLNe
^Kjm^[Vm`LO8bL[<o/dg_l32a<K9blbi]kJi_[nk][:f_LC;cm;C[k2XW9^V[:ZX
X[>eWjO0`;2j^ZfTYjNQ/Jff^/GgoooioWoolnW/nOoikn[TgmkQi>;Pj^?JeM?A
c<O6a<G2]k;2fNoQ_Jo4b/;8e<fl[:bi_[ZiY8^6XlSDc:JLTYFT]l?9c/_:cMCG
e]>[ZjVVZKS>h<c9al[=blS5cLK0_Ko0_KZm_/34al>k/ija^;2d`kn]]kN[W9f`
_Knna<[;a[nk^Gnc/JfVXZF^]ibOYJVZYj>PXZ:X[:JMXk6PW9jQVHb:ThR6X:nQ
Y:jQUi^Y]kBTVifWV8nBTXb;Sh>OWYZ`]:V^XI>IVY>SZ8ZDSHN4PWUZGFb0T9BI
XZFOSVmCD5EDCT]DHV1>BeQHBSQ8CE]eLE]HOGE]JfiaL6j7N6Y[NHJ:R6AlNWA_
K6iaLGYcJVM[LWQjQXF1NgIfNWmdJeM3?T0f9S@S6RDg@dmIAdM9CeEFDD/b?D0c
8R4dAeM<?SHeom6oa<39e<S2a<S;c/o?c/_9b<W?f>7WfLk:cm;Bf^GIfn;^moGV
fOkV@NCQg][GfN3Tg]?;c=3?cL_9b<W:b];=alK8bLO4d/6g^[fl`<WWk_KjmNOG
c<O6a<?2a<G7]KVn_KZi_L77b<W:c?k==ko0`/C6bL_<^KNf^Kjo^kJb][g4bloB
djn`Z9bKYZbZZ::c]InW`<2`^[Z]Y:NWXK6]][[5mooonOiooo?Yk?WonNoZi=oN
hNCRh>[Sf]GCdLc7a/C5`[Nb`]W_hKf_a<[2b=C=_:b/^Kjj^JB;QZ?8e<bVW9:E
Y;O3bLk;b/gDemKCZj^YYZVhc^3<bLO:cL_8aLg6`;fo`;fj_Kk0a<O3^k>N/KR`
]<>o[KNgZibM/;fo_/C:blJo^kUo/k6]YZ:U[[NLWjFYZZNSX::RZ:bVWJ>aX9bN
XIV<RY>8QZ2_XJB^XINKZKNdY9^MYiR?TY:<Rhn3WijJ/;BY[Z6CVIZCXjR:U8f7
Q89iJUe/P92DVJ:UWhi_De1EE4i;E69PCT]HF4XhB4eKMG5KF7eeKF]^LG1^QgQZ
JgV6RXQTO7YdKfa^LG5jLfYWJg9hNXJ5PG]fMWYoM6]G@ci0=RHd8aXU=d=?FDM7
BDmEEU5;<Se0<b8Q=4MGC3hf=OoA_lC0bMC8`/C8blk?clk;bLS9cmSQimW>b/oB
d][UfM_Rk_Oei]WniT7ThMkJemWPi=kCblc@clg;bLS9b/[BcLO6b<W7a=;1]kZm
_<39inkfn_GWelc7a/C3`/C5akFi_[fj^Kg1alS9b/cncCNo`<;4a/W;c;Vg][Vn
_k^f/[Jma<_?d]>_/:RLVjJ/ZZRR/kFOYl30/;Zj[JBWYj6a[KJjaOOoooWnOooc
jNciooW_j^COg^7Th^3Zhm[Edm7<alK4aL:g//;Ikn6m[lC:`/SDcKb/[;Vn^[VT
RhJSb=C<YYbBUJBg`lW>bl[=e=OFdj^[ZJJY^<kPc<W7b/g;b<G=a/2m_l2m^[fn
`<C7`k^cW[6h/;C3_jfg]j^LWK2m_kk4b/_6_k^iOk>a[JJRYJjgW9nUZJZWXj2R
XZR/YYfS/J2LWZ6IS8ZCR8JP[j6T[Z6GVjVg]:BKWJNHSi:BS8^?PinNV[2dZJjQ
TiVJTj>XRYB=QhB2NFYMK82@U9VRYIn>Ke=@EEA>BeARH4i;F5Q:>4Q=FgEaFeQm
MFe[KW5`KXMhJV]iQXZ8?7ajM6m/KW5aNW=ZIf]bN7Z6QH5kMWIjOgA[Ed<n@3HV
=2<J9CM3CeU7AdU?EEIABc8m@3<R8CA7Ed`n=SD5_bSkb[W4a]7Fa<g@dmOJfmcK
f=;=cM;Ig^34b<kAc/kGhM?>d=cZjMS7fokL<=_HeMCJi^kXf=3DgMCAcL[:c=3B
cLW6aLS=dM?Oe=;JgmgRkOOinoKZelFie=7=bLKna4O1`l?0_;c3bLW7a<;3aLW;
aLO:cM3Bdm>m_/33`l6k]kFf^Kg1a/W;];:/Y:>Y[ZnZXkBkZK30^;Fo_k:Z[JfW
/:be];[Yoo?ioQOhm_GgnOWel^_Zjo7io_gjnoCZiN;OfMCna7o1^[Be^_koe[[C
b[K?f]_>/j2/cnkghkRFXL;6/I2IZ[k<cL>idL[3`<2n^[FP[Kc0^kNi_JV]^;nh
[:Z`_KZg]kVh/Zfl]kFj`L2fZj2a^[:_];6W`L6gYZB`]kFNZkVn^KFg_:fZY9nN
XZZ`[JJKTi6FWZBRZK2^XiZMYYfMYGna/:JX/YjGZ[:S[L:nYKK<e<N_WIN]UHbG
UX=nRg^IViV_/J>VXY>DShBEWXJ4NgR6UY9gG7J:V9F@TI29RG=LDU5>Ad91BTe;
DUY>>Ci]JFNDTVAHMGAbLG9cMGJGRWafNGioOXnBS85jNGE]MFiWIfecLg9dKfe`
MWMaJV]RCDXi>3lk;S`a:2Tc@E5ME4m9B4U7@C`X>dDi:RdmBDQ1>SPknlZia<KA
e/C=d=?Gf]_LfmSBcLgBfMkPa<S>dLk>en7Cc]3Lj^WHam_ng33Kf=GDf^K^j=S@
e=gDdLg:b/c@d/g9a/G8cM7CgmCBf]oMh^ggnO_fj]O5^MCAcLW6o/A7`L?3`;bl
`lW9alC2`lG9blG7b/g@d]?C_Kk0`l?1^kNe][Vm`LK9bkBb[:BSZJj_ZZ>d^jV`
`;Re_knbZZf]Yk2/]KBjjOocnOhGn?KemoWimO;[j^_anOkmn__dj^GRgmWDo/Ao
`KZd]K[nomJjdlZfcm[Kc[>P[<o^mn>hUZ72a[6@VJZnc<g3^M7:`l30_[ZeX:fl
`;^g^KfY[KRo^:bZ/;fj]kNi^;:]_;Ne^/70]Z^P/KZb[kBaYl71]jJT/;NeWZ^i
_[Ve]kb]ZZBOWZ:Z/:fVVi>AUYjTXZV`[Z>JWJJMWJEo/K2VZ;:NUjZbXjg2_ZFf
c=C7[ifG[IF<UiJ3OX]kVI^I[k6SYZ:CU8n4UIj6Q7]hQYJBMeafRYRET96@RHUc
G59ACTM2@DY=Be9JCSTnKFUWU99TF7EdLW5bLgEfUhYlMWUnOgj?TXb1NWUeKGE^
IfM]Lg=bM6m]L7IgLFY[HTe:>CPo>bhl<BPY<d5AGEA?BDQ9Ad4l:3]5>BX]?DU8
@CXh>o_:^LC6dMK4cM3Cem[Kg=_Hd/g=d]WNh<C8c]7>c]OQdlk@g>[Yf<OKo]``
fmSEe=[Vk^SHd=CMe=7=b/[<d=;=bLK5b<gAdmoDd][OgN;]moWkm^[GaKWDdLg9
a_k4Al73`l2l_<?9bLO4`/?5bL_5al[=d=;Cdkfn`<?3`K^g]KJi_L76bL^d/ZbT
XjV^[jZS];^Y/<2h]Kno/ZZ][JN`[;Fd^^WoloWn5oSfmOOinOGbjn[[lOWnoO[k
m>[Uh]oIe?k4Ol6j];Fjo_oF^]?:]/oJfljcX:c?k_OS^9JQ`/JaT9VZ_/c=`kWA
b/?0`;jj]J2]_<2k]kVmZJfh_kR/Z[2m^[Ng^KRb[Kbg]K[1`;J[X;6j/Znd/JO1
`KNVY;2g]Ij[^Kji]KNl[JZTWijRZ[2]YY^CTIJNY::Y/:jSVYfVWIfUOk6`YZRb
WYNZ/Z>]`[jU]/cDajnMUjfES9NFPgj;NiVKVJnaXjJRTiB?Q9FNQXAkN8JFTWML
MXZHUI2AT8V9LeaBDDi7@T5:CD]BFThi?VeYIiBBI5QeM79aLW=eMYN:O7IiOWmn
Si:<PGYiMFeeKVMWKG=cLWA_KG1fMg5ZJf9=8CTh?c/^?34X:C=1DEeDCdU8BDM1
?2PkACTZ;Ce9B44j>3/5_goodl_Lh>KUcLoAe=SJfm[JgMO@dMOKfMKCh>[Wh=oV
k>3Ec];MgmC8c]3CeMOGe]GBgnSTem7GhM;@c<[:cM7DaLK6al[Af=kNfn7/kNCS
j/_>dM?Ccl[7dm;@c/g=c/o@clc6_ko5blc:aL?3al_?a<O;c]7Ad<o0`lK6`[fh
]RNj]k>`[Zna/kVg^;^j][>d[J2__[Rm_jRb_KjbZjj_Z[>d_kRbg?ohnOh;m_[o
ooklno_cl_Cjo_lOnooilNc[jNCOgMgLf=?9^J[Oo>G>g<Rde?[VcKbmdoKnof;^
dmCUf[g0b]?Dc<6i]];8^k>`/:j[W:6X[ZnZXifMX:NYVY:Yb]7?c<g?c<Fn`;Zg
^l;2^Jnd`L[9a/S6`LW>b[jj`;nf/K[1_K6VY:JZZJRZ[K2a/K^`Wi6<TYjVZ[:f
[ZCnWWnPWZF`/Jfc`JnRZ:>=Vkc2ZKBj/ZBKV9RWTH^IUh5hPGRIWYja[YVH[ijJ
Sh2CY96:P7f=XIn1HhFIYIb@SHb8UhmmHde0>3A5BDeBFUU7<49eL6RBTEm<HF9T
JG1gOH2@SXMjKFU_MVUiP7amPWa]K6e`M7QgLVj2MF]aNW9F>gmICSPV:SXn=Rd`
<34iBeiXH5A6?3Xk>cXZAE50;Rde=c@f?4MBom?;g>3ViLg?dMCHf]_Jf]gGd=7G
fmWFdn3Zin3Oi^cPeLkBgMoDb<k@dmGGemKEd]oXi=OAen7Bd<c:b/gAe<G6a/O:
dMSNg]_Qk>gThn[;c]7Cdlo:am?Bd4c>cLg>cm3?c<Jo_lG;c<[5`l?7blo4al_>
dM7@cl33a/K2_KRf^[Nc/:j_/K>i]kRk^[Jc]:fP[kjh_KnX/[fn/Z^^[jZc];nh
/]con?Wn2oKjooono?_klo;dn_ko7o_onO7/jnWTgmgMg=SCbKVZgocUc]c8]=Cj
i/fl_M?fo_mRk]?DiMZm`<[Ce<c1^KKBb;^c/;2^ZibQZ:j_ZZ>MWJ2WZIZBZL[A
clc=clc5_/2j]k_2`[V_]<7:bLK8a/79c/Zn^/2o][6j`KfaYZBVZZVXZZf`/K6k
/9nAS9:NYZZb]ZjToYioX9jU/;6]/l6_XZRSSI^l`ZVd^[:TViRHYi6;VIN1N85h
VIjN/JjIV:nNVXn0TjBARX1mSJ6OPF>5VJFLT8f<R9N?OF==@3PdADU=DUYIAc12
MG1XTY5OC65RI6U`Mgf0T8j7NVeYKgIYNH1lOH9lKFa]L7AhMg9^PWE[LGYbES]o
FDhh9RXj?SH]<30a>D]NJ61DAS`j>c/j:TEA@2h]=CLd=Sa7D_oCbmcPi^G=cm7D
f=[Kf][Mem3Aem_Ie]?Pj^OPgnK/h=G>d]gOe<S>d=?EemOFeM;Oj>CGdMOQd]3<
b/[=dMC5a/K7b]7Hg]kKhNc]i>?ZblkAdm??b/OCd]1<c/g=c/o@clc6_ko5blc:
aL?3al_?a<O;c]7Ad<o0`lK6`[fh][Zg/k2^[k6c^KNh^kZf/kB]X:nn^;foZ;:m
_[:[[ZnZ/kBo^;;LooSioP_fn_ooo_ckno?bm?[noaokooWak>_Yi=oMgMcHdlVi
Z]oliLkLb;CDn^K=_;gCm_koH^kCe>GJ_L3:dmC<`KVfd/Rk/k2`[Z^LXJR^[jZS
WIfPYjVJTZW:dLo<cLo<aKk0^[Nk`/:i[kC1b/W6b<K1bLk:_[[0_kJa^/6m/JJT
YZZYZ:Z]/;6a^k2OTHbBWZJZ/[J^Y?jNOj2NYK2a[K?1[j:XXhfK_<:Y];ZbY9^H
V:NARiVGPGR1N9VNW[6^VIR_WYZ?P9>TTHZ0OHfQWh5SQIVUW92=S8RGSgeSCD0h
=4E9CE9JFDL`@WE`J9:AGdaQHVAYL7MmP92>QgY]JFmfJGV0O7f2O6e/KG1dN7Mb
KX9eJg5jLUHk95U>>2HZ>Shf;C0`<CU;GVQPE4Hl>S/k>RY5DD0^;CDg=3HlAe85
U@gie=?Vi>OUcmOHf]cMgOkK6mGAeMcLe<[Kj_7Yh^CWi]oEb/S=dLk:blkAeMSn
fWO9dMSFcl_?e<[:bLS9blg?a<S<cLgAf=k?cmKNe/Bm`Kk1algCe]WJbLW:cM7F
f]gCdm7:`l75b/6o_K^m`<G8_;o3a/O5`/2l`<?1^kNg^M3:`KRc/[Bf_;[1c<^n
][NaWj^l^L2nXZRc]J^VZjjY/;6i[jWGoooho_Co8okhooomnogmn_Oooogimn_;
Z[cMkNk_gmOXom>/]n3nookZmogoE_SSblFhZjJbb]g7^JJIUiZNWi24N7R2SY>C
Uhb8RH:8]>SVh]kMgM[Cc;Re];Fh]k:^Y:^d_LC8alBc_Knj^/6o]/[<c<No]kFe
][Ji_lK6`Kbj]k>^Z_jYOkNl^Jn//:jUZjJW[JVQY[>/WZ>HNhBTZjbYV8=nSj:Z
Y9fNZ:NGRHF2XJBQ/jjIV:nOWI5oTJBDPGamSJ6UUXF2V:JMTiJMWh^?QFaFCT]6
EeMIGV1HACA;JVi/P85TCU5>CUIULgYlM7UjL6ARKGY=HfiWIVeRBf=]NGeiLg1_
>WicKWR4OfA;D4Lc8bPi?CDH9Rl^=TaSKUa??SDe>d12@f9_ES`f<bXW;Sa?H?WD
dnKTinG?emSJg=gMo]/KeM7Eg=cDb]_ZlNWRi>OVgmG:b<gAc/[;c]7Ef?kJMlWA
f=K?bloDb/[9b<W;cLo4b<c=cM7Hg/o?e]kFa;g1_/77cM?FfM[9bL[=dMKJgM?C
dL[3`LG:`Knm^kg0aLRl_l?6alG2`;c0`l6k]kNid<[1^;>b];Jl^/7<bkjf]k6O
Zkbi`;jRZ;>eZjJ[[ZV`/KV_ZMOoooSnm?lSo_SooogkoOgjmooooOWgjl^Z_=g]
k^oOenSodjbgh?koo^[goOmFn>?;aKR[Y[;:gLNiYYVGVYjOT8AhN8:>Ti>GS8R9
PXRdj>KRg]gMf]?<^;Fd]KRg/ZjTZkBma<S7a;>m_kZj`Knfb/c<akng]KFf][Vo
a/K1_;Zg/jjZoZUo]kbi[jb`[ZF[YZN]ZJ6V/jbNXiQkQ:B[[:VHPgj?XZZTWIjX
YiN9QH:QY:6c[YVH[inMTGnAY9B1O7f=XJFFQH:HYYfCUYfORhn5K5I>BdIGEeUN
H5Q5=4]ZKVb0PFA>DDi>EVEcNWadNGY`I69]NTeSKVMVKF9;HfeiOGUcL6ljOW=^
N8AoI4]@Ac<S:3Tm=APV;bhfC6=^G4ln=CDk@493HVmF?3Hc:RL^?4mPnMCCi^CW
iLoGf=[LgMgnfa_EdMGLg=C:fn[ajN;TinKOeL[8cM7>b/_>dMGHo]YgbM7He/o;
cmC:b/W8bL_=clC8c<g=dMSNcloFg]K4_L6n`LO=dmKIf/W9b/gAe][Mdm?Ab/?1
aL[1_kfk_L35b;bo`lK7aL;0_<33`K^g]kW@b/6h/k:d][bj`Lc;_[Jg/In[_;W0
_Z:X/kF[YZ^^ZK2a^JnYeooon?kdob?nn?oooO_moO[gooomnOO[bjZlgNg^kmoG
j?oC[;OPo_onj_OmoeKhhl_5^:^V//[MakVVVINJWYn@Q7QhPXjCTiN<R8V2R;CX
i^;NgMgJdlbh]KBe^;Nb[ZB[];g4b<O4/kfo^[[1_kK:c<c7_kNe]KJf^Ko6a/6l
^[Nc[Z[nZGng_;V_[;2^YJ^VYjfYXJJc[9jSV7^4Y:^/ZIR3OXnRZZBMWZRWUhV5
PZ6TXK>^VIR_WifAOi6TU85lOHfQYIJ5PYRVWI>FWIn;ShE/ETi;AUMGFEiPF4Dd
BfY^K821I4iACTiFIG=jO7AiNW1THVejCF=^IfI]HT]SKGUmNG=`KbanLfihQ7mT
Be17<b<X>Cde62H_;SI<HfiLCche=C]0@T=RKeHl=S<Z9bhlCf05/b_ee=CQf=[P
dn3Qh^?Rh=gLgMSHh>SUe/O?fmgBd=SHd<o;alC5al[<cLoBeOkF:=G;cLk>blS6
aLS:c<k@d<o>bM3FeM3=d=C6a<S;_jbX/:^a^/75a<2mo/T<b/c@dmK:c<g9`l75
bOjh?;Zl_l?4^Kc0`l:n^KFi_/;0_;c2bM_Db/6m_l?7_[W0c/fm]KZcY:jeZ[:m
[Z>_/ZZW[[:^_[6]XZGJooWio_ko4?gimoGdookjnokoo?Woo_[koOl1n?kmoa7M
/JnnjOokn?W[h/:dd?Com^gmogoWakNhXi^FVjc4f>?B_J29PH>8Rh1dIf9ZNHN?
QgEgSinWa>WWhMWEe=3:a;:e^;Jb[k2bWI^P/;k2_KNRZZ^UZ;>g/KRc[jnc]kRg
`l2n`/S9`[^g^[g0`L2m_<?3^[:kc<Zj_KRj_KFXY[2/Z[biUi:SWjbYV8F8WJRU
U:2XZWn[YiEoS:FPV:Z/WjBQVJ2IQI:OS7MfN7n9T9:AL8NFT8ZEYZmmPGYZIVaW
FU5AEEaMED]5FUU/N75fN6AGBd9:GVmdLVIWJ6U[LW^2KX>9NGJ0MUiLJgUhJfAZ
M6IXKGElOW]gF5=4=SLn=bLQ<SHY9ceFHEA:?SPi?T11BVmnI3A9@c`]9b/fAeWe
e=CQf=[Pdn3Qh^?Rh=gLgMSHh>SUe/O?fmgBd=SHd<o;alC5al[<cLoBeOkF:=G;
cLk>blS6aLS:c<k@d<o>bM3FeM3=d=C6a<S;_jbX/:^a^/75a<2mo/T<b/c@dmK:
c<g9`l75bOjh?;Zl_l?4^Kc0`l:n^KFi_/;0_;c2bM_Db/6m_l?7_[W0c/fm]KZc
Y:jeZ[:m[Z>_/ZZW[[:^_[6]XZGJooWio_ko4?gimoGdookjnokoo?Woo_[koOl1
n?kmoa7M/JnnjOokn?W[h/:dd?Com^gmogoWakNhXi^FVjc4f>?B_J29PH>8Rh1d
If9ZNHN?QgEgSinWa>WWhMWEe=3:a;:e^;Jb[k2bWI^P/;k2_KNRZZ^UZ;>g/KRc
[jnc]kRg`l2n`/S9`[^g^[g0`L2m_<?3^[:kc<Zj_KRj_KFXY[2/Z[biUi:SWjbY
V8F8WJRUU:2XZWn[YiEoS:FPV:Z/WjBQVJ2IQI:OS7MfN7n9T9:AL8NFT8ZEYZmm
PGYZIVaWFU5AEEaMED]5FUU/N75fN6AGBd9:GVmdLVIWJ6U[LW^2KX>9NGJ0MUiL
JgUhJfAZM6IXKGElOW]gF5=4=SLn=bLQ<SHY9ceFHEA:?SPi?T11BVmnI3A9@c`]
9b/fAeWee=CQf=[Pdn3Qh^?Rh=gLgMSHh>SUe/O?fmgBd=SHd<o;alC5al[<cLoB
eOkF:=G;cLk>blS6aLS:c<k@d<o>bM3FeM3=d=C6a<S;_jbX/:^a^/75a<2mo/T<
b/c@dmK:c<g9`l75bOjh?;Zl_l?4^Kc0`l:n^KFi_/;0_;c2bM_Db/6m_l?7_[W0
c/fm]KZcY:jeZ[:m[Z>_/ZZW[[:^_[6]XZGJooWio_ko4?gimoGdookjnokoo?Wo
o_[koOl1n?kmoa7M/JnnjOokn?W[h/:dd?Com^gmogoWakNhXi^FVjc4f>?B_J29
PH>8Rh1dIf9ZNHN?QgEgSinWa>WWhMWEe=3:a;:e^;Jb[k2bWI^P/;k2_KNRZZ^U
Z;>g/KRc[jnc]kRg`l2n`/S9`[^g^[g0`L2m_<?3^[:kc<Zj_KRj_KFXY[2/Z[bi
Ui:SWjbYV8F8WJRUU:2XZWn[YiEoS:FPV:Z/WjBQVJ2IQI:OS7MfN7n9T9:AL8NF
T8ZEYZmmPGYZIVaWFU5AEEaMED]5FUU/N75fN6AGBd9:GVmdLVIWJ6U[LW^2KX>9
NGJ0MUiLJgUhJfAZM6IXKGElOW]gF5=4=SLn=bLQ<SHY9ceFHEA:?SPi?T11BVmn
I0Q9@c`]9b/fAeT5`Wooh=kUf=_YhmcMgMcJemCBhn3Rk?Kbg/c7d]35a]?Ca/S<
clo=c];GcLk@dM3?cL_Fd/o>c/_4_Lc@e=SJf=KDd=SNfm78alW7`lC6^jnc`:Vd
aMCLfmC?eM;>bLG3`/:n`lK6`l;5bL72aLS<cm7B_L34a/Bn^;>k`<G4`/KBgBO;
aKbe];W1al2g^/S7]k:k]:Rb/9ZS_[jU/KJ_[KJk^=k2/:B_ioodnOiooogekncX
i>7PgM_Pj_7dm>OShNC[lO;`en7Zm_ooiKJYXmKnl?Ole;o=j_oolO;ok][=`jVB
XLBDUjS6hNC>]_GJ/i:1OH22MWMfM79fOhIlKh>kgmkIhNKNe<k;b<:m_/G;akjj
_lG1]kO6e]O;`Zb`ZYnQ[kNdflo3`LS>c<QoaKff][Zk]Znk^[Vk`<O>dl[6^[C8
hN3<bl[@e/nn^;jg`>;YaKBeYj2XYj2TZY^1LhbIUIRMR6N?XiJ9W:FR[YnM[J^G
WZB=RHN0LfMSJ6iOMXEoNhVO[8n;NVY/M6A8>Ca5DEICE5QNAVAkHFZ3LVMD@dQN
L75[KVIQJGV6RHIoEfmeJ6j5QW=GJ7E^G5IVN6E_MFmSHFilIF=JCDU5<QXlBTDY
6ba4Ce=<@clo?SXf<UaaFdE3?Bd/;30kBooPg^GHfnWSg=gMg=[Ge=;Sh>;/m_;N
c<OBd<G6dm?6b<c?clg>d]O=c]3Ad<o=bmKBclk>blBmc=3Df=[He]C@f=iTfm78
alW7`lC6^jnc`:VdaMCLfmC?eM;>bLG3`/:n`lK6`l;5bL72aLS<cm7B_L34a/Bn
^;>k`<G4`/KBgL_5_;Fd^L77`;Njb<Ng/[^dZ;:`VZ>n_ZFa]Zn]][^hg/:`Y:oW
ooCioWoooOG_k>SThN3Mfn3ZlOCdin?Qi>_al_3GhN[foooU]ZVSe_k`mocD_lgZ
oooal_o^f/g3ZI:Qa9BGZ<KQi<jfmMZcTX5mP89fMgIdLWIoQWa_Pk_Og]WQi]kD
c/_8`[fnaL_7_[ZoaL6g]lKFel_2[;2ZWj6_]kCKcl?1b<k<b7o5_KJf^[^f[k^j
^K_0alkCb/Jj]<SQh<c;b]3Fckjh_[O0h^W5];FWX:RWX:BZVh5cS9VEV9f8IhnS
UXVLYJ:^Wif]ZiNNY8f9Qh1cIf=XKUmfQGmkRIn/Sh]jJVadI4Pi?4EAEU=DF5i6
I7]QJX=bIeA3B5i`LF]^IV5YNHJ9QWmGKgEXKXF6LeMXMFiLEVIhIFmeKf=QKWaU
HeY=BDDb6Sa:ABTK;4A?Dda3?cln>SHbG75KAD<m;B`/<3];on3NiMSKjN?LgMgL
f]ODd^?Ph^cfl]k<am;@aLKCdlK8c<o?cLkBelg>d=7@clg;e];?c/k;a;g<d=CH
f]SFe=3HgVCKdLS7bLO3a<Jk[k?0ZKC5e=cKe<oEd/k9aL?2`[k3a/K3`/G9`L;5
b<c?dM:m`<C6a;jh/k_0aLC2a];MblFl]KBi`LO0]k[8akNb^kBX/[2JXkjnYK6f
[jff^kSN`[2T[nOom?WnOoommNo/j>CQh=gKh>[am?CWhn7Tjo7bl=OQj_KoonFf
ZJ?Fo_3go=BocN[ooo7bonkJcL>YTZ74U9NXa^7Tc[Kef[>BPGf0PWIgMWAbMWn6
O6n3^moNfN7Vg]C>blS2_Kk5blNn^[o5`KNga]KGbl://:ZOXJng]=_?`l78c/c8
OlFm][Jj^kJ_^kZi^l37c]?:a[Zdb>7Pc<_:d=K?_[Rn]l3RjLFd]JNPZ:NPY:ZK
PG><VIFHWHQWSj>FRIbUXZjOWJf[UijTSHV7P7=WHfQ^GgJ5Og^9Wjb?RgYZK7AT
B3TlAE5FDeAHGTITNf5ZPg9WE4=8GW1aJfiVHFUiQXV6?5M_MFQ^QHIcEfQeKUaF
IWQUKgE_Hf5^O6ESFTe9AC8J?4Y5:A//A4mCC4<o?chj=S9LLE]5@cd];2``>d/5
dBCohM;RiM35cKk4cm[RiNKUf=GBdmGEdm3TfLVm^/7<e=?Cd];Ao]1ob/_=c/k<
b/W?c<S5a<?2`;O0c]cSi>3Mf]WGe=7>c<_Dem[Ie=7?d=3Ae=KGemKEeM;>bl[<
cm7:d=KEdM?Ki>7Ke=;DeM;>cm?Dd<S1`<76dM_Ic;jh]kjZXk:m^kg8h=oGb;Vc
^<2h/ZVQWj>[//:IYK>LZ;jW`LR^T[SoonYof/^i];c9dmK=bL:fYiF6OJFd_;Je
`m3D`;Rfa=_ZjN;DgN[fn_K^j;^]^nGjjn3Vgm[Gf]kGa[NMUHf=UZ6Z[XZ/fogo
oo[eg<c4dN3@Wg5^HeaUMh5lLXF_h__fjNGXkNcZinCQgmk[kO7bl>[Sgm;@clk?
d=;Da]OB][35c/=o_lKCh>CJb;Vj^;FaZjFPWJJXZjjb]KRi^l[EeMKGc/2leM[3
^;nfX;_<h>KNdLS6_[R]Z[BiXhIeMX2CXIA`DI:HUHf@W::NW9FZT8^KOh9_Z[::
MFe[NHIRLYF8LG9cF7NSWgEYJE0fAE1;?CU6EU=UJ5=3D6j3G4a3Hh1UEGIYX8Ig
QZ2//;9aKV][KgAfMfM5@fUgHUmdK6]/Kg5aKV]OB5U=Deli>UQ7<R<P9R``ET0a
<cLf>D0fB5QGAC8[:c/k?Ci0on7Bh^G@aLfna<oJh^GViMSEd]?EeM?@i=W9_K[1
c=CCdm;BdOk@Ol[;cLk>c<[9clc8aLC3`/2g`<kLhnCPgM[IemCAc/c;e=OJfMCA
cm3@dMCFemOFeMGBc/_:c<oAb]3FeM7CfnCQfmCBe=GBc/oCe=38`L31a]7KfLbn
^;NnZZ>b_K^mb>3OelRi/kS0^;:YXInSZk;2VJFcW:RnYl78[Y:hoooZOm[;^KBl
bM?FcLW2]ZNEQWfU];bf]L?@e<2h]/CKj^WRe=gZm_[fk^Rk[K_Un^_Pi]oJem[N
elJgWIF=SIJQZZj:[=_mooojmMc<a=7Pd9maKV=LIGN1O7:5[n;km^WUj>g/j^OT
hMoNjngal_3ZhmoBd<o>cm3Be<KGd[J`aLk3Oko6dn3Tf/Ri^[Re/J^UX9fVZ:^^
/[Fh^K_:eMGFelk0_=GJ`kRo]Z2kc>3Vg]78a[jh[JZd^J>6MGJ0Tj6DL56BV9F=
T9bRWYbEZY2;Vgn2KjZbRWE]JgV6HW:ER75bLeQgXimeJFU@=TE@BcdiAUICIFQC
@e1^Pea<@f>0IEEfJJ26MhJP[;2bLFi[JfmdMWMWAD=YMf9OM6a[K6maLFi[GdQI
CE=O>CYHAc8S82H/<5I0<C<g=SU0=TQHEdDb:b/k>cdn@?oQd^;Ud<G=_/C?f^;U
i^GHeM;CeMGCd>CIbKfj`LcDdm?Bd]7nd7o:blg>c/c:bLo<b<G4`l;0]l3>g>?T
h=gJfMODdLk<bmCGf]WDdLo@d=7De]OGe]GEd/k;b/c?dL[@e]GAdm_ThM_Dd]CE
d/k?dmC@b<70`LKAfmW<_[Rg_ZZS/[fk_LSPgmO8^K>h`;RbZJ6OXj^b`YVU/ibX
_ZO1b:jB^?oojWoJbkVd_<WCe/g9`[JWUHImYKBl][G3d=C0^;K4fn[Yh]CMj_Kj
m^kX^jfkiO[[h>KOf]OJg]O6]ifESHfFXJZ^RZcKoOoon_GLc<CAh=2OLFiSG6Eg
PGabQJoRnoKYiNS]k>[Wi>7Og^_]lO;`j^?Od]3?c/o@d]C6em:f/<G>`gnoa]?P
i=[8^KZh]K6[YJ2MYZR[[[:e^;Vkb]GEe]O>`;cEf/>h_kJP^lcPi]kAb<Jn^:fZ
];VSQWEfP9>QU71ATYRESI2LXYjLUJZ@Ri]oPVnZ/XYeKF]iQV9bUHQaLW=HMj>O
MFUYD3I5D4/m>DIFDfEXDd=@KX=LC4=SP6EEMTBPQWN6X:b`/W5^Jf]_M7IgIdE3
JGMRGgA/Jfa_LG5^Jem8FDeCGcTjF4Lb8b0V;31F@34c=cHi@3I8F5M5<R/[>c/m
?T05_aongm;QiMC<e<kAeMSHeM3=e=CFfM_KfMKCcl_8b<cBe_WDOm;Cdm;Ac/[9
a<[@d]3<b/Zm`lgEf][GeLo?cLc:b<O6e=GFe]GDe]S;c<oAd];Ad=oLem7<bLO6
`lS<b/K5c=;BcLK5alO5`KBi_[nm_;o3^ko2`;bh]kRj[:bnbLG4bkg1`kng/kNl
/:fZZZja/K2_WYnUYkg>`[c0[ifhj>g@8/FiZjFWZZ^Y];Be^;R_Wi>^Zif;S9fZ
Z[71fNggn_Whinkho_lcn_K=[JG2eLZl_;o3a/Bn]k6^THV4Rj:of>Jha]geooom
m?7Tf=[Uk>SQ^JAoFTQEN9G<iOkoOo[hno_jnOOfm?;bn?[moogglNgMg=_Jf]_M
gmkakmWFjO7Ve=SOinSNcKnn^[>^Zjf_/YjPXjJZ[[6b^lC5_[k5`kZ=[;ji_m?E
a/WFh^7C`[VgZk>e/;6h]:VgXhYlPIBZ^:^[X8j:U9ZFZYj]S8:@M7Q`XZR=S8f7
SG=/PI67HXEjEeYn^/bXQf0Y;Rh[9RHcB5U@Ig=VFfElS6MHCFZ8LVF7Hf=`QHb2
NgaQFEEPLGUbJ7MFBfAgKfAUKWEjMFURHfMCB61=ADhfAemDAd12B4a>C3/b>3dj
>Chb?da<@34X9_he8C@do]oBhNGDc=C>dMGHf=G@cMCDe]WKfmWFdlo;b<S<d]Ki
e7oBdm?BdLk:bLC:d=;@c<[:_L?=eM[JemG?clg<b/S7a]CEe]KEe=KHblc?dM;B
dM3Og=OAc<W7a/?8c<[6aLcBd/g6aLO7aL6d^Kjo_Kbo`k^o`/2l^;Nh^Zb/_/W5
a<^m`L>o]k>g_;2]ZZZ^/K6`[ijOYJNmc/:l`:nM^>S]d2;5^J^UYjZ[ZKBd]KRh
[inC[Z^MRhbMZZZa`MW]mo[in>O^n?ko<o[fcJfU`]G:_;bo`lK4_[Na[Y69Q8^R
_mSV^<KMmOoooOCai=SJiNcXhKVTOeY8EGREc>Gnogojn?_kn_Wgm_Cbl_SjoOom
mo7]gMcKf][KgMoNlNoIe^Wai]CHgnOXg/fo_[Zc[Z^][k:NX:>VZZja/[_4aKjn
aL>jSJbn^KoCeLK9e^;Qdl:i]j^c]K2a^;BY]j>:O86DZ[R[Zj2>RYBJUZZN[Hb2
T7AhL::XSHb=QhecK86AQf:5NUMJO[[<Z8MP:Bh^:bHV<dQID6McIU]UO8aWF4eZ
R79UQf=SL8F<PW]lHEUEH75iLVQgET]TMfmTIFieNWEYHV=WDdQPCDE>=TMOE4M0
@TQ<CT`k<SPm>STn<Sm<C40a:2Kn=B4d=?kOd^7Ue<cDc]7Ef=SEd<gDe=KIfm_I
e]??blS8c=;FnMAod]?Cd]7>b/W4b]3Bd<c:b[g3cMGJf]OEclo=c<[8alKDeMKF
eMCFf<_<cm7Bd]7@gmcGdLc9alK3b<c:a/G<d];=a/G7alG1];Vn_kfl_l>k_l;0
_;Rg^;Z/[;k9aLC;_L73_kNc]kb`[JZZ[[6a/:nNWjFW_Lk2_<2_WKSXkM0RaKV[
YJNZZjVd];Fh^:nOTjj[WH^<WJZZ/L7IkOOjnOSWk_Snoc?jm/f]YL;Eb[bl_l?6
a;jg/JjARHB;X[oHi[S6gOGooogdlNCHf^G/j>6iY7mJB5EhULcUo_mon_Skno[i
moKdl_;hn_gooOOakMgLfm[JfmgOg_7_fMKYlNKDf=oWj=k=_kjj/jj[[JnbWZ2S
YZZ^/K:ka<Fn_/G3^Xf/_[VodmG6bMKRhM?2^KN[/kF`/KRdZKNSRWb1U:ZhZj^P
SXZDVYJZWZf<PY1dN72RZ8f<SHN=Lfb1THMRQGYGFWjjc:R7H2T^;R/V9S=8FE1W
LfIKIGb<IeQ=JXQbIHMSHg25S89kO65IEF1aNG9XMeI;I7M_I6E^MGYeJF9SIe=8
H4e5CSI7GeA7@498C4i<>c8h?CXi?S8oC4a0<BPVoSD1=3@5M1ojh=GPiMSCfmWJ
fmWEc/O3d=GLh^GTh]oIfmkPh=kJf?kIo=XIdmCCd/o<b<GGgnGOcknf]<G7b/c=
c<_:dM7kd7[Kf=CAd=;De/K7b/c=cLc;fm_IeM3;a/>m`<:o^[Rj_Kjh/[6c]K:_
Z:fd][Jh_/>k][:c^Kk1`[bd]/;7`;Zj/;No`/2m_Knm^KRnaLJm]<gD^9f^`;^h
^KRa[[S7a;NZYJ2PY:NUXj^XZK>m^:>@W9J6N7nDWY^Pa_Glo`7io?_o6no3YK31
_kRh[KJl]jZTZ[:UXZBbbnOmongWi_3noa7eooofi]gQl?kom]NUP8Nhi__/ogok
n>g/j^WYj^_/g_7einGdnNoUi>GWi]g>`lBn][6b^L?9/;6d^;c0`/Bg^K6RXJba
[XfX^;Bf`/2bZ;>l^ZjSXJ>N/;FST8nGVl>jZYZDX[cAc/ZiXINNXinMV:nDRHmX
IGBEThZR[9bFL7fCTHZLRDTcD9?4`Jin?DTl;RT`>WI0@FUhNF9>DfA`IUI5FWIS
FGUYJFe[H5Y^R;ZOPGEhM69@HT/i@Ui`JU]SKgQ`GUAIHe5?K58nASiOFEIDEeiS
Hf1LCdU<AcL[:Rhe?T90=bhW;B`[:BOjh=GPiMSCfmWJfmWEc/O3d=GLh^GTh]oI
fmkPh=kJf?kIo=XIdmCCd/o<b<GGgnGOcknf]<G7b/c=c<_:dM7kd7[Kf=CAd=;D
e/K7b/c=cLc;fm_IeM3;a/>m`<:o^[Rj_Kjh/[6c]K:_Z:fd][Jh_/>k][:c^Kk1
`[bd]/;7`;Zj/;No`/2m_Knm^KRnaLJm]<gD^9f^`;^h^KRa[[S7a;NZYJ2PY:NU
Xj^XZK>m^:>@W9J6N7nDWY^Pa_Glo`7io?_o6no3YK31_kRh[KJl]jZTZ[:UXZBb
bnOmongWi_3noa7eooofi]gQl?kom]NUP8Nhi__/ogokn>g/j^WYj^_/g_7einGd
nNoUi>GWi]g>`lBn][6b^L?9/;6d^;c0`/Bg^K6RXJba[XfX^;Bf`/2bZ;>l^ZjS
XJ>N/;FST8nGVl>jZYZDX[cAc/ZiXINNXinMV:nDRHmXIGBEThZR[9bFL7fCTHZL
RDTcD9?4`Jin?DTl;RT`>WI0@FUhNF9>DfA`IUI5FWISFGUYJFe[H5Y^R;ZOPGEh
M69@HT/i@Ui`JU]SKgQ`GUAIHe5?K58nASiOFEIDEeiSHf1LCdU<AcL[:Rhe?T90
=bhW;B`[:BOjh=GPiMSCfmWJfmWEc/O3d=GLh^GTh]oIfmkPh=kJf?kIo=XIdmCC
d/o<b<GGgnGOcknf]<G7b/c=c<_:dM7kd7[Kf=CAd=;De/K7b/c=cLc;fm_IeM3;
a/>m`<:o^[Rj_Kjh/[6c]K:_Z:fd][Jh_/>k][:c^Kk1`[bd]/;7`;Zj/;No`/2m
_Knm^KRnaLJm]<gD^9f^`;^h^KRa[[S7a;NZYJ2PY:NUXj^XZK>m^:>@W9J6N7nD
WY^Pa_Glo`7io?_o6no3YK31_kRh[KJl]jZTZ[:UXZBbbnOmongWi_3noa7eooof
i]gQl?kom]NUP8Nhi__/ogokn>g/j^WYj^_/g_7einGdnNoUi>GWi]g>`lBn][6b
^L?9/;6d^;c0`/Bg^K6RXJba[XfX^;Bf`/2bZ;>l^ZjSXJ>N/;FST8nGVl>jZYZD
X[cAc/ZiXINNXinMV:nDRHmXIGBEThZR[9bFL7fCTHZLRDTcD9?4`Jin?DTl;RT`
>UI0@FUhNF9>DfA`IUI5FWISFGUYJFe[H5Y^R;ZOPGEhM69@HT/i@Ui`JU]SKgQ`
GUAIHe5?K58nASiOFEIDEeiSHf1LCdU<AcL[:Rhe?T90=bhW;B`[:BL5V1olj=gQ
h]WGgMOHf][Ie];@c]STk>k[jNSYj^_Yi=cDcok@o=41blcnc@k;b<ORj>[MakF_
/<[9a/Cm`Wg>c/o@dM?Ce>;Jd<[:blg=aLO:c<g<bl[;cM3BdLg9a/31`Kjj][>c
_[Vc/[Fg]K:g^[jm^kc2alg4_/;=e=;>`kfh]K2YXj6g^Kfn_[fn_lW1^kk6b<2f
m?oAW[O1ZJbo]kBj^[:`]:fZYZBUYjVYXYRDX;:eY96EWYjEU:3nZ@G=m_oon_gj
ob7no_oI]kBmaM3M`/G7`[bl`l_LgN7[mokooOolmOCjo_gjo_l:o>WJeMO`nooj
kNgno`?kmoSko_l1oOkeo`CknOWhmOkcOoGfe^O^iN;Zj^;Vh]oNgMS?alc7`[o0
a/kCb<W<cm;EemW5a[^[Z;:h]KO8clBj]ZbMT9^VZJJW/;VY^;VTT96LX[Bd/JZR
Wj>XalRmZjB[[:IoQJbMUIAREWB2MgfZ^Z6AS8ZCSh^OUF0V8TUlUjNEIDa0=ci<
CSd[TIR=KeUOKW9oHU8kAem@AVAjLfaREEIbTk6DKeMBDU1;Ng5F?dUUJe]EGF=Q
FEEHGE19HDHfA41SB4Y@FV=UGeUNF5QME3d]:B/]<c]1@3Pa9bLV9BClj=gQh]WG
gMOHf][Ie];@c]STk>k[jNSYj^_Yi=cDcok@o=41blcnc@k;b<ORj>[MakF_/<[9
a/Cm`Wg>c/o@dM?Ce>;Jd<[:blg=aLO:c<g<bl[;cM3BdLg9a/31`Kjj][>c_[Vc
/[Fg]K:g^[jm^kc2alg4_/;=e=;>`kfh]K2YXj6g^Kfn_[fn_lW1^kk6b<2fm?oA
W[O1ZJbo]kBj^[:`]:fZYZBUYjVYXYRDX;:eY96EWYjEU:3nZ@G=m_oon_gjob7n
o_oI]kBmaM3M`/G7`[bl`l_LgN7[mokooOolmOCjo_gjo_l:o>WJeMO`noojkNgn
o`?kmoSko_l1oOkeo`CknOWhmOkcOoGfe^O^iN;Zj^;Vh]oNgMS?alc7`[o0a/kC
b<W<cm;EemW5a[^[Z;:h]KO8clBj]ZbMT9^VZJJW/;VY^;VTT96LX[Bd/JZRWj>X
alRmZjB[[:IoQJbMUIAREWB2MgfZ^Z6AS8ZCSh^OUF0V8TUlUjNEIDa0=ci<CSd[
TIR=KeUOKW9oHU8kAem@AVAjLfaREEIbTk6DKeMBDU1;Ng5F?dUUJe]EGF=QFEEH
GE19HDHfA41SB4Y@FV=UGeUNF5QME3d]:B/]<c]1@3Pa9bLV9BClj=gQh]WGgMOH
f][Ie];@c]STk>k[jNSYj^_Yi=cDcok@o=41blcnc@k;b<ORj>[MakF_/<[9a/Cm
`Wg>c/o@dM?Ce>;Jd<[:blg=aLO:c<g<bl[;cM3BdLg9a/31`Kjj][>c_[Vc/[Fg
]K:g^[jm^kc2alg4_/;=e=;>`kfh]K2YXj6g^Kfn_[fn_lW1^kk6b<2fm?oAW[O1
ZJbo]kBj^[:`]:fZYZBUYjVYXYRDX;:eY96EWYjEU:3nZ@G=m_oon_gjob7no_oI
]kBmaM3M`/G7`[bl`l_LgN7[mokooOolmOCjo_gjo_l:o>WJeMO`noojkNgno`?k
moSko_l1oOkeo`CknOWhmOkcOoGfe^O^iN;Zj^;Vh]oNgMS?alc7`[o0a/kCb<W<
cm;EemW5a[^[Z;:h]KO8clBj]ZbMT9^VZJJW/;VY^;VTT96LX[Bd/JZRWj>XalRm
ZjB[[:IoQJbMUIAREWB2MgfZ^Z6AS8ZCSh^OUF0V8TUlUjNEIDa0=ci<CSd[TIR=
KeUOCW9oHU8kAem@AVAjLfaREEIbTk6DKeMBDU1;Ng5F?dUUJe]EGF=QFEEHGE19
HDHfA41SB4Y@FV=UGeUNF5QME3d]:B/]<c]1@3Pa9bLV9B@5_`_om>OSgmSGg=;C
eMOnf1KGdmo/lo7]kNk]j^GOfM??cLW9b<O6aOk40lO:c]7ndWoHf]WAb<G;dl[8
a<2o_l31`/;4aLO9b/_HclG3b<k?cLW;cLo@d<o>a<K9bl[7`[o7alK5a<2j]/S3
_[k1`l:o`<?5a<;4b]7Je=7EgMkFcLC0]:JNWZ:S]K6^[K:h_/73^Jn^^<?8b?Go
c:?3ck_2bK^g_kba]<;1^k2UWYjSYaFNShF?YK>^XjFk`jnLXk_=f>CcnocloOl1
o_gno1Wmn^K?_kW2g?OZh][JhNSYioonm_CfmoKcoOko1OSen_ocnoko3__Zg/C8
e>Wnooomoo_hnogo1?Sin__mo_l0o_go7Oglnokln_Ofm_OhiO7glng]j^GTh=cL
g]kIe=?Cd_cAOlo@dM?De]OHgn?Md<cBdlc6dm_Fd<k:a;W1b<O3a<kI_<?1^;W8
dm>mZHmoOh^IXIZTYj:SZJNMPX:RSXJ:GeUZK5a]YkfTUZR5OH5kQY62GCHbBf1h
NET_9B4_AU17>UAUK61GGFQ]G58lA5mIDVeIFF5^KF5LHE1DFfEbQY^Y@=OE/GIK
JGA]HE]GFV1PF51?>DH_<4LlE4I9DUaTHUUABdYAFeI2=SLU9RXb>Sdi=2DV9bPY
ooCWhmoHemcBdmGGo]PFem?Ok??akNg^kN[UgmWCclg9bLS7a/Gna0?7b/kAo]9o
f=[IdLS5bm?:b<C0_ko0`L;2a<G7bL[;f<o5`lS>clg9blg?d=3?c/C6bL_:al:o
alO6aLC0^[K8`kjn`L?2_l33aLC2a<[Af]CAeMgNe/g4`;BVWYjRXkFa[Zfb^;k1
`kV_[[S3b<SeolbS`lnk`/Vk]knl/KC2`K^`YIjNXjLEWXn5SjFc[Z>U^l>_W:>k
cMSTlo_lo?go0Okmo_`IoO[Vckni`]cgj^;Jf^7XjNOoo_Kdm_Oflogno`GhmO[o
lo_no`kkj]k4b=CYo_oooOokn?_mo`ChnO[koOko0?kmoagmo?_no?[gm_Kgn>Ga
mo?]kN[Ui>3Lg=kNfMCCdm;ldGo?d=7Ce=KGf=oSgM3<d]?<a]?Ke]3>b/Bi`LS7
`lC>fKc3`KRib=?C_JV?Ogn;VJ6JY:NRXjVWWH:2XXj6RUmIJVaLKJNmY9JXQGf1
NhJAPUdf<T]PN7UI;bDQ;dI@AcYDIFaPEeeXKEaB?4AOFE9]FEUQKVeQG65@E5]U
LXJKZD3GeK5fFfUdKF5KEeYPH5Q@CcU6;c17?5A6BE9LI69IDD]:DE]F@SHg9BHZ
<SXm>C@U9RLX:Oodin?Of=OLd]?EeokH5]OCgncclNg]k^gZiMoIdlo=bLW8alK5
o/@3al[>dOkBOmSJfM78aL_Cb/S4`;no`<72`/C5alW:bmS?aL?8c/o=bL_=cm3@
clk4a/W;b/O2_lO7a/G4`;Zfb<>n_/73`[o0`lG4`/C:dM[DdMGMg]K=a<2dYYjN
XZ>e/Jj]/[Rn`L>i[jjh`lS8mOo<Xl??^l;9^kNo_;6d`/6k/:FNWZ>W5Ij?QHnU
/jjSYK_3[ibS^lgHi??ko?cmo`7noOkl6Ogji/no^L;Lmn[Rf][Qj>WWookfm?Kg
m_?mo_l5n?Gjoo?ko_l>nn[Na<SDjOkooogonoSkoOl4n?Wjnogno`3noOlMoOck
o_cjmoKfmoSUlOOckNgZiNCPg=cNg]WDdm?Bo=5ocm3AdmCFemSOhmg@c=;Cc<KC
fmK@c/[4^L78al?4c]Vl`l6h^LSCdkfYSgmoRiVQVZBWXZ>YYif2PZ:>QXYOFFY/
G6fW_JBFZ8EmPG^6TH9M=S9;H7QiFBlU8Bm6D4LjE6E/H5MMJ6eLDSa4GeUBKEUI
HFi]HEaQD5AKIG:6VjTdemFaMU]YM6eQFeMJH61HD4liARl`AcaDATUBG6ARFE5;
BU5KET8f=bDV:S8j?CTd9BHW:2T5QPWoo>oTg=WJgMKFnmEQgNSdm^oZjo3cknWS
h=oPh]cKfMKCd<k=a<O<d]KIfmcVgmG=b/gBeLC3`/;3aLO9b/_<cLk@dM79`Kc1
c]SIe/c>d=;Cdm;Ac<c:a/6l]kC;b/[=clg6_knj]KJj_;^h_;on`DW6cmODd]7B
dLg4_KVk/Z:MZ[Nk^kF_/[c9d]K6_kRf_m;Wm_cZ`K34bL33bl2i_;fk_lRg][6[
Z[6nb;^YUi:JX9fFVkS7/j:fiOko0O_lm?lGo?7LblkYooofk>kjooohooCQem_Y
mooeo_l2n_?ho_l0oOko5OcbhL^g^mG^moKooOcnoookmo_loOkdo`;nnoSnmWog
l_Wno?G`k^k[inCVjngZi]_LgMgKf=GCgMgLfm_JfMWRj>KLf=gJdLG;dM7?cm;E
f=cJcKfc]K^m^[2W[K^k/:RFPWUoRiJJRINQXZF[YYZNSYIaIGIMIEmLBejJ/:2L
WgIZJUiZQXb2DD1<DEePBDDf9R4[>TE:7ciJH5Q>?dD`AT8b?5iQGWIVF5EPIf1J
FTYXT:jk`/W@hNG;UG9fQH]fJ5aMIVEEA5/k@30mFdUGE5IKHfUXGeMIEEIFARdQ
8bPZ;Bh_oRh>9RLY:Rgoo>oTg=WJgMKFnmEQgNSdm^oZjo3cknWSh=oPh]cKfMKC
d<k=a<O<d]KIfmcVgmG=b/gBeLC3`/;3aLO9b/_<cLk@dM79`Kc1c]SIe/c>d=;C
dm;Ac<c:a/6l]kC;b/[=clg6_knj]KJj_;^h_;on`DW6cmODd]7BdLg4_KVk/Z:M
Z[Nk^kF_/[c9d]K6_kRf_m;Wm_cZ`K34bL33bl2i_;fk_lRg][6[Z[6nb;^YUi:J
X9fFVkS7/j:fiOko0O_lm?lGo?7LblkYooofk>kjooohooCQem_Ymooeo_l2n_?h
o_l0oOko5OcbhL^g^mG^moKooOcnoookmo_loOkdo`;nnoSnmWogl_Wno?G`k^k[
inCVjngZi]_LgMgKf=GCgMgLfm_JfMWRj>KLf=gJdLG;dM7?cm;Ef=cJcKfc]K^m
^[2W[K^k/:RFPWUoRiJJRINQXZF[YYZNSYIaIGIMIEmLBejJ/:2LWgIZJUiZQXb2
DD1<DEePBDDf9R4[>TE:7ciJH5Q>?dD`AT8b?5iQGWIVF5EPIf1JFTYXT:jk`/W@
hNG;UG9fQH]fJ5aMIVEEA5/k@30mFdUGE5IKHfUXGeMIEEIFARdQ8bPZ;Bh_oRh>
9RLY:Rgoo>oTg=WJgMKFnmEQgNSdm^oZjo3cknWSh=oPh]cKfMKCd<k=a<O<d]KI
fmcVgmG=b/gBeLC3`/;3aLO9b/_<cLk@dM79`Kc1c]SIe/c>d=;Cdm;Ac<c:a/6l
]kC;b/[=clg6_knj]KJj_;^h_;on`DW6cmODd]7BdLg4_KVk/Z:MZ[Nk^kF_/[c9
d]K6_kRf_m;Wm_cZ`K34bL33bl2i_;fk_lRg][6[Z[6nb;^YUi:JX9fFVkS7/j:f
iOko0O_lm?lGo?7LblkYooofk>kjooohooCQem_Ymooeo_l2n_?ho_l0oOko5Ocb
hL^g^mG^moKooOcnoookmo_loOkdo`;nnoSnmWogl_Wno?G`k^k[inCVjngZi]_L
gMgKf=GCgMgLfm_JfMWRj>KLf=gJdLG;dM7?cm;Ef=cJcKfc]K^m^[2W[K^k/:RF
PWUoRiJJRINQXZF[YYZNSYIaIGIMIEmLBejJ/:2LWgIZJUiZQXb2DD1<DEePBDDf
9R4[>TE:7ciJH5Q>?dD`AT8b?5iQGWIVF5EPIf1JFTYXT:jk`/W@hNG;UG9fQH]f
J5aMIVEEA5/k@30mFdUGE5IKHfUXGeMIEEIFARdQ8bPZ;Bh_oRh49RLY:Rd5Ucoo
oO;SfmgRiMkNgMgNgn7Rj?;im^[Tj>ogm?3[inCRh^OUhMgHdm3>`<?8c=3CdmC/
g/k8bLS1^;^m`LK:cm;Co]`1gMgngWK>a/;9e]kId/c>d=;Cdm;Ad<g8`kjk^KS7
a/O>eMG=aKji]KFj_Kbi`/?2_kg0bM34a<6j/Zf^/:bh]ZNT]<73bLC1a]7JgMc@
dLk8b=Sdooo?][ji/kB_`/2j][c5a;^VZk2a/KO2c;^`XIRDTXj9U[[Dd<OHn__o
1?ghm?cno?l0o_ko2?O/k_coookloOgo2?K[gm_Sl?_oo_ko6?kknocoooScm?Oh
n?ofgLc=h?[on_cmo?WnmoKo0Okno?moo?SfmOKfl??gn??^l?Ccl>kamOKck^?Q
g]cKg=kOl>o]j^KShN3Ni>3Dd]WId]7?cLW3`<G=cLo;^jFFTiJRWi5oNWeeIXZA
V9ZESXZ9WJN[YZBWX9FIR8iXGW9MIeiIA4mmRh68NG5`G4QVQG]eBT=ACUALDV1G
AC0T:3Y;@f5?O81fIThi=cPZ<eAIE6N7LV1OHF1UKUa`RIZIRg]aQXZ6MFIWLWa`
IemNH5a@AE`mA3E4HU1NFeYKH6EWHUe/I5iE?R<I7ci2@cX/92DZ:2Sn:CoooO;S
fmgRiMkNgMgNgn7Rj?;im^[Tj>ogm?3[inCRh^OUhMgHdm3>`<?8c=3CdmC/g/k8
bLS1^;^m`LK:cm;Co]`1gMgngWK>a/;9e]kId/c>d=;Cdm;Ad<g8`kjk^KS7a/O>
eMG=aKji]KFj_Kbi`/?2_kg0bM34a<6j/Zf^/:bh]ZNT]<73bLC1a]7JgMc@dLk8
b=Sdooo?][ji/kB_`/2j][c5a;^VZk2a/KO2c;^`XIRDTXj9U[[Dd<OHn__o1?gh
m?cno?l0o_ko2?O/k_coookloOgo2?K[gm_Sl?_oo_ko6?kknocoooScm?Ohn?of
gLc=h?[on_cmo?WnmoKo0Okno?moo?SfmOKfl??gn??^l?Ccl>kamOKck^?Qg]cK
g=kOl>o]j^KShN3Ni>3Dd]WId]7?cLW3`<G=cLo;^jFFTiJRWi5oNWeeIXZAV9ZE
SXZ9WJN[YZBWX9FIR8iXGW9MIeiIA4mmRh68NG5`G4QVQG]eBT=ACUALDV1GAC0T
:3Y;@f5?O81fIThi=cPZ<eAIE6N7LV1OHF1UKUa`RIZIRg]aQXZ6MFIWLWa`IemN
H5a@AE`mA3E4HU1NFeYKH6EWHUe/I5iE?R<I7ci2@cX/92DZ:2Sn:CoooO;SfmgR
iMkNgMgNgn7Rj?;im^[Tj>ogm?3[inCRh^OUhMgHdm3>`<?8c=3CdmC/g/k8bLS1
^;^m`LK:cm;Co]`1gMgngWK>a/;9e]kId/c>d=;Cdm;Ad<g8`kjk^KS7a/O>eMG=
aKji]KFj_Kbi`/?2_kg0bM34a<6j/Zf^/:bh]ZNT]<73bLC1a]7JgMc@dLk8b=Sd
ooo?][ji/kB_`/2j][c5a;^VZk2a/KO2c;^`XIRDTXj9U[[Dd<OHn__o1?ghm?cn
o?l0o_ko2?O/k_coookloOgo2?K[gm_Sl?_oo_ko6?kknocoooScm?Ohn?ofgLc=
h?[on_cmo?WnmoKo0Okno?moo?SfmOKfl??gn??^l?Ccl>kamOKck^?Qg]cKg=kO
l>o]j^KShN3Ni>3Dd]WId]7?cLW3`<G=cLo;^jFFTiJRWi5oNWeeIXZAV9ZESXZ9
WJN[YZBWX9FIR8iXGW9MIeiIA4mmRh68NG5`G4QVQG]eBT=ACUALDV1GAC0T:3Y;
@f5?O81fIThi=cPZ<eAIE6N7LV1OHF1UKUa`RIZIRg]aQXZ6MFIWLWa`IemNH5a@
AE`mA3E4HU1NFeYKH6EWHUe/I5iE?R<I7ci2@cX/92DZ:2Sn:@FY?ocklN;LhNW/
i>CVj>gbm_W_mocei]oTkNg/j>;IclO1e]??bL>m^;Jj_;o2a<G5a<g0][_9cL2b
]KW1bM3FfM[ig7oPe/oBfmc@a<[<cm7BdM3?blS4`;o1a<O2`<?<e]O@amG@c<gA
e=CAd]7<`kZi_/Bh^;>VVINR[JNh^jbW/[Zgc/[8cMCDcLG?eMG9_/GNm_n/X/>c
ZkV`^;jj/[_:`JZ//[B]Wi>@TXV;SI:GW9nQ]=_nooCZiN3VlOkon>cRgPccm__o
ookkn?Smo__mo_l0n_ko1_kkoooaloSnoa[hl?oon_[oookgl_Cem?Gkooofoooa
fm[eoocno`3nm_l<no[in?Wjo?kooogimokfOo3`m?Sfl_Oom_?bm?SglNcYhm_F
emkVk?Cckn_VhMkLjngVf=KQiN7OfMGAc<[Cgl?7akb[X9nSQHZ3Lf]/JF2GXjRL
Qgj6U:baZibDU8j2NWB<M6mmGV1TGT=2HFAKJ5QfPUU1LXeXJT<nBCm2De=3Bddo
;2TjCCQ>GemLG5I<Od53<cICDdUHM7=lQgmXEeAJFEaRIf5DAd=2ATi=AD=6EUQJ
F5A?CDe6;CTZ=511DeEAD5=JGUiKG5MEDdHh>dQGG5]:<B<T:bTY9bHTo?_ah]cQ
jNcTi>KXkO;fnNogo?GVgnC]kNcXh]W?al7Fdlo9`kfh][Zl_l;4aLG4cL2f3;_9
cL2b]KW1bM3FfM[ig7oPe/oBfmc@a<[<cm7BdM3?blS4`;o1a<O2`<?<e]O@amG@
c<gAe=CAd]7<`kZi_/Bh^;>VVINR[JNh^jbW/[Zgc/[8cMCDcLG?eMG9_/GNm_n/
X/>cZkV`^;jj/[_:`JZ//[B]Wi>@TXV;SI:GW9nQ]=_nooCZiN3VlOkon>cRgPcc
m__oookkn?Smo__mo_l0n_ko1_kkoooaloSnoa[hl?oon_[oookgl_Cem?Gkooof
oooafm[eoocno`3nm_l<no[in?Wjo?kooogimokfOo3`m?Sfl_Oom_?bm?SglNcY
hm_FemkVk?Cckn_VhMkLjngVf=KQiN7OfMGAc<[Cgl?7akb[X9nSQHZ3Lf]/JF2G
XjRLQgj6U:baZibDU8j2NWB<M6mmGV1TGT=2HFAKJ5QfPUU1LXeXJT<nBCm2De=3
Bddo;2TjCCQ>GemLG5I<Od53<cICDdUHM7=lQgmXEeAJFEaRIf5DAd=2ATi=AD=6
EUQJF5A?CDe6;CTZ=511DeEAD5=JGUiKG5MEDdHh>dQGG5]:<B<T:bTY9bHTo?_a
h]cQjNcTi>KXkO;fnNogo?GVgnC]kNcXh]W?al7Fdlo9`kfh][Zl_l;4aLG4cL2f
3;_9cL2b]KW1bM3FfM[ig7oPe/oBfmc@a<[<cm7BdM3?blS4`;o1a<O2`<?<e]O@
amG@c<gAe=CAd]7<`kZi_/Bh^;>VVINR[JNh^jbW/[Zgc/[8cMCDcLG?eMG9_/GN
m_n/X/>cZkV`^;jj/[_:`JZ//[B]Wi>@TXV;SI:GW9nQ]=_nooCZiN3VlOkon>cR
gPccm__oookkn?Smo__mo_l0n_ko1_kkoooaloSnoa[hl?oon_[oookgl_Cem?Gk
ooofoooafm[eoocno`3nm_l<no[in?Wjo?kooogimokfOo3`m?Sfl_Oom_?bm?Sg
lNcYhm_FemkVk?Cckn_VhMkLjngVf=KQiN7OfMGAc<[Cgl?7akb[X9nSQHZ3Lf]/
JF2GXjRLQgj6U:baZibDU8j2NWB<M6mmGV1TGT=2HFAKJ5QfPUU1LXeXJT<nBCm2
De=3Bddo;2TjCCQ>GemLG5I<C453<cICDdUHM7=lQgmXEeAJFEaRIf5DAd=2ATi=
AD=6EUQJF5A?CDe6;CTZ=511DeEAD5=JGUiKG5MEDdHh>dQGG5]:<B<T:bTY9bHT
1K0ElnWOgMoMdlW1cMOGd]GRl?olln_UhOkPOn;Pf<g:cmO>dM7:_kZoaKjj]kW0
aLK5^Ko8d=?BcL[4a<O>eMOCcL_?d]3=c<oCfmWKiOCnook?a<G?cL73d;NSTIFZ
_<2k]kRj_/?8cM3[gm??d];<a;nm^[Rg^;Vjak^XVYFLZ;:n_K^k_lG;cm3@clk=
c<c;eLo0ZIJBWJVK<96L/k:PYl:h^[fm]jjTWJ^^[J>GT9>ITIFHUY>GXjfZY<Gm
omo8dO;Yh^ObmNcQkOKno`7dn?So0oSooo_no`OfoOKgooojn_go5ocjooofn_CZ
gmcUmoo]n_oomnk`m_ooo_go1?koooknoOl6nokno?Sgo?goOogjmO7^gnkloO;Y
jNoblmgHlO?Wl>GYk>WThNCXj^7Ulo7Sh>[^k^cYi=cDcm?Uh/k?iNWHd<[8]::d
[gmGN89ZG6]hLiNHVi5`EfJ7Y:C0Z9jYRXeoShajO8QjFU5TEcU9M6XiBUimMeQT
Ng9HB3D_?De>AT0`?TPb<DI:8ca=IdmKIe@bC3<^BfMUEDaKDUQ[KemCEE1EG65R
GEMBCC<iA3HkCTeBEUMBBdaGHT96@34_?dmD@Ca0BD]9D5e?C4]@EeM>ADYbOeXd
;BhV8AhL7bGcjMoMgmgCbL7=emOBeN;`ooccjnGQo^1oh^3HcL[?elkAdLZo^[o5
_[Zg^L35a/Fi_lS@dm;=b/C4alkEem?=bloBd<g<cm?KfM_Um?koo/o4aLo=`L?@
]j>AUJZl`;^g^;Zn`lS=d>_OdloBd/c4_kfj^;Nh^K[7^jRJUIbX/[jm^k^oaL_?
d=3?c/g<c<_Ecl2YUY:MZI/`TIbc/Z2W`[Rj_Kfg[ZBMZjj]XiN@TiVAUIRFTiNS
[JZTaOgoglSAl^WRio;ek>7]m_ko0OChn?l3n?oonoko1oKmm_Oooo[joOlGo?[o
ooKjm>[Og>Ggongjooogk_3fooonoOl4o_ooo_kmo`Kko_kln?OloOmooO[elNkO
k_cml^WYko;cgMSalnO`iNW/jNCQi>SZhNGclN?Pj^k^k>WTg=C?dnGRc/oUjMS@
b/RdX[B_OeMhPVYLJgQcUiRKTG1GIXNTY<2XWZV:SGn?S7YlR7YJDFAG>DUdJSU:
GWegF6AkLUQ8=BlmCDi6@30nB38aATXS?4eWCe]WE39<<bi;IfEEC5]BF6]_Ge=E
D5ELHF9MEe9=<cU4=S]>CE9FEe9;C5MR@TI0<BloCeA1?419BdU@GDm<Be1GEdi5
BW9oFS@];RHQ7Q`O9O?YgmgOgM?9`LgGem;Eh_3oo??[iN7nh7oRh=S=b/oGc]7A
b[nj_lFn^[Ni`<G6aKVob=3Cd/g:a<C7c]GGdlg;cm;@cLc?dm_IfnGdo_onclC5
clg1`m2gXi6EZ[c0^kNh^[k3b<g@jmoCcm;Bc<Bo_KZh]kRi^/NkZ9ZEW:Rb_[fk
^ko5blo@d<o>cLc<bmG?`:VFTYfYVc2AW;>bX:O2^;Zm_KN^Y9f[[ZfSUi2CVI6E
V9JCUj>]ZZC5oOoOb=7bjN;Wl_G/hNgfo_l1m?Sho`?hoooko_l7m_gfmooon_[m
oaOln_oom_[dj]oLiOOokO[oooO^l?Koookmo`Cnooono_go1__no_chmocmogom
n_Gak]o^o?gbjNW_l_?Mf?7cio3UjNcYi>7Tj>[QiO?ahn3Zk^k/jNCLe<oCiN;>
cnGYf=3:b;BR]:moEgR2JUa[N7>GV9^AL5MVQjBT`:RNZHZ=Ohn<NWb8NUYAI5Li
BGAZ>DYNOGMHI7]bF4Pe;ce=CTI0<3i8<S56BR<lCE5?FfMD<T`c;T]WIEE<Fe9H
JfmODeE@EEaQHUeGDTdc>D@f>di=DUIGDT]<Ef92AT0a;cm?E44l@4U;BE1MCda;
D5MGCTE:LWmJ=2d^9R4N71lU1Jd?mncPg=cIc/CBf]oJdLkGh_kN8MoQhnGVem[J
dl[6bLkCe]SBbLC6b/W4`<77c<g;fMWHemOnf7o>c<_>d<k6_kVoa/W8bLkBe=[N
gMcUmoofg<W7`kJ^/;>/Y:B[][k2alW;c<[5`;c[d[>OWJ>XZJNY[K:h_/;5bLBl
]kJj`<Fm^[Jd]ko7cLK2_;Rg^Kk1`;bdZ9jKX:FKTYZ`[inV_kVi^;Jd/[2^UY^N
ViBBUY^<UZ6TWiZHVAV;V<WoomoEk>OLe=[[n_klnO3`nookn_oknokj5o_loO?o
ooGan_ggooonooonoookooomo_co1OCXhNCanogo0_SdoOko0Ogno_l6o?ooo_ck
o_Ko0okln_Wnn7oQk_Whk>;Ri]OYh]_UgMGWj>g]gm3?h??hj>;ZjMS=cMGFd/Jl
`MGW_<k?_l3Bd/6h_<JdWJjeU7FCWH=`MWYaRXJ6PgI_Q:B?QIMlOZ:O]WJ1NfY^
PWmXE514?DaPFdPmCFYTAe9[I4e:?C0`>d4oCd9EI5=GKgE<D51<Ce=7=UaB@Ca:
DTe;D5QEGVi]GEAIDeMNHfARGEU9<ca5=CYDFEMLHV=QGUmQEUaFAT5;EEM8@dE>
CTI8DUIBCe=HFUA>EG1gGde;?RPU8R0S:OO/h=cLfLk4d][Of]7>en;ngR7OhN?U
i]OJf]?:a/W>dmKHd/W4a/[9a<31alc=bmWIf=OGo]Qoc/c;c]3>a[ni_lK9b<W>
d]CJg]gLiOOom]c9al>f[[2c[:BTZkJn`/O9blc:aL2ljm:cWifSZ:VWZJfb^;k2
aLW4_;Nf^/35_KZf];Noalg6`[bh]kVn`L2l]:RNVj2UVi:J/:nOY[ni^KRf];:`
[YJKWY^DTYJKS9JQY9nJV9TIRiS9oooOeNcWg=CJjo[no?W`l?_ono[ono_nnQOk
o?gcoooelO[mmoooo_ooo_oonooooOklo`Gdj>7TlO_mo`;hm?gno`7mo_ko1_co
ooklnokfo`?no?[io_QohNkin>cRh^KGjN;KiMgEinS]kMo@cn3cn>SRj^WHcLgE
e];6_<7Eikc>cko0d];1^;c6]9f^]IAeTif3L7IjLHZ6QX=fKhBTShFGO7jRWkIf
PG]ZKX9oJ5A@A3e<H5]8?DeZI4MBJfA=BSd`<3]1?dm2EFACEfmeC51@C4mCAcIL
DT4lBU9=Be1HEEi^KEeDFE=GGV=THUeIBC<lACDjE5UGG69SHEiOHEILETI1BeEG
B4=5CTi6B59FDTmCF5YDCUE`Mem=BchX9B8P8bWgk>3Lg=W>a=;Jgm[Ac]ORo]hQ
gn7SiNKGf][Cb/K9c]?Ff=;9a<K:bLC0`LO<cL_IfMSGeokHOlk<blk@c/Jo^Ko6
bLS9c];Df]kMg>GgooKLbLO3]Zj`/jbTY:^f_/;7bL_<b/G0_>_B/inMXjRYYjV]
/[Rn`/G9a;bg][[0aKfj][Bg_lO=a/:l^;Ni_/70_;BXWY^PYI^BV[2_WjJo^KVh
][Bb/:jFVijKU9:FVhbFXJBOVYRI6H^HbOoogmG/imcDf^_jo_cil?3koo_joo_k
o_XGnocmlooomO7joOOoookoookooo_ooogno?l5m>SQi?7koOl2n?Cmo_l1oOkn
o`Klooono?_nm_l3o_cjnOkhOn7^nOS/h^;VenWRfnGMeNOXkNgOd<oPloSXh^[Y
f<g=eMKBa[c1eNNlc/no`=;B`KRla[BM[[FDMI>MPg1fNW6:QXJ3MVn4Y8n5Ugan
XYnfMX5kJVj2OfQDD4@mC61KB3e=JVA7DV]TCDXm<30k@Cm?@UETDeM_MDa@D4a?
DdLfC591?4YBCD]@F5ENKVeME5UCEeiSI69MFDTc?4De>UAIEeaRHf5NGf5FG5I6
@D]EEdQ3ADi>ATQBEU9?DeQJE4iEL7MOCD/n:2DR82<Y1IelooGWhN7MdlWKh>;L
d/kCfn3Ri>CRg]WFd]GHeLo:bL[EfM_Id/g<c/o9`l;7blc;in;Ke]KLhnSNg=_M
g]_Cc<[AfMgKfM_McM[Qe/K<k?ohfKbf]k2UX;Bh^[Jb];k7blkBdlo5^kC?^J2D
VJJ`]9ZNYZnh_/;5][Rl`<?naDBi][:a/k[2ak2a/kBc/:f[Xj2MWInPWIVXWjFg
]j^aaK:`[J^/[k>fU9ZPXJ2OXJF//;Bb[:FSXjRliooZ]jo:ooc[j?;mo`;biOCe
o`3jo_l1mOWmob7io?[en?ofo_gdlo[jl_onn>kWj?3hoookkN7Sl?koo?[mn_l2
noCgoOm?o_goookgn?Gako3enoo_n?kjk^CSi]O/gl:cWYbjg=oI`jnbcn^dZ:B^
]JnWYZV`[Yf;Sjc8V:RYW9f[[9fFWk6TRYVZUfj7SgQUIVEMNgCnKgmjV;NYVZ=o
OJ2O^9fMRF]SKFYJIE13BUAIGfQ<EFiZCeUbKEILDc//<3HdASaDJEiWPXYoKUmL
Ede9CD]=DeI;?3Y3BDmMIf1@CEAJG61RHUmKF5=0BD/a<U1LFEaRJFaWFe9AFEI6
?dA8ASdh?DU<A498CTU5ADU<BTQ@FeYBEGmI@b4`;B/_=Ooein7QgM?9fn3Rg=;>
dm_Ph^CTh]kIe];Ef=G?b/W:eMWKfM;=c<k?bL?2al_<bnORfmKFg>?Xg]cKgMkK
dlc:dMWMfmWKgLgJhMK6c>con=Vl][N`YJ2d^;Zf/[Bnal_>d]??aK^dckVPU9VV
/;BJWZJ_^;k2a@Bf^;c0`ok5A;Vf/[6c^/;7/;6c];>`[J^SX9fMWj2MVJROYKNg
Zk75/[2]Zjb_/kJDVZ2QX9nQYJb`];:/YJ>SZ;cWonZg[l[oo>_Xl_go0_;Um?Go
0?[no`7enOgo8OWln_GhooKnoOCcn_[bookhk^OXl?Sooo_]hN?`o_oln_gjo`;k
m?OmodonoOooo_OhmO7_l?Gkonoho_[^i>?VencO`[>NW;[LgmW3[k;?jkBXY:je
[jNVZK2^WH^?[<RHZ:VLWJ^/WIJO/JB:VJZGKXN?N6EVIEekM?i_OgZH]jVJXgmm
X9nhWIf9Jf=]JUYUD4=:E5UOJ4aEKVY?FG9]EUaC>b``=SA6?5AYGVN2RWm^GeaG
CDU=BdeCET/l>T=9CeeWH51=E5YLH69RGe]HDd19Bc4bD5aIG69YK6MKDU5IETHo
A4Q6?CPmBDa4@TQ>BDE5BDa:B51KFU9EOeU38C0]:bleooGWhN7MdlWKh>;Ld/kC
fn3Ri>CRg]WFd]GHeLo:bL[EfM_Id/g<c/o9`l;7blc;in;Ke]KLhnSNg=_Mg]_C
c<[AfMgKfM_McM[Qe/K<k?ohfKbf]k2UX;Bh^[Jb];k7blkBdlo5^kC?^J2DVJJ`
]9ZNYZnh_/;51;Jh_<33o/E4^KJb/K>j`/N`/K>d/k2]Zj>PWIfOX9fIZ9nU]kN[
/LFb/:f[[:nc]YBJX:6PWj6U[;2d/ZbUXj>X_>Ooj[N_b_oljnSboOl2l^GdmOl0
n_ko0OGioOlQnOcjmOSom_kmm??jn_;oo_S^inS`n?oonngQho3noocjoO[o0__d
mogoCokmooonmoSelNo`mO_okoSnn^kThnKGk=o2/ijL^]cOfL>_//o[]:RT[[F_
YjJY/:jMRhn/b9RXZIbMZjbMUYnaY8ZIZYM^QhmhIFIUGG]doVmoNYRgZIZSOgfP
WkRMWHU[HfeZFVE@@dYDFEmXC5E^JTmILVeFG5<k;30f=4HlE6UNIh::OfiOG5M=
BDe;CE=FBc`j@dU?GFMPD4eDFUaPHV9OFeQC@4U;<C9@G5ULHVU/Ie]BDEUFASm4
B4Hm>3e9C4A2B4i9ADE9C4Y8D5]JDUD7FD<Q<2d[;cD5agCoo>oZjn_SfmWMgmcF
eM_Qg^7Ui^?Kd/cCe][Kf=??cM7De]KCd<g<c<Fm^[k2a<?Bclc<d=SQi]SGfMkS
hmkHhnS]k>GMf]W5d]W?`<CNnMO9_Kc2a<?2_L74`[fl`<Bn`LG7alG1_[6/Z[6l
`;VaYJR^/kOn^@BLWjFZ[_j`8;>e]kZl_KjnX:Zi`/6fYY^VWiZOZ:fXXK6XZkNi
/[O4Y_fU=:NYZZBX[[:c/kBdclFgZ:6T[KF=WlKReKS1hOool>[_n?oon>3Fioko
n_?ooocinO[lo_7io?moo_KWg]gIdmSSi>[VfM?Fd/SFemODdM?JhLk:`K>YZ[G0
f]SIh>W_l>k[kngPd];RloSYf]KKf/k1cl[5`/K?f^;Tj>[Uf]?Be?Oohkb[W:;4
/JbPT8J>Y;QiNWn4QHB7S9>LWY9oNHBBQHb7Ngb:T8Z7R9F<MX>BP6AeNFQKGfAo
HWmnNW9_OjC4]k32XIJVT9ZZYHe/FeaGC79XF4Y=GW=nIFMlO69XOge]LfI9>clk
;S@ZAEaCG7QoOfQOJ69=BUXoCf9VECha;cE4EUY>@418Fe]LFeUGE5=VEE]E;bU6
E5ICDeQMF4Tk@DY:?SPm@3dh=3a?F5AAEDY6@Cm0@dIoB4a>BTM@F4L/>SLf>T7o
o>oZjn_SfmWMgmcFeM_Qg^7Ui^?Kd/cCe][Kf=??cM7De]KCd<g<c<Fm^[k2a<?B
clc<d=SQi]SGfMkShmkHhnS]k>GMf]W5d]W?`<CNnMO9_Kc2a<?2_L74`[fl`<Bn
`LG7alG1_[6/Z[6l`;VaYJP2[[>go[T4W9nUZZkn/22c]KNj_;fn_Z2Z^L;1]ZJK
YYnJWjR]Z:6aZ:^g^K:ga:KmYCBWZJZTZ:jb/k>d]<o5]jRQY:feSIo6h]Fh`N7o
oo3ZkoSoooSPe^Onoo[cooolnOWjo?kanOcoOokfimkMfM?HhnCZi]WCe];8e]OG
e=7Cf^7>b/6cZJZe`=[HfN3Yko3^jno]h=;Bh_?hjM[Ffm[>`Lo:aL;6cm[Ri>SZ
iM[Cd]Cgon>lZibRa;6/X926SZBhNGYoQ8F4QhbCW9jBOgV4TXF<Qg]lRY2:QhRE
S7J3TX1TMGUXFemTOf9oOWYbKgnTa;N``Z6FYY2JZZF=K5]LEdabJ5Q:CEicOVEW
O7aRJ7mmKG=VBC/o>bhd:TELDeahOgmXGfQRCDYJ?dmRIUDn<BleA5IJCT10B5]K
G5]IEeACIUEKEBlYAUAFDe=HGEQ9>d5:BShh?D0m>3@lCeQDDEE:AT4o@4=6OdQ<
CTY7D5Q7;3Xg=SY1ooc_j^_[hm_IgMoLe]GKhMkQiNKSfm;<dmKJfmSCclgAe=KF
dm3=c<c5_KZn`/C3d/o<c=3HhNKHemWNhn?Nf>?XkNcUgM[IaM;Icl34g_WGbKfl
`/C3`[g1a<:m_<34_/75alO5`Kja[:Za_<2i/JFX0Zjc]oji19bOYJZ^o[0P/kFg
^[bm_[jPZ[W2`KJVVjJOVYnX[JRQ/JR[]kVb]lBVoJDdYjVZY:R^/[>c];C?aKNX
XJB]]HfOa^;E^<7Qooo`j^ohooohh=KWo_ojloooo?Win_cnlOWlogonm^ONgMWC
f>?Tj^KIdmKBb=KGemCAdm[Qc/[1/jVZ]L3Jf=WPjNo`k^__kN3Bd^;cn>WJe]_J
c/7?b/G2a/oJh^CXj^GJdm;DmooS_:^LX/Ba[:2@QXjT^7UjOhB5Q8N<TibNTWmi
Q9:5S8MkO8Z@RXN8UHafPi:0I7EiJ5]OI7mROgijLVmoY<Bg/<:QUZJ@VZZUSFaK
G5M<LVQHBTeNLgiUIgalHVQoOFecITTk?c/^=2Y5G5=LN7moJ5mXHTe:FSm?HVIE
?S4_=DAFFTi0@4QKFeaKFEMDDfIEFeD_:DIDEU=CF5eHBC]1BTXn>3e0?CPd?4mH
E55EBTI1?d13APe8C4i:Ae1HAb`j=cHj@@G;7oogjnW^lNgWgMkOg=WIgN75c=OQ
i^CPg=7BeMSIe]7=o/`:cLk=b/S<a;^g^l3n``?5bLg@o]8j`L32b<g>bL?Be]SD
c<?0`;Nm`/?2aLcC`loIf=CEfmo:a/;4alO2_KRf]KFh_L?6[jja^KjfXi:c];Km
^7ngWijNWj:VZZf^]/79blJm]jZ`^;fl]JbU_[B/[KJl^kJaZZR^/[6d^jFWZjf/
Yj6MXJ>X[kNl_[o5^JVKUi^RYj:Q[Kfi[;C:a<6o`lcDf]bj/[K7d/g7am3=b<C3
a<S:b/WCjO_hi]OGb;bi/j^^^Kk4`KF`];6WZ:Z[ZJJW[GncViVDS8F2QHVOWj:/
^L;5aL33_k2OW:Zj^ZbMW::SV8bIU8f:SYVV[[Ff];2[Z:Z/_/F^WZVWY;VCQGMd
O8F6Q8VGWY:2O8B>UIFBShf?UIZGU8QkO8^HW:2>Sh]lQX]bP8J2LVQ]MW]oS924
NhZ_cYFF]9nIYhbAOGabHeeSJCQXNXinCDA/Qh5^J7^0IVEhMW1dIDe>GE8e=2Y3
FDaAJFi=@TYOGTQ2D4QFHEmCAS`e<TEGETY1@DCnCeU@DUEGFFeLHe`e;DQEFE17
ATY9@CQ8D4m3?dUAD4]4BUiYIF1REE=ACTa>DeMFF5E?DEIBBC/h>3a4ooO[jNka
kNOMg]oLfMWMhLG<en7Vi>3LdM;Ef=WFdLgnc0[=c/g:b<c4^kNk`?k30lG9cM3n
dS[1`<;8cLk9`m;Ff=C<`l30]kg2`l;5c=?3cmWHe=GKgl[6`/C7al:m^;Je]KRm
`lJ_[[6i_[JST[>d]_fhOkNOWYjOXZJZ[Jjf`LW;a[fgZ[2h_Kbe[:Fn]:b]][bk
][6ZZ:jb/KBkYJN[[JbWXIfQXjR_]kbn_lFiZI^GVj:WXZ6]_KV/]<[4`Ko3c=CJ
g;Zb]/OBcLO7d<g8a<?4b<[:bM?YnoSVemO8_;VcZjji_/C1]K2d/JNXZZ^YYZN]
Ok>KVIB<QH:5RInOXZbi`/G5`<>o/9nLZ[Zj[9fLXZ>HS9VDSHZ>VJJ^]KJd/:^X
ZZbnaJjNZJNT^I>5MgAlQHJ4RINNTX9lQ8jEUI:?SHnEVYNDR7]lRiRLX8j?Rgb6
Rg:0QX9bJ6efNgn<T8AkRZo>UIJdWiVWS95mO79SGF=Y>6QjSWi=A6b7PFiXNh1V
IGQfL7AUCDiMDSDd:T=IC55YKTe2BUmNB49@B5IQGe=6?3DbAEMFBT51A?i?FE1B
EEMIKEaSG3D]B5EID4M6BTU1>4Q@Cd<oBE5@BdA:GVUUH69EDe5>C4iCEeIHEDmA
EU99>cPh?4Comn_Yk_7]imgNgmcIfMgQaLcGhNKTh=cAd]GHfMKAcOk<2/g>cL[8
c<Bk]k_0o/<3aLW=d?kB>/70`/S=c/W3d]KHe<c3`<2g_L;3`/G<dl??fMSDeM_O
b/K2a<O7`[fh][Fe^;g3aZn^/KVn]Z>B/kBfoKQo]inNWYnRYZZ][[K1bL_6_KNZ
/;Rm_;F/YKjd[:ff_;^f/JZX[[:a];^UYj^][:NQWJ6SZ:ng_;joaKVYViNKXZNR
XJfm^Jbdb/C1_l?<e=[L^[:fam;=alO@cLS4`lC8b/[9dnWkn>KGelRl^K>[[[Vn
a<6e/;BaYjRZZjVVYjeo/i^IU8b5PXF9WinR[;W2aLG0`kn`WibZ^[Z/WIbRXiR<
VIB=RXjIYZje][B`ZjRZ[;k5[YjYYjBiThEgM7b5QXB9UijBPWb4SYFETXn=SiFJ
UiB8Ngb;V9bPSXn;O8J;LX26PW9XKGIkOhb@Q7^:[ljEU[BOVJN<TGelLV=MHfTh
J7Z>OTe4K8N1KVQkP6IUN7I`M6E=CUeB=C@Z@eU<DFU^CD9:Gei8@U18EV5ODdHl
=C95EeI:@D54oTliD59EEeU]G6=L=Be8EEU@AdI:BD4hB51?@cm9DE1;A4YNJFEP
HUECDDi<CU=GEUQECe5FDTTk>3PlA0G@3OS/h=oVk>_WinGQg]_Jo]]oh>S^l>cV
hLc:bLgAd/k:c/W5aL[=cL_Cbl6m`/W=cm3Df]gJdLS1`/71a<O5_[Rm`<6m][>d
^:b[/;[6b<2g`=KTfLO2a<G=a/72alW3_Kjj/jn`]ko5]JjY[KFh/ZZg][Jg^Kg1
a;Nd/:j`][g2/;[7dM;:_[K1^[6ZZJjf_;X3]Jn]/?jdE[jg/[>h_;jo/;>h^[N^
YIjBT9:KZKBk_:bZZ:VZYinHeL:d/:NGTIJSYJRZZj^YYiVJY[FeZjR_[:NPViVK
X:>e[kcOn_CIa<Zk/JfUVYVQWJFWXJB^[ojYOjJOV9NKX:JUXj2LV9JDSHf@VZNa
];Ba/JbOTXnGXIR@RHZAUI:<SHR1OX6:UIbGUYBCUIZPXiFPUY^f[Y>A/9j@UJBX
V8J3UIjAQ8RDVhV1NGV7W;:o]JfOUIJR/K[2YZ2OTiVKPY6>Pg=UHFEYIGV6P7f=
YKB?RjF<Qi^6TGAcOfmYIg1nR9:k]7QRQIV7M6UlQF]RKFYOIea:Eg5U@CP]@eA2
@EAF=3Q7EUI:AdeII6EDATM>D49FI61IEe==CDa;CE9IH6EUE5iP@ciFGUeEC4Q:
CU5AGF1GA3i;F5]HC4YGH5YAD5IHFEMCDeMLFUeMF55>CTlj=cLlA?S/h=oV2>c[
inOUhMkKf_kKOn3Xk_3/i^7<b/W=dM;>b/k9aLG:cLg;dl_1_L;9cLo@e=[Mf]78
`L;1`LC7aKjh_L31_KJc];R/Zk2ja/S0]l3Fi=W7`/C5cLK1`/O9`kfn^[>_/;No
aKF^ZJfe^;:Z]kJf]kVm`LBg];2^/;Jm`[2jam7Bb[jf`KZaZZV^][bj0kF_[K3n
]5Jn]k:c^;bn_k2c^;Zg[ZFNTY2BVjVd^kb/ZZRYZZNOV=G2];2WUi6FXjFXZZ^[
ZJNIVZJe]J^X[jbWX9^IVj2S]Jnlgo[dfLC:^k6]YIZIXIfUYj6T[ZonZGnVWiRG
Vj2VYJ>PW9RFU8f=T9ZW/KBd/K6/Wi:?Uj6HT8V:TIFBS8f8PGj1RYFLUiJDTiFJ
X:>EX9JK]ZjCTK2NT9FTZ9R6PiFNTHB8U9^9PGUiQibb_kF]WiFFX[6j`ZJPWi>I
Vh:ASX=cIF5UJFEiQX1mSJFdSh^US8NKQY5dLgm_JFM`OXRB^kAhHXFIQgAYO8E[
HVeZGfMLBUMaID4h;D=D@T5DES@hAeIFBTM=FFAUE4I7CU12EVAPFEMCCDe<BdeB
FF1UIEANH4<nEUiMEDa8BTiADEePEd@nBeQKF4a:Ef1JDE1FF5UGDe=GG5YMGEQA
CTi?>SLg?4Chk>3OiPS/jnOWiN7Nfm[nfgoPj>k`k>KQc<[9cM7Bc/[>bLG5b/g=
bm?;`Kg2bLg?d=CJgM[Ab<72`L74alFn^;g0`Kff/kBh[:^`^/K8`;O0e^CIal;4
aLg6`L;7bL>m_[Zc[k2g_lFe[ZV]]KRbZ[Nf][Ni_L74]kB`[[2f_L:`^/OAd/Zn
]/6j/JZY[[Jl^P>e[jf`o[AF_[Nb/kRl_[n`/kRj]jjUWY:@TY^Y];^l[:ZXZJZW
WiSE`[B`YiNAUZ>UZ:Z[ZjVWVIZV]KF[Z:n/Yj2KVI^PXkF__=ojm=W4b[^a[JFJ
VJ6MYJNQY:j_oZUoYYnHUi^PYZFSX9bHUYB=SI2JYk6d];6a[9nBSiNQV929RY6E
TXb=R85nPHZEW9NFU9>EVZ2SUJ2FVkJ^Ti6`WY2EY:RHQX>EWY64R9BKRH5iNHNL
/[ne[InEUZ:a^/:VX9nCVI^2THj3LfEQIFUUNHJ0OHfU]8n;YHb7VhJAM7=jKfUW
L7j8T[^dN6:5VHMdJGb5Jf9]JUmWG4YGLFE1>2e3E491E5Hd>4MFETY7CEUTIEA6
Adi@@UITH5UGDde=C4]=DUUPIFEDGV13?UINGEE<B4Y>DE5MH5M4?T]HFeQ<BUMP
FU5@EUQIEe=CEeaJGEeHDDi>CcXg=ca41M5on>_Nfn7Wi^;Sh=kMgn7Rh_3alo;]
iMgHclW4alkCdLkHclG5c=CGemS?aL;8dMOJhNCXjN?JclSBdM;Gg=_Fd<c;aknh
][_0[k2e`Lg@b;o4e=K4]K>aZ/G6a/:n_L76`Knl^[^oa<Nn]Jnc`Lg@cKbi];:e
_<C9_;^j^kk4bLeo^Kk6blc8`Kc5`;Rb/KFl`JFZ/;2]ZZVZ`[bc/;No`;^i^KZi
][:]ZZ2ITYBOZZn`XZ:U[;>bZ9n/Y:B^]KNi_kRh]k:YXIbJZ:BZ]KJ^[[F_ZZ:K
VI^PY;bgan[nlmgBf<_2`;JWXZNNZ:bZ[kc0^kNe/JRQXJN^_kbh][Fd/k4DYJ>T
ZkBk_;Zk^;:]ZJV[[JBQWYbLoYeoWYZDT96FWZ>LVYRLYK6k`M3HcLoWgL2melZo
`<G0ZiQjPhEoQiZQVgUjNgYoSjRj]ZjWYJJZ/k_3Zjf]VijYW9:>QW][FU9AFVQb
MhFEThB=RJ67P95jPhQoLVIOIWV<X/WD/8f9RX5hJGf:KeiQG5]_Je9FKFE3?S=7
ECliB4MoAE1BB498CTe?KWiXC4MAFUEVL6a[KVIGJVIOFEMIGV5TDEaUCdaMG5MI
FEQJHFaeOWQQ@SE0D5IKBT9=EU59AeAKH5mJEUUMHF5TIV1CAd54@T97D?S[g]_Q
inKRhn3NgMoQh^;`lO?bkNGMf<o9a<O>dm7>f<o5aLcDemOHclEo`/SAem[Qi>SY
hm[?b=;Ad]OLfmK@c<_7_kRf^l2_/;G1cM38_lCDe/Be/k6ZaLK6`[jm`LK1_kbj
^ko4akje[k?1cM3=_;Vd/[Fla<Vl^kZk_/C9cKVna/_<b<6laL2h/[6e_<6UZ[2`
[JZYZ/:l/k2g_l2k^KVj^KJb[JZPVI9YU9nZ[k2RXZF//k:XWjbTY:je]kVo^;Rg
/ZVQW9ZXY:Ze]Zj^]JnZXY^IVj2T_;O7j_kcgM;Hbl;0]ZNRYijX[:Z__<2k]kFa
Z:6QYjjo_;Rf]KBc/JFSY:^d^kbj^kRb[JVYZjfTXIjLW?jMOijJU92AUYjSW9ZH
W:Fa^l7@f<g?img0_MO:_l35`:^HNX>5OhNJXI]iNW]jOhnX^[J^YjFVZ[>k`j^]
[I^NZIbBSXIkJeYBDEYXLWN5UI>4SHVQQh2ANX>8Og9VGfIiS:;9e;2=RHZ1N6Um
RVmNHEaKKf]BEVeU@chcAeDo>DQ7OdE@DTQ2B4i=CfinJ4a7DEYEIW1/JfiVEfYV
GeUGFEiQI55LIDm<GEaGFEUHFV5/MGihHD8e@51FFdY2CEIABDMDFf1OFUIIGF5Q
I6IPDdM1A492Ae3hjmkKhNOVh^?Pg]gOhN;Rl?7cl^gUgMS?bLC7c]?Ac]S?aLG<
e=OGf<o5Ol;8dMOJhNCXjN?JclSBdM;Gg=_Fd<c;aknh][_0[k2e`Lg@b;o4e=K4
]K>aZ/G6a/:n_L76`Knl^[^oa<Nn]Jnc`Lg@cKbi];:e_<C9_;^j^kk4bLfi_/K;
c<S1_<G0^;:a]Kc1YJZ`/:fZZJ[2_;>`]ko0^kVi^[Vf/ZfZX9VBJIBOZZn`XZ:U
[;>bZ9n/Y:B^]KNi_kRh]k:YXIbJZ:BZ]KJ^[[F_ZZ:KVI^PY;bgan[nlmgBf<_2
`;JWXZNNZ:bZ[kc0^kNe/JRQXJN^_kbh][Fd/k6UXjB[];^l^[^h/ZfYZJ^]Y:6N
W9cnWGnNVYB@TIJNXibJV9bU/K_1d=S=cnOM`;gGb[o0aL2[V7Z3QGn7VZ6KNGYk
NWn?Z;Zf[ZNUYZZc^l>[[JfKWZVLTXj6Nf]JDU5JJ79gQIFCQ8f9XHN0TGZ3R7mb
IUmVNHbRbMB`SHV:PGQYOHY_GV5LFfm[DUI]ID<n<dME?cU8AeA5D598@TQ>CDm^
OVQ<Ae5JEFI`K6]^IUMZIUmIEeUNHFAAG6E?C5eLEeUIF5YQK7EnN652=D1@EU]:
@TeFDDU7E5]PGeYFFEeQHFAVH5=7@DA2@TM@1M5ooo?Sg^?WiN7FeMGKhn__l<oB
e]WKf]SFe/k7bM;IfMKRe/W8d=_PhMK=`l78d]WLiNOYj^SSgMWAd]OQjno]jN?O
eLNj][[0^ko6cmKJf=K?eLjl^/C3][_6cLBd/Ko@^kk2al_>cm3Ab/C7c/k6_<Fo
]Zn_]Kk4[:jc^;g1a<D4`<71`/;n`gnk`LW?c/Jm]Z6``<Bn]K:b[jVOVZ6/[:Fj
]k>`[Zj`/L>eY9jQYZRVX9NATijWZJRc];Zo_KJd^;Rj^[Nd/kFh_:nY/[Rf][bk
]JfVXjJ[[l;1d^ogj=gOk>3Ielfk/kNc_;nk_l[=ajj]ZJ>PYK2i^K>/Z:Z/[Zjg
/k:e^knm^Wnm^;Bd^;^j]k>c[jJLUIFHXinJUYFHWJ2SX:2V]<GAf=WMb/GNhmo^
g=G=a[f`Wi>UX969VZnWSW^=WY^<QHnNXYjNXjBQXZN^X:Z/Ti>YZZ>QX9f>MfIP
Kg=eP9b[T6QTJY64PY9eN7U[FD]5D6f9VK?>aiibHVQ_Gg>3Ie5@B7mWQHAQDV5J
?Di2EF9:@Tm>EF1B;b<fAD8dKi^;H4Q9CUm]LfmcNVmITHMhIe]DDU9]EUmYEU1H
DDeFH6EWL7n<XIEdBSDnCUISD4QDHF5LG61YLW9[IVMZM75dOWiZCciDDE9GH?oc
hmkSinGQe]GEfn?[ko3?d]KIfm[He]K>afW9d]WIe^;FbLS@fn3Qe/g3`LSBfMcU
inWZj>?MfM7Ben7[kngYhmoEakZf^/2k_lK?e][He/oEc[bja<>f^lK=a;Ba_m2k
_/;7blk?d=7:a<O>c/JlaKnf[jne_/B/[[>h_L74aL31`L;2o/=o^l79clk6_KJQ
/<34_[Fb/ZnYWiZQ[:bU^[Nc/:j^/;73]JBNXJJXYZ2GTI>NYjVX/kBj_kff];Rh
^[Zg];>e^;b_ZK:h][Jl^kF]YZ>VZjo2`M;_mnSMgncPfMO=^k>g/kbo^ko:cLN^
[JVSX:F`^KVc[:RZ[:j^]k>b]K^o_KYo_KRd];Rk^[Nc/jnVW9FEV:>OVYJEV9fP
Xj2PY[C5dMSIgL[5g^?Ok]cEcLJm/9nCYJ2ARIZ_YhikSIjKS8F?WZ:NWZ>TXJ:W
[Z2Z[9>CZJZSXJ2MSWMVH6mcMH2LZi1XI6ZAQ8:BMGQiJeU;AE1]RIVcc/NNLV9X
KemcPfMAD4QoIhF4HE9QFSe>@UERBT9?CUEPDRlS=TE2=6nKRf18BDiOKG=_LgY_
FI67N6MKE59BKEIOJEI@F55=EV1UIg1oS:6EM4Xe?TiFHe18E65QG5aPJG9bJfIW
JWAaM7inJTlnE55BEf3oln?NhnOUhMKEeM_Sjno`cm;FfM_Jf=KFc/MYbM;IfMKR
e/W8d=_PhMK=`l78d]WLiNOYj^SSgMWAd]OQjno]jN?OeLNj][[0^ko6cmKJf=K?
eLjl^/C3][_6cLBd/Ko@^kk2al_>cm3Ab/C7c/k6_<Fo]Zn_]Kk4[:jc^;g1a<G0
`L72`_k3Ok_1bLo>a[ffXK30a;je/[:_ZInJXJb/YKZg/k2^[[2a`kFTWZ6VZ:JP
Ui6CWZNYZ;>d^[nm][Bh^;Zj]kBc]KRl[jVb^;Jf_;^e[JJSYZ^_`/7BkoOXgMo/
h=WGcK^c]k>l_k^ob/g7[ZfYXj2U/;Vi/jbXZZb^[[Nc/[Fk_kfjOkfh];Bh^kZg
/k>_YYbEUIRSWiZFUIRMX:>PX:JdaM7HfMg:aMkSgnkLeLg6_K2OTjFPTHVJ[jN>
NhfNVhb5SijRWYjSY:6RYjjPZZbCTjVZXj6PWHigIV1_LgF0W:^@J6AZTHB2TWEh
NF]IBdE@KHVI/lk7WW9RJ6mOLh=WDE18I6N5Q65BHEXmCT9EHTY2CdiEH58_8cI5
@SA_Vh]PB4U>GfecKg=jKeVAQgQWFeABDVeFGfUFD5QACEIPIFM`OhbQUGA:=Ci>
EV=@B5AQHEaLH6UbLV]VIfYdLGAnOVY??UAADUMP1Lelooolmo3Xh]k=cM;Ki>SU
hMCOjN[Th>CYhM_Dc<S8blg4b<g=bl_?e<cEe<S4c=?Af][IfmoVk?3dknSRgn3S
i_7ak>7Bal;2b/c>d=7Ad<oAdM[SgLg8c/?8al2l`<?2j]oEdmKGd<SB_kkBelFi
_/;3`Kbi_<G=_l75b/gnc`SAc<K6bL_9a/7n`PG0_KZh^KWm^Wni^Kk0_kZd/KBi
][Fc];Jk`LFh^kJZZKFi]L2i/Zna/k:``/;3`/2m^[Rl][Ji/jV/^;Vk_KZf]KZo
/kF/WYj/]K>o/:Va^Kc2cLG>emK<a/O</;6d][Nf]KC1_kfj^KZk_;Ve]KJ]XjZj
/k[2a/O8cM7@cLS2_KZh]jjWYZVTW7nR/<W3]jROWjVbVJ>fX]Roc=6jf[g8eko6
`/6k/:FPXjjgYYjLXjBMX:VPVinYZZ2MXZVOUiNKVY:9P7b7W:BU//S3X:VOXYaM
CGFAZi^7XZMkJFiNRZ>DW8=mRHelH55GIJ6`[Zb[QVMbIFMXJFAKCTFRXY=eGEQP
J5EBDEAHF7mDCdYNIE=1A59LDE=ZRHibED]YJg9lPGicJH^7OgAVF4e7HEaQK6YG
Ad9=ADaPIf1TLHBCV8ATF6MmFdi=H71^IV=YMGedHEQOK6YYIFUhPG1EADA6CUWo
oocgl>SRg/g=d]_Tj>GQe=oYj^CPi>WQfmC<b<S;cLC8cLg;bloDc5?Ee<S4c=?A
f][IfmoVk?3dknSRgn3Si_7ak>7Bal;2b/c>d=7Ad<oAdM[SgLg8c/?8al2l`<?2
j]oEdmKGd<SB_kkBelFi_/;3`Kbi_<G=_l75b/gnc`SAc<K6bL_9a/7n`PG0_KZh
^KWm^Wni^Kk0_kZd/KBi][Fc];Jk`LFh^kJZZKFi]L2i/Zna/k:``/;3`/2m^[Rl
][Ji/jV/^;Vk_KZf]KZo/kF/WYj/]K>o/:Va^Kc2cLG>emK<a/O</;6d][Nf]KC1
_kfj^KZk_;Ve]KJ]XjZj/k[2a/O8cM7@cLS2_KZh]jjWYZVTW7nR/<W3]jROWjVb
VJ>fX]Roc=6jf[g8eko6`/6k/:FPXjjgYYjLXjBMX:VPVinYZZ2MXZVOUiNKVY:9
P7b7W:BU//S3X:VOXYaMCGFAZi^7XZMkJFiNRZ>DW8=mRHelH55GIJ6`[Zb[QVMb
IFMXJFAKCTFRXY=eGEQPJ5EBDEAHF7mDCdYNIE=1A59LDE=ZRHibED]YJg9lPGic
JH^7OgAVF4e7HEaQK6YGAd9=ADaPIf1TLHBCV8ATF6MmFdi=H71^IV=YMGedHEQO
K6YYIFUhPG1EADA6CUWooocgl>SRg/g=d]_Tj>GQe=oYj^CPi>WQfmC<b<S;cLC8
cLg;bloDc5?Ee<S4c=?Af][IfmoVk?3dknSRgn3Si_7ak>7Bal;2b/c>d=7Ad<oA
dM[SgLg8c/?8al2l`<?2j]oEdmKGd<SB_kkBelFi_/;3`Kbi_<G=_l75b/gnc`SA
c<K6bL_9a/7n`PG0_KZh^KWm^Wni^Kk0_kZd/KBi][Fc];Jk`LFh^kJZZKFi]L2i
/Zna/k:``/;3`/2m^[Rl][Ji/jV/^;Vk_KZf]KZo/kF/WYj/]K>o/:Va^Kc2cLG>
emK<a/O</;6d][Nf]KC1_kfj^KZk_;Ve]KJ]XjZj/k[2a/O8cM7@cLS2_KZh]jjW
YZVTW7nR/<W3]jROWjVbVJ>fX]Roc=6jf[g8eko6`/6k/:FPXjjgYYjLXjBMX:VP
VinYZZ2MXZVOUiNKVY:9P7b7W:BU//S3X:VOXYaMCGFAZi^7XZMkJFiNRZ>DW8=m
RHelH55GIJ6`[Zb[QVMbIFMXJFAKCTFRXY=eGEQPJ5EBDEAHF5IDCdYNIE=1A59L
DE=ZRHibED]YJg9lPGicJH^7OgAVF4e7HEaQK6YGAd9=ADaPIf1TLHBCV8ATF6Mm
Fdi=H71^IV=YMGedHEQOK6YYIFUhPG1EADA6CUT5cWogm_C`j^CNfmkOhncenOKb
l?WoooK_l?G[in3JemSKgLgAe=;?cm?Hh^WVem3Ef]OGf=[Nh^O[k^oZh]cIf]gP
i>GTgM;;b/_=cm;EemSHemCCfN3Jc<WAjNg]jNGUhn7Yg]CBe]O@b=K4aMWMb[k3
aLO8a/;4b]3:blg>c/c:b@SAc<K6bL_9a/Onb0G6`knn_[om`7no_[g0`/2m_/C9
b/O3`<32aLO2a/6e]L35`LFn]kFg^KRe_l31`/6o_;_1_;c0^Znb_KVk_KZf]KZo
]KVbYZJb^KFo/:Zb^[c2c;[3c<[1^kc1]KNi^kbl^k[3`Knm_;bm_/2j^[^cZ[2o
^l77b<G4a/W=blK1_[^j^[Na/[Rg/WnjbN7Me<Nm_<?:`lWE^>?2bL[4h/;:eKZn
^Knj/JRSYZfc/ZVX[ZnXZ[>d[Jjg^;2`]lNn][Fj^K6XWIVP[JjVZkZ`TInKYJM^
GWF;ZJ:9UIj3MGAKP9N<WXb7Rhj>R7icK9>UZJnfVH2>JF=OHFAPE4R;T8]gGe9C
EeQDCdmBDgmACEM/MVEBDUeTEUAQN7]UDD]3BUQ/P8^=RhN5P7U`If1LBDE;EeM9
?clc;30o@SXkADIFI65FEVYnKf9QLX1mMG=jPHEoLfebNHZ:QhbN[:6:Z:NX[kWg
m_C`j^CNfmkOhncenOKbl?WoooK_l?G[in3JemSKgLgAe=;?cm?HhUoYi]O@eM[G
emSJg^;Wjnk_j^;LfM[Mh>CUi=gBbl[;cLoBeMOHf=ODdmWPf/c9dNW]kNWUiN?Q
jMkDd]KGd<SFa<GIgLZn`lG7b<K2a<[@b/_=c/k<b/WAc<K6bL_9a/Onb0G6`knn
_[om`7no_[g0`/2m_/C9b/O3`<32aLO2a/6e]L35`LFn]kFg^KRe_l31`/6o_;_1
_;c0^Znb_KVk_KZf]KZo]KVbYZJb^KFo/:Zb^[c2c;[3c<[1^kc1]KNi^kbl^k[3
`Knm_;bm_/2j^[^cZ[2o^l77b<G4a/W=blK1_[^j^[Na/[Rg/WnjbN7Me<Nm_<?:
`lWE^>?2bL[4h/;:eKZn^Knj/JRSYZfc/ZVX[ZnXZ[>d[Jjg^;2`]lNn][Fj^K6X
WIVP[JjVZkZ`TInKYJM^GWF;ZJ:9UIj3MGAKP9N<WXb7Rhj>R7icK9>UZJnfVH2>
JF=OHFAPE4R;T8]gGe9CEeQDCdmBDgmACEM/MVEBDUeTEUAQN7]UDD]3BUQ/P8^=
RhN5P7U`If1LBDE;EeM9?clc;30o@SXkADIFI65FEVYnKf9QLX1mMG=jPHEoLfeb
NHZ:QhbN[:6:Z:NX[kWgm_C`j^CNfmkOhncenOKbl?WoooK_l?G[in3JemSKgLgA
e=;?cm?HhUoYi]O@eM[GemSJg^;Wjnk_j^;LfM[Mh>CUi=gBbl[;cLoBeMOHf=OD
dmWPf/c9dNW]kNWUiN?QjMkDd]KGd<SFa<GIgLZn`lG7b<K2a<[@b/_=c/k<b/WA
c<K6bL_9a/Onb0G6`knn_[om`7no_[g0`/2m_/C9b/O3`<32aLO2a/6e]L35`LFn
]kFg^KRe_l31`/6o_;_1_;c0^Znb_KVk_KZf]KZo]KVbYZJb^KFo/:Zb^[c2c;[3
c<[1^kc1]KNi^kbl^k[3`Knm_;bm_/2j^[^cZ[2o^l77b<G4a/W=blK1_[^j^[Na
/[Rg/WnjbN7Me<Nm_<?:`lWE^>?2bL[4h/;:eKZn^Knj/JRSYZfc/ZVX[ZnXZ[>d
[Jjg^;2`]lNn][Fj^K6XWIVP[JjVZkZ`TInKYJM^GWF;ZJ:9UIj3MGAKP9N<WXb7
Rhj>R7icK9>UZJnfVH2>JF=OHFAPE4R;T8]gGe9CEeQDCdmBDeIACEM/MVEBDUeT
EUAQN7]UDD]3BUQ/P8^=RhN5P7U`If1LBDE;EeM9?clc;30o@SXkADIFI65FEVYn
Kf9QLX1mMG=jPHEoLfebNHZ:QhbN[:6:Z:NX[kT5b`_moOcjm_7/jNc]lOWno`7n
moko8??Yj>__k>SThnCWjMWKg=WDd]KKhnWTd/O:blOAeMcRiokZOnSSg=KCe=OJ
e=OJem;?dMC9c=3Ef=[KfmWEem_Eb/_FmoSjnoS`jNCWgM?Ae]O@b=W:cN7Sc/?9
a/_@dLk<c]7HemKDd<_6`m7<a/K9blW6c/k?c/c9a/C4aLK8b<K5a;g2a/S9cMGL
f=C>b<C3a<G7blJj^lK<b<W4_Kbn_kfjDk^l_l72`L2oa/73al6f^<>i^kfj][Fj
_kJl^[6a^[bf_[2Z/k^l`/^d_/K5_;Fg^k^l_l72`L30a/C2`;no`<78`;k0^k:g
a<C8c<W3_ko0bLO4`OfnOk^g^/?5a<kNiNCOeL_7bLkAe=Zff[>e]K;A/KW5ZZnY
^kNa[:VYZjbi/:jd]:f_^;BZZ:j`Zjnic<>k^[jn]ZbZZ[6i]:NTZjJ<W9NU[WIU
IW6EW7YaP7j3O5YfRH>NTgafNH^MVGaPEfabOHUaG6a]GU9FI6ULC6mjPGMOBD=7
AeiFC4Q9C4a;@UmeLfefQXnCSI2KW8n3P92CW:^mb/k>c<_9alC1_kkFdmSTi]kK
hMWDeMgMeM?Hf^C_l>_[l___hn;bo?K_k_ke7OCblO3`inKPhO7on^Sak^kdo?gm
o?[flNcYk>ganOko0Okgo_lPlnWXjno/j>CSi>OYfM_LfMCBe]_SjNCBal[;am7E
g>;Wo^Yoj>?Le]?Dem[Dem[Gd/oAe<W<d=GHf]_KfMGGfmG:bmKgn?[kn?3Yi>OM
dm7Fem38fL[=hN?>`lW6bm3Ac/c>dMSGe]C@blK3dLc6a/W;bLK>c/o>c<W6a<C5
a/S8a/G4_L;6b<W=eMcHe<k8a<?4aLO;a[Zka/c8bLBm_;jo_KYC^kbo`L;1`;o6
`L?7`KJh`kVk_KZf]KZo][bj/K6j_;Jn/:Zc^kc2bkBna/Fl]KNk^kbo`L;1`<36
a<;0_ko0`LS0_/2k/[O4a<S<bL>o_l39alC1oKio^kNj`lG4c]kUi=oEblO9c]7D
f[KJ/kFe/]6a^LFZ[jVk]k6/ZJV[[;V`[[Bd[Jnh]:ZX[[2[[kW<`k^j_[jf[:ZZ
/KVdYjB[YXbLUjF^MVEVLIFLNW60OX=lFWJ9PijCO7IiRifIO61GK79mRG5LK6eN
DUITJEa<KgZ1Mem9@dM7GUI<B4U<C4]2GgEcKGJ6Si>=T9^LSh>0T9>LZkg:c/k<
blW7a<6o_]KCf>CVg]_QfMCEgMgEdmSJi>o`jn_bnnoSh_;lm^o^o_DMm?;al?3W
i^3QlOojj?7^k_CloOgln_Kak>W/kO7io_l1o_Onob3cjNS[kncXi>?TinWIfmcI
e=;Ffn?Yi=;7b/_7dMGLh^OnjWoXhmcFdmCGf]CGf]OBcm7DbLc@eMSJfm_IeMOK
eL[;e_Ohn__hl>WTimgCdMKGd<SIb/gQhlk3bLK;d=7>c<kAf=OFe=3;a/?Ac<K6
bL_9a/k>clk<bLK4a<G6b<S6aLBm`/K8bLgEg=SDc/S4`lC5al_6^[_6c<S9a;fl
_[nm^U>k_;o1`/70_lK1`lO1][S3^K^m^[Je^[nf_;Za/KZl][j`Z[>k_<;;];k6
aKbe]k^k_;o1`/70`<K4`/2o_l31b<2n`;^b]lC4b<c9`kno`<W7a<7m_Wnk]k[3
aLC>g^GTgmG;alW>dMCJ]]Zc]KFbdK6iaJZ_ZK^g/JbYZJ^/^K2^];B][kRdZZR^
/:^_^Lc3^kZn_[J/ZZZa^KBWY:^VS9bGYJifIFIaUIajLH1nPgaJMXV3WY=lMWV;
WIUlH5M/LWf9LEa/KEiBEVAYG4a_NX5gGdU3AdMNETa8BDa<Bd9OMG=]MXJ?Thf@
Vib?Ph2@Tib[_L[>c/c;bLO4`Knne]?Hi>KNfn7Ie=GMgMGCf=[Tko3[jo;kkn?R
l_cfknknmA7dl_7`l>OVh>7aoo[XlNk^m?`0o`\>"], "Output",
 ImageSize->{269.5, 185.312},
 ImageMargins->{{80, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[TextData[{
 StyleBox["URL",
  FontWeight->"Bold"],
 ": Oscillator at ",
 ButtonBox["http://www.ifm.mavt.ethz.ch/~kaufmann/applets.html",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www.ifm.mavt.ethz.ch/~kaufmann/applets.html"], None}],
 "."
}], "Quote"],

Cell["\<\
A mass attached to a vertical spring is driven by moving the support up and \
down.\
\>", "MathCaption"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"Show", "[", 
    RowBox[{
    "Import", "[", 
     "\"\</Users/paul/Physics/Courses/ElectroMagnetism/Software/Tipler \
Art/11-15/F14-24.JPG\>\"", "]"}], "]"}], ";"}], 
  TraditionalForm]], "HiddenInput",
 CellLabel->"In[513]:="]
}, Open  ]],

Cell[TextData[Cell[BoxData[GridBox[{
   {
    ButtonBox[
     StyleBox["\[FirstPage]", "SR"],
     BaseStyle->"SlideHyperlink",
     ButtonFunction:>FrontEndExecute[{
        FrontEndToken[
         FrontEnd`SelectedNotebook[], "ScrollPageFirst"]}],
     ButtonNote->"First Slide"], 
    ButtonBox[
     StyleBox["\[LeftPointer]", "SR"],
     BaseStyle->"SlideHyperlink",
     ButtonFunction:>FrontEndExecute[{
        FrontEndToken[
         FrontEnd`SelectedNotebook[], "ScrollPagePrevious"]}],
     ButtonNote->"Previous Slide"], 
    ButtonBox[
     StyleBox["\[RightPointer]", "SR"],
     BaseStyle->"SlideHyperlink",
     ButtonFunction:>FrontEndExecute[{
        FrontEndToken[
         FrontEnd`SelectedNotebook[], "ScrollPageNext"]}],
     ButtonNote->"Next Slide"], 
    ButtonBox[
     StyleBox["\[LastPage]", "SR"],
     BaseStyle->"SlideHyperlink",
     ButtonFunction:>FrontEndExecute[{
        FrontEndToken[
         FrontEnd`SelectedNotebook[], "ScrollPageLast"]}],
     ButtonNote->"Last Slide"], " ", 
    ButtonBox[
     StyleBox[
      RowBox[{
       CounterBox["SlideShowNavigationBar"], 
       RowBox[{" ", "of", " "}], 
       CounterBox["SlideShowNavigationBar", "LastSlide"]}], "SR"],
     Appearance->{Automatic, None}]}
  }]]]], "SlideShowNavigationBar"],

Cell[CellGroupData[{

Cell["Forced Oscillations and Resonance", "SectionTwo"],

Cell[TextData[{
 "Assuming that the driving force is oscillatory, ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"F", "(", "t", ")"}], "=", 
    RowBox[{
     SubscriptBox["F", "0"], 
     RowBox[{"cos", "(", 
      RowBox[{"\[Omega]", " ", "t"}], ")"}]}]}], TraditionalForm]]],
 ", where ",
 Cell[BoxData[
  FormBox["\[Omega]", TraditionalForm]]],
 " is the angular frequency of the driving force, the differential equation \
reads"
}], "Text"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"m", " ", 
     FractionBox[
      RowBox[{
       SuperscriptBox["\[DifferentialD]", "2"], 
       RowBox[{"x", "(", "t", ")"}]}], 
      RowBox[{"\[DifferentialD]", 
       SuperscriptBox["t", "2"]}]]}], "+", 
    RowBox[{"b", 
     FractionBox[
      RowBox[{"\[DifferentialD]", 
       RowBox[{"x", "(", "t", ")"}]}], 
      RowBox[{"\[DifferentialD]", "t"}]]}], "+", 
    RowBox[{"k", " ", 
     RowBox[{"x", "(", "t", ")"}]}]}], "=", 
   RowBox[{
    SubscriptBox["F", "0"], 
    RowBox[{
     RowBox[{"cos", "(", 
      RowBox[{"\[Omega]", " ", "t"}], ")"}], "."}]}]}], 
  TraditionalForm]], "DisplayFormula"],

Cell[TextData[{
 "Although you may not realise it, you've already solved this equation \
\[LongDash] because it is equivalent to a series ",
 StyleBox["LCR",
  FontSlant->"Italic"],
 " circuit driven by an AC supply, ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     OverscriptBox["V", "~"], "(", "t", ")"}], "=", 
    RowBox[{
     SubscriptBox["V", "0"], 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "\[Omega]", " ", "t"}]]}]}], 
   TraditionalForm]]],
 "."
}], "Text"],

Cell[TextData[{
 "Earlier we showed that the current for a series ",
 StyleBox["LCR",
  FontSlant->"Italic"],
 " circuit, written in terms of ",
 Cell[BoxData[
  FormBox["Q", TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Omega]", "0"], TraditionalForm]]],
 ", is"
}], "Text"],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{"\[LeftBracketingBar]", 
     OverscriptBox["\[ScriptCapitalI]", "~"], "\[RightBracketingBar]"}], 
    RowBox[{"\[LeftBracketingBar]", 
     OverscriptBox["V", "~"], "\[RightBracketingBar]"}]], "=", 
   RowBox[{
    FractionBox["1", "R"], 
    RowBox[{
     FractionBox[
      FractionBox["\[Omega]", 
       RowBox[{"Q", " ", 
        SubscriptBox["\[Omega]", "0"]}]], 
      SqrtBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "-", 
           FractionBox[
            SuperscriptBox["\[Omega]", "2"], 
            SubsuperscriptBox["\[Omega]", "0", "2"]]}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          FractionBox["\[Omega]", 
           RowBox[{"Q", " ", 
            SubscriptBox["\[Omega]", "0"]}]], ")"}], "2"]}]]], "."}]}]}], 
  TraditionalForm]], "DisplayFormula"],

Cell["Since ", "Text"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{
     OverscriptBox["Q", "~"], "(", "t", ")"}], "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       SubscriptBox["Q", "0"], 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "\[Omega]", " ", "t"}]]}], "\[Implies]", 
      RowBox[{
       OverscriptBox["\[ScriptCapitalI]", "~"], "(", "t", ")"}]}], "=", 
     RowBox[{
      FractionBox[
       RowBox[{"\[DifferentialD]", 
        RowBox[{
         OverscriptBox["Q", "~"], "(", "t", ")"}]}], 
       RowBox[{"\[DifferentialD]", "t"}]], "=", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"\[ImaginaryI]", " ", "\[Omega]", " ", 
           SubscriptBox["Q", "0"]}], ")"}], 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"\[ImaginaryI]", " ", "\[Omega]", " ", "t"}]]}], 
        "\[Implies]", 
        FractionBox[
         SubscriptBox["Q", "0"], 
         SubscriptBox["V", "0"]]}], "=", 
       RowBox[{
        FractionBox["1", "\[Omega]"], 
        FractionBox[
         RowBox[{"\[LeftBracketingBar]", 
          OverscriptBox["\[ScriptCapitalI]", "~"], "\[RightBracketingBar]"}], 
         
         RowBox[{"\[LeftBracketingBar]", 
          OverscriptBox["V", "~"], "\[RightBracketingBar]"}]]}]}]}]}]}], 
   ","}], TraditionalForm]], "DisplayFormula"],

Cell["and", "Text"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{
     FractionBox["1", "\[Omega]"], 
     FractionBox["1", "R"], 
     FractionBox["\[Omega]", 
      RowBox[{"Q", " ", 
       SubscriptBox["\[Omega]", "0"]}]]}], "=", 
    RowBox[{
     RowBox[{
      FractionBox["1", "R"], 
      FractionBox["1", 
       RowBox[{"Q", " ", 
        SubscriptBox["\[Omega]", "0"]}]]}], "=", 
     RowBox[{
      RowBox[{
       FractionBox["1", "R"], 
       FractionBox["R", 
        RowBox[{"L", " ", 
         SubsuperscriptBox["\[Omega]", "0", "2"]}]]}], "=", 
      RowBox[{
       FractionBox[
        RowBox[{"L", " ", "C"}], 
        RowBox[{"L", " "}]], "=", "C"}]}]}]}], ","}], 
  TraditionalForm]], "DisplayFormula"],

Cell[TextData[{
 "using ",
 Cell[BoxData[
  FormBox[
   RowBox[{"C", "\[Rule]", 
    RowBox[{"1", "/", "k"}]}], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["Q", "0"], "\[Rule]", 
    SubscriptBox["x", "0"]}], TraditionalForm]]],
 ", and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["V", "0"], "\[Rule]", 
    SubscriptBox["F", "0"]}], TraditionalForm]]],
 ", we see that the amplitude of a forced mechanical oscillator is"
}], "Text"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"\[Implies]", 
    FractionBox[
     SubscriptBox["x", "0"], 
     SubscriptBox["F", "0"]]}], "=", 
   RowBox[{
    RowBox[{
     FractionBox["1", "k"], 
     FractionBox["1", 
      SqrtBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "-", 
           FractionBox[
            SuperscriptBox["\[Omega]", "2"], 
            SubsuperscriptBox["\[Omega]", "0", "2"]]}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          FractionBox["\[Omega]", 
           RowBox[{"Q", " ", 
            SubscriptBox["\[Omega]", "0"]}]], ")"}], "2"]}]]]}], "=", 
    RowBox[{
     FractionBox["1", "k"], 
     RowBox[{
      RowBox[{"G", "(", "\[Omega]", ")"}], "."}]}]}]}], 
  TraditionalForm]], "DisplayFormula"],

Cell["Similarly, it can be shown that the phase is", "Text"],

Cell[BoxData[
 FormBox[
  RowBox[{" ", 
   RowBox[{
    RowBox[{"tan", "(", "\[Phi]", ")"}], "=", 
    RowBox[{"-", 
     RowBox[{
      FractionBox[
       FractionBox["\[Omega]", 
        RowBox[{"Q", " ", 
         SubscriptBox["\[Omega]", "0"]}]], 
       RowBox[{"1", "-", 
        FractionBox[
         SuperscriptBox["\[Omega]", "2"], 
         SubsuperscriptBox["\[Omega]", "0", "2"]]}]], "."}]}]}]}], 
  TraditionalForm]], "DisplayFormula"]
}, Open  ]],

Cell[TextData[Cell[BoxData[GridBox[{
   {
    ButtonBox[
     StyleBox["\[FirstPage]", "SR"],
     BaseStyle->"SlideHyperlink",
     ButtonFunction:>FrontEndExecute[{
        FrontEndToken[
         FrontEnd`SelectedNotebook[], "ScrollPageFirst"]}],
     ButtonNote->"First Slide"], 
    ButtonBox[
     StyleBox["\[LeftPointer]", "SR"],
     BaseStyle->"SlideHyperlink",
     ButtonFunction:>FrontEndExecute[{
        FrontEndToken[
         FrontEnd`SelectedNotebook[], "ScrollPagePrevious"]}],
     ButtonNote->"Previous Slide"], 
    ButtonBox[
     StyleBox["\[RightPointer]", "SR"],
     BaseStyle->"SlideHyperlink",
     ButtonFunction:>FrontEndExecute[{
        FrontEndToken[
         FrontEnd`SelectedNotebook[], "ScrollPageNext"]}],
     ButtonNote->"Next Slide"], 
    ButtonBox[
     StyleBox["\[LastPage]", "SR"],
     BaseStyle->"SlideHyperlink",
     ButtonFunction:>FrontEndExecute[{
        FrontEndToken[
         FrontEnd`SelectedNotebook[], "ScrollPageLast"]}],
     ButtonNote->"Last Slide"], " ", 
    ButtonBox[
     StyleBox[
      RowBox[{
       CounterBox["SlideShowNavigationBar"], 
       RowBox[{" ", "of", " "}], 
       CounterBox["SlideShowNavigationBar", "LastSlide"]}], "SR"],
     Appearance->{Automatic, None}]}
  }]]]], "SlideShowNavigationBar"],

Cell[CellGroupData[{

Cell["Forced Oscillations and Resonance", "SectionTwo"],

Cell[TextData[{
 "Plot of the dimensionless function ",
 Cell[BoxData[
  FormBox[
   RowBox[{"G", "(", "\[Omega]", ")"}], TraditionalForm]]],
 " as a function of ",
 Cell[BoxData[
  FormBox["\[Omega]", TraditionalForm]]],
 " for ",
 Cell[BoxData[
  FormBox[
   RowBox[{"Q", "=", "1"}], TraditionalForm]]],
 " (",
 StyleBox["\[LongDash]",
  FontColor->RGBColor[1, 0, 0]],
 "), ",
 Cell[BoxData[
  FormBox[
   RowBox[{"Q", "=", "10"}], TraditionalForm]]],
 " (",
 StyleBox["\[LongDash]",
  FontColor->RGBColor[0, 1, 0]],
 "), and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"Q", "=", "100"}], TraditionalForm]]],
 " (",
 StyleBox["\[LongDash]",
  FontColor->RGBColor[0, 0, 1]],
 ")."
}], "MathCaption"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"With", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"z", "=", 
       RowBox[{
        RowBox[{
         RowBox[{"1", "/", 
          SqrtBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"1", "-", 
               FractionBox[
                SuperscriptBox["\[Omega]", "2"], 
                SubsuperscriptBox["\[Omega]", "0", "2"]]}], ")"}], "2"], "+", 
            
            SuperscriptBox[
             RowBox[{"(", 
              FractionBox["\[Omega]", 
               RowBox[{"Q", " ", 
                SubscriptBox["\[Omega]", "0"]}]], ")"}], "2"], " "}]]}], "/.", 
         RowBox[{"Q", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"1", ",", "10", ",", "100"}], "}"}]}]}], "/.", 
        RowBox[{
         SubscriptBox["\[Omega]", "0"], "\[Rule]", "1"}]}]}], "}"}], ",", 
     RowBox[{"LogLogPlot", "[", 
      RowBox[{
       RowBox[{"Evaluate", "[", "z", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Omega]", ",", 
         SuperscriptBox["10", 
          RowBox[{"-", "1"}]], ",", "10"}], "}"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
       RowBox[{"PlotPoints", "\[Rule]", "50"}], ",", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          FractionBox["\[Omega]", 
           SubscriptBox["\[Omega]", "0"]], ",", 
          RowBox[{"G", "(", "\[Omega]", ")"}]}], "}"}]}], ",", 
       RowBox[{"Ticks", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Hue", "[", "1", "]"}], ",", 
          RowBox[{"Hue", "[", 
           RowBox[{"1", "/", "3"}], "]"}], ",", 
          RowBox[{"Hue", "[", 
           RowBox[{"2", "/", "3"}], "]"}]}], "}"}]}]}], "]"}]}], "]"}], ";"}],
   TraditionalForm]], "HiddenInput",
 CellLabel->"In[35]:="],

Cell[TextData[{
 "At low frequency the response, ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["x", "0"], "=", 
    RowBox[{
     SubscriptBox["F", "0"], "/", "k"}]}], TraditionalForm]]],
 ", depends only on the spring. On resonance the response depends on the ",
 Cell[BoxData[
  FormBox["Q", TraditionalForm]]],
 ": ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["x", "0"], "\[TildeTilde]", 
    RowBox[{"Q", " ", 
     RowBox[{
      SubscriptBox["F", "0"], "/", "k"}]}]}], TraditionalForm]]],
 " for ",
 Cell[BoxData[
  FormBox[
   RowBox[{"Q", "\[GreaterGreater]", "1"}], TraditionalForm]]],
 ". At high frequency the response is ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["x", "0"], "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       SubscriptBox["F", "0"], "/", "k"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Omega]", "0"], "/", "\[Omega]"}], ")"}], "2"]}], "=", 
     RowBox[{
      RowBox[{
       SubscriptBox["F", "0"], "/", 
       RowBox[{"(", 
        RowBox[{"m", " ", 
         SuperscriptBox["\[Omega]", "2"]}], ")"}]}], "\[Rule]", "0"}]}]}], 
   TraditionalForm]]],
 ", which is the same as for a free mass."
}], "Text"]
}, Open  ]],

Cell[TextData[Cell[BoxData[GridBox[{
   {
    ButtonBox[
     StyleBox["\[FirstPage]", "SR"],
     BaseStyle->"SlideHyperlink",
     ButtonFunction:>FrontEndExecute[{
        FrontEndToken[
         FrontEnd`SelectedNotebook[], "ScrollPageFirst"]}],
     ButtonNote->"First Slide"], 
    ButtonBox[
     StyleBox["\[LeftPointer]", "SR"],
     BaseStyle->"SlideHyperlink",
     ButtonFunction:>FrontEndExecute[{
        FrontEndToken[
         FrontEnd`SelectedNotebook[], "ScrollPagePrevious"]}],
     ButtonNote->"Previous Slide"], 
    ButtonBox[
     StyleBox["\[RightPointer]", "SR"],
     BaseStyle->"SlideHyperlink",
     ButtonFunction:>FrontEndExecute[{
        FrontEndToken[
         FrontEnd`SelectedNotebook[], "ScrollPageNext"]}],
     ButtonNote->"Next Slide"], 
    ButtonBox[
     StyleBox["\[LastPage]", "SR"],
     BaseStyle->"SlideHyperlink",
     ButtonFunction:>FrontEndExecute[{
        FrontEndToken[
         FrontEnd`SelectedNotebook[], "ScrollPageLast"]}],
     ButtonNote->"Last Slide"], " ", 
    ButtonBox[
     StyleBox[
      RowBox[{
       CounterBox["SlideShowNavigationBar"], 
       RowBox[{" ", "of", " "}], 
       CounterBox["SlideShowNavigationBar", "LastSlide"]}], "SR"],
     Appearance->{Automatic, None}]}
  }]]]], "SlideShowNavigationBar"],

Cell[CellGroupData[{

Cell["Forced Oscillations and Resonance", "SectionTwo",
 CellTags->"LastSlide"],

Cell[TextData[{
 "Plot of the phase ",
 Cell[BoxData[
  FormBox["\[Phi]", TraditionalForm]]],
 " as a function of ",
 Cell[BoxData[
  FormBox["\[Omega]", TraditionalForm]]],
 " for ",
 Cell[BoxData[
  FormBox[
   RowBox[{"Q", "=", "1"}], TraditionalForm]]],
 " (",
 StyleBox["\[LongDash]",
  FontColor->RGBColor[1, 0, 0]],
 "), ",
 Cell[BoxData[
  FormBox[
   RowBox[{"Q", "=", "10"}], TraditionalForm]]],
 " (",
 StyleBox["\[LongDash]",
  FontColor->RGBColor[0, 1, 0]],
 "), and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"Q", "=", "100"}], TraditionalForm]]],
 " (",
 StyleBox["\[LongDash]",
  FontColor->RGBColor[0, 0, 1]],
 ")."
}], "MathCaption"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"With", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"t", "=", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          RowBox[{"Mod", "[", 
           RowBox[{
            RowBox[{
             SuperscriptBox["tan", 
              RowBox[{"-", "1"}]], "(", 
             RowBox[{
              RowBox[{"1", "-", 
               FractionBox[
                SuperscriptBox["\[Omega]", "2"], 
                SubsuperscriptBox["\[Omega]", "0", "2"]]}], ",", 
              FractionBox["\[Omega]", 
               RowBox[{"Q", " ", 
                SubscriptBox["\[Omega]", "0"]}]]}], ")"}], ",", 
            RowBox[{"2", "\[Pi]"}]}], "]"}]}], "/.", "\[InvisibleSpace]", 
         RowBox[{"Q", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"1", ",", "10", ",", "100"}], "}"}]}]}], "/.", 
        RowBox[{
         SubscriptBox["\[Omega]", "0"], "\[Rule]", "1"}]}]}], "}"}], ",", 
     RowBox[{"LogLinearPlot", "(", 
      RowBox[{
       RowBox[{"Evaluate", "[", "t", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Omega]", ",", 
         SuperscriptBox["10", 
          RowBox[{"-", "2"}]], ",", 
         SuperscriptBox["10", "2"]}], "}"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
       RowBox[{"PlotPoints", "\[Rule]", "1000"}], ",", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          FractionBox["\[Omega]", 
           SubscriptBox["\[Omega]", "0"]], ",", "\[Phi]"}], "}"}]}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Automatic", ",", 
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{
             FractionBox["1", "2"], " ", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"n", " ", "\[Pi]"}], ",", 
               RowBox[{"n", " ", "\[Pi]"}]}], "}"}]}], ",", 
            RowBox[{"{", 
             RowBox[{"n", ",", 
              RowBox[{"-", "2"}], ",", "0"}], "}"}]}], "]"}]}], "}"}]}], ",", 
       
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Hue", "[", "1", "]"}], ",", 
          RowBox[{"Hue", "[", 
           FractionBox["1", "3"], "]"}], ",", 
          RowBox[{"Hue", "[", 
           FractionBox["2", "3"], "]"}]}], "}"}]}]}], ")"}]}], "]"}], ";"}], 
  TraditionalForm]], "HiddenInput",
 CellLabel->"In[155]:="],

Cell[TextData[{
 "At low frequency ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["x", "0"], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["F", "0"], TraditionalForm]]],
 " are in phase. On resonance they are ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{"-", "90"}], "\[Degree]"}], "=", 
    RowBox[{
     RowBox[{"-", "\[Pi]"}], "/", "2"}]}], TraditionalForm]]],
 " out of phase. At high frequency they are opposite in phase. The transition \
gets sharper as ",
 Cell[BoxData[
  FormBox["Q", TraditionalForm]]],
 " increases."
}], "Text"]
}, Open  ]]
},
AutoGeneratedPackage->None,
ScreenStyleEnvironment->"SlideShow",
PrintingStyleEnvironment->"EnhancedPrintout",
WindowToolbars->{},
WindowSize->{1284, 851},
WindowMargins->{{4, Automatic}, {Automatic, 1}},
Visible->True,
PrintingCopies->1,
PrintingStartingPageNumber->38,
PrintingPageRange->{1, Automatic},
InputAliases->{"notation" -> RowBox[{"Notation", "[", 
     RowBox[{
       TagBox[
       "\[Placeholder]", NotationBoxTag, TagStyle -> "NotationTemplateStyle"],
        " ", "\[DoubleLongLeftRightArrow]", " ", 
       TagBox[
       "\[Placeholder]", NotationBoxTag, TagStyle -> 
        "NotationTemplateStyle"]}], "]"}], "notation>" -> 
  RowBox[{"Notation", "[", 
     RowBox[{
       TagBox[
       "\[Placeholder]", NotationBoxTag, TagStyle -> "NotationTemplateStyle"],
        " ", "\[DoubleLongRightArrow]", " ", 
       TagBox[
       "\[Placeholder]", NotationBoxTag, TagStyle -> 
        "NotationTemplateStyle"]}], "]"}], "notation<" -> 
  RowBox[{"Notation", "[", 
     RowBox[{
       TagBox[
       "\[Placeholder]", NotationBoxTag, TagStyle -> "NotationTemplateStyle"],
        " ", "\[DoubleLongLeftArrow]", " ", 
       TagBox[
       "\[Placeholder]", NotationBoxTag, TagStyle -> 
        "NotationTemplateStyle"]}], "]"}], "symb" -> RowBox[{"Symbolize", "[", 
     TagBox[
     "\[Placeholder]", NotationBoxTag, TagStyle -> "NotationTemplateStyle"], 
     "]"}], "infixnotation" -> RowBox[{"InfixNotation", "[", 
     RowBox[{
       TagBox[
       "\[Placeholder]", NotationBoxTag, TagStyle -> "NotationTemplateStyle"],
        ",", "\[Placeholder]"}], "]"}], "addia" -> 
  RowBox[{"AddInputAlias", "[", 
     RowBox[{"\"\[Placeholder]\"", "\[Rule]", 
       TagBox[
       "\[Placeholder]", NotationBoxTag, TagStyle -> 
        "NotationTemplateStyle"]}], "]"}], "pattwraper" -> 
  TagBox["\[Placeholder]", NotationPatternTag, TagStyle -> 
    "NotationPatternWrapperStyle"], "madeboxeswraper" -> 
  TagBox["\[Placeholder]", NotationMadeBoxesTag, TagStyle -> 
    "NotationMadeBoxesWrapperStyle"]},
Magnification->1,
FrontEndVersion->"8.0 for Microsoft Windows (64-bit) (November 7, 2010)",
StyleDefinitions->Notebook[{
   Cell[
    CellGroupData[{
      Cell["Style Definitions for On-line Help", "Subtitle"], 
      Cell[
      "These styles are carefully tuned for all aspects of the online help. \
It's recommended that they remain unchanged.", "Text"], 
      Cell[
       CellGroupData[{
         Cell["Style Environment Names", "Section"], 
         Cell[
          StyleData[All, "Working"], PageWidth -> WindowWidth, 
          ShowCellBracket -> False, ShowAutoStyles -> False, ScriptMinSize -> 
          9], 
         Cell[
          StyleData[All, "Brackets"], PageWidth -> WindowWidth, 
          ShowCellBracket -> True, ShowAutoStyles -> False, ScriptMinSize -> 
          9], 
         Cell[
          StyleData[All, "SlideShow"], PageWidth -> WindowWidth, 
          ScrollingOptions -> {"PagewiseDisplay" -> True}, ShowCellBracket -> 
          False, ShowCellLabel -> False, ScriptMinSize -> 9, Magnification -> 
          2], 
         Cell[
          StyleData[All, "Printout"], PageWidth -> PaperWidth, 
          ShowCellBracket -> False, ShowCellLabel -> False, ShowAutoStyles -> 
          False, ScriptMinSize -> 5, 
          PrivateFontOptions -> {"FontType" -> "Outline"}], 
         Cell[
          StyleData[All, "EnhancedPrintout"], PageWidth -> PaperWidth, 
          ShowCellBracket -> False, ShowCellLabel -> False, ScriptMinSize -> 
          5, FontFamily -> "Palatino", 
          PrivateFontOptions -> {"FontType" -> "Outline"}], 
         Cell[
          StyleData[All, "EnhancedPrintoutNonGray"], PageWidth -> PaperWidth, 
          ShowCellBracket -> False, ShowCellLabel -> False, ScriptMinSize -> 
          5, FontFamily -> "Palatino", 
          PrivateFontOptions -> {"FontType" -> "Outline"}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Notebook Options", "Section"], 
         Cell[
         "  The options defined for the style below will be used at the \
Notebook level.  ", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Notebook"], CellLabelAutoDelete -> False, 
             CellFrameLabelMargins -> 6, StyleMenuListing -> None], 
            Cell[
             StyleData["Notebook", "Printout"], PageHeaders -> {{
                Cell[
                 TextData[{
                   CounterBox["Page"]}], "PageNumber"], None, None}, {
               None, None, 
                Cell[
                 TextData[{
                   CounterBox["Page"]}], "PageNumber"]}}, 
             PageFooters -> {{None, 
                Cell[
                 TextData[{"\[Copyright]2002 Paul Abbott"}], "PageFooter"], 
                None}, {None, 
                Cell[
                 TextData[{"\[Copyright]2002 Paul Abbott"}], "PageFooter"], 
                None}}, PageHeaderLines -> {True, True}, 
             PageFooterLines -> {True, True}, 
             PrintingOptions -> {"FacingPages" -> True}], 
            Cell[
             StyleData["Notebook", "EnhancedPrintout"], PageHeaders -> {{
                Cell[
                 TextData[{
                   CounterBox["Page"]}], "PageNumber"], None, None}, {
               None, None, 
                Cell[
                 TextData[{
                   CounterBox["Page"]}], "PageNumber"]}}, 
             PageFooters -> {{None, 
                Cell[
                 TextData[{"\[Copyright]2002 Paul Abbott"}], "PageFooter"], 
                None}, {None, 
                Cell[
                 TextData[{"\[Copyright]2002 Paul Abbott"}], "PageFooter"], 
                None}}, PageHeaderLines -> {True, True}, 
             PrintingOptions -> {
              "FacingPages" -> True, "FirstPageFace" -> Left, 
               "FirstPageHeader" -> False, 
               "PrintingMargins" -> {{62, 62}, {62, 72}}}]}, Closed]]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell["Headings", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Chapter"], CellFrame -> {{0, 0}, {0.5, 0}}, 
             CellMargins -> {{12, Inherited}, {10, 40}}, 
             CellGroupingRules -> {"TitleGrouping", 0}, PageBreakBelow -> 
             False, DefaultNewInlineCellStyle -> "None", 
             InputAutoReplacements -> {"TeX" -> StyleBox[
                 RowBox[{"T", 
                   AdjustmentBox[
                   "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                    BoxBaselineShift -> 0.5], "X"}]], "LaTeX" -> StyleBox[
                 RowBox[{"L", 
                   StyleBox[
                    AdjustmentBox[
                    "A", BoxMargins -> {{-0.36, -0.1}, {0, 0}}, 
                    BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
                   AdjustmentBox[
                   "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                    BoxBaselineShift -> 0.5], "X"}]], "mma" -> "Mathematica", 
               "Mma" -> "Mathematica", "MMA" -> "Mathematica", 
               "webMathematica" -> FormBox[
                 RowBox[{"web", 
                   AdjustmentBox[
                    StyleBox["Mathematica", FontSlant -> "Italic"], 
                    BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm]}, 
             LanguageCategory -> "NaturalLanguage", CounterIncrements -> 
             "Title", 
             CounterAssignments -> {{"Section", 0}, {"Equation", 0}, {
               "Figure", 0}, {"Subtitle", 0}, {"Subsubtitle", 0}}, FontFamily -> 
             "Helvetica", FontSize -> 18, FontWeight -> "Plain"], 
            Cell[
             StyleData["Chapter", "Printout"], 
             CellMargins -> {{2, 10}, {6, 30}}, FontSize -> 14], 
            Cell[
             StyleData["Chapter", "EnhancedPrintout"], 
             CellMargins -> {{2, 10}, {6, 30}}, FontFamily -> "Futura", 
             FontSize -> 14], 
            Cell[
             StyleData["Chapter", "EnhancedPrintoutNonGray"], 
             CellMargins -> {{2, 10}, {6, 30}}, FontFamily -> "Futura", 
             FontSize -> 14]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Section"], CellMargins -> {{10, 4}, {12, 18}}, 
             CellGroupingRules -> {"SectionGrouping", 30}, CounterIncrements -> 
             "Section", FontFamily -> "Helvetica", FontSize -> 20, FontWeight -> 
             "Bold"], 
            Cell[
             StyleData["Section", "SlideShow"], 
             CellFrame -> {{0, 0}, {0, 0.5}}, ShowCellBracket -> False, 
             CellMargins -> {{0, 0}, {5, 0}}, PageBreakBelow -> False, 
             CellFrameMargins -> {{36, 36}, {Inherited, 15}}, FontFamily -> 
             "Helvetica", FontSize -> 18, FontWeight -> "Bold", FontColor -> 
             GrayLevel[1], Background -> RGBColor[0.408011, 0.440726, 0.8]], 
            Cell[
             StyleData["Section", "Printout"], 
             CellMargins -> {{2, 0}, {0, 18}}, PageBreakBelow -> False, 
             FontSize -> 18], 
            Cell[
             StyleData["Section", "EnhancedPrintout"], 
             CellFrame -> {{0, 0}, {0.5, 0}}, 
             CellMargins -> {{2, Inherited}, {5, 30}}, 
             CellGroupingRules -> {"SectionGrouping", 30}, PageBreakBelow -> 
             False, CellFrameMargins -> 8, CounterIncrements -> "Section", 
             CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}}, 
             FontFamily -> "Futura", FontSize -> 16], 
            Cell[
             StyleData["Section", "EnhancedPrintoutNonGray"], 
             CellFrame -> {{0, 0}, {0.5, 0}}, 
             CellMargins -> {{2, Inherited}, {5, 30}}, 
             CellGroupingRules -> {"SectionGrouping", 30}, PageBreakBelow -> 
             False, CellFrameMargins -> 8, CounterIncrements -> "Section", 
             CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}}, 
             FontFamily -> "Futura", FontSize -> 16]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["SectionTwo"], CellMargins -> {{10, 4}, {12, 18}}, 
             CellGroupingRules -> {"SectionGrouping", 30}, CounterIncrements -> 
             "Section", FontFamily -> "Helvetica", FontSize -> 20, FontWeight -> 
             "Bold"], 
            Cell[
             StyleData["SectionTwo", "SlideShow"], 
             CellFrame -> {{0, 0}, {0, 0.5}}, ShowCellBracket -> False, 
             CellMargins -> {{0, 0}, {5, 0}}, PageBreakBelow -> False, 
             CellFrameMargins -> {{36, 36}, {Inherited, 15}}, FontFamily -> 
             "Helvetica", FontSize -> 18, FontWeight -> "Bold", FontColor -> 
             GrayLevel[1], Background -> RGBColor[0.408011, 0.440726, 0.8]], 
            Cell[
             StyleData["SectionTwo", "Printout"], ShowCellBracket -> False, 
             CellMargins -> {{0, 0}, {0, 0}}, 
             CellElementSpacings -> {"ClosedCellHeight" -> 0}, CellOpen -> 
             False], 
            Cell[
             StyleData["SectionTwo", "EnhancedPrintout"], ShowCellBracket -> 
             False, CellMargins -> {{0, 0}, {0, 0}}, 
             CellElementSpacings -> {"ClosedCellHeight" -> 0}, CellOpen -> 
             False]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subsection"], CellDingbat -> "\[FilledSquare]", 
             CellMargins -> {{24, 4}, {0, 18}}, 
             CellElementSpacings -> {"ClosedGroupTopMargin" -> 18}, 
             CellGroupingRules -> {"SectionGrouping", 40}, 
             ConversionRules :> {
              "HTML" -> {
                "<li type=\"square\"><font size=\"+1\" face=\"Helvetica, \
Arial\"><p><b>", "</b></p></font></li>\n"}}, CellFrameLabelMargins -> 6, 
             InputAutoReplacements -> {"TeX" -> StyleBox[
                 RowBox[{"T", 
                   AdjustmentBox[
                   "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                    BoxBaselineShift -> 0.5], "X"}]], "LaTeX" -> StyleBox[
                 RowBox[{"L", 
                   StyleBox[
                    AdjustmentBox[
                    "A", BoxMargins -> {{-0.36, -0.1}, {0, 0}}, 
                    BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
                   AdjustmentBox[
                   "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                    BoxBaselineShift -> 0.5], "X"}]], "mma" -> "Mathematica", 
               "Mma" -> "Mathematica", "MMA" -> "Mathematica", 
               "webMathematica" -> FormBox[
                 RowBox[{"web", 
                   AdjustmentBox[
                    StyleBox["Mathematica", FontSlant -> "Italic"], 
                    BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm]}, 
             FontFamily -> "Helvetica", FontSize -> 16, FontWeight -> "Bold"], 
            Cell[
             StyleData["Subsection", "SlideShow"], CellDingbat -> None, 
             ShowCellBracket -> False, CellMargins -> {{0, 0}, {0, 0}}, 
             CellElementSpacings -> {"ClosedCellHeight" -> 0}, CellOpen -> 
             False], 
            Cell[
             StyleData["Subsection", "Printout"], ShowCellBracket -> False, 
             CellMargins -> {{0, 0}, {0, 0}}, 
             CellElementSpacings -> {"ClosedCellHeight" -> 0}, CellOpen -> 
             False], 
            Cell[
             StyleData["Subsection", "EnhancedPrintout"], ShowCellBracket -> 
             False, CellMargins -> {{0, 0}, {0, 0}}, 
             CellElementSpacings -> {"ClosedCellHeight" -> 0}, CellOpen -> 
             False], 
            Cell[
             StyleData["Subsection", "EnhancedPrintoutNonGray"], 
             ShowCellBracket -> False, CellMargins -> {{0, 0}, {0, 0}}, 
             CellElementSpacings -> {"ClosedCellHeight" -> 0}, CellOpen -> 
             False]}, Open]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subsubsection"], CellMargins -> {{10, 4}, {0, 18}}, 
             CellElementSpacings -> {"ClosedGroupTopMargin" -> 18}, 
             CellGroupingRules -> {"SectionGrouping", 50}, 
             ConversionRules :> {
              "HTML" -> {
                "<font face=\"Helvetica, Arial\"><p><b>", 
                 "</b></p></font>\n"}}, 
             InputAutoReplacements -> {"TeX" -> StyleBox[
                 RowBox[{"T", 
                   AdjustmentBox[
                   "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                    BoxBaselineShift -> 0.5], "X"}]], "LaTeX" -> StyleBox[
                 RowBox[{"L", 
                   StyleBox[
                    AdjustmentBox[
                    "A", BoxMargins -> {{-0.36, -0.1}, {0, 0}}, 
                    BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
                   AdjustmentBox[
                   "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                    BoxBaselineShift -> 0.5], "X"}]], "mma" -> "Mathematica", 
               "Mma" -> "Mathematica", "MMA" -> "Mathematica", 
               "webMathematica" -> FormBox[
                 RowBox[{"web", 
                   AdjustmentBox[
                    StyleBox["Mathematica", FontSlant -> "Italic"], 
                    BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm]}, 
             FontFamily -> "Helvetica", FontSize -> 12, FontWeight -> "Bold"], 
            Cell[
             StyleData["Subsubsection", "Printout"], 
             CellMargins -> {{2, 0}, {3, 8}}, FontSize -> 10], 
            Cell[
             StyleData["Subsubsection", "EnhancedPrintout"], 
             CellMargins -> {{2, 0}, {3, 8}}, FontFamily -> "Futura", 
             FontSize -> 10], 
            Cell[
             StyleData["Subsubsection", "EnhancedPrintoutNonGray"], 
             CellMargins -> {{2, 0}, {3, 8}}, FontFamily -> "Futura", 
             FontSize -> 10]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["SubsubsectionColor"], 
             CellMargins -> {{10, 4}, {0, 18}}, 
             CellElementSpacings -> {"ClosedGroupTopMargin" -> 18}, 
             CellGroupingRules -> {"SectionGrouping", 50}, 
             ConversionRules :> {
              "HTML" -> {
                "<font face=\"Helvetica, Arial\" color=\"660099\"><p><b>", 
                 "</b></p></font>\n"}}, 
             InputAutoReplacements -> {"TeX" -> StyleBox[
                 RowBox[{"T", 
                   AdjustmentBox[
                   "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                    BoxBaselineShift -> 0.5], "X"}]], "LaTeX" -> StyleBox[
                 RowBox[{"L", 
                   StyleBox[
                    AdjustmentBox[
                    "A", BoxMargins -> {{-0.36, -0.1}, {0, 0}}, 
                    BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
                   AdjustmentBox[
                   "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                    BoxBaselineShift -> 0.5], "X"}]], "mma" -> "Mathematica", 
               "Mma" -> "Mathematica", "MMA" -> "Mathematica", 
               "webMathematica" -> FormBox[
                 RowBox[{"web", 
                   AdjustmentBox[
                    StyleBox["Mathematica", FontSlant -> "Italic"], 
                    BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm]}, 
             StyleMenuListing -> None, FontFamily -> "Helvetica", FontSize -> 
             12, FontWeight -> "Bold", FontColor -> 
             RGBColor[0.297993, 0, 0.454994]], 
            Cell[
             StyleData["SubsubsectionColor", "Printout"], 
             CellMargins -> {{2, 0}, {0, 18}}, PageBreakBelow -> False, 
             FontSize -> 10]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["SubsectionIcon"], ShowGroupOpener -> True, 
             CellMargins -> {{36, 4}, {6, 12}}, 
             CellElementSpacings -> {"ClosedGroupTopMargin" -> 8}, 
             CellGroupingRules -> {"SectionGrouping", 40}, 
             ConversionRules :> {
              "HTML" -> {
                "<li type=\"square\"><font face=\"Helvetica, Arial\"><p><b>", 
                 "</b></p></font>\n"}}, 
             InputAutoReplacements -> {"TeX" -> StyleBox[
                 RowBox[{"T", 
                   AdjustmentBox[
                   "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                    BoxBaselineShift -> 0.5], "X"}]], "LaTeX" -> StyleBox[
                 RowBox[{"L", 
                   StyleBox[
                    AdjustmentBox[
                    "A", BoxMargins -> {{-0.36, -0.1}, {0, 0}}, 
                    BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
                   AdjustmentBox[
                   "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                    BoxBaselineShift -> 0.5], "X"}]], "mma" -> "Mathematica", 
               "Mma" -> "Mathematica", "MMA" -> "Mathematica", 
               "webMathematica" -> FormBox[
                 RowBox[{"web", 
                   AdjustmentBox[
                    StyleBox["Mathematica", FontSlant -> "Italic"], 
                    BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm]}, 
             CounterIncrements -> "Section", FontFamily -> "Helvetica", 
             FontSize -> 16, FontWeight -> "Bold"], 
            Cell[
             StyleData["SubsectionIcon", "Printout"], CellDingbat -> 
             "\[FilledSquare]", ShowGroupOpener -> False, 
             CellMargins -> {{16, 0}, {0, 18}}, PageBreakBelow -> False, 
             FontSize -> 16], 
            Cell[
             StyleData["SubsectionIcon", "EnhancedPrintout"], 
             CellMargins -> {{16, 0}, {0, 18}}, PageBreakBelow -> False, 
             FontSize -> 14]}, Open]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["SubsubsectionIcon"], ShowGroupOpener -> True, 
             CellMargins -> {{24, 4}, {0, 8}}, 
             CellElementSpacings -> {"ClosedGroupTopMargin" -> 4}, 
             CellGroupingRules -> {"SectionGrouping", 50}, 
             ConversionRules :> {
              "HTML" -> {
                "<li type=\"square\"><font face=\"Helvetica, Arial\"><p><b>", 
                 "</b></p></font>\n"}}, 
             InputAutoReplacements -> {"TeX" -> StyleBox[
                 RowBox[{"T", 
                   AdjustmentBox[
                   "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                    BoxBaselineShift -> 0.5], "X"}]], "LaTeX" -> StyleBox[
                 RowBox[{"L", 
                   StyleBox[
                    AdjustmentBox[
                    "A", BoxMargins -> {{-0.36, -0.1}, {0, 0}}, 
                    BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
                   AdjustmentBox[
                   "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                    BoxBaselineShift -> 0.5], "X"}]], "mma" -> "Mathematica", 
               "Mma" -> "Mathematica", "MMA" -> "Mathematica", 
               "webMathematica" -> FormBox[
                 RowBox[{"web", 
                   AdjustmentBox[
                    StyleBox["Mathematica", FontSlant -> "Italic"], 
                    BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm]}, 
             CounterIncrements -> "Subsection", 
             CounterAssignments -> {{"Subsubsection", 0}}, FontFamily -> 
             "Helvetica", FontSize -> 12, FontWeight -> "Bold"], 
            Cell[
             StyleData["SubsubsectionIcon", "Printout"], ShowGroupOpener -> 
             False, CellMargins -> {{2, 0}, {0, 18}}, PageBreakBelow -> False,
              FontSize -> 10]}, Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Text", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Text"], CellMargins -> {{10, 4}, {0, 8}}, 
             ConversionRules :> {"HTML" -> {"<p>", "</p>"}}, 
             InputAutoReplacements -> {"TeX" -> StyleBox[
                 RowBox[{"T", 
                   AdjustmentBox[
                   "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                    BoxBaselineShift -> 0.5], "X"}]], "LaTeX" -> StyleBox[
                 RowBox[{"L", 
                   StyleBox[
                    AdjustmentBox[
                    "A", BoxMargins -> {{-0.36, -0.1}, {0, 0}}, 
                    BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
                   AdjustmentBox[
                   "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                    BoxBaselineShift -> 0.5], "X"}]], "mma" -> "Mathematica", 
               "Mma" -> "Mathematica", "MMA" -> "Mathematica", 
               "webMathematica" -> FormBox[
                 RowBox[{"web", 
                   AdjustmentBox[
                    StyleBox["Mathematica", FontSlant -> "Italic"], 
                    BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm]}, 
             Hyphenation -> True, ParagraphSpacing -> {0, 8}, FontSize -> 12], 
            Cell[
             StyleData["Text", "SlideShow"], 
             CellMargins -> {{36, 24}, {4, 4}}, Hyphenation -> False], 
            Cell[
             StyleData["Text", "Printout"], CellMargins -> {{2, 2}, {6, 6}}, 
             TextJustification -> 1, FontSize -> 10], 
            Cell[
             StyleData["Text", "EnhancedPrintout"], 
             CellMargins -> {{2, 2}, {6, 6}}, TextJustification -> 1, 
             FontFamily -> "Palatino", FontSize -> 10], 
            Cell[
             StyleData["Text", "EnhancedPrintoutNonGray"], 
             CellMargins -> {{2, 2}, {6, 6}}, TextJustification -> 1, 
             FontFamily -> "Palatino", FontSize -> 10]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["TextSans"], CellMargins -> {{10, 4}, {0, 8}}, 
             ConversionRules :> {
              "HTML" -> {
                "<font size=\"-1\" face=\"Helvetica, Arial\">", "</font>\n"}},
              CellHorizontalScrolling -> True, Hyphenation -> True, 
             ParagraphSpacing -> {0, 8}, StyleMenuListing -> None, FontFamily -> 
             "Helvetica", FontSize -> 10], 
            Cell[
             StyleData["TextSans", "Printout"], 
             CellMargins -> {{2, 0}, {0, 8}}, FontSize -> 8], 
            Cell[
             StyleData["TextSans", "EnhancedPrintout"], 
             CellMargins -> {{2, 0}, {0, 8}}, FontSize -> 8], 
            Cell[
             StyleData["TextSans", "EnhancedPrintoutNonGray"], 
             CellMargins -> {{2, 0}, {0, 8}}, FontSize -> 8]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["ItemizedText"], CellMargins -> {{19, 4}, {4, 4}}, 
             ConversionRules :> {"HTML" -> {"<blockquote>", "</blockquote>"}},
              Hyphenation -> True, LineSpacing -> {1, 3}, 
             ParagraphIndent -> -22, CounterIncrements -> "ItemizedText", 
             StyleMenuListing -> None], 
            Cell[
             StyleData["ItemizedText", "Printout"], FontSize -> 10], 
            Cell[
             StyleData["ItemizedText", "EnhancedPrintout"], 
             CellMargins -> {{16, 4}, {2, 4}}, FontFamily -> "Palatino", 
             FontSize -> 10], 
            Cell[
             StyleData["ItemizedText", "EnhancedPrintoutNonGray"], 
             ParagraphIndent -> -18, FontFamily -> "Palatino", FontSize -> 
             10]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["ItemizedTextNote"], CellMargins -> {{41, 4}, {4, 0}}, 
             ConversionRules :> {"HTML" -> {"<blockquote>", "</blockquote>"}},
              Hyphenation -> True, LineSpacing -> {1, 2}, CounterIncrements -> 
             "Text", StyleMenuListing -> None], 
            Cell[
             StyleData["ItemizedTextNote", "Printout"], 
             CellMargins -> {{34, 4}, {4, 1}}, FontSize -> 10], 
            Cell[
             StyleData["ItemizedTextNote", "EnhancedPrintout"], 
             CellMargins -> {{39, 4}, {4, 1}}, FontFamily -> "Palatino", 
             FontSize -> 10], 
            Cell[
             StyleData["ItemizedTextNote", "EnhancedPrintoutNonGray"], 
             CellMargins -> {{39, 4}, {4, 1}}, FontFamily -> "Palatino", 
             FontSize -> 10]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["IndentedText"], CellMargins -> {{20, 4}, {0, 6}}, 
             ConversionRules :> {"HTML" -> {"<blockquote>", "</blockquote>"}},
              LineSpacing -> {1, 3}, CounterIncrements -> "Text", 
             StyleMenuListing -> None], 
            Cell[
             StyleData["IndentedText", "SlideShow"], 
             CellMargins -> {{80, 24}, {5, 5}}, Hyphenation -> False, 
             FontSize -> 13], 
            Cell[
             StyleData["IndentedText", "Printout"], FontSize -> 11], 
            Cell[
             StyleData["IndentedText", "EnhancedPrintout"], FontFamily -> 
             "Palatino", FontSize -> 10], 
            Cell[
             StyleData["IndentedText", "EnhancedPrintoutNonGray"], FontFamily -> 
             "Palatino", FontSize -> 10]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["MathCaption"], CellDingbat -> "\[FilledSmallSquare]", 
             CellMargins -> {{19, 62}, {0, 14}}, 
             ConversionRules :> {
              "HTML" -> {
                "<li type=\"square\"><p><font color=\"000066\">", 
                 "</font></p></li>"}}, PageBreakBelow -> False, 
             CellFrameLabelMargins -> 4, Hyphenation -> True, 
             LineSpacing -> {1, 1}, ParagraphSpacing -> {0, 8}, FontColor -> 
             RGBColor[0, 0, 0.4]], 
            Cell[
             StyleData["MathCaption", "SlideShow"], ShowCellBracket -> False, 
             CellMargins -> {{36, 36}, {6, 6}}], 
            Cell[
             StyleData["MathCaption", "Printout"], 
             CellMargins -> {{9, 0}, {0, 14}}, FontSize -> 9, FontColor -> 
             GrayLevel[0]], 
            Cell[
             StyleData["MathCaption", "EnhancedPrintout"], 
             CellMargins -> {{9, 0}, {0, 14}}, FontSize -> 9, FontColor -> 
             GrayLevel[0]], 
            Cell[
             StyleData["MathCaption", "EnhancedPrintoutNonGray"], 
             CellMargins -> {{9, 0}, {0, 14}}, FontSize -> 9, FontColor -> 
             GrayLevel[0]]}, Open]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Warning"], CellDingbat -> "\[WarningSign]", 
             CellMargins -> {{36, 24}, {Inherited, Inherited}}, 
             LineSpacing -> {1, 3}], 
            Cell[
             StyleData["Warning", "SlideShow"]], 
            Cell[
             StyleData["Warning", "Printout"], 
             CellMargins -> {{2, 24}, {Inherited, 0}}, TextJustification -> 1,
              FontSize -> 10], 
            Cell[
             StyleData["Warning", "EnhancedPrintout"], 
             CellMargins -> {{2, 24}, {Inherited, 0}}, TextJustification -> 1,
              FontSize -> 10]}, Open]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Quote"], 
             CellMargins -> {{20, 20}, {Inherited, Inherited}}, 
             TextJustification -> 0, LineSpacing -> {1, 3}, FontFamily -> 
             "Times", FontSize -> 12], 
            Cell[
             StyleData["Quote", "Presentation"], FontSize -> 14], 
            Cell[
             StyleData["Quote", "Printout"], FontSize -> 10], 
            Cell[
             StyleData["Quote", "EnhancedPrintout"], FontSize -> 10]}, 
           Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Input/Output", "Section"], 
         Cell[
         "The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.    ", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Input"], ShowCellBracket -> True, 
             CellMargins -> {{70, 4}, {3, 8}}, Evaluatable -> True, 
             CellGroupingRules -> "InputGrouping", PageBreakWithin -> False, 
             GroupPageBreakWithin -> False, CellLabelAutoDelete -> False, 
             CellLabelMargins -> {{14, Inherited}, {Inherited, Inherited}}, 
             DefaultFormatType -> DefaultInputFormatType, 
             ShowSpecialCharacters -> Automatic, 
             HyphenationOptions -> {
              "HyphenationCharacter" -> "\[Continuation]"}, LanguageCategory -> 
             "Mathematica", FormatType -> StandardForm, ShowStringCharacters -> 
             True, NumberMarks -> True, FontWeight -> "Bold"], 
            Cell[
             StyleData["Input", "SlideShow"], ShowCellBracket -> False], 
            Cell[
             StyleData["Input", "Printout"], ShowCellBracket -> False, 
             CellMargins -> {{39, 0}, {4, 6}}, FontSize -> 9], 
            Cell[
             StyleData["Input", "EnhancedPrintout"], ShowCellBracket -> False,
              CellMargins -> {{39, 0}, {4, 6}}, FontSize -> 9], 
            Cell[
             StyleData["Input", "EnhancedPrintoutNonGray"], ShowCellBracket -> 
             False, CellMargins -> {{39, 0}, {4, 6}}, FontSize -> 9]}, 
           Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Output"], ShowCellBracket -> True, 
             CellMargins -> {{70, 4}, {4, 2}}, CellEditDuplicate -> True, 
             CellGroupingRules -> "OutputGrouping", CellHorizontalScrolling -> 
             True, PageBreakWithin -> False, GroupPageBreakWithin -> False, 
             GeneratedCell -> True, CellAutoOverwrite -> True, 
             CellLabelAutoDelete -> False, 
             CellLabelMargins -> {{14, Inherited}, {Inherited, Inherited}}, 
             DefaultFormatType -> DefaultOutputFormatType, 
             HyphenationOptions -> {
              "HyphenationCharacter" -> "\[Continuation]"}, LanguageCategory -> 
             None, FormatType -> StandardForm], 
            Cell[
             StyleData["Output", "SlideShow"], ShowCellBracket -> False], 
            Cell[
             StyleData["Output", "Printout"], ShowCellBracket -> False, 
             CellMargins -> {{39, 0}, {6, 4}}, FontSize -> 9], 
            Cell[
             StyleData["Output", "EnhancedPrintout"], ShowCellBracket -> 
             False, CellMargins -> {{39, 0}, {6, 4}}, FontSize -> 9], 
            Cell[
             StyleData["Output", "EnhancedPrintoutNonGray"], ShowCellBracket -> 
             False, CellMargins -> {{39, 0}, {6, 4}}, FontSize -> 9]}, 
           Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["HiddenInput"], CellMargins -> {{46, 4}, {3, 8}}, 
             Evaluatable -> True, CellGroupingRules -> "InputGrouping", 
             PageBreakWithin -> False, GroupPageBreakWithin -> False, 
             CellLabelAutoDelete -> False, 
             CellLabelMargins -> {{14, Inherited}, {Inherited, Inherited}}, 
             DefaultFormatType -> DefaultInputFormatType, 
             ShowSpecialCharacters -> Automatic, 
             HyphenationOptions -> {
              "HyphenationCharacter" -> "\[Continuation]"}, LanguageCategory -> 
             "Mathematica", FormatType -> StandardForm, ShowStringCharacters -> 
             True, NumberMarks -> True, FontWeight -> "Bold"], 
            Cell[
             StyleData["HiddenInput", "SlideShow"], ShowCellBracket -> False, 
             CellMargins -> {{0, 0}, {0, 0}}, 
             CellElementSpacings -> {"ClosedCellHeight" -> 0}, CellOpen -> 
             False], 
            Cell[
             StyleData["HiddenInput", "Printout"], ShowCellBracket -> False, 
             CellMargins -> {{0, 0}, {0, 0}}, 
             CellElementSpacings -> {"ClosedCellHeight" -> 0}, CellOpen -> 
             False], 
            Cell[
             StyleData["HiddenInput", "EnhancedPrintout"], ShowCellBracket -> 
             False, CellMargins -> {{0, 0}, {0, 0}}, 
             CellElementSpacings -> {"ClosedCellHeight" -> 0}, CellOpen -> 
             False], 
            Cell[
             StyleData["HiddenInput", "EnhancedPrintoutNonGray"], 
             ShowCellBracket -> False, CellMargins -> {{0, 0}, {0, 0}}, 
             CellElementSpacings -> {"ClosedCellHeight" -> 0}, CellOpen -> 
             False]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Message"], ShowCellBracket -> True, 
             CellMargins -> {{47, 4}, {4, 2}}, CellGroupingRules -> 
             "OutputGrouping", PageBreakWithin -> False, GroupPageBreakWithin -> 
             False, GeneratedCell -> True, CellAutoOverwrite -> True, 
             ShowCellLabel -> False, 
             CellLabelMargins -> {{14, Inherited}, {Inherited, Inherited}}, 
             DefaultFormatType -> DefaultOutputFormatType, 
             HyphenationOptions -> {
              "HyphenationCharacter" -> "\[Continuation]"}, LanguageCategory -> 
             None, FormatType -> InputForm, StyleMenuListing -> None, 
             FontColor -> RGBColor[0, 0, 1]], 
            Cell[
             StyleData["Message", "SlideShow"], 
             CellMargins -> {{70, 30}, {4, 4}}, FontSize -> 10, FontColor -> 
             RGBColor[0.699992, 0.4, 0]], 
            Cell[
             StyleData["Message", "Printout"], ShowCellBracket -> False, 
             CellMargins -> {{39, Inherited}, {Inherited, Inherited}}, 
             FontSize -> 9, FontColor -> GrayLevel[0]], 
            Cell[
             StyleData["Message", "EnhancedPrintout"], ShowCellBracket -> 
             False, CellMargins -> {{39, Inherited}, {Inherited, Inherited}}, 
             FontFamily -> "Courier", FontSize -> 9, FontColor -> 
             GrayLevel[0]], 
            Cell[
             StyleData["Message", "EnhancedPrintoutNonGray"], ShowCellBracket -> 
             False, CellMargins -> {{39, Inherited}, {Inherited, Inherited}}, 
             FontFamily -> "Courier", FontSize -> 9, FontColor -> 
             GrayLevel[0]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Print"], ShowCellBracket -> True, 
             CellMargins -> {{47, 4}, {4, 2}}, CellGroupingRules -> 
             "OutputGrouping", PageBreakWithin -> False, GroupPageBreakWithin -> 
             False, GeneratedCell -> True, CellAutoOverwrite -> True, 
             ShowCellLabel -> False, 
             CellLabelMargins -> {{14, Inherited}, {Inherited, Inherited}}, 
             DefaultFormatType -> DefaultOutputFormatType, 
             HyphenationOptions -> {
              "HyphenationCharacter" -> "\[Continuation]"}, LanguageCategory -> 
             None, FormatType -> InputForm, StyleMenuListing -> None], 
            Cell[
             StyleData["Print", "SlideShow"], 
             CellMargins -> {{100, 50}, {6, 6}}], 
            Cell[
             StyleData["Print", "Printout"], ShowCellBracket -> False, 
             CellMargins -> {{57, Inherited}, {Inherited, Inherited}}, 
             FontSize -> 9], 
            Cell[
             StyleData["Print", "EnhancedPrintout"], ShowCellBracket -> False,
              CellMargins -> {{57, Inherited}, {Inherited, Inherited}}, 
             FontFamily -> "Courier", FontSize -> 9], 
            Cell[
             StyleData["Print", "EnhancedPrintoutNonGray"], ShowCellBracket -> 
             False, CellMargins -> {{57, Inherited}, {Inherited, Inherited}}, 
             FontFamily -> "Courier", FontSize -> 9]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Graphics"], ShowCellBracket -> True, 
             CellMargins -> {{50, 4}, {4, 2}}, CellGroupingRules -> 
             "GraphicsGrouping", PageBreakWithin -> False, GeneratedCell -> 
             True, CellAutoOverwrite -> True, ShowCellLabel -> False, 
             DefaultFormatType -> 
             Utilities`Notation`Private`DefaultFormatTypeForOutput, 
             LanguageCategory -> None, FormatType -> InputForm, 
             StyleMenuListing -> None, FontWeight -> "Plain"], 
            Cell[
             StyleData["Graphics", "SlideShow"], ShowCellBracket -> False, 
             CellMargins -> {{50, 20}, {6, 0}}, PageBreakWithin -> False, 
             GroupPageBreakWithin -> False, Magnification -> 2], 
            Cell[
             StyleData["Graphics", "Printout"], ShowCellBracket -> False, 
             CellMargins -> {{40, Inherited}, {Inherited, Inherited}}, 
             ImageSize -> {250, 250}, FontSize -> 9, Magnification -> 1], 
            Cell[
             StyleData["Graphics", "EnhancedPrintout"], ShowCellBracket -> 
             False, CellMargins -> {{40, Inherited}, {Inherited, Inherited}}, 
             ImageSize -> {250, 250}, FontFamily -> "Courier", FontSize -> 9, 
             Magnification -> 1]}, Open]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["CellLabel"], LanguageCategory -> None, 
             StyleMenuListing -> None, FontFamily -> "Helvetica", FontSize -> 
             9, FontWeight -> "Plain", FontColor -> RGBColor[0, 0, 1]], 
            Cell[
             StyleData["CellLabel", "SlideShow"], FontColor -> 
             RGBColor[0.699992, 0.4, 0]], 
            Cell[
             StyleData["CellLabel", "Printout"], FontFamily -> "Courier", 
             FontSize -> 8, FontSlant -> "Italic", FontColor -> GrayLevel[0]], 
            Cell[
             StyleData["CellLabel", "EnhancedPrintout"], FontFamily -> 
             "Courier", FontSize -> 8, FontSlant -> "Italic", FontColor -> 
             GrayLevel[0]], 
            Cell[
             StyleData["CellLabel", "EnhancedPrintoutNonGray"], FontFamily -> 
             "Courier", FontSize -> 8, FontSlant -> "Italic", FontColor -> 
             GrayLevel[0]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Name"], StyleMenuListing -> None, FontFamily -> 
             "Helvetica", FontSize -> 9, FontWeight -> "Plain", FontSlant -> 
             "Italic", FontColor -> RGBColor[0, 0, 1]], 
            Cell[
             StyleData["Name", "Printout"], FontSize -> 7, FontColor -> 
             GrayLevel[0]], 
            Cell[
             StyleData["Name", "EnhancedPrintout"], FontSize -> 7, FontColor -> 
             GrayLevel[0]], 
            Cell[
             StyleData["Name", "EnhancedPrintoutNonGray"], FontSize -> 7, 
             FontColor -> GrayLevel[0]]}, Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Hyperlinks", "Section"], 
         Cell[
         "The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks. The others point to the various sections of the help \
browser. These styles will modify individual words or letters in a cell \
exclusive of the cell tag.", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Hyperlink"], StyleMenuListing -> None, 
             ButtonStyleMenuListing -> Automatic, 
             FontVariations -> {"Underline" -> True}, FontColor -> 
             RGBColor[0, 0, 1], 
             ButtonBoxOptions -> {
              Active -> True, ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`NotebookLocate[#2]}]& ), ButtonNote -> 
               ButtonData}], 
            Cell[
             StyleData["Hyperlink", "Printout"], 
             FontVariations -> {"Underline" -> False}, FontColor -> 
             GrayLevel[0]], 
            Cell[
             StyleData["Hyperlink", "EnhancedPrintout"], FontFamily -> 
             "Palatino", FontVariations -> {"Underline" -> False}, FontColor -> 
             GrayLevel[0]], 
            Cell[
             StyleData["Hyperlink", "EnhancedPrintoutNonGray"], FontFamily -> 
             "Palatino", FontVariations -> {"Underline" -> False}, FontColor -> 
             GrayLevel[0]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["MainBookLink"], StyleMenuListing -> None, 
             ButtonStyleMenuListing -> Automatic, 
             FontVariations -> {"Underline" -> True}, FontColor -> 
             RGBColor[0, 0, 1], 
             ButtonBoxOptions -> {
              Active -> True, Appearance -> {Automatic, None}, 
               ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`HelpBrowserLookup["MainBook", #]}]& )}], 
            Cell[
             StyleData["MainBookLink", "Printout"], 
             FontVariations -> {"Underline" -> False}, FontColor -> 
             GrayLevel[0]], 
            Cell[
             StyleData["MainBookLink", "EnhancedPrintout"], FontFamily -> 
             "Palatino", FontVariations -> {"Underline" -> False}, FontColor -> 
             GrayLevel[0]], 
            Cell[
             StyleData["MainBookLink", "EnhancedPrintoutNonGray"], FontFamily -> 
             "Palatino", FontVariations -> {"Underline" -> False}, FontColor -> 
             GrayLevel[0]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["MainBookLinkMR"], StyleMenuListing -> None, 
             ButtonStyleMenuListing -> Automatic, FontFamily -> "Courier", 
             FontVariations -> {"Underline" -> True}, FontColor -> 
             RGBColor[0, 0, 1], 
             ButtonBoxOptions -> {
              Active -> True, Appearance -> {Automatic, None}, 
               ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`HelpBrowserLookup["MainBook", #]}]& )}], 
            Cell[
             StyleData["MainBookLinkMR", "Printout"], 
             FontVariations -> {"Underline" -> False}, FontColor -> 
             GrayLevel[0]], 
            Cell[
             StyleData["MainBookLinkMR", "EnhancedPrintout"], 
             FontVariations -> {"Underline" -> False}, FontColor -> 
             GrayLevel[0]], 
            Cell[
             StyleData["MainBookLinkMR", "EnhancedPrintoutNonGray"], 
             FontVariations -> {"Underline" -> False}, FontColor -> 
             GrayLevel[0]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["AddOnsLink"], StyleMenuListing -> None, 
             ButtonStyleMenuListing -> Automatic, FontFamily -> "Courier", 
             FontVariations -> {"Underline" -> True}, FontColor -> 
             RGBColor[0, 0, 1], 
             ButtonBoxOptions -> {
              Active -> True, Appearance -> {Automatic, None}, 
               ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`HelpBrowserLookup["AddOns", #]}]& )}], 
            Cell[
             StyleData["AddOnsLink", "Printout"], 
             FontVariations -> {"Underline" -> False}, FontColor -> 
             GrayLevel[0]], 
            Cell[
             StyleData["AddOnsLink", "EnhancedPrintout"], FontFamily -> 
             "WRICourier", FontVariations -> {"Underline" -> False}, 
             FontColor -> GrayLevel[0]], 
            Cell[
             StyleData["AddOnsLink", "EnhancedPrintoutNonGray"], FontFamily -> 
             "WRICourier", FontVariations -> {"Underline" -> False}, 
             FontColor -> GrayLevel[0]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["AddOnsLinkText"], StyleMenuListing -> None, 
             ButtonStyleMenuListing -> Automatic, FontFamily -> "Times", 
             FontVariations -> {"Underline" -> True}, FontColor -> 
             RGBColor[0, 0, 1], 
             ButtonBoxOptions -> {
              Active -> True, Appearance -> {Automatic, None}, 
               ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`HelpBrowserLookup["AddOns", #]}]& )}], 
            Cell[
             StyleData["AddOnsLinkText", "Printout"], 
             FontVariations -> {"Underline" -> False}, FontColor -> 
             GrayLevel[0]], 
            Cell[
             StyleData["AddOnsLinkText", "EnhancedPrintout"], FontFamily -> 
             "Palatino", FontVariations -> {"Underline" -> False}, FontColor -> 
             GrayLevel[0]], 
            Cell[
             StyleData["AddOnsLinkText", "EnhancedPrintoutNonGray"], 
             FontFamily -> "Palatino", 
             FontVariations -> {"Underline" -> False}, FontColor -> 
             GrayLevel[0]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["RefGuideLink"], StyleMenuListing -> None, 
             ButtonStyleMenuListing -> Automatic, FontFamily -> "Courier", 
             FontVariations -> {"Underline" -> True}, FontColor -> 
             RGBColor[0, 0, 1], 
             ButtonBoxOptions -> {
              Active -> True, Appearance -> {Automatic, None}, 
               ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`HelpBrowserLookup["RefGuide", #]}]& )}], 
            Cell[
             StyleData["RefGuideLink", "Printout"], 
             FontVariations -> {"Underline" -> False}, FontColor -> 
             GrayLevel[0]], 
            Cell[
             StyleData["RefGuideLink", "EnhancedPrintout"], FontFamily -> 
             "WRICourier", FontVariations -> {"Underline" -> False}, 
             FontColor -> GrayLevel[0]], 
            Cell[
             StyleData["RefGuideLink", "EnhancedPrintoutNonGray"], FontFamily -> 
             "WRICourier", FontVariations -> {"Underline" -> False}, 
             FontColor -> GrayLevel[0]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["GettingStartedLink"], StyleMenuListing -> None, 
             ButtonStyleMenuListing -> Automatic, 
             FontVariations -> {"Underline" -> True}, FontColor -> 
             RGBColor[0, 0, 1], 
             ButtonBoxOptions -> {
              Active -> True, Appearance -> {Automatic, None}, 
               ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`HelpBrowserLookup["GettingStarted", #]}]& )}], 
            Cell[
             StyleData["GettingStartedLink", "Printout"], 
             FontVariations -> {"Underline" -> False}, FontColor -> 
             GrayLevel[0]], 
            Cell[
             StyleData["GettingStartedLink", "EnhancedPrintout"], FontFamily -> 
             "Palatino", FontVariations -> {"Underline" -> False}, FontColor -> 
             GrayLevel[0]], 
            Cell[
             StyleData["GettingStartedLink", "EnhancedPrintoutNonGray"], 
             FontFamily -> "Palatino", 
             FontVariations -> {"Underline" -> False}, FontColor -> 
             GrayLevel[0]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["OtherInformationLink"], StyleMenuListing -> None, 
             ButtonStyleMenuListing -> Automatic, 
             FontVariations -> {"Underline" -> True}, FontColor -> 
             RGBColor[0, 0, 1], 
             ButtonBoxOptions -> {
              Active -> True, Appearance -> {Automatic, None}, 
               ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`HelpBrowserLookup["OtherInformation", #]}]& )}], 
            Cell[
             StyleData["OtherInformationLink", "Printout"], 
             FontVariations -> {"Underline" -> False}, FontColor -> 
             GrayLevel[0]], 
            Cell[
             StyleData["OtherInformationLink", "EnhancedPrintout"], 
             FontFamily -> "Palatino", 
             FontVariations -> {"Underline" -> False}, FontColor -> 
             GrayLevel[0]], 
            Cell[
             StyleData["OtherInformationLink", "EnhancedPrintoutNonGray"], 
             FontFamily -> "Palatino", 
             FontVariations -> {"Underline" -> False}, FontColor -> 
             GrayLevel[0]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["OtherInformationLinkMR"], StyleMenuListing -> None, 
             FontFamily -> "Courier", FontVariations -> {"Underline" -> True},
              FontColor -> RGBColor[0, 0, 1], 
             ButtonBoxOptions -> {
              Active -> True, Appearance -> {Automatic, None}, 
               ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`HelpBrowserLookup["OtherInformation", #]}]& )}], 
            Cell[
             StyleData["OtherInformationLinkMR", "Printout"], 
             FontVariations -> {"Underline" -> False}, FontColor -> 
             GrayLevel[0]], 
            Cell[
             StyleData["OtherInformationLinkMR", "EnhancedPrintout"], 
             FontVariations -> {"Underline" -> False}, FontColor -> 
             GrayLevel[0]], 
            Cell[
             StyleData["OtherInformationLinkMR", "EnhancedPrintoutNonGray"], 
             FontVariations -> {"Underline" -> False}, FontColor -> 
             GrayLevel[0]]}, Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Palette Styles", "Section"], 
         Cell[
         "The cells below define styles that define standard ButtonFunctions, \
for use in palette buttons.", "Text"], 
         Cell[
          StyleData["Paste"], StyleMenuListing -> None, 
          ButtonStyleMenuListing -> Automatic, 
          ButtonBoxOptions -> {ButtonFunction :> (FrontEndExecute[{
               FrontEnd`NotebookApply[
                FrontEnd`InputNotebook[], #, After]}]& )}], 
         Cell[
          StyleData["Evaluate"], StyleMenuListing -> None, 
          ButtonStyleMenuListing -> Automatic, 
          ButtonBoxOptions -> {ButtonFunction :> (FrontEndExecute[{
               FrontEnd`NotebookApply[
                FrontEnd`InputNotebook[], #, All], 
               SelectionEvaluate[
                FrontEnd`InputNotebook[], All]}]& )}], 
         Cell[
          StyleData["EvaluateCell"], StyleMenuListing -> None, 
          ButtonStyleMenuListing -> Automatic, 
          ButtonBoxOptions -> {ButtonFunction :> (FrontEndExecute[{
               FrontEnd`NotebookApply[
                FrontEnd`InputNotebook[], #, All], 
               FrontEnd`SelectionMove[
                FrontEnd`InputNotebook[], All, Cell, 1], 
               FrontEnd`SelectionEvaluateCreateCell[
                FrontEnd`InputNotebook[], All]}]& )}], 
         Cell[
          StyleData["CopyEvaluate"], StyleMenuListing -> None, 
          ButtonStyleMenuListing -> Automatic, 
          ButtonBoxOptions -> {ButtonFunction :> (FrontEndExecute[{
               FrontEnd`SelectionCreateCell[
                FrontEnd`InputNotebook[], All], 
               FrontEnd`NotebookApply[
                FrontEnd`InputNotebook[], #, All], 
               FrontEnd`SelectionEvaluate[
                FrontEnd`InputNotebook[], All]}]& )}], 
         Cell[
          StyleData["CopyEvaluateCell"], StyleMenuListing -> None, 
          ButtonStyleMenuListing -> Automatic, 
          ButtonBoxOptions -> {ButtonFunction :> (FrontEndExecute[{
               FrontEnd`SelectionCreateCell[
                FrontEnd`InputNotebook[], All], 
               FrontEnd`NotebookApply[
                FrontEnd`InputNotebook[], #, All], 
               FrontEnd`SelectionEvaluateCreateCell[
                FrontEnd`InputNotebook[], All]}]& )}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Inline Formatting", "Section"], 
         Cell[
         "These styles are for modifying individual words or letters in a \
cell exclusive of the cell tag.", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["JT"], StyleMenuListing -> None, FontFamily -> 
             "JFontText"], 
            Cell[
             StyleData["JT", "Printout"]], 
            Cell[
             StyleData["JT", "EnhancedPrintout"]], 
            Cell[
             StyleData["JT", "EnhancedPrintoutNonGray"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["JS"], StyleMenuListing -> None, FontFamily -> 
             "JFontSans"], 
            Cell[
             StyleData["JS", "Printout"]], 
            Cell[
             StyleData["JS", "EnhancedPrintout"]], 
            Cell[
             StyleData["JS", "EnhancedPrintoutNonGray"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["JSB"], StyleMenuListing -> None, FontFamily -> 
             "JFontSansBold"], 
            Cell[
             StyleData["JSB", "Printout"]], 
            Cell[
             StyleData["JSB", "EnhancedPrintout"]], 
            Cell[
             StyleData["JSB", "EnhancedPrintoutNonGray"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["RM"], StyleMenuListing -> None, FontWeight -> "Plain",
              FontSlant -> "Plain"], 
            Cell[
             StyleData["RM", "Printout"]], 
            Cell[
             StyleData["RM", "EnhancedPrintout"]], 
            Cell[
             StyleData["RM", "EnhancedPrintoutNonGray"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["BF"], ConversionRules :> {"HTML" -> {"<b>", "</b>"}}, 
             StyleMenuListing -> None, FontWeight -> "Bold"], 
            Cell[
             StyleData["BF", "Printout"]], 
            Cell[
             StyleData["BF", "EnhancedPrintout"]], 
            Cell[
             StyleData["BF", "EnhancedPrintoutNonGray"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["IT"], ConversionRules :> {"HTML" -> {"<i>", "</i>"}}, 
             StyleMenuListing -> None, FontSlant -> "Italic"], 
            Cell[
             StyleData["IT", "Printout"]], 
            Cell[
             StyleData["IT", "EnhancedPrintout"]], 
            Cell[
             StyleData["IT", "EnhancedPrintoutNonGray"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["TR"], StyleMenuListing -> None, FontFamily -> "Times",
              FontWeight -> "Plain", FontSlant -> "Plain"], 
            Cell[
             StyleData["TR", "Printout"]], 
            Cell[
             StyleData["TR", "EnhancedPrintout"]], 
            Cell[
             StyleData["TR", "EnhancedPrintoutNonGray"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["TI"], ConversionRules :> {"HTML" -> {"<i>", "</i>"}}, 
             StyleMenuListing -> None, FontFamily -> "Times", FontSlant -> 
             "Italic"], 
            Cell[
             StyleData["TI", "Printout"]], 
            Cell[
             StyleData["TI", "EnhancedPrintout"]], 
            Cell[
             StyleData["TI", "EnhancedPrintoutNonGray"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["TB"], ConversionRules :> {"HTML" -> {"<b>", "</b>"}}, 
             StyleMenuListing -> None, FontFamily -> "Times", FontWeight -> 
             "Bold", FontSlant -> "Plain"], 
            Cell[
             StyleData["TB", "Printout"]], 
            Cell[
             StyleData["TB", "EnhancedPrintout"], FontFamily -> "Palatino"], 
            Cell[
             StyleData["TB", "EnhancedPrintoutNonGray"], FontFamily -> 
             "Palatino"]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["TBI"], 
             ConversionRules :> {"HTML" -> {"<b><i>", "</i></b>"}}, 
             StyleMenuListing -> None, FontFamily -> "Times", FontWeight -> 
             "Bold", FontSlant -> "Italic"], 
            Cell[
             StyleData["TBI", "Printout"]], 
            Cell[
             StyleData["TBI", "EnhancedPrintout"], FontFamily -> "Palatino"], 
            
            Cell[
             StyleData["TBI", "EnhancedPrintoutNonGray"], FontFamily -> 
             "Palatino"]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["MR"], 
             ConversionRules :> {"HTML" -> {"<tt>", "</tt>"}}, Hyphenation -> 
             True, HyphenationOptions -> {
              "HyphenationCharacter" -> "\[Continuation]"}, StyleMenuListing -> 
             None, FontFamily -> "Courier", FontWeight -> "Plain", FontSlant -> 
             "Plain"], 
            Cell[
             StyleData["MR", "Printout"]], 
            Cell[
             StyleData["MR", "EnhancedPrintout"], FontFamily -> "WriCourier"], 
            Cell[
             StyleData["MR", "EnhancedPrintoutNonGray"], FontFamily -> 
             "WriCourier"]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["MO"], 
             ConversionRules :> {"HTML" -> {"<tt><i>", "</i></tt>"}}, 
             HyphenationOptions -> {
              "HyphenationCharacter" -> "\[Continuation]"}, StyleMenuListing -> 
             None, FontFamily -> "Courier", FontWeight -> "Plain", FontSlant -> 
             "Italic"], 
            Cell[
             StyleData["MO", "Printout"]], 
            Cell[
             StyleData["MO", "EnhancedPrintout"], FontFamily -> "WriCourier"], 
            Cell[
             StyleData["MO", "EnhancedPrintoutNonGray"], FontFamily -> 
             "WriCourier"]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["MB"], 
             ConversionRules :> {"HTML" -> {"<tt><b>", "</b></tt>"}}, 
             HyphenationOptions -> {
              "HyphenationCharacter" -> "\[Continuation]"}, StyleMenuListing -> 
             None, FontFamily -> "Courier", FontWeight -> "Bold", FontSlant -> 
             "Plain"], 
            Cell[
             StyleData["MB", "Printout"]], 
            Cell[
             StyleData["MB", "EnhancedPrintout"], FontFamily -> "WriCourier"], 
            Cell[
             StyleData["MB", "EnhancedPrintoutNonGray"], FontFamily -> 
             "WriCourier"]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["MBO"], 
             ConversionRules :> {"HTML" -> {"<tt><i><b>", "</b></i></tt>"}}, 
             HyphenationOptions -> {
              "HyphenationCharacter" -> "\[Continuation]"}, StyleMenuListing -> 
             None, FontFamily -> "Courier", FontWeight -> "Bold", FontSlant -> 
             "Italic"], 
            Cell[
             StyleData["MBO", "Printout"]], 
            Cell[
             StyleData["MBO", "EnhancedPrintout"], FontFamily -> 
             "WriCourier"], 
            Cell[
             StyleData["MBO", "EnhancedPrintoutNonGray"], FontFamily -> 
             "WriCourier"]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["SR"], 
             ConversionRules :> {
              "HTML" -> {"<font=\"Helvetica, Arial\">", "</font>"}}, 
             StyleMenuListing -> None, FontFamily -> "Helvetica", FontWeight -> 
             "Plain", FontSlant -> "Plain"], 
            Cell[
             StyleData["SR", "Printout"]], 
            Cell[
             StyleData["SR", "EnhancedPrintout"], FontFamily -> "Futura"], 
            Cell[
             StyleData["SR", "EnhancedPrintoutNonGray"], FontFamily -> 
             "Futura"]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["SO"], 
             ConversionRules :> {
              "HTML" -> {"<font=\"Futura\"><i>", "</i></font>"}}, 
             StyleMenuListing -> None, FontFamily -> "Helvetica", FontWeight -> 
             "Plain", FontSlant -> "Italic"], 
            Cell[
             StyleData["SO", "Printout"], 
             ConversionRules :> {
              "HTML" -> {"<I><Font=Futura>", "</I></Font>"}}, 
             StyleMenuListing -> None, FontFamily -> "Helvetica", FontWeight -> 
             "Plain", FontSlant -> "Italic"], 
            Cell[
             StyleData["SO", "EnhancedPrintout"], FontFamily -> "Futura"], 
            Cell[
             StyleData["SO", "EnhancedPrintoutNonGray"], FontFamily -> 
             "Futura"]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["SB"], 
             ConversionRules :> {
              "HTML" -> {"<font=\"Futura\"><b>", "</b></font>"}}, 
             StyleMenuListing -> None, FontFamily -> "Helvetica", FontWeight -> 
             "Bold", FontSlant -> "Plain"], 
            Cell[
             StyleData["SB", "Printout"], 
             ConversionRules :> {
              "HTML" -> {"<B><Font=Futura>", "</B></Font>"}}, 
             StyleMenuListing -> None, FontFamily -> "Helvetica", FontWeight -> 
             "Bold", FontSlant -> "Plain"], 
            Cell[
             StyleData["SB", "EnhancedPrintout"], FontFamily -> "Futura"], 
            Cell[
             StyleData["SB", "EnhancedPrintoutNonGray"], FontFamily -> 
             "Futura"]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["SBO"], 
             ConversionRules :> {
              "HTML" -> {"<font=\"Futura\"><b><i>", "</i></b></font>"}}, 
             StyleMenuListing -> None, FontFamily -> "Helvetica", FontWeight -> 
             "Bold", FontSlant -> "Italic"], 
            Cell[
             StyleData["SBO", "Printout"], 
             ConversionRules :> {
              "HTML" -> {"<B><I><Font=Futura>", "</B></I></Font>"}}, 
             StyleMenuListing -> None, FontFamily -> "Helvetica", FontWeight -> 
             "Bold", FontSlant -> "Italic"], 
            Cell[
             StyleData["SBO", "EnhancedPrintout"], FontFamily -> "Futura"], 
            Cell[
             StyleData["SBO", "EnhancedPrintoutNonGray"], FontFamily -> 
             "Futura"]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["M4"], ShowCellBracket -> True, StyleMenuListing -> 
             None, FontFamily -> "Math4", CharacterEncoding -> "Math4"], 
            Cell[
             StyleData["M4", "Printout"], ShowCellBracket -> True, 
             StyleMenuListing -> None, FontFamily -> "Math4", 
             CharacterEncoding -> "Math4"], 
            Cell[
             StyleData["M4", "EnhancedPrintout"], ShowCellBracket -> True, 
             StyleMenuListing -> None, FontFamily -> "Math4", 
             CharacterEncoding -> "Math4"], 
            Cell[
             StyleData["M4", "EnhancedPrintoutNonGray"], ShowCellBracket -> 
             True, StyleMenuListing -> None, FontFamily -> "Math4", 
             CharacterEncoding -> "Math4"]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["SO10"], 
             ConversionRules :> {
              "HTML" -> {"<font=\"Helvetica, Arial\"><i>", "</i></font>"}}, 
             StyleMenuListing -> None, FontFamily -> "Helvetica", FontSize -> 
             10, FontWeight -> "Plain", FontSlant -> "Italic"], 
            Cell[
             StyleData["SO10", "Printout"], StyleMenuListing -> None, 
             FontFamily -> "Helvetica", FontSize -> 8, FontWeight -> "Plain", 
             FontSlant -> "Italic"], 
            Cell[
             StyleData["SO10", "EnhancedPrintout"], StyleMenuListing -> None, 
             FontFamily -> "Futura", FontSize -> 8, FontWeight -> "Plain", 
             FontSlant -> "Italic"], 
            Cell[
             StyleData["SO10", "EnhancedPrintoutNonGray"], StyleMenuListing -> 
             None, FontFamily -> "Futura", FontSize -> 8, FontWeight -> 
             "Plain", FontSlant -> "Italic"]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["C1"], StyleMenuListing -> None, FontColor -> 
             RGBColor[0.4, 0, 1]], 
            Cell[
             StyleData["C1", "Printout"], FontColor -> GrayLevel[0]], 
            Cell[
             StyleData["C1", "EnhancedPrintout"], FontColor -> GrayLevel[0]], 
            
            Cell[
             StyleData["C1", "EnhancedPrintoutNonGray"], FontColor -> 
             GrayLevel[0]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["C1MR"], StyleMenuListing -> None, FontFamily -> 
             "Courier", FontColor -> RGBColor[0.4, 0, 1]], 
            Cell[
             StyleData["C1MR", "Printout"], FontColor -> GrayLevel[0]], 
            Cell[
             StyleData["C1MR", "EnhancedPrintout"], FontColor -> 
             GrayLevel[0]], 
            Cell[
             StyleData["C1MR", "EnhancedPrintoutNonGray"], FontColor -> 
             GrayLevel[0]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["CapSmallCaps"], StyleMenuListing -> None, FontFamily -> 
             "Helvetica", FontWeight -> "Plain", FontSlant -> "Plain"], 
            Cell[
             StyleData["CapSmallCaps", "Printout"]], 
            Cell[
             StyleData["CapSmallCaps", "EnhancedPrintout"], FontFamily -> 
             "Futura"], 
            Cell[
             StyleData["CapSmallCaps", "EnhancedPrintoutNonGray"], FontFamily -> 
             "Futura"]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["KeyboardChars"], StyleMenuListing -> None, FontSize -> 
             12], 
            Cell[
             StyleData["KeyboardChars", "Printout"], FontSize -> 10], 
            Cell[
             StyleData["KeyboardChars", "EnhancedPrintout"], FontSize -> 10], 
            
            Cell[
             StyleData["KeyboardChars", "EnhancedPrintoutNonGray"], FontSize -> 
             10]}, Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Emphasis Boxes and Pictures", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Box"], CellMargins -> {{10, 4}, {0, 8}}, 
             CellHorizontalScrolling -> True, StyleMenuListing -> None, 
             Background -> RGBColor[1, 0.6, 0.6], 
             FrameBoxOptions -> {
              BoxFrame -> 0.5, FrameMargins -> {{True, True}, {True, True}}}, 
             GridBoxOptions -> {GridBoxSpacings -> {"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.7]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}}], 
            Cell[
             StyleData["Box", "Printout"], CellMargins -> {{2, 0}, {0, 8}}, 
             FontSize -> 10, Background -> GrayLevel[0.900008]], 
            Cell[
             StyleData["Box", "EnhancedPrintout"], 
             CellMargins -> {{2, 0}, {0, 8}}, FontSize -> 10, Background -> 
             GrayLevel[0.900008]], 
            Cell[
             StyleData["Box", "EnhancedPrintoutNonGray"], 
             CellMargins -> {{2, 0}, {0, 8}}, FontSize -> 10, Background -> 
             GrayLevel[1]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["DoubleBox"], CellMargins -> {{10, 4}, {0, 8}}, 
             CellHorizontalScrolling -> True, StyleMenuListing -> None, 
             Background -> RGBColor[1, 0.6, 0.6], 
             FrameBoxOptions -> {
              BoxFrame -> 0.5, FrameMargins -> {{True, True}, {True, True}}}, 
             GridBoxOptions -> {
              GridBoxAlignment -> {
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Top}}, "RowsIndexed" -> {}}, 
               GridBoxSpacings -> {"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[1.4]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}}], 
            Cell[
             StyleData["DoubleBox", "Printout"], 
             CellMargins -> {{2, 0}, {0, 8}}, FontSize -> 10, Background -> 
             GrayLevel[0.900008]], 
            Cell[
             StyleData["DoubleBox", "EnhancedPrintout"], 
             CellMargins -> {{2, 0}, {0, 8}}, FontSize -> 10, Background -> 
             GrayLevel[0.900008]], 
            Cell[
             StyleData["DoubleBox", "EnhancedPrintoutNonGray"], 
             CellMargins -> {{2, 0}, {0, 8}}, FontSize -> 10, Background -> 
             GrayLevel[1]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["1ColumnBox"], CellMargins -> {{10, 4}, {0, 8}}, 
             CellHorizontalScrolling -> True, LineIndent -> 0, 
             StyleMenuListing -> None, Background -> RGBColor[1, 0.6, 0.6], 
             FrameBoxOptions -> {
              BoxFrame -> 0.5, FrameMargins -> {{True, True}, {True, True}}}, 
             GridBoxOptions -> {GridBoxSpacings -> {"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.7]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}}], 
            Cell[
             StyleData["1ColumnBox", "Printout"], 
             CellMargins -> {{2, 0}, {0, 8}}, FontSize -> 10, Background -> 
             GrayLevel[0.900008]], 
            Cell[
             StyleData["1ColumnBox", "EnhancedPrintout"], 
             CellMargins -> {{2, 0}, {0, 8}}, FontSize -> 10, Background -> 
             GrayLevel[0.900008]], 
            Cell[
             StyleData["1ColumnBox", "EnhancedPrintoutNonGray"], 
             CellMargins -> {{2, 0}, {0, 8}}, FontSize -> 10, Background -> 
             GrayLevel[1]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["2ColumnBox"], CellMargins -> {{10, 4}, {0, 8}}, 
             CellHorizontalScrolling -> True, LineIndent -> 0, 
             StyleMenuListing -> None, Background -> RGBColor[1, 0.6, 0.6], 
             FrameBoxOptions -> {
              BoxFrame -> 0.5, FrameMargins -> {{True, True}, {True, True}}}, 
             GridBoxOptions -> {GridBoxItemSize -> {"Columns" -> {
                   Scaled[0.31], {
                    Scaled[0.67]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
                 "RowsIndexed" -> {}}}], 
            Cell[
             StyleData["2ColumnBox", "Printout"], 
             CellMargins -> {{2, 0}, {0, 8}}, FontSize -> 9, Background -> 
             GrayLevel[0.900008]], 
            Cell[
             StyleData["2ColumnBox", "EnhancedPrintout"], 
             CellMargins -> {{2, 0}, {0, 8}}, FontSize -> 9, Background -> 
             GrayLevel[0.900008]], 
            Cell[
             StyleData["2ColumnBox", "EnhancedPrintoutNonGray"], 
             CellMargins -> {{2, 0}, {0, 8}}, FontSize -> 9, Background -> 
             GrayLevel[1]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["2ColumnEvenBox"], CellMargins -> {{10, 4}, {0, 8}}, 
             CellHorizontalScrolling -> True, LineIndent -> 0, 
             StyleMenuListing -> None, Background -> RGBColor[1, 0.6, 0.6], 
             FrameBoxOptions -> {
              BoxFrame -> 0.5, FrameMargins -> {{True, True}, {True, True}}}, 
             GridBoxOptions -> {GridBoxItemSize -> {"Columns" -> {{
                    Scaled[0.46]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
                 "RowsIndexed" -> {}}}], 
            Cell[
             StyleData["2ColumnEvenBox", "Printout"], 
             CellMargins -> {{2, 0}, {0, 8}}, FontSize -> 10, Background -> 
             GrayLevel[0.900008]], 
            Cell[
             StyleData["2ColumnEvenBox", "EnhancedPrintout"], 
             CellMargins -> {{2, 0}, {0, 8}}, FontSize -> 10, Background -> 
             GrayLevel[0.900008]], 
            Cell[
             StyleData["2ColumnEvenBox", "EnhancedPrintoutNonGray"], 
             CellMargins -> {{2, 0}, {0, 8}}, FontSize -> 10, Background -> 
             GrayLevel[1]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["2ColumnSmallBox"], CellMargins -> {{10, 4}, {0, 8}}, 
             CellHorizontalScrolling -> True, LineIndent -> 0, 
             StyleMenuListing -> None, Background -> RGBColor[1, 0.6, 0.6], 
             FrameBoxOptions -> {
              BoxFrame -> 0.5, FrameMargins -> {{True, True}, {True, True}}}, 
             GridBoxOptions -> {
              GridBoxAlignment -> {
                "Columns" -> {Right, {Left}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}, 
               GridBoxItemSize -> {"Columns" -> {{
                    Scaled[0.35]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
                 "RowsIndexed" -> {}}, GridBoxSpacings -> {"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[1.0499999999999998`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}}], 
            Cell[
             StyleData["2ColumnSmallBox", "Printout"], 
             CellMargins -> {{2, 0}, {0, 8}}, FontSize -> 10, Background -> 
             GrayLevel[0.900008]], 
            Cell[
             StyleData["2ColumnSmallBox", "EnhancedPrintout"], 
             CellMargins -> {{2, 0}, {0, 8}}, FontSize -> 10, Background -> 
             GrayLevel[0.900008]], 
            Cell[
             StyleData["2ColumnSmallBox", "EnhancedPrintoutNonGray"], 
             CellMargins -> {{2, 0}, {0, 8}}, FontSize -> 10, Background -> 
             GrayLevel[1]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["3ColumnBox"], CellMargins -> {{10, 4}, {0, 8}}, 
             CellHorizontalScrolling -> True, LineIndent -> 0, 
             StyleMenuListing -> None, Background -> RGBColor[1, 0.6, 0.6], 
             FrameBoxOptions -> {
              BoxFrame -> 0.5, FrameMargins -> {{True, True}, {True, True}}}, 
             GridBoxOptions -> {GridBoxItemSize -> {"Columns" -> {{
                    Scaled[0.32]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
                 "RowsIndexed" -> {}}}], 
            Cell[
             StyleData["3ColumnBox", "Printout"], 
             CellMargins -> {{2, 0}, {0, 8}}, FontSize -> 10, Background -> 
             GrayLevel[0.900008]], 
            Cell[
             StyleData["3ColumnBox", "EnhancedPrintout"], 
             CellMargins -> {{2, 0}, {0, 8}}, FontSize -> 10, Background -> 
             GrayLevel[0.900008]], 
            Cell[
             StyleData["3ColumnBox", "EnhancedPrintoutNonGray"], 
             CellMargins -> {{2, 0}, {0, 8}}, FontSize -> 10, Background -> 
             GrayLevel[1]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["3ColumnSmallBox"], CellMargins -> {{10, 4}, {0, 8}}, 
             CellHorizontalScrolling -> True, LineIndent -> 0, 
             StyleMenuListing -> None, Background -> RGBColor[1, 0.6, 0.6], 
             FrameBoxOptions -> {
              BoxFrame -> 0.5, FrameMargins -> {{True, True}, {True, True}}}, 
             GridBoxOptions -> {
              GridBoxAlignment -> {
                "Columns" -> {Right, Center, {Left}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}, 
               GridBoxItemSize -> {"Columns" -> {{
                    Scaled[0.24]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
                 "RowsIndexed" -> {}}, GridBoxSpacings -> {"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[1.0499999999999998`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}}], 
            Cell[
             StyleData["3ColumnSmallBox", "Printout"], 
             CellMargins -> {{2, 0}, {0, 8}}, FontSize -> 10, Background -> 
             GrayLevel[0.900008]], 
            Cell[
             StyleData["3ColumnSmallBox", "EnhancedPrintout"], 
             CellMargins -> {{2, 0}, {0, 8}}, FontSize -> 10, Background -> 
             GrayLevel[0.900008]], 
            Cell[
             StyleData["3ColumnSmallBox", "EnhancedPrintoutNonGray"], 
             CellMargins -> {{2, 0}, {0, 8}}, FontSize -> 10, Background -> 
             GrayLevel[1]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["4ColumnBox"], CellMargins -> {{10, 4}, {0, 8}}, 
             CellHorizontalScrolling -> True, LineIndent -> 0, 
             StyleMenuListing -> None, Background -> RGBColor[1, 0.6, 0.6], 
             FrameBoxOptions -> {
              BoxFrame -> 0.5, FrameMargins -> {{True, True}, {True, True}}}, 
             GridBoxOptions -> {GridBoxItemSize -> {"Columns" -> {
                   Scaled[0.13], 
                   Scaled[0.35], 
                   Scaled[0.13], {
                    Scaled[0.35]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
                 "RowsIndexed" -> {}}}], 
            Cell[
             StyleData["4ColumnBox", "Printout"], 
             CellMargins -> {{2, 0}, {0, 8}}, FontSize -> 10, Background -> 
             GrayLevel[0.900008]], 
            Cell[
             StyleData["4ColumnBox", "EnhancedPrintout"], 
             CellMargins -> {{2, 0}, {0, 8}}, FontSize -> 10, Background -> 
             GrayLevel[0.900008]], 
            Cell[
             StyleData["4ColumnBox", "EnhancedPrintoutNonGray"], 
             CellMargins -> {{2, 0}, {0, 8}}, FontSize -> 10, Background -> 
             GrayLevel[1]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["5ColumnBox"], CellMargins -> {{10, 4}, {0, 8}}, 
             CellHorizontalScrolling -> True, LineIndent -> 0, 
             StyleMenuListing -> None, Background -> RGBColor[1, 0.6, 0.6], 
             FrameBoxOptions -> {
              BoxFrame -> 0.5, FrameMargins -> {{True, True}, {True, True}}}, 
             GridBoxOptions -> {GridBoxItemSize -> {"Columns" -> {{
                    Scaled[0.202]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}},
                  "RowsIndexed" -> {}}}], 
            Cell[
             StyleData["5ColumnBox", "Printout"], 
             CellMargins -> {{2, 0}, {0, 8}}, FontSize -> 9, Background -> 
             GrayLevel[0.900008]], 
            Cell[
             StyleData["5ColumnBox", "EnhancedPrintout"], 
             CellMargins -> {{2, 0}, {0, 8}}, FontSize -> 9, Background -> 
             GrayLevel[0.900008]], 
            Cell[
             StyleData["5ColumnBox", "EnhancedPrintoutNonGray"], 
             CellMargins -> {{2, 0}, {0, 8}}, FontSize -> 9, Background -> 
             GrayLevel[1]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["6ColumnBox"], CellMargins -> {{10, 4}, {0, 8}}, 
             CellHorizontalScrolling -> True, LineIndent -> 0, 
             StyleMenuListing -> None, Background -> RGBColor[1, 0.6, 0.6], 
             FrameBoxOptions -> {
              BoxFrame -> 0.5, FrameMargins -> {{True, True}, {True, True}}}, 
             GridBoxOptions -> {GridBoxItemSize -> {"Columns" -> {
                   Scaled[0.12], 
                   Scaled[0.22], 
                   Scaled[0.12], 
                   Scaled[0.12], 
                   Scaled[0.22], {
                    Scaled[0.12]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
                 "RowsIndexed" -> {}}}], 
            Cell[
             StyleData["6ColumnBox", "Printout"], 
             CellMargins -> {{2, 0}, {0, 8}}, FontSize -> 10, Background -> 
             GrayLevel[0.900008]], 
            Cell[
             StyleData["6ColumnBox", "EnhancedPrintout"], 
             CellMargins -> {{2, 0}, {0, 8}}, FontSize -> 10, Background -> 
             GrayLevel[0.900008]], 
            Cell[
             StyleData["6ColumnBox", "EnhancedPrintoutNonGray"], 
             CellMargins -> {{2, 0}, {0, 8}}, FontSize -> 10, Background -> 
             GrayLevel[1]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["FramedBox"], CellFrame -> 0.5, 
             CellMargins -> {{10, 4}, {0, 8}}, CellHorizontalScrolling -> 
             True, PageBreakWithin -> False, AutoIndent -> False, AutoSpacing -> 
             False, LineIndent -> 0, FontWeight -> "Plain", Background -> 
             RGBColor[1, 0.6, 0.6], 
             GridBoxOptions -> {
              GridBoxAlignment -> {
                "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}, 
               GridBoxSpacings -> {"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.5599999999999999]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.6]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}}], 
            Cell[
             StyleData["FramedBox", "Printout"], 
             CellMargins -> {{2, 4}, {0, 8}}, FontSize -> 10, Background -> 
             GrayLevel[1]], 
            Cell[
             StyleData["FramedBox", "EnhancedPrintout"], 
             CellMargins -> {{2, 4}, {0, 8}}, FontFamily -> "Palatino", 
             FontSize -> 10, Background -> GrayLevel[1]], 
            Cell[
             StyleData["FramedBox", "EnhancedPrintoutNonGray"], 
             CellMargins -> {{2, 4}, {0, 8}}, FontFamily -> "Palatino", 
             FontSize -> 10, Background -> GrayLevel[1]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["DefinitionBox"], CellFrame -> 0.5, 
             CellMargins -> {{10, 4}, {0, 8}}, CellHorizontalScrolling -> 
             True, PageBreakWithin -> False, AutoIndent -> False, AutoSpacing -> 
             False, LineIndent -> 0, FontWeight -> "Plain", Background -> 
             RGBColor[1, 0.6, 0.6], 
             GridBoxOptions -> {
              GridBoxAlignment -> {
                "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}, 
               GridBoxItemSize -> {"Columns" -> {
                   Scaled[0.4], {
                    Scaled[0.6]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
                 "RowsIndexed" -> {}}, GridBoxSpacings -> {"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.7]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.6]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}}], 
            Cell[
             StyleData["DefinitionBox", "Printout"], 
             CellMargins -> {{2, 4}, {0, 8}}, FontSize -> 10, Background -> 
             GrayLevel[1]], 
            Cell[
             StyleData["DefinitionBox", "EnhancedPrintout"], 
             CellMargins -> {{2, 4}, {0, 8}}, FontFamily -> "Palatino", 
             FontSize -> 10, Background -> GrayLevel[1]], 
            Cell[
             StyleData["DefinitionBox", "EnhancedPrintoutNonGray"], 
             CellMargins -> {{2, 4}, {0, 8}}, FontFamily -> "Palatino", 
             FontSize -> 10, Background -> GrayLevel[1]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["DefinitionBox3Col"], CellFrame -> 0.5, 
             CellMargins -> {{10, 4}, {0, 8}}, CellHorizontalScrolling -> 
             True, PageBreakWithin -> False, AutoIndent -> False, AutoSpacing -> 
             False, LineIndent -> 0, FontWeight -> "Plain", Background -> 
             RGBColor[1, 0.6, 0.6], 
             GridBoxOptions -> {
              GridBoxAlignment -> {
                "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}, 
               GridBoxItemSize -> {"Columns" -> {
                   Scaled[0.35], 
                   Scaled[0.2], {
                    Scaled[0.45]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
                 "RowsIndexed" -> {}}, GridBoxSpacings -> {"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.7]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.6]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}}], 
            Cell[
             StyleData["DefinitionBox3Col", "Printout"], 
             CellMargins -> {{2, 4}, {0, 8}}, FontSize -> 10, Background -> 
             GrayLevel[1]], 
            Cell[
             StyleData["DefinitionBox3Col", "EnhancedPrintout"], 
             CellMargins -> {{2, 4}, {0, 8}}, FontFamily -> "Palatino", 
             FontSize -> 10, Background -> GrayLevel[1]], 
            Cell[
             StyleData["DefinitionBox3Col", "EnhancedPrintoutNonGray"], 
             CellMargins -> {{2, 4}, {0, 8}}, FontFamily -> "Palatino", 
             FontSize -> 10, Background -> GrayLevel[1]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["DefinitionBox4Col"], CellFrame -> 0.5, 
             CellMargins -> {{10, 4}, {0, 8}}, CellHorizontalScrolling -> 
             True, PageBreakWithin -> False, AutoIndent -> False, AutoSpacing -> 
             False, LineIndent -> 0, FontWeight -> "Plain", Background -> 
             RGBColor[1, 0.6, 0.6], 
             GridBoxOptions -> {
              GridBoxAlignment -> {
                "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}, 
               GridBoxItemSize -> {"Columns" -> {
                   Scaled[0.15], 
                   Scaled[0.35], 
                   Scaled[0.15], {
                    Scaled[0.35]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
                 "RowsIndexed" -> {}}, GridBoxSpacings -> {"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.7]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.6]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}}], 
            Cell[
             StyleData["DefinitionBox4Col", "Printout"], 
             CellMargins -> {{2, 4}, {0, 8}}, FontSize -> 10, Background -> 
             GrayLevel[1]], 
            Cell[
             StyleData["DefinitionBox4Col", "EnhancedPrintout"], 
             CellMargins -> {{2, 4}, {0, 8}}, FontFamily -> "Palatino", 
             FontSize -> 10, Background -> GrayLevel[1]], 
            Cell[
             StyleData["DefinitionBox4Col", "EnhancedPrintoutNonGray"], 
             CellMargins -> {{2, 4}, {0, 8}}, FontFamily -> "Palatino", 
             FontSize -> 10, Background -> GrayLevel[1]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["DefinitionBox5Col"], CellFrame -> 0.5, 
             CellMargins -> {{10, 4}, {0, 8}}, CellHorizontalScrolling -> 
             True, PageBreakWithin -> False, AutoIndent -> False, AutoSpacing -> 
             False, LineIndent -> 0, FontWeight -> "Plain", Background -> 
             RGBColor[1, 0.6, 0.6], 
             GridBoxOptions -> {
              GridBoxAlignment -> {
                "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}, 
               GridBoxItemSize -> {"Columns" -> {{
                    Scaled[0.2]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
                 "RowsIndexed" -> {}}, GridBoxSpacings -> {"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.7]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.6]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}}], 
            Cell[
             StyleData["DefinitionBox5Col", "Printout"], 
             CellMargins -> {{2, 4}, {0, 8}}, FontSize -> 10, Background -> 
             GrayLevel[1]], 
            Cell[
             StyleData["DefinitionBox5Col", "EnhancedPrintout"], 
             CellMargins -> {{2, 4}, {0, 8}}, FontFamily -> "Palatino", 
             FontSize -> 10, Background -> GrayLevel[1]], 
            Cell[
             StyleData["DefinitionBox5Col", "EnhancedPrintoutNonGray"], 
             CellMargins -> {{2, 4}, {0, 8}}, FontFamily -> "Palatino", 
             FontSize -> 10, Background -> GrayLevel[1]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["DefinitionBox6Col"], CellFrame -> 0.5, 
             CellMargins -> {{10, 4}, {0, 8}}, CellHorizontalScrolling -> 
             True, PageBreakWithin -> False, AutoIndent -> False, AutoSpacing -> 
             False, LineIndent -> 0, FontWeight -> "Plain", Background -> 
             RGBColor[1, 0.6, 0.6], 
             GridBoxOptions -> {
              GridBoxAlignment -> {
                "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}, 
               GridBoxItemSize -> {"Columns" -> {
                   Scaled[0.13], 
                   Scaled[0.24], 
                   Scaled[0.13], 
                   Scaled[0.13], 
                   Scaled[0.24], {
                    Scaled[0.13]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
                 "RowsIndexed" -> {}}, GridBoxSpacings -> {"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.7]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.6]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}}], 
            Cell[
             StyleData["DefinitionBox6Col", "Printout"], 
             CellMargins -> {{2, 4}, {0, 8}}, FontSize -> 10, Background -> 
             GrayLevel[1]], 
            Cell[
             StyleData["DefinitionBox6Col", "EnhancedPrintout"], 
             CellMargins -> {{2, 4}, {0, 8}}, FontFamily -> "Palatino", 
             FontSize -> 10, Background -> GrayLevel[1]], 
            Cell[
             StyleData["DefinitionBox6Col", "EnhancedPrintoutNonGray"], 
             CellMargins -> {{2, 4}, {0, 8}}, FontFamily -> "Palatino", 
             FontSize -> 10, Background -> GrayLevel[1]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["TopBox"], CellFrame -> {{0.5, 0.5}, {0, 0.5}}, 
             CellMargins -> {{11, 4}, {0, 8}}, CellHorizontalScrolling -> 
             True, PageBreakBelow -> False, AutoIndent -> False, AutoSpacing -> 
             False, LineIndent -> 0, StyleMenuListing -> None, FontWeight -> 
             "Plain", Background -> RGBColor[1, 0.6, 0.6], 
             GridBoxOptions -> {
              GridBoxAlignment -> {
                "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}, 
               GridBoxItemSize -> {"Columns" -> {
                   Scaled[0.31], {
                    Scaled[0.62]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
                 "RowsIndexed" -> {}}, GridBoxSpacings -> {"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.7]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.6]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}}], 
            Cell[
             StyleData["TopBox", "Printout"], CellMargins -> {{2, 0}, {0, 8}},
              Background -> GrayLevel[1]], 
            Cell[
             StyleData["TopBox", "EnhancedPrintout"], 
             CellMargins -> {{2, 0}, {0, 8}}, FontFamily -> "Palatino", 
             Background -> GrayLevel[1]], 
            Cell[
             StyleData["TopBox", "EnhancedPrintoutNonGray"], 
             CellMargins -> {{2, 0}, {0, 8}}, FontFamily -> "Palatino", 
             Background -> GrayLevel[1]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["MiddleBox"], CellFrame -> {{0.5, 0.5}, {0, 0}}, 
             CellMargins -> {{11, 4}, {0, -7}}, CellHorizontalScrolling -> 
             True, PageBreakAbove -> False, PageBreakBelow -> False, 
             AutoIndent -> False, AutoSpacing -> False, LineIndent -> 0, 
             StyleMenuListing -> None, FontWeight -> "Plain", Background -> 
             RGBColor[1, 0.6, 0.6], 
             GridBoxOptions -> {
              GridBoxAlignment -> {
                "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}, 
               GridBoxItemSize -> {"Columns" -> {
                   Scaled[0.31], {
                    Scaled[0.62]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
                 "RowsIndexed" -> {}}, GridBoxSpacings -> {"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.7]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.6]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}}], 
            Cell[
             StyleData["MiddleBox", "Printout"], 
             CellMargins -> {{2, 0}, {0, 2}}, Background -> GrayLevel[1]], 
            Cell[
             StyleData["MiddleBox", "EnhancedPrintout"], 
             CellMargins -> {{2, 0}, {0, 4}}, FontFamily -> "Palatino", 
             Background -> GrayLevel[1]], 
            Cell[
             StyleData["MiddleBox", "EnhancedPrintoutNonGray"], 
             CellMargins -> {{2, 0}, {0, 4}}, FontFamily -> "Palatino", 
             Background -> GrayLevel[1]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["BottomBox"], CellFrame -> {{0.5, 0.5}, {0.5, 0}}, 
             CellMargins -> {{11, 4}, {0, -7}}, CellHorizontalScrolling -> 
             True, PageBreakAbove -> False, PageBreakBelow -> False, 
             AutoIndent -> False, AutoSpacing -> False, LineIndent -> 0, 
             StyleMenuListing -> None, FontWeight -> "Plain", Background -> 
             RGBColor[1, 0.6, 0.6], 
             GridBoxOptions -> {
              GridBoxAlignment -> {
                "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}, 
               GridBoxItemSize -> {"Columns" -> {
                   Scaled[0.31], {
                    Scaled[0.62]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
                 "RowsIndexed" -> {}}, GridBoxSpacings -> {"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.7]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.6]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}}], 
            Cell[
             StyleData["BottomBox", "Printout"], 
             CellMargins -> {{2, 0}, {0, -5}}, FontSize -> 10, Background -> 
             GrayLevel[1], 
             GridBoxOptions -> {
              GridBoxItemSize -> {
                "Columns" -> {{All}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{2.2}}, "RowsIndexed" -> {}}}], 
            Cell[
             StyleData["BottomBox", "EnhancedPrintout"], 
             CellMargins -> {{2, 0}, {0, -5}}, FontFamily -> "Palatino", 
             FontSize -> 10, Background -> GrayLevel[1], 
             GridBoxOptions -> {
              GridBoxItemSize -> {
                "Columns" -> {{All}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{2.2}}, "RowsIndexed" -> {}}}], 
            Cell[
             StyleData["BottomBox", "EnhancedPrintoutNonGray"], 
             CellMargins -> {{2, 0}, {0, -5}}, FontFamily -> "Palatino", 
             FontSize -> 10, Background -> GrayLevel[1], 
             GridBoxOptions -> {
              GridBoxItemSize -> {
                "Columns" -> {{All}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{2.2}}, "RowsIndexed" -> {}}}]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["TopSpanBox"], CellFrame -> {{0.5, 0.5}, {0, 0.5}}, 
             CellMargins -> {{11, 4}, {-2, 8}}, CellHorizontalScrolling -> 
             True, PageBreakBelow -> False, AutoIndent -> False, AutoSpacing -> 
             False, LineIndent -> 0, StyleMenuListing -> None, FontWeight -> 
             "Plain", Background -> RGBColor[1, 0.6, 0.6], 
             GridBoxOptions -> {
              GridBoxAlignment -> {
                "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}, 
               GridBoxItemSize -> {"Columns" -> {
                   Scaled[0.9], {
                    Scaled[0.03]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
                 "RowsIndexed" -> {}}, GridBoxSpacings -> {"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.7]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.6]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}}], 
            Cell[
             StyleData["TopSpanBox", "Printout"], 
             CellMargins -> {{2, 0}, {-2, 8}}, FontSize -> 10, Background -> 
             GrayLevel[1]], 
            Cell[
             StyleData["TopSpanBox", "EnhancedPrintout"], 
             CellMargins -> {{2, 0}, {-4, 8}}, FontFamily -> "Palatino", 
             FontSize -> 10, Background -> GrayLevel[1]], 
            Cell[
             StyleData["TopSpanBox", "EnhancedPrintoutNonGray"], 
             CellMargins -> {{2, 0}, {-4, 8}}, FontFamily -> "Palatino", 
             FontSize -> 10, Background -> GrayLevel[1]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["MiddleSpanBox"], CellFrame -> {{0.5, 0.5}, {0, 0}}, 
             CellMargins -> {{11, 4}, {0, 0}}, CellHorizontalScrolling -> 
             True, PageBreakAbove -> False, PageBreakBelow -> False, 
             AutoIndent -> False, AutoSpacing -> False, LineIndent -> 0, 
             StyleMenuListing -> None, FontWeight -> "Plain", Background -> 
             RGBColor[1, 0.6, 0.6], 
             GridBoxOptions -> {
              GridBoxAlignment -> {
                "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}, 
               GridBoxItemSize -> {"Columns" -> {
                   Scaled[0.9], {
                    Scaled[0.03]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
                 "RowsIndexed" -> {}}, GridBoxSpacings -> {"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.7]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.6]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}}], 
            Cell[
             StyleData["MiddleSpanBox", "Printout"], 
             CellMargins -> {{2, 0}, {-5, 0}}, FontSize -> 10, Background -> 
             GrayLevel[1], 
             GridBoxOptions -> {
              GridBoxItemSize -> {
                "Columns" -> {{All}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{1.8}}, "RowsIndexed" -> {}}}], 
            Cell[
             StyleData["MiddleSpanBox", "EnhancedPrintout"], 
             CellMargins -> {{2, 0}, {-7, 0}}, FontFamily -> "Palatino", 
             FontSize -> 10, Background -> GrayLevel[1], 
             GridBoxOptions -> {
              GridBoxItemSize -> {
                "Columns" -> {{All}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{1.8}}, "RowsIndexed" -> {}}}], 
            Cell[
             StyleData["MiddleSpanBox", "EnhancedPrintoutNonGray"], 
             CellMargins -> {{2, 0}, {-7, 0}}, FontFamily -> "Palatino", 
             FontSize -> 10, Background -> GrayLevel[1], 
             GridBoxOptions -> {
              GridBoxItemSize -> {
                "Columns" -> {{All}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{1.8}}, "RowsIndexed" -> {}}}]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Picture"], CellMargins -> {{10, Inherited}, {4, 4}}, 
             CellGroupingRules -> "GraphicsGrouping", CellHorizontalScrolling -> 
             True, StyleMenuListing -> None], 
            Cell[
             StyleData["Picture", "Printout"], 
             CellMargins -> {{2, Inherited}, {4, 4}}, Magnification -> 0.65], 
            
            Cell[
             StyleData["Picture", "EnhancedPrintout"], 
             CellMargins -> {{2, Inherited}, {4, 2}}, Magnification -> 0.65], 
            
            Cell[
             StyleData["Picture", "EnhancedPrintoutNonGray"], 
             CellMargins -> {{2, Inherited}, {4, 2}}, Magnification -> 0.65]},
            Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["OpenCloseItemizedPicture"], 
             CellMargins -> {{41, 4}, {4, 4}}, 
             PrivateCellOptions -> {"DefaultCellGroupOpen" -> False}, 
             CellGroupingRules -> "GraphicsGrouping", CellHorizontalScrolling -> 
             True, StyleMenuListing -> None], 
            Cell[
             StyleData["OpenCloseItemizedPicture", "Printout"], 
             CellMargins -> {{76, 2}, {0, 0}}, 
             CellElementSpacings -> {
              "CellMinHeight" -> 1, "ClosedCellHeight" -> 0}, CellOpen -> 
             False], 
            Cell[
             StyleData["OpenCloseItemizedPicture", "EnhancedPrintout"], 
             CellMargins -> {{76, 2}, {0, 0}}, 
             CellElementSpacings -> {
              "CellMinHeight" -> 1, "ClosedCellHeight" -> 0}, CellOpen -> 
             False], 
            Cell[
             StyleData["OpenCloseItemizedPicture", "EnhancedPrintoutNonGray"],
              CellMargins -> {{76, 2}, {0, 0}}, 
             CellElementSpacings -> {
              "CellMinHeight" -> 1, "ClosedCellHeight" -> 0}, CellOpen -> 
             False]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["ItemizedPicture"], CellMargins -> {{41, 4}, {4, 4}}, 
             CellGroupingRules -> "GraphicsGrouping", CellHorizontalScrolling -> 
             True, StyleMenuListing -> None], 
            Cell[
             StyleData["ItemizedPicture", "Printout"], 
             CellMargins -> {{77, 2}, {4, -4}}, Magnification -> 0.5], 
            Cell[
             StyleData["ItemizedPicture", "EnhancedPrintout"], 
             CellMargins -> {{78, 2}, {12, -6}}, Magnification -> 0.5], 
            Cell[
             StyleData["ItemizedPicture", "EnhancedPrintoutNonGray"], 
             CellMargins -> {{75, 2}, {4, -6}}, Magnification -> 0.5]}, 
           Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["PictureGroup"], CellMargins -> {{41, 4}, {0, 4}}, 
             CellGroupingRules -> "GraphicsGrouping", CellHorizontalScrolling -> 
             True, StyleMenuListing -> None], 
            Cell[
             StyleData["PictureGroup", "Printout"], 
             CellMargins -> {{76, 2}, {0, 0}}, 
             CellElementSpacings -> {
              "CellMinHeight" -> 1, "ClosedCellHeight" -> 0}, CellOpen -> 
             False], 
            Cell[
             StyleData["PictureGroup", "EnhancedPrintout"], 
             CellMargins -> {{76, 2}, {0, 0}}, 
             CellElementSpacings -> {
              "CellMinHeight" -> 1, "ClosedCellHeight" -> 0}, CellOpen -> 
             False], 
            Cell[
             StyleData["PictureGroup", "EnhancedPrintoutNonGray"], 
             CellMargins -> {{76, 2}, {0, 0}}, 
             CellElementSpacings -> {
              "CellMinHeight" -> 1, "ClosedCellHeight" -> 0}, CellOpen -> 
             False]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Sound"], ShowCellBracket -> True, 
             CellMargins -> {{10, Inherited}, {0, 8}}, StyleMenuListing -> 
             None], 
            Cell[
             StyleData["Sound", "Printout"], CellMargins -> {{2, 0}, {0, 8}}, 
             FontSize -> 10], 
            Cell[
             StyleData["Sound", "EnhancedPrintout"], 
             CellMargins -> {{2, 0}, {0, 8}}, FontSize -> 10], 
            Cell[
             StyleData["Sound", "EnhancedPrintoutNonGray"], 
             CellMargins -> {{2, 0}, {0, 8}}, FontSize -> 10]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Caption"], CellMargins -> {{10, 4}, {0, 3}}, 
             PageBreakAbove -> False, StyleMenuListing -> None, FontFamily -> 
             "Helvetica", FontSize -> 9], 
            Cell[
             StyleData["Caption", "Printout"], 
             CellMargins -> {{2, 4}, {2, 0}}, FontSize -> 7], 
            Cell[
             StyleData["Caption", "EnhancedPrintout"], 
             CellMargins -> {{5, 4}, {2, -2}}, FontFamily -> "Futura", 
             FontSize -> 7], 
            Cell[
             StyleData["Caption", "EnhancedPrintoutNonGray"], 
             CellMargins -> {{5, 4}, {2, -2}}, FontFamily -> "Futura", 
             FontSize -> 7]}, Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Tables", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["2ColumnTable"], CellMargins -> {{10, 4}, {0, 8}}, 
             CellHorizontalScrolling -> True, LineIndent -> 0, 
             StyleMenuListing -> None, 
             GridBoxOptions -> {
              GridBoxAlignment -> {
                "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}, 
               GridBoxItemSize -> {"Columns" -> {
                   Scaled[0.34], {
                    Scaled[0.64]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
                 "RowsIndexed" -> {}}}], 
            Cell[
             StyleData["2ColumnTable", "Printout"], 
             CellMargins -> {{2, 0}, {0, 8}}, FontSize -> 9], 
            Cell[
             StyleData["2ColumnTable", "EnhancedPrintout"], 
             CellMargins -> {{2, 0}, {0, 8}}, FontSize -> 9], 
            Cell[
             StyleData["2ColumnTable", "EnhancedPrintoutNonGray"], 
             CellMargins -> {{2, 0}, {0, 8}}, FontSize -> 9]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["2ColumnEvenTable"], CellMargins -> {{10, 4}, {0, 8}}, 
             CellHorizontalScrolling -> True, LineIndent -> 0, 
             StyleMenuListing -> None, 
             GridBoxOptions -> {
              GridBoxAlignment -> {
                "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}, 
               GridBoxItemSize -> {"Columns" -> {{
                    Scaled[0.49]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
                 "RowsIndexed" -> {}}}], 
            Cell[
             StyleData["2ColumnEvenTable", "Printout"], 
             CellMargins -> {{2, 0}, {0, 8}}, FontSize -> 9], 
            Cell[
             StyleData["2ColumnEvenTable", "EnhancedPrintout"], 
             CellMargins -> {{2, 0}, {0, 8}}, FontSize -> 9], 
            Cell[
             StyleData["2ColumnEvenTable", "EnhancedPrintoutNonGray"], 
             CellMargins -> {{2, 0}, {0, 8}}, FontSize -> 9]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["3ColumnTable"], CellMargins -> {{10, 4}, {0, 8}}, 
             CellHorizontalScrolling -> True, LineIndent -> 0, 
             StyleMenuListing -> None, 
             GridBoxOptions -> {
              GridBoxAlignment -> {
                "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}, 
               GridBoxItemSize -> {"Columns" -> {
                   Scaled[0.28], 
                   Scaled[0.28], {
                    Scaled[0.43]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
                 "RowsIndexed" -> {}}}], 
            Cell[
             StyleData["3ColumnTable", "Printout"], 
             CellMargins -> {{2, 0}, {0, 8}}, FontSize -> 9], 
            Cell[
             StyleData["3ColumnTable", "EnhancedPrintout"], 
             CellMargins -> {{2, 0}, {0, 8}}, FontSize -> 9], 
            Cell[
             StyleData["3ColumnTable", "EnhancedPrintoutNonGray"], 
             CellMargins -> {{2, 0}, {0, 8}}, FontSize -> 9]}, Closed]]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell["Formulas and Programming", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["InlineFormula"], CellMargins -> {{10, 4}, {0, 8}}, 
             CellHorizontalScrolling -> True, 
             "TwoByteSyntaxCharacterAutoReplacement" -> True, 
             HyphenationOptions -> {
              "HyphenationCharacter" -> "\[Continuation]"}, LanguageCategory -> 
             "Formula", ScriptLevel -> 1, SingleLetterItalics -> True, 
             SpanMaxSize -> Infinity, StyleMenuListing -> None, 
             GridBoxOptions -> {
              GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{1.}}, "RowsIndexed" -> {}}}], 
            Cell[
             StyleData["InlineFormula", "Printout"], 
             CellMargins -> {{2, 0}, {0, 8}}, FontSize -> 10], 
            Cell[
             StyleData["InlineFormula", "EnhancedPrintout"], 
             CellMargins -> {{2, 0}, {0, 8}}, FontSize -> 10], 
            Cell[
             StyleData["InlineFormula", "EnhancedPrintoutNonGray"], 
             CellMargins -> {{2, 0}, {0, 8}}, FontSize -> 10]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["InlineOutput"], CellMargins -> {{10, 4}, {0, 8}}, 
             CellHorizontalScrolling -> True, 
             "TwoByteSyntaxCharacterAutoReplacement" -> True, 
             HyphenationOptions -> {
              "HyphenationCharacter" -> "\[Continuation]"}, LanguageCategory -> 
             None, StyleMenuListing -> None, FontFamily -> "Courier"], 
            Cell[
             StyleData["InlineOutput", "Printout"], 
             CellMargins -> {{2, 0}, {0, 8}}, FontSize -> 9.5], 
            Cell[
             StyleData["InlineOutput", "EnhancedPrintout"], 
             CellMargins -> {{2, 0}, {0, 8}}, FontSize -> 9.5], 
            Cell[
             StyleData["InlineOutput", "EnhancedPrintoutNonGray"], 
             CellMargins -> {{2, 0}, {0, 8}}, FontSize -> 9.5]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["DisplayFormula"], 
             CellMargins -> {{42, Inherited}, {Inherited, 10}}, 
             CellHorizontalScrolling -> True, DefaultFormatType -> 
             DefaultInputFormatType, "TwoByteSyntaxCharacterAutoReplacement" -> 
             True, HyphenationOptions -> {
              "HyphenationCharacter" -> "\[Continuation]"}, LanguageCategory -> 
             "Formula", ScriptLevel -> 0, SingleLetterItalics -> True, 
             SpanMaxSize -> Infinity, 
             UnderoverscriptBoxOptions -> {LimitsPositioning -> True}, 
             GridBoxOptions -> {
              GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{1.}}, "RowsIndexed" -> {}}}], 
            Cell[
             StyleData["DisplayFormula", "SlideShow"], 
             CellMargins -> {{60, Inherited}, {Inherited, 10}}], 
            Cell[
             StyleData["DisplayFormula", "Printout"], FontSize -> 10], 
            Cell[
             StyleData["DisplayFormula", "EnhancedPrintout"], FontSize -> 
             10]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["NumberedEquation"], CellMargins -> {{45, 10}, {7, 7}},
              CellFrameLabels -> {{None, 
                Cell[
                 TextData[{"(", 
                   CounterBox["NumberedEquation"], ")"}]]}, {None, None}}, 
             DefaultFormatType -> DefaultInputFormatType, 
             "TwoByteSyntaxCharacterAutoReplacement" -> True, 
             LanguageCategory -> "Formula", CounterIncrements -> 
             "NumberedEquation", FormatTypeAutoConvert -> False], 
            Cell[
             StyleData["NumberedEquation", "Printout"], 
             CellMargins -> {{39, 55}, {0, 10}}, FontSize -> 10], 
            Cell[
             StyleData["NumberedEquation", "EnhancedPrintout"], 
             CellMargins -> {{39, 55}, {0, 10}}, FontFamily -> "Palatino", 
             FontSize -> 10], 
            Cell[
             StyleData["NumberedEquation", "EnhancedPrintoutNonGray"], 
             CellMargins -> {{39, 55}, {0, 10}}, FontFamily -> "Palatino", 
             FontSize -> 10]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["EquationNumber"], LineSpacing -> {1.83, 0}, 
             LanguageCategory -> "Formula"], 
            Cell[
             StyleData["EquationNumber", "Printout"], 
             LineSpacing -> {1.7, 0}], 
            Cell[
             StyleData["EquationNumber", "EnhancedPrintout"], 
             LineSpacing -> {1.7, 0}, FontFamily -> "Palatino"], 
            Cell[
             StyleData["EquationNumber", "EnhancedPrintoutNonGray"], 
             LineSpacing -> {1.7, 0}, FontFamily -> "Palatino"]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Program"], 
             CellMargins -> {{16, Inherited}, {Inherited, 10}}, 
             CellHorizontalScrolling -> True, ShowSpecialCharacters -> 
             Automatic, LanguageCategory -> "Formula", FontFamily -> 
             "Courier"], 
            Cell[
             StyleData["Program", "Printout"], 
             CellMargins -> {{42, 30}, {Inherited, 4}}, FontSize -> 9.5], 
            Cell[
             StyleData["Program", "EnhancedPrintout"], 
             CellMargins -> {{42, 30}, {Inherited, 4}}, FontFamily -> 
             "WRICourier", FontSize -> 9.5], 
            Cell[
             StyleData["Program", "EnhancedPrintoutNonGray"], 
             CellMargins -> {{42, 30}, {Inherited, 4}}, FontFamily -> 
             "WRICourier", FontSize -> 9.5]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["BeginNumberedList"], 
             CellMargins -> {{30, 10}, {Inherited, Inherited}}, 
             CounterIncrements -> "List", CounterAssignments -> {{"List", 0}},
              FontFamily -> "Times", FontSize -> 12], 
            Cell[
             StyleData["BeginNumberedList", "SlideShow"]], 
            Cell[
             StyleData["BeginNumberedList", "Printout"], FontSize -> 10], 
            Cell[
             StyleData["BeginNumberedList", "EnhancedPrintout"], Hyphenation -> 
             True, ParagraphIndent -> -13, FontFamily -> "Janson Text", 
             FontSize -> 10, 
             FontProperties -> {
              "FontMonospaced" -> False, "FontSerifed" -> True}]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["NumberedList"], 
             CellMargins -> {{30, 10}, {Inherited, Inherited}}, 
             CellFrameLabels -> {{None, None}, {None, None}}, 
             CounterIncrements -> "List", FontFamily -> "Times", FontSize -> 
             12], 
            Cell[
             StyleData["NumberedList", "SlideShow"]], 
            Cell[
             StyleData["NumberedList", "Printout"], FontSize -> 10], 
            Cell[
             StyleData["NumberedList", "EnhancedPrintout"], TextJustification -> 
             1, Hyphenation -> True, ParagraphIndent -> -13, FontFamily -> 
             "Janson Text", FontSize -> 10, 
             FontProperties -> {
              "FontMonospaced" -> False, "FontSerifed" -> True}]}, Closed]]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell["Unique Help Browser Styles", "Section"], 
         Cell[
          CellGroupData[{
            Cell["Standard Styles\n", "Subsection"], 
            Cell[
             CellGroupData[{
               Cell[
                StyleData["InspectorLevel1"], ShowGroupOpener -> True, 
                CellMargins -> {{12, 10}, {2, 7}}, 
                CellGroupingRules -> {"SectionGrouping", 60}, 
                HyphenationOptions -> {"HyphenationCharacter" -> "-"}, 
                ParagraphIndent -> -38, StyleMenuListing -> None, FontFamily -> 
                "Helvetica", FontSize -> 16, FontWeight -> "Bold"], 
               Cell[
                StyleData["InspectorLevel1", "Brackets"], 
                HyphenationOptions -> {"HyphenationCharacter" -> "-"}], 
               Cell[
                StyleData["InspectorLevel1", "SlideShow"], 
                HyphenationOptions -> {"HyphenationCharacter" -> "-"}], 
               Cell[
                StyleData["InspectorLevel1", "Printout"], 
                HyphenationOptions -> {"HyphenationCharacter" -> "-"}, 
                FontSize -> 14]}, Closed]], 
            Cell[
             CellGroupData[{
               Cell[
                StyleData["InspectorLevel2"], ShowGroupOpener -> True, 
                CellMargins -> {{10, 4}, {0, 14}}, 
                HyphenationOptions -> {"HyphenationCharacter" -> "-"}, 
                StyleMenuListing -> None, FontFamily -> "Helvetica", FontSize -> 
                14, FontWeight -> "Bold"], 
               Cell[
                StyleData["InspectorLevel2", "Brackets"], ShowGroupOpener -> 
                True, CellMargins -> {{48, 10}, {2, 12}}, 
                CellGroupingRules -> {"SectionGrouping", 70}, 
                HyphenationOptions -> {"HyphenationCharacter" -> "-"}, 
                ParagraphIndent -> -27, FontFamily -> "Helvetica", FontSize -> 
                14, FontWeight -> "Bold"], 
               Cell[
                StyleData["InspectorLevel2", "SlideShow"], ShowGroupOpener -> 
                True, CellMargins -> {{48, 10}, {2, 12}}, 
                CellGroupingRules -> {"SectionGrouping", 70}, 
                HyphenationOptions -> {"HyphenationCharacter" -> "-"}, 
                ParagraphIndent -> -27, FontFamily -> "Helvetica", FontSize -> 
                14, FontWeight -> "Bold"], 
               Cell[
                StyleData["InspectorLevel2", "Printout"], 
                HyphenationOptions -> {"HyphenationCharacter" -> "-"}, 
                FontSize -> 12]}, Closed]], 
            Cell[
             CellGroupData[{
               Cell[
                StyleData["ObjectName"], CellMargins -> {{10, 4}, {1, 10}}, 
                CellGroupingRules -> {"SectionGrouping", 50}, 
                HyphenationOptions -> {"HyphenationCharacter" -> "-"}, 
                StyleMenuListing -> None, FontFamily -> "Courier", FontSize -> 
                16, FontWeight -> "Bold"], 
               Cell[
                StyleData["ObjectName", "Brackets"], 
                CellMargins -> {{72, 4}, {1, 14}}, 
                HyphenationOptions -> {"HyphenationCharacter" -> "-"}, 
                StyleMenuListing -> None, FontFamily -> "Courier", FontSize -> 
                12, FontWeight -> "Bold"], 
               Cell[
                StyleData["ObjectName", "SlideShow"], 
                CellMargins -> {{72, 4}, {1, 14}}, 
                CellGroupingRules -> {"SectionGrouping", 90}, 
                HyphenationOptions -> {"HyphenationCharacter" -> "-"}, 
                StyleMenuListing -> None, FontFamily -> "Courier", FontSize -> 
                12, FontWeight -> "Bold"], 
               Cell[
                StyleData["ObjectName", "Printout"], 
                CellMargins -> {{2, 0}, {1, 10}}, 
                HyphenationOptions -> {"HyphenationCharacter" -> "-"}, 
                FontSize -> 12]}, Closed]], 
            Cell[
             CellGroupData[{
               Cell[
                StyleData["SubObjectNameClosed"], ShowGroupOpener -> True, 
                CellMargins -> {{10, 4}, {1, 10}}, 
                PrivateCellOptions -> {"DefaultCellGroupOpen" -> False}, 
                CellGroupingRules -> {"SectionGrouping", 90}, 
                HyphenationOptions -> {"HyphenationCharacter" -> "-"}, 
                StyleMenuListing -> None, FontFamily -> "Courier", FontSize -> 
                14, FontWeight -> "Bold"], 
               Cell[
                StyleData["SubObjectNameClosed", "Brackets"], 
                CellMargins -> {{72, 4}, {1, 14}}, 
                HyphenationOptions -> {"HyphenationCharacter" -> "-"}, 
                StyleMenuListing -> None, FontFamily -> "Courier", FontSize -> 
                12, FontWeight -> "Bold"], 
               Cell[
                StyleData["SubObjectNameClosed", "SlideShow"], 
                CellMargins -> {{72, 4}, {1, 14}}, 
                HyphenationOptions -> {"HyphenationCharacter" -> "-"}, 
                StyleMenuListing -> None, FontFamily -> "Courier", FontSize -> 
                12, FontWeight -> "Bold"], 
               Cell[
                StyleData["SubObjectNameClosed", "Printout"], 
                CellMargins -> {{2, 0}, {1, 10}}, 
                HyphenationOptions -> {"HyphenationCharacter" -> "-"}, 
                FontSize -> 12]}, Closed]], 
            Cell[
             CellGroupData[{
               Cell[
                StyleData["SubObjectName"], ShowGroupOpener -> True, 
                CellMargins -> {{24, 4}, {1, 10}}, 
                HyphenationOptions -> {"HyphenationCharacter" -> "-"}, 
                StyleMenuListing -> None, FontFamily -> "Courier", FontSize -> 
                16, FontWeight -> "Bold"], 
               Cell[
                StyleData["SubObjectName", "Brackets"], ShowGroupOpener -> 
                True, CellMargins -> {{90, 4}, {1, 14}}, 
                HyphenationOptions -> {"HyphenationCharacter" -> "-"}, 
                FontFamily -> "Courier", FontSize -> 12], 
               Cell[
                StyleData["SubObjectName", "SlideShow"], ShowGroupOpener -> 
                True, CellMargins -> {{90, 4}, {1, 14}}, 
                HyphenationOptions -> {"HyphenationCharacter" -> "-"}, 
                FontFamily -> "Courier", FontSize -> 12], 
               Cell[
                StyleData["SubObjectName", "Printout"], 
                CellMargins -> {{2, 0}, {1, 10}}, 
                HyphenationOptions -> {"HyphenationCharacter" -> "-"}, 
                FontFamily -> "Courier", FontSize -> 12]}, Closed]], 
            Cell[
             CellGroupData[{
               Cell[
                StyleData["GroupObjectName"], ShowGroupOpener -> True, 
                CellMargins -> {{10, 4}, {0, 14}}, 
                HyphenationOptions -> {"HyphenationCharacter" -> "-"}, 
                StyleMenuListing -> None, FontFamily -> "Courier", FontSize -> 
                16, FontWeight -> "Bold"], 
               Cell[
                StyleData["GroupObjectName", "Brackets"], ShowGroupOpener -> 
                True, CellMargins -> {{72, 10}, {2, 12}}, 
                CellGroupingRules -> {"SectionGrouping", 70}, 
                HyphenationOptions -> {"HyphenationCharacter" -> "-"}, 
                ParagraphIndent -> -27, CounterIncrements -> "Outline2", 
                FontFamily -> "Courier", FontSize -> 12, FontWeight -> 
                "Bold"], 
               Cell[
                StyleData["GroupObjectName", "SlideShow"], ShowGroupOpener -> 
                True, CellMargins -> {{72, 10}, {2, 12}}, 
                CellGroupingRules -> {"SectionGrouping", 70}, 
                HyphenationOptions -> {"HyphenationCharacter" -> "-"}, 
                ParagraphIndent -> -27, CounterIncrements -> "Outline2", 
                FontFamily -> "Courier", FontSize -> 12, FontWeight -> 
                "Bold"], 
               Cell[
                StyleData["GroupObjectName", "Printout"], 
                HyphenationOptions -> {"HyphenationCharacter" -> "-"}, 
                FontSize -> 14]}, Closed]], 
            Cell[
             CellGroupData[{
               Cell[
                StyleData["GroupObjectNameClosed"], ShowGroupOpener -> True, 
                CellMargins -> {{10, 4}, {0, 14}}, 
                PrivateCellOptions -> {"DefaultCellGroupOpen" -> False}, 
                CellGroupingRules -> {"SectionGrouping", 80}, 
                HyphenationOptions -> {"HyphenationCharacter" -> "-"}, 
                StyleMenuListing -> None, FontFamily -> "Courier", FontSize -> 
                16, FontWeight -> "Bold"], 
               Cell[
                StyleData["GroupObjectNameClosed", "Brackets"], 
                ShowGroupOpener -> True, CellMargins -> {{72, 10}, {2, 12}}, 
                CellGroupingRules -> {"SectionGrouping", 70}, 
                HyphenationOptions -> {"HyphenationCharacter" -> "-"}, 
                ParagraphIndent -> -27, CounterIncrements -> "Outline2", 
                FontFamily -> "Courier", FontSize -> 12, FontWeight -> 
                "Bold"], 
               Cell[
                StyleData["GroupObjectNameClosed", "SlideShow"], 
                ShowGroupOpener -> True, CellMargins -> {{72, 10}, {2, 12}}, 
                CellGroupingRules -> {"SectionGrouping", 70}, 
                HyphenationOptions -> {"HyphenationCharacter" -> "-"}, 
                ParagraphIndent -> -27, CounterIncrements -> "Outline2", 
                FontFamily -> "Courier", FontSize -> 12, FontWeight -> 
                "Bold"], 
               Cell[
                StyleData["GroupObjectNameClosed", "Printout"], 
                HyphenationOptions -> {"HyphenationCharacter" -> "-"}, 
                FontSize -> 14]}, Closed]], 
            Cell[
             CellGroupData[{
               Cell[
                StyleData["ObjectNameWarningMessages"], 
                CellMargins -> {{10, 4}, {1, 10}}, 
                CellGroupingRules -> {"SectionGrouping", 65}, 
                HyphenationOptions -> {"HyphenationCharacter" -> "-"}, 
                StyleMenuListing -> None, FontFamily -> "Courier", FontSize -> 
                16, FontWeight -> "Bold"], 
               Cell[
                StyleData["ObjectNameWarningMessages", "Brackets"], 
                CellMargins -> {{10, 4}, {1, 10}}, 
                CellGroupingRules -> {"SectionGrouping", 65}, 
                HyphenationOptions -> {"HyphenationCharacter" -> "-"}, 
                FontFamily -> "Courier", FontSize -> 16, FontWeight -> 
                "Bold"], 
               Cell[
                StyleData["ObjectNameWarningMessages", "SlideShow"], 
                CellMargins -> {{10, 4}, {1, 10}}, 
                CellGroupingRules -> {"SectionGrouping", 65}, 
                HyphenationOptions -> {"HyphenationCharacter" -> "-"}, 
                FontFamily -> "Courier", FontSize -> 16, FontWeight -> 
                "Bold"], 
               Cell[
                StyleData["ObjectNameWarningMessages", "Printout"], 
                CellMargins -> {{2, 0}, {1, 10}}, 
                HyphenationOptions -> {"HyphenationCharacter" -> "-"}, 
                FontSize -> 12]}, Closed]], 
            Cell[
             CellGroupData[{
               Cell[
                StyleData["Command"], CellMargins -> {{10, 4}, {0, 14}}, 
                HyphenationOptions -> {"HyphenationCharacter" -> "-"}, 
                CounterIncrements -> "Section", StyleMenuListing -> None, 
                FontFamily -> "Helvetica", FontSize -> 16, FontWeight -> 
                "Bold"], 
               Cell[
                StyleData["Command", "Printout"], 
                CellMargins -> {{2, 0}, {0, 14}}, PageBreakBelow -> False, 
                HyphenationOptions -> {"HyphenationCharacter" -> "-"}, 
                FontSize -> 14]}, Closed]], 
            Cell[
             CellGroupData[{
               Cell[
                StyleData["CharacterName"], CellFrame -> {{0, 0}, {0.5, 0.5}},
                 CellMargins -> {{10, 4}, {0, 4}}, CellFrameMargins -> 4, 
                HyphenationOptions -> {"HyphenationCharacter" -> "-"}, 
                StyleMenuListing -> None], 
               Cell[
                StyleData["CharacterName", "Brackets"], 
                CellMargins -> {{72, 4}, {1, 14}}, 
                CellGroupingRules -> {"SectionGrouping", 90}, 
                HyphenationOptions -> {"HyphenationCharacter" -> "-"}, 
                StyleMenuListing -> None, FontFamily -> "Courier", FontSize -> 
                12, FontWeight -> "Bold"], 
               Cell[
                StyleData["CharacterName", "SlideShow"], 
                CellMargins -> {{72, 4}, {1, 14}}, 
                CellGroupingRules -> {"SectionGrouping", 90}, 
                HyphenationOptions -> {"HyphenationCharacter" -> "-"}, 
                StyleMenuListing -> None, FontFamily -> "Courier", FontSize -> 
                12, FontWeight -> "Bold"], 
               Cell[
                StyleData["CharacterName", "Printout"], 
                CellMargins -> {{2, 0}, {0, 4}}, 
                HyphenationOptions -> {"HyphenationCharacter" -> "-"}, 
                FontSize -> 10]}, Closed]], 
            Cell[
             CellGroupData[{
               Cell[
                StyleData["Usage"], CellFrame -> {{0, 0}, {0.5, 0.5}}, 
                CellMargins -> {{10, 4}, {0, 4}}, CellFrameMargins -> 5, 
                Hyphenation -> True, 
                HyphenationOptions -> {"HyphenationCharacter" -> "-"}, 
                ParagraphSpacing -> {0, 6}, ParagraphIndent -> -10, 
                StyleMenuListing -> None], 
               Cell[
                StyleData["Usage", "Brackets"], 
                CellFrame -> {{0, 0}, {0.5, 0.5}}, 
                CellMargins -> {{72, 4}, {0, 4}}, CellFrameMargins -> 5, 
                HyphenationOptions -> {"HyphenationCharacter" -> "-"}, 
                ParagraphSpacing -> {0, 6}, ParagraphIndent -> -10, 
                StyleMenuListing -> None], 
               Cell[
                StyleData["Usage", "SlideShow"], 
                CellFrame -> {{0, 0}, {0.5, 0.5}}, 
                CellMargins -> {{72, 4}, {0, 4}}, CellFrameMargins -> 5, 
                HyphenationOptions -> {"HyphenationCharacter" -> "-"}, 
                ParagraphSpacing -> {0, 6}, ParagraphIndent -> -10, 
                StyleMenuListing -> None], 
               Cell[
                StyleData["Usage", "Printout"], 
                CellMargins -> {{2, 0}, {0, 4}}, 
                HyphenationOptions -> {"HyphenationCharacter" -> "-"}, 
                StyleMenuListing -> None, FontSize -> 10, FontWeight -> 
                "Plain"]}, Closed]], 
            Cell[
             CellGroupData[{
               Cell[
                StyleData["ErrorMessage"], CellFrame -> {{0, 0}, {0.5, 0.5}}, 
                ShowCellBracket -> True, CellMargins -> {{10, 4}, {0, 4}}, 
                CellGroupingRules -> "OutputGrouping", PageBreakWithin -> 
                False, GroupPageBreakWithin -> False, GeneratedCell -> True, 
                CellAutoOverwrite -> True, ShowCellLabel -> False, 
                CellLabelMargins -> {{14, Inherited}, {Inherited, Inherited}},
                 CellFrameMargins -> 5, DefaultFormatType -> 
                DefaultOutputFormatType, 
                HyphenationOptions -> {"HyphenationCharacter" -> "-"}, 
                FormatType -> InputForm, StyleMenuListing -> None, FontColor -> 
                RGBColor[0, 0, 1]], 
               Cell[
                StyleData["ErrorMessage", "Brackets"], 
                CellMargins -> {{72, 4}, {0, 8}}, CellHorizontalScrolling -> 
                True, HyphenationOptions -> {"HyphenationCharacter" -> "-"}, 
                StyleMenuListing -> None], 
               Cell[
                StyleData["ErrorMessage", "SlideShow"], 
                CellMargins -> {{72, 4}, {0, 8}}, CellHorizontalScrolling -> 
                True, HyphenationOptions -> {"HyphenationCharacter" -> "-"}, 
                StyleMenuListing -> None], 
               Cell[
                StyleData["ErrorMessage", "Printout"], 
                HyphenationOptions -> {"HyphenationCharacter" -> "-"}, 
                FontSize -> 9, FontColor -> GrayLevel[0]]}, Closed]], 
            Cell[
             CellGroupData[{
               Cell[
                StyleData["Notes"], CellMargins -> {{10, 4}, {0, 8}}, 
                CellHorizontalScrolling -> True, Hyphenation -> True, 
                HyphenationOptions -> {"HyphenationCharacter" -> "-"}, 
                ParagraphSpacing -> {0, 6}, ParagraphIndent -> -10, 
                StyleMenuListing -> None, FontFamily -> "Times"], 
               Cell[
                StyleData["Notes", "Brackets"], 
                CellMargins -> {{72, 4}, {0, 8}}, CellHorizontalScrolling -> 
                True, HyphenationOptions -> {"HyphenationCharacter" -> "-"}, 
                ParagraphSpacing -> {0, 6}, ParagraphIndent -> -10, 
                StyleMenuListing -> None, FontFamily -> "Times"], 
               Cell[
                StyleData["Notes", "SlideShow"], 
                CellMargins -> {{72, 4}, {0, 8}}, CellHorizontalScrolling -> 
                True, HyphenationOptions -> {"HyphenationCharacter" -> "-"}, 
                ParagraphSpacing -> {0, 6}, ParagraphIndent -> -10, 
                StyleMenuListing -> None, FontFamily -> "Times"], 
               Cell[
                StyleData["Notes", "Printout"], 
                CellMargins -> {{2, 0}, {0, 8}}, 
                HyphenationOptions -> {"HyphenationCharacter" -> "-"}, 
                FontSize -> 9]}, Closed]], 
            Cell[
             CellGroupData[{
               Cell[
                StyleData["NotesList"], CellMargins -> {{20, 4}, {2, 8}}, 
                CellHorizontalScrolling -> True, Hyphenation -> True, 
                HyphenationOptions -> {"HyphenationCharacter" -> "-"}, 
                ScriptLevel -> 1, SingleLetterItalics -> True, 
                StyleMenuListing -> None, FontFamily -> "Times"], 
               Cell[
                StyleData["NotesList", "Brackets"], 
                CellMargins -> {{82, 4}, {2, 8}}, CellHorizontalScrolling -> 
                True, HyphenationOptions -> {"HyphenationCharacter" -> "-"}, 
                ScriptLevel -> 1, SingleLetterItalics -> True, 
                StyleMenuListing -> None, FontFamily -> "Times"], 
               Cell[
                StyleData["NotesList", "SlideShow"], 
                CellMargins -> {{82, 4}, {2, 8}}, CellHorizontalScrolling -> 
                True, HyphenationOptions -> {"HyphenationCharacter" -> "-"}, 
                ScriptLevel -> 1, SingleLetterItalics -> True, 
                StyleMenuListing -> None, FontFamily -> "Times"], 
               Cell[
                StyleData["NotesList", "Printout"], 
                CellMargins -> {{12, 0}, {2, 8}}, 
                HyphenationOptions -> {"HyphenationCharacter" -> "-"}, 
                FontSize -> 9]}, Closed]], 
            Cell[
             CellGroupData[{
               Cell[
                StyleData["ExampleSection"], CellFrame -> {{0, 0}, {0, 0.5}}, 
                ShowGroupOpener -> True, CellMargins -> {{11, 4}, {0, 10}}, 
                CellGroupingRules -> {"SectionGrouping", 70}, 
                CellFrameMargins -> 12, 
                HyphenationOptions -> {"HyphenationCharacter" -> "-"}, 
                StyleMenuListing -> None, FontSize -> 13, FontWeight -> 
                "Bold", FontSlant -> "Italic", FontColor -> 
                RGBColor[0, 0, 0.4]], 
               Cell[
                StyleData["ExampleSection", "Printout"], 
                CellMargins -> {{3, 0}, {0, 10}}, PageBreakBelow -> False, 
                HyphenationOptions -> {"HyphenationCharacter" -> "-"}, 
                FontSize -> 9, FontColor -> GrayLevel[0]]}, Closed]], 
            Cell[
             CellGroupData[{
               Cell[
                StyleData["ExampleText"], CellMargins -> {{20, 40}, {0, 18}}, 
                Hyphenation -> True, 
                HyphenationOptions -> {"HyphenationCharacter" -> "-"}, 
                ParagraphSpacing -> {0, 6}, StyleMenuListing -> None, 
                FontColor -> RGBColor[0, 0, 0.4]], 
               Cell[
                StyleData["ExampleText", "Printout"], 
                CellMargins -> {{2, 80}, {0, 8}}, PageBreakBelow -> False, 
                HyphenationOptions -> {"HyphenationCharacter" -> "-"}, 
                FontSize -> 8, FontColor -> GrayLevel[0]]}, Closed]], 
            Cell[
             CellGroupData[{
               Cell[
                StyleData["ExampleSubsection"], ShowCellBracket -> True, 
                CellMargins -> {{20, 4}, {0, 16}}, 
                CellGroupingRules -> {"SectionGrouping", 80}, 
                HyphenationOptions -> {"HyphenationCharacter" -> "-"}, 
                StyleMenuListing -> None, FontFamily -> "Helvetica", FontSize -> 
                10, FontWeight -> "Bold"], 
               Cell[
                StyleData["ExampleSubsection", "Printout"], 
                CellMargins -> {{12, 0}, {0, 16}}, PageBreakBelow -> False, 
                HyphenationOptions -> {"HyphenationCharacter" -> "-"}, 
                FontSize -> 7]}, Closed]], 
            Cell[
             CellGroupData[{
               Cell[
                StyleData["LineHead"], CellFrame -> {{0, 0}, {0.5, 0}}, 
                CellMargins -> {{10, 4}, {8, 18}}, 
                HyphenationOptions -> {"HyphenationCharacter" -> "-"}, 
                CounterIncrements -> "Subsection", 
                CounterAssignments -> {{"Subsubsection", 0}}, 
                StyleMenuListing -> None, FontFamily -> "Helvetica", FontSize -> 
                12, FontWeight -> "Bold"], 
               Cell[
                StyleData["LineHead", "Printout"], 
                CellMargins -> {{2, 0}, {8, 18}}, PageBreakBelow -> False, 
                HyphenationOptions -> {"HyphenationCharacter" -> "-"}, 
                FontSize -> 10]}, Closed]], 
            Cell[
             CellGroupData[{
               Cell[
                StyleData["FlushInput"], CellMargins -> {{10, 4}, {1, 4}}, 
                Evaluatable -> True, CellGroupingRules -> "InputGrouping", 
                CellHorizontalScrolling -> True, PageBreakWithin -> False, 
                GroupPageBreakWithin -> False, CellLabelAutoDelete -> False, 
                CellLabelMargins -> {{23, Inherited}, {Inherited, Inherited}},
                 DefaultFormatType -> DefaultInputFormatType, 
                ShowSpecialCharacters -> Automatic, 
                HyphenationOptions -> {"HyphenationCharacter" -> "-"}, 
                FormatType -> StandardForm, ShowStringCharacters -> True, 
                NumberMarks -> True, StyleMenuListing -> None, FontWeight -> 
                "Bold"], 
               Cell[
                StyleData["FlushInput", "Printout"], 
                CellMargins -> {{2, 0}, {1, 4}}, 
                HyphenationOptions -> {"HyphenationCharacter" -> "-"}, 
                FontSize -> 10]}, Closed]], 
            Cell[
             CellGroupData[{
               Cell[
                StyleData["FlushOutput"], 
                CellMargins -> {{10, Inherited}, {Inherited, Inherited}}, 
                CellEditDuplicate -> True, CellGroupingRules -> 
                "OutputGrouping", CellHorizontalScrolling -> True, 
                PageBreakWithin -> False, GroupPageBreakWithin -> False, 
                GeneratedCell -> True, CellAutoOverwrite -> True, 
                CellLabelAutoDelete -> False, 
                CellLabelMargins -> {{23, Inherited}, {Inherited, Inherited}},
                 DefaultFormatType -> DefaultOutputFormatType, 
                HyphenationOptions -> {"HyphenationCharacter" -> "-"}, 
                FormatType -> StandardForm, StyleMenuListing -> None], 
               Cell[
                StyleData["FlushOutput", "Printout"], 
                CellMargins -> {{2, Inherited}, {Inherited, Inherited}}, 
                HyphenationOptions -> {"HyphenationCharacter" -> "-"}, 
                FontSize -> 10]}, Closed]], 
            Cell[
             CellGroupData[{
               Cell[
                StyleData["DialogItem"], CellDingbat -> "\[EmptyDiamond]", 
                CellMargins -> {{20, 4}, {0, 12}}, 
                CellGroupingRules -> {"SectionGrouping", 70}, 
                HyphenationOptions -> {"HyphenationCharacter" -> "-"}, 
                StyleMenuListing -> None, FontFamily -> "Helvetica", FontSize -> 
                10, FontWeight -> "Bold"], 
               Cell[
                StyleData["DialogItem", "Printout"], 
                CellMargins -> {{12, 0}, {0, 12}}, PageBreakBelow -> False, 
                HyphenationOptions -> {"HyphenationCharacter" -> "-"}, 
                FontSize -> 8]}, Closed]], 
            Cell[
             StyleData["GroupDivider"], 
             CellMargins -> {{10, Inherited}, {Inherited, Inherited}}, 
             CellEditDuplicate -> True, 
             CellGroupingRules -> {"TitleGrouping", 0}, 
             HyphenationOptions -> {"HyphenationCharacter" -> "-"}, 
             StyleMenuListing -> None], 
            Cell[
             CellGroupData[{
               Cell[
                StyleData["Highlight"], CellMargins -> {{10, 4}, {0, 18}}, 
                HyphenationOptions -> {"HyphenationCharacter" -> "-"}, 
                StyleMenuListing -> None, FontFamily -> "Helvetica", FontSize -> 
                12, Background -> GrayLevel[0.900008]], 
               Cell[
                StyleData["Highlight", "Printout"], 
                CellMargins -> {{2, 0}, {0, 18}}, 
                HyphenationOptions -> {"HyphenationCharacter" -> "-"}, 
                LineSpacing -> {1, 3}]}, Closed]], 
            Cell[
             CellGroupData[{
               Cell[
                StyleData["UserNotes"], CellFrame -> {{2, 0}, {0, 0.25}}, 
                CellMargins -> {{10, 4}, {0, 8}}, Hyphenation -> True, 
                HyphenationOptions -> {"HyphenationCharacter" -> "-"}, 
                ParagraphIndent -> -7, StyleMenuListing -> None, FontFamily -> 
                "Helvetica", FontSize -> 10], 
               Cell[
                StyleData["UserNotes", "Printout"], 
                CellMargins -> {{2, 0}, {0, 4}}, 
                HyphenationOptions -> {"HyphenationCharacter" -> "-"}, 
                LineSpacing -> {1, 3}, FontSize -> 8]}, Closed]], 
            Cell[
             CellGroupData[{
               Cell[
                StyleData["MoreInfo"], CellFrame -> {{2, 0}, {0, 0.25}}, 
                CellMargins -> {{10, 4}, {0, 8}}, Hyphenation -> True, 
                HyphenationOptions -> {"HyphenationCharacter" -> "-"}, 
                ParagraphIndent -> -7, StyleMenuListing -> None, FontFamily -> 
                "Helvetica", FontSize -> 10, FontColor -> GrayLevel[1], 
                Background -> RGBColor[0.4, 0.6, 0.550011]], 
               Cell[
                StyleData["MoreInfo", "Printout"], 
                CellMargins -> {{2, 0}, {0, 4}}, 
                HyphenationOptions -> {"HyphenationCharacter" -> "-"}, 
                LineSpacing -> {1, 3}, FontSize -> 8]}, Closed]], 
            Cell[
             CellGroupData[{
               Cell[
                StyleData["UserTips"], CellFrame -> {{2, 0}, {0, 0.25}}, 
                CellMargins -> {{10, 4}, {0, 8}}, Hyphenation -> True, 
                HyphenationOptions -> {"HyphenationCharacter" -> "-"}, 
                ParagraphIndent -> -7, StyleMenuListing -> None, FontFamily -> 
                "Helvetica", FontSize -> 10, FontColor -> GrayLevel[1], 
                Background -> RGBColor[0.300008, 0.600015, 0.700008]], 
               Cell[
                StyleData["UserTips", "Printout"], 
                CellMargins -> {{2, 0}, {0, 4}}, 
                HyphenationOptions -> {"HyphenationCharacter" -> "-"}, 
                LineSpacing -> {1, 3}, FontSize -> 8, Background -> 
                GrayLevel[0.700008]]}, Closed]], 
            Cell[
             CellGroupData[{
               Cell[
                StyleData["Theorem"], CellFrame -> {{4, 0}, {0, 0}}, 
                CellMargins -> {{12, 62}, {0, 14}}, CellFrameMargins -> 4, 
                CellFrameColor -> RGBColor[0, 0, 0.8], 
                HyphenationOptions -> {"HyphenationCharacter" -> "-"}, 
                LineSpacing -> {1, 1}, ParagraphSpacing -> {0, 8}], 
               Cell[
                StyleData["Theorem", "Printout"], 
                CellMargins -> {{2, 0}, {0, 14}}, CellFrameMargins -> 3, 
                CellFrameColor -> GrayLevel[0.8], 
                HyphenationOptions -> {"HyphenationCharacter" -> "-"}, 
                FontSize -> 9, FontColor -> GrayLevel[0]]}, Closed]], 
            Cell[
             CellGroupData[{
               Cell[
                StyleData["Commentary"], CellFrame -> {{2, 0}, {0, 0}}, 
                CellMargins -> {{36, 10}, {7, 7}}, PageBreakBelow -> False, 
                CellFrameMargins -> 8, CellFrameColor -> RGBColor[0, 0.2, 1], 
                LineSpacing -> {1, 3}, FontSlant -> "Italic"], 
               Cell[
                StyleData["Commentary", "Printout"], 
                CellMargins -> {{36, 0}, {6, 6}}, CellFrameColor -> 
                GrayLevel[0.8], FontSize -> 10], 
               Cell[
                StyleData["Commentary", "EnhancedPrintout"], 
                CellMargins -> {{36, 0}, {6, 6}}, CellFrameColor -> 
                GrayLevel[0.8], FontFamily -> "Palatino", FontSize -> 10], 
               Cell[
                StyleData["Commentary", "EnhancedPrintoutNonGray"], 
                CellMargins -> {{36, 0}, {6, 6}}, CellFrameColor -> 
                GrayLevel[0.8], FontFamily -> "Palatino", FontSize -> 10]}, 
              Closed]], 
            Cell[
             CellGroupData[{
               Cell[
                StyleData["Level1Icon"], ShowGroupOpener -> True, 
                CellMargins -> {{10, 4}, {0, 8}}, CellHorizontalScrolling -> 
                True, HyphenationOptions -> {"HyphenationCharacter" -> "-"}, 
                ParagraphSpacing -> {0, 8}, StyleMenuListing -> None], 
               Cell[
                StyleData["Level1Icon", "Printout"], 
                CellMargins -> {{2, 0}, {0, 8}}, 
                HyphenationOptions -> {"HyphenationCharacter" -> "-"}, 
                FontSize -> 10]}, Closed]], 
            Cell[
             CellGroupData[{
               Cell[
                StyleData["Level2Icon"], ShowGroupOpener -> True, 
                CellMargins -> {{10, 4}, {0, 8}}, CellHorizontalScrolling -> 
                True, HyphenationOptions -> {"HyphenationCharacter" -> "-"}, 
                ParagraphSpacing -> {0, 8}, StyleMenuListing -> None], 
               Cell[
                StyleData["Level2Icon", "Printout"], 
                CellMargins -> {{2, 0}, {0, 8}}, 
                HyphenationOptions -> {"HyphenationCharacter" -> "-"}, 
                FontSize -> 10]}, Closed]], 
            Cell[
             CellGroupData[{
               Cell[
                StyleData["CopyrightHead"], CellMargins -> {{10, 4}, {0, 8}}, 
                PageBreakAbove -> False, StyleMenuListing -> None, FontFamily -> 
                "Helvetica", FontSize -> 12, FontWeight -> "Bold"], 
               Cell[
                StyleData["CopyrightHead", "Printout"], 
                CellMargins -> {{2, 2}, {6, 6}}, TextJustification -> 1, 
                FontSize -> 10]}, Closed]], 
            Cell[
             CellGroupData[{
               Cell[
                StyleData["Copyright"], CellMargins -> {{10, 4}, {0, 8}}, 
                PageBreakAbove -> False, StyleMenuListing -> None], 
               Cell[
                StyleData["Copyright", "Printout"], 
                CellMargins -> {{2, 2}, {6, 6}}, TextJustification -> 1, 
                FontSize -> 10]}, Closed]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell["Manual.nb Merge", "Subsection"], 
            Cell[
             CellGroupData[{
               Cell["Function List", "Subsubsection"], 
               Cell[
                CellGroupData[{
                  Cell[
                   StyleData["FunctionName"], CellDingbat -> 
                   "\[FilledSquare]", CellMargins -> {{24, 10}, {10, 12}}, 
                   CellGroupingRules -> {"SectionGrouping", 40}, 
                   PageBreakBelow -> False, StyleMenuListing -> None, 
                   FontFamily -> "Courier", FontSize -> 14, FontWeight -> 
                   "Bold", CellTags -> "FunctionName"], 
                  Cell[
                   StyleData["FunctionName", "Printout"], 
                   CellMargins -> {{9, 0}, {10, 10}}, FontSize -> 12], 
                  Cell[
                   StyleData["FunctionName", "EnhancedPrintout"], 
                   CellMargins -> {{9, 0}, {10, 10}}, FontFamily -> "Courier",
                    FontSize -> 12], 
                  Cell[
                   StyleData["FunctionName", "EnhancedPrintoutNonGray"], 
                   CellMargins -> {{9, 0}, {10, 10}}, FontFamily -> "Courier",
                    FontSize -> 12]}, Closed]], 
               Cell[
                CellGroupData[{
                  Cell[
                   StyleData["SubsectionIcon"], ShowGroupOpener -> True, 
                   CellMargins -> {{24, 10}, {0, 30}}, 
                   CellGroupingRules -> {"SectionGrouping", 50}, 
                   PageBreakBelow -> False, StyleMenuListing -> None, 
                   FontSize -> 14, FontWeight -> "Bold", CellTags -> 
                   "FunctionSection"], 
                  Cell[
                   StyleData["SubsectionIcon", "Printout"], 
                   CellMargins -> {{20, 0}, {0, 20}}, FontSize -> 13], 
                  Cell[
                   StyleData["SubsectionIcon", "EnhancedPrintout"], 
                   CellMargins -> {{20, 0}, {0, 20}}, FontFamily -> 
                   "Palatino", FontSize -> 10], 
                  Cell[
                   StyleData["SubsectionIcon", "EnhancedPrintoutNonGray"], 
                   CellMargins -> {{20, 0}, {0, 20}}, FontFamily -> 
                   "Palatino", FontSize -> 10]}, Closed]], 
               Cell[
                CellGroupData[{
                  Cell[
                   StyleData["FunctionSubsection"], CellDingbat -> 
                   "\[FilledSquare]", CellMargins -> {{36, 10}, {0, 6}}, 
                   CellGroupingRules -> {"SectionGrouping", 60}, 
                   PageBreakBelow -> False, StyleMenuListing -> None, 
                   FontWeight -> "Bold", CellTags -> "FunctionSubsection"], 
                  Cell[
                   StyleData["FunctionSubsection", "Printout"], 
                   CellMargins -> {{30, 0}, {0, 6}}], 
                  Cell[
                   StyleData["FunctionSubsection", "EnhancedPrintout"], 
                   CellMargins -> {{30, 0}, {0, 6}}, FontFamily -> "Palatino",
                    FontSize -> 11], 
                  Cell[
                   StyleData["FunctionSubsection", "EnhancedPrintoutNonGray"],
                    CellMargins -> {{30, 0}, {0, 6}}, FontFamily -> 
                   "Palatino", FontSize -> 11]}, Closed]], 
               Cell[
                CellGroupData[{
                  Cell[
                   StyleData["SubsubsectionIcon"], ShowGroupOpener -> True, 
                   CellMargins -> {{36, 10}, {0, 6}}, 
                   CellGroupingRules -> {"SectionGrouping", 60}, 
                   PageBreakBelow -> False, StyleMenuListing -> None, 
                   FontWeight -> "Bold", CellTags -> "SubsubsectionIcon"], 
                  Cell[
                   StyleData["SubsubsectionIcon", "Printout"], 
                   CellMargins -> {{30, 0}, {0, 6}}, FontSize -> 11], 
                  Cell[
                   StyleData["SubsubsectionIcon", "EnhancedPrintout"], 
                   CellMargins -> {{30, 0}, {0, 6}}, FontFamily -> "Palatino",
                    FontSize -> 9], 
                  Cell[
                   StyleData["SubsubsectionIcon", "EnhancedPrintoutNonGray"], 
                   CellMargins -> {{30, 0}, {0, 6}}, FontFamily -> "Palatino",
                    FontSize -> 9]}, Closed]], 
               Cell[
                CellGroupData[{
                  Cell[
                   StyleData["FunctionDescription"], 
                   CellMargins -> {{36, 10}, {4, 0}}, LineSpacing -> {1, 3}, 
                   ParagraphSpacing -> {0.7, 0}, CounterIncrements -> "Text", 
                   StyleMenuListing -> None, FontWeight -> "Plain"], 
                  Cell[
                   StyleData["FunctionDescription", "Printout"], 
                   CellMargins -> {{30, 0}, {4, 0}}, FontSize -> 11], 
                  Cell[
                   StyleData["FunctionDescription", "EnhancedPrintout"], 
                   CellMargins -> {{30, 0}, {4, 0}}, TextJustification -> 0, 
                   FontFamily -> "Palatino", FontSize -> 10], 
                  Cell[
                   StyleData[
                   "FunctionDescription", "EnhancedPrintoutNonGray"], 
                   CellMargins -> {{30, 0}, {4, 0}}, TextJustification -> 0, 
                   FontFamily -> "Palatino", FontSize -> 10]}, Closed]], 
               Cell[
                CellGroupData[{
                  Cell[
                   StyleData["FunctionDescriptionRuled"], 
                   CellFrame -> {{0, 0}, {0.25, 0.25}}, 
                   CellMargins -> {{36, 10}, {4, 0}}, LineSpacing -> {1, 3}, 
                   ParagraphSpacing -> {0.7, 0}, CounterIncrements -> "Text", 
                   StyleMenuListing -> None], 
                  Cell[
                   StyleData["FunctionDescriptionRuled", "Printout"], 
                   CellMargins -> {{30, 0}, {4, 0}}, FontSize -> 11], 
                  Cell[
                   StyleData["FunctionDescriptionRuled", "EnhancedPrintout"], 
                   CellMargins -> {{30, 0}, {4, 0}}, TextJustification -> 0, 
                   FontFamily -> "Palatino", FontSize -> 10], 
                  Cell[
                   StyleData[
                   "FunctionDescriptionRuled", "EnhancedPrintoutNonGray"], 
                   CellMargins -> {{30, 0}, {4, 0}}, TextJustification -> 0, 
                   FontFamily -> "Palatino", FontSize -> 10]}, Closed]], 
               Cell[
                CellGroupData[{
                  Cell[
                   StyleData["FunctionDescriptionRuleTop"], 
                   CellFrame -> {{0, 0}, {0, 0.25}}, 
                   CellMargins -> {{36, 10}, {4, 0}}, LineSpacing -> {1, 3}, 
                   ParagraphSpacing -> {0.7, 0}, CounterIncrements -> "Text", 
                   StyleMenuListing -> None], 
                  Cell[
                   StyleData["FunctionDescriptionRuleTop", "Printout"], 
                   CellMargins -> {{30, 0}, {4, 0}}, FontSize -> 11], 
                  Cell[
                   StyleData[
                   "FunctionDescriptionRuleTop", "EnhancedPrintout"], 
                   CellMargins -> {{30, 0}, {4, 0}}, TextJustification -> 0, 
                   FontFamily -> "Palatino", FontSize -> 10], 
                  Cell[
                   StyleData[
                   "FunctionDescriptionRuleTop", "EnhancedPrintoutNonGray"], 
                   CellMargins -> {{30, 0}, {4, 0}}, TextJustification -> 0, 
                   FontFamily -> "Palatino", FontSize -> 10]}, Closed]], 
               Cell[
                CellGroupData[{
                  Cell[
                   StyleData["FunctionDescriptionRuleBottom"], 
                   CellFrame -> {{0, 0}, {0.25, 0}}, 
                   CellMargins -> {{36, 10}, {4, 0}}, LineSpacing -> {1, 3}, 
                   ParagraphSpacing -> {0.7, 0}, CounterIncrements -> "Text", 
                   StyleMenuListing -> None], 
                  Cell[
                   StyleData["FunctionDescriptionRuleBottom", "Printout"], 
                   CellMargins -> {{30, 0}, {4, 0}}, FontSize -> 11], 
                  Cell[
                   StyleData[
                   "FunctionDescriptionRuleBottom", "EnhancedPrintout"], 
                   CellMargins -> {{30, 0}, {4, 0}}, TextJustification -> 0, 
                   FontFamily -> "Palatino", FontSize -> 10], 
                  Cell[
                   StyleData[
                   "FunctionDescriptionRuleBottom", 
                    "EnhancedPrintoutNonGray"], 
                   CellMargins -> {{30, 0}, {4, 0}}, TextJustification -> 0, 
                   FontFamily -> "Palatino", FontSize -> 10]}, Closed]], 
               Cell[
                CellGroupData[{
                  Cell[
                   StyleData["FunctionExample"], 
                   CellMargins -> {{36, 10}, {4, 0}}, StyleMenuListing -> 
                   None, FontSize -> 10], 
                  Cell[
                   StyleData["FunctionExample", "Printout"], 
                   CellMargins -> {{30, 0}, {4, 0}}, FontSize -> 9], 
                  Cell[
                   StyleData["FunctionExample", "EnhancedPrintout"], 
                   CellMargins -> {{30, 0}, {4, 0}}, FontFamily -> "Palatino",
                    FontSize -> 9], 
                  Cell[
                   StyleData["FunctionExample", "EnhancedPrintoutNonGray"], 
                   CellMargins -> {{30, 0}, {4, 0}}, FontFamily -> "Palatino",
                    FontSize -> 9]}, Closed]], 
               Cell[
                CellGroupData[{
                  Cell[
                   StyleData["FunctionTextNote"], 
                   CellMargins -> {{36, 4}, {0, 4}}, LineSpacing -> {1, 3}, 
                   ParagraphSpacing -> {0, 4}, LineIndent -> 0, 
                   StyleMenuListing -> None], 
                  Cell[
                   StyleData["FunctionTextNote", "Printout"], 
                   CellMargins -> {{36, 4}, {0, 4}}, FontSize -> 9], 
                  Cell[
                   StyleData["FunctionTextNote", "EnhancedPrintout"], 
                   CellMargins -> {{36, 4}, {0, 4}}, FontFamily -> "Palatino",
                    FontSize -> 8], 
                  Cell[
                   StyleData["FunctionTextNote", "EnhancedPrintoutNonGray"], 
                   CellMargins -> {{36, 4}, {0, 4}}, FontFamily -> "Palatino",
                    FontSize -> 8]}, Closed]], 
               Cell[
                CellGroupData[{
                  Cell[
                   StyleData["3ColumnFunctionTable"], 
                   CellMargins -> {{36, 4}, {0, 8}}, CellHorizontalScrolling -> 
                   True, PageBreakWithin -> False, AutoIndent -> False, 
                   AutoSpacing -> False, LineIndent -> 0, StyleMenuListing -> 
                   None, GridBoxOptions -> {
                    GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
                    "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}, 
                    GridBoxItemSize -> {"Columns" -> {
                    Scaled[0.28], 
                    Scaled[0.28], {
                    Scaled[0.43]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
                    "RowsIndexed" -> {}}, GridBoxSpacings -> {"Columns" -> {
                    Offset[0.27999999999999997`], {
                    Offset[1.4]}, 
                    Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                    "Rows" -> {
                    Offset[0.2], {
                    Offset[0.6]}, 
                    Offset[0.2]}, "RowsIndexed" -> {}}}], 
                  Cell[
                   StyleData["3ColumnFunctionTable", "Printout"], 
                   CellMargins -> {{30, 0}, {0, 8}}, FontSize -> 10], 
                  Cell[
                   StyleData["3ColumnFunctionTable", "EnhancedPrintout"], 
                   CellMargins -> {{30, 0}, {0, 8}}, FontSize -> 10], 
                  Cell[
                   StyleData[
                   "3ColumnFunctionTable", "EnhancedPrintoutNonGray"], 
                   CellMargins -> {{30, 0}, {0, 8}}, FontSize -> 10]}, 
                 Closed]]}, Open]], 
            Cell[
             CellGroupData[{
               Cell["Browser Emulation", "Subsubsection"], 
               Cell[
                CellGroupData[{
                  Cell[
                   StyleData["TextNormal"], CellMargins -> {{12, 10}, {7, 7}},
                    LineSpacing -> {1, 3}, CounterIncrements -> "Text", 
                   StyleMenuListing -> None, FontFamily -> "Times", FontSize -> 
                   12], 
                  Cell[
                   StyleData["TextNormal", "Printout"], 
                   CellMargins -> {{2, 2}, {6, 6}}, FontSize -> 10]}, 
                 Closed]], 
               Cell[
                CellGroupData[{
                  Cell[
                   StyleData["BrowserEmulation"], 
                   CellMargins -> {{12, 1}, {7, 24}}, 
                   CellGroupingRules -> {"SectionGrouping", 70}, 
                   LineSpacing -> {1, 3}, StyleMenuListing -> None, 
                   FontFamily -> "Helvetica", 
                   GridBoxOptions -> {
                    GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
                    "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}, 
                    GridBoxDividers -> {
                    "Columns" -> {{True}}, "ColumnsIndexed" -> {}, 
                    "Rows" -> {True, {False}, True}, "RowsIndexed" -> {}}, 
                    GridBoxItemSize -> {"Columns" -> {{
                    Scaled[0.25]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
                    "RowsIndexed" -> {}}, GridBoxSpacings -> {"Columns" -> {
                    Offset[0.35], {
                    Offset[0.5599999999999999]}, 
                    Offset[0.35]}, "ColumnsIndexed" -> {}, "Rows" -> {
                    Offset[0.2], {
                    Offset[0.4]}, 
                    Offset[0.2]}, "RowsIndexed" -> {}}}], 
                  Cell[
                   StyleData["BrowserEmulation", "Printout"], 
                   CellMargins -> {{2, 2}, {6, 6}}, FontSize -> 10]}, 
                 Closed]], 
               Cell[
                CellGroupData[{
                  Cell[
                   StyleData["CategoryDefs"], 
                   CellMargins -> {{300, 10}, {7, 7}}, LineSpacing -> {1, 3}, 
                   StyleMenuListing -> None, FontFamily -> "Helvetica", 
                   Background -> RGBColor[1, 0.8, 0.6], 
                   GridBoxOptions -> {
                    GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
                    "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}, 
                    GridBoxDividers -> {
                    "Columns" -> {False, {True}, False}, 
                    "ColumnsIndexed" -> {}, "Rows" -> {False, {True}, False}, 
                    "RowsIndexed" -> {}}}], 
                  Cell[
                   StyleData["CategoryDefs", "Printout"], 
                   CellMargins -> {{2, 2}, {6, 6}}, FontSize -> 10]}, 
                 Closed]], 
               Cell[
                CellGroupData[{
                  Cell[
                   StyleData["Category1"], ShowCellBracket -> False, 
                   ShowGroupOpener -> True, CellMargins -> {{12, 10}, {7, 7}},
                    CellGroupingRules -> {"SectionGrouping", 50}, 
                   StyleMenuListing -> None, FontSize -> 16, FontWeight -> 
                   "Bold"], 
                  Cell[
                   StyleData["Category1", "Printout"], 
                   CellMargins -> {{2, 2}, {6, 6}}]}, Closed]], 
               Cell[
                CellGroupData[{
                  Cell[
                   StyleData["Category2"], ShowCellBracket -> False, 
                   ShowGroupOpener -> True, CellMargins -> {{85, 10}, {7, 7}},
                    CellGroupingRules -> {"SectionGrouping", 60}, 
                   StyleMenuListing -> None, FontSize -> 14, FontWeight -> 
                   "Bold", FontColor -> RGBColor[0, 0, 0.500008]], 
                  Cell[
                   StyleData["Category2", "Printout"], 
                   CellMargins -> {{2, 2}, {6, 6}}]}, Closed]], 
               Cell[
                CellGroupData[{
                  Cell[
                   StyleData["Category3"], ShowCellBracket -> False, 
                   ShowGroupOpener -> True, 
                   CellMargins -> {{157, 10}, {7, 7}}, 
                   CellGroupingRules -> {"SectionGrouping", 70}, 
                   StyleMenuListing -> None, FontSize -> 12, FontWeight -> 
                   "Bold", FontColor -> RGBColor[0.2, 0, 0.4]], 
                  Cell[
                   StyleData["Category3", "Printout"], 
                   CellMargins -> {{2, 2}, {6, 6}}]}, Closed]], 
               Cell[
                CellGroupData[{
                  Cell[
                   StyleData["Category4"], ShowCellBracket -> False, 
                   ShowGroupOpener -> True, 
                   CellMargins -> {{230, 10}, {7, 7}}, 
                   CellGroupingRules -> {"SectionGrouping", 80}, 
                   StyleMenuListing -> None, FontWeight -> "Bold", FontColor -> 
                   RGBColor[0, 0.300008, 0.4]], 
                  Cell[
                   StyleData["Category4", "Printout"], 
                   CellMargins -> {{2, 2}, {6, 6}}]}, Closed]]}, Open]], 
            Cell[
             CellGroupData[{
               Cell["Misc", "Subsubsection"], 
               Cell[
                CellGroupData[{
                  Cell[
                   StyleData["4ColumnTable"], 
                   CellMargins -> {{10, 4}, {0, 8}}, CellHorizontalScrolling -> 
                   True, PageBreakWithin -> False, AutoIndent -> False, 
                   AutoSpacing -> False, LineIndent -> 0, StyleMenuListing -> 
                   None, GridBoxOptions -> {
                    GridBoxAlignment -> {
                    "Columns" -> {Left, {Center}}, "ColumnsIndexed" -> {}, 
                    "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}, 
                    GridBoxItemSize -> {"Columns" -> {{
                    Scaled[0.25]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
                    "RowsIndexed" -> {}}, GridBoxSpacings -> {"Columns" -> {
                    Offset[0.27999999999999997`], {
                    Offset[1.4]}, 
                    Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                    "Rows" -> {
                    Offset[0.2], {
                    Offset[0.6]}, 
                    Offset[0.2]}, "RowsIndexed" -> {}}}], 
                  Cell[
                   StyleData["4ColumnTable", "Printout"], 
                   CellMargins -> {{2, 0}, {0, 8}}], 
                  Cell[
                   StyleData["4ColumnTable", "EnhancedPrintout"], 
                   CellMargins -> {{2, 0}, {0, 8}}], 
                  Cell[
                   StyleData["4ColumnTable", "EnhancedPrintoutNonGray"], 
                   CellMargins -> {{2, 0}, {0, 8}}]}, Closed]], 
               Cell[
                CellGroupData[{
                  Cell[
                   StyleData["5ColumnTable"], 
                   CellMargins -> {{10, 4}, {0, 8}}, CellHorizontalScrolling -> 
                   True, PageBreakWithin -> False, AutoIndent -> False, 
                   AutoSpacing -> False, LineIndent -> 0, StyleMenuListing -> 
                   None, GridBoxOptions -> {
                    GridBoxAlignment -> {
                    "Columns" -> {Left, {Center}}, "ColumnsIndexed" -> {}, 
                    "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}, 
                    GridBoxItemSize -> {"Columns" -> {{
                    Scaled[0.2]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
                    "RowsIndexed" -> {}}, GridBoxSpacings -> {"Columns" -> {
                    Offset[0.27999999999999997`], {
                    Offset[1.4]}, 
                    Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                    "Rows" -> {
                    Offset[0.2], {
                    Offset[0.6]}, 
                    Offset[0.2]}, "RowsIndexed" -> {}}}], 
                  Cell[
                   StyleData["5ColumnTable", "Printout"], 
                   CellMargins -> {{2, 0}, {0, 8}}], 
                  Cell[
                   StyleData["5ColumnTable", "EnhancedPrintout"], 
                   CellMargins -> {{2, 0}, {0, 8}}], 
                  Cell[
                   StyleData["5ColumnTable", "EnhancedPrintoutNonGray"], 
                   CellMargins -> {{2, 0}, {0, 8}}]}, Closed]], 
               Cell[
                CellGroupData[{
                  Cell[
                   StyleData["6ColumnTable"], 
                   CellMargins -> {{10, 4}, {0, 8}}, CellHorizontalScrolling -> 
                   True, PageBreakWithin -> False, AutoIndent -> False, 
                   AutoSpacing -> False, LineIndent -> 0, StyleMenuListing -> 
                   None, GridBoxOptions -> {
                    GridBoxAlignment -> {
                    "Columns" -> {Left, {Center}}, "ColumnsIndexed" -> {}, 
                    "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}, 
                    GridBoxItemSize -> {"Columns" -> {{
                    Scaled[0.16]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
                    "RowsIndexed" -> {}}, GridBoxSpacings -> {"Columns" -> {
                    Offset[0.27999999999999997`], {
                    Offset[1.4]}, 
                    Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                    "Rows" -> {
                    Offset[0.2], {
                    Offset[0.6]}, 
                    Offset[0.2]}, "RowsIndexed" -> {}}}], 
                  Cell[
                   StyleData["6ColumnTable", "Printout"], 
                   CellMargins -> {{2, 0}, {0, 8}}], 
                  Cell[
                   StyleData["6ColumnTable", "EnhancedPrintout"], 
                   CellMargins -> {{2, 0}, {0, 8}}], 
                  Cell[
                   StyleData["6ColumnTable", "EnhancedPrintoutNonGray"], 
                   CellMargins -> {{2, 0}, {0, 8}}]}, Closed]], 
               Cell[
                CellGroupData[{
                  Cell[
                   StyleData["7ColumnTable"], 
                   CellMargins -> {{10, 4}, {0, 8}}, CellHorizontalScrolling -> 
                   True, PageBreakWithin -> False, AutoIndent -> False, 
                   AutoSpacing -> False, LineIndent -> 0, StyleMenuListing -> 
                   None, GridBoxOptions -> {
                    GridBoxAlignment -> {
                    "Columns" -> {Left, {Center}}, "ColumnsIndexed" -> {}, 
                    "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}, 
                    GridBoxItemSize -> {"Columns" -> {{
                    Scaled[0.14]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
                    "RowsIndexed" -> {}}, GridBoxSpacings -> {"Columns" -> {
                    Offset[0.27999999999999997`], {
                    Offset[1.4]}, 
                    Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                    "Rows" -> {
                    Offset[0.2], {
                    Offset[0.6]}, 
                    Offset[0.2]}, "RowsIndexed" -> {}}}], 
                  Cell[
                   StyleData["7ColumnTable", "Printout"], 
                   CellMargins -> {{2, 0}, {0, 8}}], 
                  Cell[
                   StyleData["7ColumnTable", "EnhancedPrintout"], 
                   CellMargins -> {{2, 0}, {0, 8}}], 
                  Cell[
                   StyleData["7ColumnTable", "EnhancedPrintoutNonGray"], 
                   CellMargins -> {{2, 0}, {0, 8}}]}, Closed]], 
               Cell[
                CellGroupData[{
                  Cell[
                   StyleData["8ColumnTable"], 
                   CellMargins -> {{10, 4}, {0, 8}}, CellHorizontalScrolling -> 
                   True, PageBreakWithin -> False, AutoIndent -> False, 
                   AutoSpacing -> False, LineIndent -> 0, StyleMenuListing -> 
                   None, GridBoxOptions -> {
                    GridBoxAlignment -> {
                    "Columns" -> {Left, {Center}}, "ColumnsIndexed" -> {}, 
                    "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}, 
                    GridBoxItemSize -> {"Columns" -> {{
                    Scaled[0.12]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
                    "RowsIndexed" -> {}}, GridBoxSpacings -> {"Columns" -> {
                    Offset[0.27999999999999997`], {
                    Offset[1.4]}, 
                    Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                    "Rows" -> {
                    Offset[0.2], {
                    Offset[0.6]}, 
                    Offset[0.2]}, "RowsIndexed" -> {}}}], 
                  Cell[
                   StyleData["8ColumnTable", "Printout"], 
                   CellMargins -> {{2, 0}, {0, 8}}], 
                  Cell[
                   StyleData["8ColumnTable", "EnhancedPrintout"], 
                   CellMargins -> {{2, 0}, {0, 8}}], 
                  Cell[
                   StyleData["8ColumnTable", "EnhancedPrintoutNonGray"], 
                   CellMargins -> {{2, 0}, {0, 8}}]}, Closed]], 
               Cell[
                CellGroupData[{
                  Cell[
                   StyleData["ABItemizedText"], 
                   CellMargins -> {{20, 4}, {0, 5}}, Hyphenation -> True, 
                   LineSpacing -> {1, 3}, ParagraphIndent -> -21, 
                   CounterIncrements -> "ItemizedText", StyleMenuListing -> 
                   None], 
                  Cell[
                   StyleData["ABItemizedText", "Printout"], 
                   ParagraphIndent -> -21, FontSize -> 11], 
                  Cell[
                   StyleData["ABItemizedText", "EnhancedPrintout"], 
                   ParagraphIndent -> -21, FontFamily -> "Palatino", FontSize -> 
                   10], 
                  Cell[
                   StyleData["ABItemizedText", "EnhancedPrintoutNonGray"], 
                   ParagraphIndent -> -21, FontFamily -> "Palatino", FontSize -> 
                   10]}, Closed]], 
               Cell[
                CellGroupData[{
                  Cell[
                   StyleData["ChapNumber"], 
                   CellMargins -> {{12, Inherited}, {20, 40}}, 
                   CellGroupingRules -> {"TitleGrouping", 0}, PageBreakBelow -> 
                   False, DefaultNewInlineCellStyle -> "None", 
                   InputAutoReplacements -> {"TeX" -> StyleBox[
                    RowBox[{"T", 
                    AdjustmentBox[
                    "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                    BoxBaselineShift -> 0.5], "X"}]], "LaTeX" -> StyleBox[
                    RowBox[{"L", 
                    StyleBox[
                    AdjustmentBox[
                    "A", BoxMargins -> {{-0.36, -0.1}, {0, 0}}, 
                    BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
                    AdjustmentBox[
                    "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                    BoxBaselineShift -> 0.5], "X"}]], "mma" -> "Mathematica", 
                    "Mma" -> "Mathematica", "MMA" -> "Mathematica", 
                    "webMathematica" -> FormBox[
                    RowBox[{"web", 
                    AdjustmentBox[
                    StyleBox["Mathematica", FontSlant -> "Italic"], 
                    BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm]}, 
                   LanguageCategory -> "NaturalLanguage", CounterIncrements -> 
                   "Title", 
                   CounterAssignments -> {{"Section", 0}, {"Equation", 0}, {
                    "Figure", 0}, {"Subtitle", 0}, {"Subsubtitle", 0}}, 
                   StyleMenuListing -> None, FontFamily -> "Helvetica", 
                   FontSize -> 42, FontWeight -> "Plain"], 
                  Cell[
                   StyleData["ChapNumber", "Printout"], 
                   CellMargins -> {{2, 10}, {15, 30}}, FontSize -> 36], 
                  Cell[
                   StyleData["ChapNumber", "EnhancedPrintout"], 
                   CellMargins -> {{2, 10}, {15, 30}}, FontFamily -> "Futura",
                    FontSize -> 36], 
                  Cell[
                   StyleData["ChapNumber", "EnhancedPrintoutNonGray"], 
                   CellMargins -> {{2, 10}, {15, 30}}, FontFamily -> "Futura",
                    FontSize -> 36]}, Closed]], 
               Cell[
                CellGroupData[{
                  Cell[
                   StyleData["ChapTitle"], 
                   CellMargins -> {{12, Inherited}, {80, 10}}, 
                   CellGroupingRules -> {"TitleGrouping", 0}, PageBreakBelow -> 
                   False, DefaultNewInlineCellStyle -> "None", 
                   InputAutoReplacements -> {"TeX" -> StyleBox[
                    RowBox[{"T", 
                    AdjustmentBox[
                    "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                    BoxBaselineShift -> 0.5], "X"}]], "LaTeX" -> StyleBox[
                    RowBox[{"L", 
                    StyleBox[
                    AdjustmentBox[
                    "A", BoxMargins -> {{-0.36, -0.1}, {0, 0}}, 
                    BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
                    AdjustmentBox[
                    "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                    BoxBaselineShift -> 0.5], "X"}]], "mma" -> "Mathematica", 
                    "Mma" -> "Mathematica", "MMA" -> "Mathematica", 
                    "webMathematica" -> FormBox[
                    RowBox[{"web", 
                    AdjustmentBox[
                    StyleBox["Mathematica", FontSlant -> "Italic"], 
                    BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm]}, 
                   LanguageCategory -> "NaturalLanguage", CounterIncrements -> 
                   "Title", 
                   CounterAssignments -> {{"Section", 0}, {"Equation", 0}, {
                    "Figure", 0}, {"Subtitle", 0}, {"Subsubtitle", 0}}, 
                   StyleMenuListing -> None, FontFamily -> "Helvetica", 
                   FontSize -> 36, FontWeight -> "Bold"], 
                  Cell[
                   StyleData["ChapTitle", "Printout"], 
                   CellMargins -> {{2, 10}, {80, 6}}, FontSize -> 30], 
                  Cell[
                   StyleData["ChapTitle", "EnhancedPrintout"], 
                   CellMargins -> {{2, 10}, {80, 6}}, FontFamily -> "Futura", 
                   FontSize -> 30], 
                  Cell[
                   StyleData["ChapTitle", "EnhancedPrintoutNonGray"], 
                   CellMargins -> {{2, 10}, {80, 6}}, FontFamily -> "Futura", 
                   FontSize -> 30]}, Closed]], 
               Cell[
                CellGroupData[{
                  Cell[
                   StyleData["ItemDingbat"], CellSize -> {22, 14}, 
                   TextAlignment -> Right, StyleMenuListing -> None, 
                   FontWeight -> "Bold"], 
                  Cell[
                   StyleData["ItemDingbat", "Printout"], 
                   CellSize -> {22, 13.125}], 
                  Cell[
                   StyleData["ItemDingbat", "EnhancedPrintout"], 
                   CellSize -> {22, 11}], 
                  Cell[
                   StyleData["ItemDingbat", "EnhancedPrintoutNonGray"], 
                   CellSize -> {22, 11}]}, Closed]], 
               Cell[
                CellGroupData[{
                  Cell[
                   StyleData["Item1"], CellMargins -> {{19, 4}, {4, 4}}, 
                   ParagraphIndent -> -22, CounterIncrements -> "Item1", 
                   StyleMenuListing -> None], 
                  Cell[
                   StyleData["Item1", "Printout"], 
                   CellMargins -> {{12, 0}, {2, 4}}, FontSize -> 10], 
                  Cell[
                   StyleData["Item1", "EnhancedPrintout"], 
                   CellMargins -> {{16, 0}, {2, 4}}, FontSize -> 10], 
                  Cell[
                   StyleData["Item1", "EnhancedPrintoutNonGray"], 
                   CellMargins -> {{16, 0}, {2, 4}}, FontSize -> 10]}, 
                 Closed]], 
               Cell[
                CellGroupData[{
                  Cell[
                   StyleData["Item1Continued"], 
                   CellMargins -> {{41, 4}, {4, 1}}, CounterIncrements -> 
                   "Item1Continued", StyleMenuListing -> None], 
                  Cell[
                   StyleData["Item1Continued", "Printout"], 
                   CellMargins -> {{34, 0}, {4, 1}}, FontSize -> 10], 
                  Cell[
                   StyleData["Item1Continued", "EnhancedPrintout"], 
                   CellMargins -> {{39, 0}, {4, 1}}, FontSize -> 10], 
                  Cell[
                   StyleData["Item1Continued", "EnhancedPrintoutNonGray"], 
                   CellMargins -> {{39, 0}, {4, 1}}, FontSize -> 10]}, 
                 Closed]], 
               Cell[
                CellGroupData[{
                  Cell[
                   StyleData["Item2"], CellMargins -> {{32, 4}, {4, 4}}, 
                   ParagraphIndent -> -22, CounterIncrements -> "Item2", 
                   StyleMenuListing -> None], 
                  Cell[
                   StyleData["Item2", "Printout"], 
                   CellMargins -> {{26, 0}, {4, 4}}, ParagraphIndent -> -22, 
                   FontSize -> 10], 
                  Cell[
                   StyleData["Item2", "EnhancedPrintout"], 
                   CellMargins -> {{29, 0}, {2, 4}}, ParagraphIndent -> -22, 
                   FontSize -> 10], 
                  Cell[
                   StyleData["Item2", "EnhancedPrintoutNonGray"], 
                   CellMargins -> {{29, 0}, {2, 4}}, ParagraphIndent -> -22, 
                   FontSize -> 10]}, Closed]], 
               Cell[
                CellGroupData[{
                  Cell[
                   StyleData["Item2Continued"], 
                   CellMargins -> {{54, 4}, {4, 1}}, CounterIncrements -> 
                   "Item2Continued", StyleMenuListing -> None], 
                  Cell[
                   StyleData["Item2Continued", "Printout"], 
                   CellMargins -> {{27, 0}, {4, 1}}], 
                  Cell[
                   StyleData["Item2Continued", "EnhancedPrintout"], 
                   CellMargins -> {{52, 0}, {4, 1}}, FontSize -> 10], 
                  Cell[
                   StyleData["Item2Continued", "EnhancedPrintoutNonGray"], 
                   CellMargins -> {{52, 0}, {4, 1}}]}, Closed]], 
               Cell[
                CellGroupData[{
                  Cell[
                   StyleData["Item3"], CellMargins -> {{45, 4}, {4, 4}}, 
                   ParagraphIndent -> -23, CounterIncrements -> "Item3", 
                   StyleMenuListing -> None], 
                  Cell[
                   StyleData["Item3", "Printout"], 
                   CellMargins -> {{27, 0}, {2, 4}}], 
                  Cell[
                   StyleData["Item3", "EnhancedPrintout"], 
                   CellMargins -> {{42, 0}, {2, 4}}, FontSize -> 10], 
                  Cell[
                   StyleData["Item3", "EnhancedPrintoutNonGray"], 
                   CellMargins -> {{42, 0}, {2, 4}}, StyleMenuListing -> 
                   None]}, Closed]], 
               Cell[
                CellGroupData[{
                  Cell[
                   StyleData["Item3Continued"], 
                   CellMargins -> {{67, 4}, {4, 1}}, CounterIncrements -> 
                   "Item3Continued", StyleMenuListing -> None], 
                  Cell[
                   StyleData["Item3Continued", "Printout"], 
                   CellMargins -> {{27, 0}, {4, 1}}], 
                  Cell[
                   StyleData["Item3Continued", "EnhancedPrintout"], 
                   CellMargins -> {{65, 0}, {4, 1}}, FontSize -> 10], 
                  Cell[
                   StyleData["Item3Continued", "EnhancedPrintoutNonGray"], 
                   CellMargins -> {{65, 0}, {4, 1}}]}, Closed]], 
               Cell[
                CellGroupData[{
                  Cell[
                   StyleData["ItemizedBulletText"], 
                   CellMargins -> {{19, 4}, {0, 5}}, Hyphenation -> True, 
                   LineSpacing -> {1, 3}, ParagraphIndent -> -22, 
                   CounterIncrements -> "ItemizedBulletText", 
                   StyleMenuListing -> None], 
                  Cell[
                   StyleData["ItemizedBulletText", "Printout"], 
                   ParagraphIndent -> -20, FontSize -> 11], 
                  Cell[
                   StyleData["ItemizedBulletText", "EnhancedPrintout"], 
                   ParagraphIndent -> -19, FontFamily -> "Palatino", FontSize -> 
                   10], 
                  Cell[
                   StyleData["ItemizedBulletText", "EnhancedPrintoutNonGray"],
                    ParagraphIndent -> -19, FontFamily -> "Palatino", 
                   FontSize -> 10]}, Closed]], 
               Cell[
                CellGroupData[{
                  Cell[
                   StyleData["NoteBox"], CellFrame -> 0.5, 
                   CellMargins -> {{10, 4}, {8, 8}}, CellHorizontalScrolling -> 
                   True, LineIndent -> 0, StyleMenuListing -> None, 
                   Background -> RGBColor[1, 0.6, 0.6], 
                   FrameBoxOptions -> {
                    FrameMargins -> {{15.600000000000001`, 
                    15.600000000000001`}, {11.700000000000001`, 
                    11.700000000000001`}}}, 
                   GridBoxOptions -> {GridBoxSpacings -> {"Columns" -> {
                    Offset[0.27999999999999997`], {
                    Offset[0.7]}, 
                    Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                    "Rows" -> {
                    Offset[0.2], {
                    Offset[0.4]}, 
                    Offset[0.2]}, "RowsIndexed" -> {}}}], 
                  Cell[
                   StyleData["NoteBox", "Printout"], 
                   CellMargins -> {{2, 4}, {6, 2}}, FontSize -> 10, 
                   Background -> GrayLevel[0.900008]], 
                  Cell[
                   StyleData["NoteBox", "EnhancedPrintout"], 
                   CellMargins -> {{2, 4}, {6, 2}}, FontSize -> 10, 
                   Background -> GrayLevel[0.900008]], 
                  Cell[
                   StyleData["NoteBox", "EnhancedPrintoutNonGray"], 
                   CellMargins -> {{2, 4}, {6, 2}}, FontSize -> 10, 
                   Background -> GrayLevel[1]]}, Closed]], 
               Cell[
                CellGroupData[{
                  Cell[
                   StyleData["ItemizedNoteBox"], CellFrame -> 0.5, 
                   CellMargins -> {{41, 4}, {8, 2}}, CellHorizontalScrolling -> 
                   True, LineIndent -> 0, StyleMenuListing -> None, 
                   Background -> RGBColor[1, 0.6, 0.6], 
                   FrameBoxOptions -> {
                    FrameMargins -> {{15.600000000000001`, 
                    15.600000000000001`}, {11.700000000000001`, 
                    11.700000000000001`}}}, 
                   GridBoxOptions -> {GridBoxSpacings -> {"Columns" -> {
                    Offset[0.27999999999999997`], {
                    Offset[0.7]}, 
                    Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                    "Rows" -> {
                    Offset[0.2], {
                    Offset[0.4]}, 
                    Offset[0.2]}, "RowsIndexed" -> {}}}], 
                  Cell[
                   StyleData["ItemizedNoteBox", "Printout"], 
                   CellMargins -> {{39, 4}, {6, 2}}, FontSize -> 10, 
                   Background -> GrayLevel[0.900008]], 
                  Cell[
                   StyleData["ItemizedNoteBox", "EnhancedPrintout"], 
                   CellMargins -> {{39, 4}, {6, 2}}, FontSize -> 10, 
                   Background -> GrayLevel[0.900008]], 
                  Cell[
                   StyleData["ItemizedNoteBox", "EnhancedPrintoutNonGray"], 
                   CellMargins -> {{39, 4}, {6, 2}}, FontSize -> 10, 
                   Background -> GrayLevel[1]]}, Closed]], 
               Cell[
                CellGroupData[{
                  Cell[
                   StyleData["ItemizedTopBox"], 
                   CellFrame -> {{0.5, 0.5}, {0, 0.5}}, 
                   CellMargins -> {{37, 4}, {0, 8}}, CellHorizontalScrolling -> 
                   True, CellFrameMargins -> {{8, 8}, {0, 8}}, LineIndent -> 
                   0, StyleMenuListing -> None, Background -> 
                   RGBColor[1, 0.6, 0.6], 
                   GridBoxOptions -> {
                    GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
                    "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}, 
                    GridBoxItemSize -> {"Columns" -> {
                    Scaled[0.31], {
                    Scaled[0.62]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
                    "RowsIndexed" -> {}}, GridBoxSpacings -> {"Columns" -> {
                    Offset[0.27999999999999997`], {
                    Offset[0.7]}, 
                    Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                    "Rows" -> {
                    Offset[0.2], {
                    Offset[0.6]}, 
                    Offset[0.2]}, "RowsIndexed" -> {}}}], 
                  Cell[
                   StyleData["ItemizedTopBox", "Printout"], FontSize -> 10, 
                   Background -> GrayLevel[0.900008]], 
                  Cell[
                   StyleData["ItemizedTopBox", "EnhancedPrintout"], 
                   CellMargins -> {{39, 4}, {0, 6}}, FontSize -> 10, 
                   Background -> GrayLevel[0.900008]], 
                  Cell[
                   StyleData["ItemizedTopBox", "EnhancedPrintoutNonGray"], 
                   CellMargins -> {{39, 4}, {0, 6}}, FontSize -> 10, 
                   Background -> GrayLevel[1]]}, Closed]], 
               Cell[
                CellGroupData[{
                  Cell[
                   StyleData["ItemizedBottomBox"], 
                   CellFrame -> {{0.5, 0.5}, {0.5, 0}}, 
                   CellMargins -> {{37, 4}, {4, 0}}, CellHorizontalScrolling -> 
                   True, CellFrameMargins -> {{8, 8}, {8, 0}}, LineIndent -> 
                   0, StyleMenuListing -> None, Background -> 
                   RGBColor[1, 0.6, 0.6], 
                   GridBoxOptions -> {
                    GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
                    "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}, 
                    GridBoxItemSize -> {"Columns" -> {
                    Scaled[0.31], {
                    Scaled[0.62]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
                    "RowsIndexed" -> {}}, GridBoxSpacings -> {"Columns" -> {
                    Offset[0.27999999999999997`], {
                    Offset[0.7]}, 
                    Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                    "Rows" -> {
                    Offset[0.2], {
                    Offset[0.6]}, 
                    Offset[0.2]}, "RowsIndexed" -> {}}}], 
                  Cell[
                   StyleData["ItemizedBottomBox", "Printout"], FontSize -> 10,
                    Background -> GrayLevel[0.900008]], 
                  Cell[
                   StyleData["ItemizedBottomBox", "EnhancedPrintout"], 
                   CellMargins -> {{39, 4}, {6, 0}}, FontSize -> 10, 
                   Background -> GrayLevel[0.900008]], 
                  Cell[
                   StyleData["ItemizedBottomBox", "EnhancedPrintoutNonGray"], 
                   CellMargins -> {{39, 4}, {6, 0}}, FontSize -> 10, 
                   Background -> GrayLevel[1]]}, Closed]], 
               Cell[
                CellGroupData[{
                  Cell[
                   StyleData["MiddleSpacedBox"], 
                   CellFrame -> {{0.5, 0.5}, {0, 0}}, 
                   CellMargins -> {{11, 4}, {0, -7}}, CellHorizontalScrolling -> 
                   True, PageBreakAbove -> False, PageBreakBelow -> False, 
                   AutoIndent -> False, AutoSpacing -> False, LineIndent -> 0,
                    StyleMenuListing -> None, FontWeight -> "Plain", 
                   Background -> RGBColor[1, 0.6, 0.6], 
                   GridBoxOptions -> {
                    GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
                    "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}, 
                    GridBoxItemSize -> {"Columns" -> {
                    Scaled[0.31], {
                    Scaled[0.62]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
                    "RowsIndexed" -> {}}, GridBoxSpacings -> {"Columns" -> {
                    Offset[0.27999999999999997`], {
                    Offset[0.7]}, 
                    Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                    "Rows" -> {
                    Offset[0.2], {
                    Offset[0.6]}, 
                    Offset[0.2]}, "RowsIndexed" -> {}}}], 
                  Cell[
                   StyleData["MiddleSpacedBox", "Printout"], 
                   CellMargins -> {{2, 0}, {0, 0}}, Background -> 
                   GrayLevel[1], 
                   GridBoxOptions -> {
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "ColumnsIndexed" -> {}, 
                    "Rows" -> {{1.8}}, "RowsIndexed" -> {}}}], 
                  Cell[
                   StyleData["MiddleSpacedBox", "EnhancedPrintout"], 
                   CellMargins -> {{2, 0}, {0, 0}}, FontFamily -> "Palatino", 
                   Background -> GrayLevel[1], 
                   GridBoxOptions -> {
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "ColumnsIndexed" -> {}, 
                    "Rows" -> {{1.8}}, "RowsIndexed" -> {}}}], 
                  Cell[
                   StyleData["MiddleSpacedBox", "EnhancedPrintoutNonGray"], 
                   CellMargins -> {{2, 0}, {0, 0}}, FontFamily -> "Palatino", 
                   Background -> GrayLevel[1], 
                   GridBoxOptions -> {
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "ColumnsIndexed" -> {}, 
                    "Rows" -> {{1.8}}, "RowsIndexed" -> {}}}]}, Closed]], 
               Cell[
                CellGroupData[{
                  Cell[
                   StyleData["ItemizedNote"], 
                   CellMargins -> {{41, 4}, {0, 12}}, Hyphenation -> True, 
                   LineSpacing -> {1, 2}, CounterIncrements -> "Text", 
                   StyleMenuListing -> None], 
                  Cell[
                   StyleData["ItemizedNote", "Printout"], 
                   CellMargins -> {{38, 4}, {0, 9}}, FontSize -> 11], 
                  Cell[
                   StyleData["ItemizedNote", "EnhancedPrintout"], 
                   CellMargins -> {{38, 4}, {0, 0}}, TextJustification -> 1, 
                   FontFamily -> "Palatino", FontSize -> 10], 
                  Cell[
                   StyleData["ItemizedNote", "EnhancedPrintoutNonGray"], 
                   CellMargins -> {{38, 4}, {0, 0}}, TextJustification -> 1, 
                   FontFamily -> "Palatino", FontSize -> 10]}, Closed]], 
               Cell[
                CellGroupData[{
                  Cell[
                   StyleData["ItemizedNoteBelow"], 
                   CellMargins -> {{41, 4}, {0, 8}}, Hyphenation -> True, 
                   LineSpacing -> {1, 2}, CounterIncrements -> "Text", 
                   StyleMenuListing -> None], 
                  Cell[
                   StyleData["ItemizedNoteBelow", "Printout"], 
                   CellMargins -> {{38, 4}, {0, 12}}, FontSize -> 11], 
                  Cell[
                   StyleData["ItemizedNoteBelow", "EnhancedPrintout"], 
                   CellMargins -> {{38, 4}, {0, 8}}, TextJustification -> 1, 
                   FontFamily -> "Palatino", FontSize -> 10], 
                  Cell[
                   StyleData["ItemizedNoteBelow", "EnhancedPrintoutNonGray"], 
                   CellMargins -> {{38, 4}, {0, 8}}, TextJustification -> 1, 
                   FontFamily -> "Palatino", FontSize -> 10]}, Closed]], 
               Cell[
                CellGroupData[{
                  Cell[
                   StyleData["ItemizedTextBelowPic"], 
                   CellMargins -> {{19, 4}, {0, 8}}, Hyphenation -> True, 
                   LineSpacing -> {1, 3}, ParagraphIndent -> -22, 
                   CounterIncrements -> "ItemizedText", StyleMenuListing -> 
                   None], 
                  Cell[
                   StyleData["ItemizedTextBelowPic", "Printout"], 
                   CellMargins -> {{20, 4}, {2, 12}}, ParagraphIndent -> -18, 
                   FontSize -> 11], 
                  Cell[
                   StyleData["ItemizedTextBelowPic", "EnhancedPrintout"], 
                   CellMargins -> {{20, 4}, {2, 12}}, ParagraphIndent -> -17, 
                   FontFamily -> "Palatino", FontSize -> 10], 
                  Cell[
                   StyleData[
                   "ItemizedTextBelowPic", "EnhancedPrintoutNonGray"], 
                   CellMargins -> {{20, 4}, {2, 12}}, ParagraphIndent -> -17, 
                   FontFamily -> "Palatino", FontSize -> 10]}, Closed]], 
               Cell[
                CellGroupData[{
                  Cell[
                   StyleData["ItemizedTextNote2"], 
                   CellMargins -> {{41, 4}, {0, 4}}, Hyphenation -> True, 
                   LineSpacing -> {1, 2}, CounterIncrements -> "Text", 
                   StyleMenuListing -> None], 
                  Cell[
                   StyleData["ItemizedTextNote2", "Printout"], 
                   CellMargins -> {{38, 4}, {0, 2}}, FontSize -> 11], 
                  Cell[
                   StyleData["ItemizedTextNote2", "EnhancedPrintout"], 
                   CellMargins -> {{38, 4}, {0, 2}}, FontFamily -> "Palatino",
                    FontSize -> 10], 
                  Cell[
                   StyleData["ItemizedTextNote2", "EnhancedPrintoutNonGray"], 
                   CellMargins -> {{38, 4}, {0, 2}}, FontFamily -> "Palatino",
                    FontSize -> 10]}, Closed]], 
               Cell[
                CellGroupData[{
                  Cell[
                   StyleData["NumberedItem1"], 
                   CellMargins -> {{48, 4}, {4, 4}}, 
                   CellGroupingRules -> {"SectionGrouping", 15}, 
                   ParagraphIndent -> -23, CounterIncrements -> 
                   "NumberedItem1", StyleMenuListing -> None], 
                  Cell[
                   StyleData["NumberedItem1", "Printout"], 
                   CellMargins -> {{12, 0}, {0, 8}}], 
                  Cell[
                   StyleData["NumberedItem1", "EnhancedPrintout"], 
                   CellMargins -> {{12, 0}, {0, 8}}], 
                  Cell[
                   StyleData["NumberedItem1", "EnhancedPrintoutNonGray"], 
                   CellMargins -> {{12, 0}, {0, 8}}]}, Closed]], 
               Cell[
                CellGroupData[{
                  Cell[
                   StyleData["NumberedItem2"], 
                   CellMargins -> {{71, 4}, {3, 3}}, 
                   CellGroupingRules -> {"SectionGrouping", 15}, 
                   ParagraphIndent -> -21, CounterIncrements -> 
                   "NumberedItem2", StyleMenuListing -> None], 
                  Cell[
                   StyleData["NumberedItem2", "Printout"], 
                   CellMargins -> {{27, 0}, {0, 4}}], 
                  Cell[
                   StyleData["NumberedItem2", "EnhancedPrintout"], 
                   CellMargins -> {{27, 0}, {0, 4}}], 
                  Cell[
                   StyleData["NumberedItem2", "EnhancedPrintoutNonGray"], 
                   CellMargins -> {{27, 0}, {0, 4}}]}, Closed]], 
               Cell[
                CellGroupData[{
                  Cell[
                   StyleData["NumberedItem3"], 
                   CellMargins -> {{94, 4}, {2, 2}}, 
                   CellGroupingRules -> {"SectionGrouping", 15}, 
                   ParagraphIndent -> -23, CounterIncrements -> 
                   "NumberedItem3", StyleMenuListing -> None], 
                  Cell[
                   StyleData["NumberedItem3", "Printout"], 
                   CellMargins -> {{27, 0}, {0, 4}}], 
                  Cell[
                   StyleData["NumberedItem3", "EnhancedPrintout"], 
                   CellMargins -> {{27, 0}, {0, 4}}], 
                  Cell[
                   StyleData["NumberedItem3", "EnhancedPrintoutNonGray"], 
                   CellMargins -> {{27, 0}, {0, 4}}, StyleMenuListing -> 
                   None]}, Closed]], 
               Cell[
                CellGroupData[{
                  Cell[
                   StyleData["PageHeaderBold"], 
                   CellMargins -> {{0, 0}, {2, 0}}, StyleMenuListing -> None, 
                   FontSize -> 8, FontWeight -> "Bold", FontSlant -> 
                   "Italic"], 
                  Cell[
                   StyleData["Header", "Printout"]], 
                  Cell[
                   StyleData["Header", "EnhancedPrintout"], FontFamily -> 
                   "Futura"], 
                  Cell[
                   StyleData["Header", "EnhancedPrintoutNonGray"], FontFamily -> 
                   "Futura"]}, Closed]], 
               Cell[
                CellGroupData[{
                  Cell[
                   StyleData["S9"], 
                   ConversionRules :> {
                    "HTML" -> {"<font=\"Helvetica, Arial\">", "</font>"}}, 
                   StyleMenuListing -> None, FontFamily -> "Helvetica", 
                   FontSize -> 9, FontWeight -> "Plain"], 
                  Cell[
                   StyleData["S9", "Printout"], FontSize -> 9, FontWeight -> 
                   "Plain"], 
                  Cell[
                   StyleData["S9", "EnhancedPrintout"], FontFamily -> 
                   "Futura", FontSize -> 9, FontWeight -> "Plain"], 
                  Cell[
                   StyleData["S9", "EnhancedPrintoutNonGray"], FontFamily -> 
                   "Futura", FontSize -> 9, FontWeight -> "Plain"]}, Closed]], 
               Cell[
                CellGroupData[{
                  Cell[
                   StyleData["S10"], 
                   ConversionRules :> {
                    "HTML" -> {"<font=\"Helvetica, Arial\">", "</font>"}}, 
                   StyleMenuListing -> None, FontFamily -> "Helvetica", 
                   FontSize -> 10, FontWeight -> "Plain"], 
                  Cell[
                   StyleData["S10", "Printout"], FontSize -> 10, FontWeight -> 
                   "Plain"], 
                  Cell[
                   StyleData["S10", "EnhancedPrintout"], FontFamily -> 
                   "Futura", FontSize -> 10, FontWeight -> "Plain"], 
                  Cell[
                   StyleData["S10", "EnhancedPrintoutNonGray"], FontFamily -> 
                   "Futura", FontSize -> 10, FontWeight -> "Plain"]}, 
                 Closed]], 
               Cell[
                CellGroupData[{
                  Cell[
                   StyleData["SB9"], 
                   ConversionRules :> {
                    "HTML" -> {"<font=\"Helvetica, Arial\">", "</font>"}}, 
                   StyleMenuListing -> None, FontFamily -> "Helvetica", 
                   FontSize -> 9, FontWeight -> "Bold", 
                   PrivateFontOptions -> {"OperatorSubstitution" -> False}], 
                  Cell[
                   StyleData["SB9", "Printout"], FontSize -> 7], 
                  Cell[
                   StyleData["SB9", "EnhancedPrintout"], FontFamily -> 
                   "Futura", FontSize -> 7], 
                  Cell[
                   StyleData["SB9", "EnhancedPrintoutNonGray"], FontFamily -> 
                   "Futura", FontSize -> 7]}, Closed]], 
               Cell[
                CellGroupData[{
                  Cell[
                   StyleData["SB10"], 
                   ConversionRules :> {
                    "HTML" -> {"<font=\"Helvetica, Arial\">", "</font>"}}, 
                   StyleMenuListing -> None, FontFamily -> "Helvetica", 
                   FontSize -> 10, FontWeight -> "Bold"], 
                  Cell[
                   StyleData["SB10", "Printout"], FontSize -> 7], 
                  Cell[
                   StyleData["SB10", "EnhancedPrintout"], FontFamily -> 
                   "Futura", FontSize -> 7], 
                  Cell[
                   StyleData["SB10", "EnhancedPrintoutNonGray"], FontFamily -> 
                   "Futura", FontSize -> 7]}, Closed]], 
               Cell[
                CellGroupData[{
                  Cell[
                   StyleData["SingleRowTable"], 
                   CellMargins -> {{10, 4}, {0, 8}}, CellHorizontalScrolling -> 
                   True, PageBreakWithin -> False, AutoIndent -> False, 
                   AutoSpacing -> False, LineIndent -> 0, StyleMenuListing -> 
                   None, GridBoxOptions -> {
                    GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
                    "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}, 
                    GridBoxSpacings -> {"Columns" -> {
                    Offset[0.27999999999999997`], {
                    Offset[1.4]}, 
                    Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                    "Rows" -> {
                    Offset[0.2], {
                    Offset[0.6]}, 
                    Offset[0.2]}, "RowsIndexed" -> {}}}], 
                  Cell[
                   StyleData["SingleRowTable", "Printout"], 
                   CellMargins -> {{2, 0}, {0, 8}}], 
                  Cell[
                   StyleData["SingleRowTable", "EnhancedPrintout"], 
                   CellMargins -> {{2, 0}, {0, 8}}], 
                  Cell[
                   StyleData["SingleRowTable", "EnhancedPrintoutNonGray"], 
                   CellMargins -> {{2, 0}, {0, 8}}]}, Closed]], 
               Cell[
                CellGroupData[{
                  Cell[
                   StyleData["Subsubsubsection"], 
                   CellMargins -> {{10, 4}, {0, 18}}, 
                   CellElementSpacings -> {"ClosedGroupTopMargin" -> 18}, 
                   StyleMenuListing -> None, FontSize -> 12, FontWeight -> 
                   "Bold"], 
                  Cell[
                   StyleData["Subsubsubsection", "Printout"], 
                   CellMargins -> {{2, 0}, {3, 8}}, FontSize -> 10], 
                  Cell[
                   StyleData["Subsubsubsection", "EnhancedPrintout"], 
                   CellMargins -> {{2, 0}, {3, 8}}, FontFamily -> "Palatino", 
                   FontSize -> 10], 
                  Cell[
                   StyleData["Subsubsubsection", "EnhancedPrintoutNonGray"], 
                   CellMargins -> {{2, 0}, {3, 8}}, FontFamily -> "Palatino", 
                   FontSize -> 10]}, Closed]], 
               Cell[
                CellGroupData[{
                  Cell[
                   StyleData["Subsubtitle"], 
                   CellMargins -> {{12, Inherited}, {20, 15}}, 
                   CellGroupingRules -> {"TitleGrouping", 20}, PageBreakBelow -> 
                   False, DefaultNewInlineCellStyle -> "None", 
                   InputAutoReplacements -> {"TeX" -> StyleBox[
                    RowBox[{"T", 
                    AdjustmentBox[
                    "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                    BoxBaselineShift -> 0.5], "X"}]], "LaTeX" -> StyleBox[
                    RowBox[{"L", 
                    StyleBox[
                    AdjustmentBox[
                    "A", BoxMargins -> {{-0.36, -0.1}, {0, 0}}, 
                    BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
                    AdjustmentBox[
                    "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                    BoxBaselineShift -> 0.5], "X"}]], "mma" -> "Mathematica", 
                    "Mma" -> "Mathematica", "MMA" -> "Mathematica", 
                    "webMathematica" -> FormBox[
                    RowBox[{"web", 
                    AdjustmentBox[
                    StyleBox["Mathematica", FontSlant -> "Italic"], 
                    BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm]}, 
                   LanguageCategory -> "NaturalLanguage", CounterIncrements -> 
                   "Subsubtitle", 
                   CounterAssignments -> {{"Section", 0}, {"Equation", 0}, {
                    "Figure", 0}}, StyleMenuListing -> None, FontFamily -> 
                   "Helvetica", FontSize -> 14, FontSlant -> "Italic"], 
                  Cell[
                   StyleData["Subsubtitle", "Printout"], 
                   CellMargins -> {{2, 10}, {8, 10}}, FontSize -> 12], 
                  Cell[
                   StyleData["Subsubtitle", "EnhancedPrintout"], 
                   CellMargins -> {{2, 10}, {8, 10}}, FontFamily -> "Futura", 
                   FontSize -> 12], 
                  Cell[
                   StyleData["Subsubtitle", "EnhancedPrintoutNonGray"], 
                   CellMargins -> {{2, 10}, {8, 10}}, FontFamily -> "Futura", 
                   FontSize -> 12]}, Closed]], 
               Cell[
                CellGroupData[{
                  Cell[
                   StyleData["Subtitle"], 
                   CellMargins -> {{12, Inherited}, {20, 15}}, 
                   CellGroupingRules -> {"TitleGrouping", 10}, PageBreakBelow -> 
                   False, DefaultNewInlineCellStyle -> "None", 
                   InputAutoReplacements -> {"TeX" -> StyleBox[
                    RowBox[{"T", 
                    AdjustmentBox[
                    "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                    BoxBaselineShift -> 0.5], "X"}]], "LaTeX" -> StyleBox[
                    RowBox[{"L", 
                    StyleBox[
                    AdjustmentBox[
                    "A", BoxMargins -> {{-0.36, -0.1}, {0, 0}}, 
                    BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
                    AdjustmentBox[
                    "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                    BoxBaselineShift -> 0.5], "X"}]], "mma" -> "Mathematica", 
                    "Mma" -> "Mathematica", "MMA" -> "Mathematica", 
                    "webMathematica" -> FormBox[
                    RowBox[{"web", 
                    AdjustmentBox[
                    StyleBox["Mathematica", FontSlant -> "Italic"], 
                    BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm]}, 
                   LanguageCategory -> "NaturalLanguage", CounterIncrements -> 
                   "Subtitle", 
                   CounterAssignments -> {{"Section", 0}, {"Equation", 0}, {
                    "Figure", 0}, {"Subsubtitle", 0}}, StyleMenuListing -> 
                   None, FontFamily -> "Helvetica", FontSize -> 24], 
                  Cell[
                   StyleData["Subtitle", "Printout"], 
                   CellMargins -> {{2, 10}, {10, 15}}, FontSize -> 24], 
                  Cell[
                   StyleData["Subtitle", "EnhancedPrintout"], 
                   CellMargins -> {{2, 10}, {10, 15}}, FontFamily -> "Futura",
                    FontSize -> 24], 
                  Cell[
                   StyleData["Subtitle", "EnhancedPrintoutNonGray"], 
                   CellMargins -> {{2, 10}, {10, 15}}, FontFamily -> "Futura",
                    FontSize -> 24]}, Closed]], 
               Cell[
                CellGroupData[{
                  Cell[
                   StyleData["TextBelow"], CellMargins -> {{10, 4}, {0, 14}}, 
                   ConversionRules :> {"HTML" -> {"<p>", "</p>"}}, 
                   InputAutoReplacements -> {"TeX" -> StyleBox[
                    RowBox[{"T", 
                    AdjustmentBox[
                    "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                    BoxBaselineShift -> 0.5], "X"}]], "LaTeX" -> StyleBox[
                    RowBox[{"L", 
                    StyleBox[
                    AdjustmentBox[
                    "A", BoxMargins -> {{-0.36, -0.1}, {0, 0}}, 
                    BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
                    AdjustmentBox[
                    "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                    BoxBaselineShift -> 0.5], "X"}]], "mma" -> "Mathematica", 
                    "Mma" -> "Mathematica", "MMA" -> "Mathematica", 
                    "webMathematica" -> FormBox[
                    RowBox[{"web", 
                    AdjustmentBox[
                    StyleBox["Mathematica", FontSlant -> "Italic"], 
                    BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm]}, 
                   Hyphenation -> True, ParagraphSpacing -> {0, 8}, 
                   StyleMenuListing -> None, FontSize -> 12], 
                  Cell[
                   StyleData["TextBelow", "Printout"], 
                   CellMargins -> {{2, 2}, {6, 12}}, TextJustification -> 1, 
                   FontSize -> 10], 
                  Cell[
                   StyleData["TextBelow", "EnhancedPrintout"], 
                   CellMargins -> {{2, 2}, {6, 12}}, TextJustification -> 1, 
                   FontFamily -> "Palatino", FontSize -> 10], 
                  Cell[
                   StyleData["TextBelow", "EnhancedPrintoutNonGray"], 
                   CellMargins -> {{2, 2}, {6, 12}}, TextJustification -> 1, 
                   FontFamily -> "Palatino", FontSize -> 10]}, Closed]], 
               Cell[
                CellGroupData[{
                  Cell[
                   StyleData["Title"], 
                   CellMargins -> {{12, Inherited}, {20, 40}}, 
                   CellGroupingRules -> {"TitleGrouping", 0}, PageBreakBelow -> 
                   False, DefaultNewInlineCellStyle -> "None", 
                   InputAutoReplacements -> {"TeX" -> StyleBox[
                    RowBox[{"T", 
                    AdjustmentBox[
                    "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                    BoxBaselineShift -> 0.5], "X"}]], "LaTeX" -> StyleBox[
                    RowBox[{"L", 
                    StyleBox[
                    AdjustmentBox[
                    "A", BoxMargins -> {{-0.36, -0.1}, {0, 0}}, 
                    BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
                    AdjustmentBox[
                    "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                    BoxBaselineShift -> 0.5], "X"}]], "mma" -> "Mathematica", 
                    "Mma" -> "Mathematica", "MMA" -> "Mathematica", 
                    "webMathematica" -> FormBox[
                    RowBox[{"web", 
                    AdjustmentBox[
                    StyleBox["Mathematica", FontSlant -> "Italic"], 
                    BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm]}, 
                   LanguageCategory -> "NaturalLanguage", CounterIncrements -> 
                   "Title", 
                   CounterAssignments -> {{"Section", 0}, {"Equation", 0}, {
                    "Figure", 0}, {"Subtitle", 0}, {"Subsubtitle", 0}}, 
                   StyleMenuListing -> None, FontFamily -> "Helvetica", 
                   FontSize -> 36, FontWeight -> "Bold"], 
                  Cell[
                   StyleData["Title", "Printout"], 
                   CellMargins -> {{2, 10}, {15, 30}}, FontSize -> 30], 
                  Cell[
                   StyleData["Title", "EnhancedPrintout"], 
                   CellMargins -> {{2, 10}, {15, 30}}, FontFamily -> "Futura",
                    FontSize -> 30.5], 
                  Cell[
                   StyleData["Title", "EnhancedPrintoutNonGray"], 
                   CellMargins -> {{2, 10}, {15, 30}}, FontFamily -> "Futura",
                    FontSize -> 30.5]}, Closed]], 
               Cell[
                CellGroupData[{
                  Cell[
                   StyleData["Undersubsection"], 
                   CellMargins -> {{10, 4}, {0, 18}}, 
                   CellElementSpacings -> {"ClosedGroupTopMargin" -> 18}, 
                   ConversionRules :> {
                    "HTML" -> {
                    "<p><font face=\"Helvetica, Arial\"><b>", 
                    "</b></font></p>\n"}}, 
                   InputAutoReplacements -> {"TeX" -> StyleBox[
                    RowBox[{"T", 
                    AdjustmentBox[
                    "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                    BoxBaselineShift -> 0.5], "X"}]], "LaTeX" -> StyleBox[
                    RowBox[{"L", 
                    StyleBox[
                    AdjustmentBox[
                    "A", BoxMargins -> {{-0.36, -0.1}, {0, 0}}, 
                    BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
                    AdjustmentBox[
                    "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                    BoxBaselineShift -> 0.5], "X"}]], "mma" -> "Mathematica", 
                    "Mma" -> "Mathematica", "MMA" -> "Mathematica", 
                    "webMathematica" -> FormBox[
                    RowBox[{"web", 
                    AdjustmentBox[
                    StyleBox["Mathematica", FontSlant -> "Italic"], 
                    BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm]}, 
                   StyleMenuListing -> None, FontFamily -> "Helvetica", 
                   FontSize -> 12, FontWeight -> "Bold"], 
                  Cell[
                   StyleData["Undersubsection", "Printout"], 
                   CellMargins -> {{2, 0}, {7, 10}}, FontSize -> 10], 
                  Cell[
                   StyleData["Undersubsection", "EnhancedPrintout"], 
                   CellMargins -> {{2, 0}, {7, 8}}, FontFamily -> "Futura", 
                   FontSize -> 10], 
                  Cell[
                   StyleData["Undersubsection", "EnhancedPrintoutNonGray"], 
                   CellMargins -> {{2, 0}, {7, 8}}, FontFamily -> "Futura", 
                   FontSize -> 10]}, Closed]], 
               Cell[
                CellGroupData[{
                  Cell[
                   StyleData["SectionFirst"], 
                   CellMargins -> {{10, 4}, {12, 18}}, 
                   CellGroupingRules -> {"SectionGrouping", 30}, 
                   CounterIncrements -> "Section", FontFamily -> "Helvetica", 
                   FontSize -> 20, FontWeight -> "Bold"], 
                  Cell[
                   StyleData["SectionFirst", "Printout"], 
                   CellMargins -> {{2, 0}, {0, 6}}, PageBreakBelow -> False, 
                   FontSize -> 18], 
                  Cell[
                   StyleData["SectionFirst", "EnhancedPrintout"], 
                   CellFrame -> {{0, 0}, {0.5, 0}}, 
                   CellMargins -> {{2, Inherited}, {5, 6}}, 
                   CellGroupingRules -> {"SectionGrouping", 30}, 
                   PageBreakBelow -> False, CellFrameMargins -> 8, 
                   CounterIncrements -> "Section", 
                   CounterAssignments -> {{"Subsection", 0}, {
                    "Subsubsection", 0}}, FontFamily -> "Futura", FontSize -> 
                   16], 
                  Cell[
                   StyleData["SectionFirst", "EnhancedPrintoutNonGray"], 
                   CellFrame -> {{0, 0}, {0.5, 0}}, 
                   CellMargins -> {{2, Inherited}, {5, 6}}, 
                   CellGroupingRules -> {"SectionGrouping", 30}, 
                   PageBreakBelow -> False, CellFrameMargins -> 8, 
                   CounterIncrements -> "Section", 
                   CounterAssignments -> {{"Subsection", 0}, {
                    "Subsubsection", 0}}, FontFamily -> "Futura", FontSize -> 
                   16]}, Closed]], 
               Cell[
                CellGroupData[{
                  Cell[
                   StyleData["SubsectionFirst"], CellDingbat -> 
                   "\[FilledSquare]", CellMargins -> {{24, 4}, {0, 18}}, 
                   CellElementSpacings -> {"ClosedGroupTopMargin" -> 18}, 
                   CellGroupingRules -> {"SectionGrouping", 40}, FontFamily -> 
                   "Helvetica", FontSize -> 16, FontWeight -> "Bold"], 
                  Cell[
                   StyleData["SubsectionFirst", "SlideShow"], CellDingbat -> 
                   None, CellMargins -> {{70, 0}, {4, 6}}, FontSize -> 12], 
                  Cell[
                   StyleData["SubsectionFirst", "Printout"], 
                   CellMargins -> {{9, 0}, {5, 6}}, 
                   CellBracketOptions -> {"Color" -> RGBColor[1, 0, 0]}, 
                   FontSize -> 12], 
                  Cell[
                   StyleData["SubsectionFirst", "EnhancedPrintout"], 
                   CellMargins -> {{9, 0}, {5, 6}}, 
                   CellBracketOptions -> {"Color" -> RGBColor[1, 0, 0]}, 
                   FontFamily -> "Futura", FontSize -> 12], 
                  Cell[
                   StyleData["SubsectionFirst", "EnhancedPrintoutNonGray"], 
                   CellMargins -> {{9, 0}, {5, 6}}, 
                   CellBracketOptions -> {"Color" -> RGBColor[1, 0, 0]}, 
                   FontFamily -> "Futura", FontSize -> 12]}, Closed]], 
               Cell[
                CellGroupData[{
                  Cell[
                   StyleData["SubsubsectionFirst"], 
                   CellMargins -> {{10, 4}, {0, 18}}, 
                   CellElementSpacings -> {"ClosedGroupTopMargin" -> 18}, 
                   CellGroupingRules -> {"SectionGrouping", 50}, FontFamily -> 
                   "Helvetica", FontSize -> 12, FontWeight -> "Bold"], 
                  Cell[
                   StyleData["SubsubsectionFirst", "Printout"], 
                   CellMargins -> {{2, 0}, {3, 3}}, 
                   CellBracketOptions -> {"Color" -> RGBColor[1, 0, 0]}, 
                   FontSize -> 10], 
                  Cell[
                   StyleData["SubsubsectionFirst", "EnhancedPrintout"], 
                   CellMargins -> {{2, 0}, {3, 3}}, 
                   CellBracketOptions -> {"Color" -> RGBColor[1, 0, 0]}, 
                   FontFamily -> "Futura", FontSize -> 10], 
                  Cell[
                   StyleData["SubsubsectionFirst", "EnhancedPrintoutNonGray"],
                    CellMargins -> {{2, 0}, {3, 3}}, 
                   CellBracketOptions -> {"Color" -> RGBColor[1, 0, 0]}, 
                   FontFamily -> "Futura", FontSize -> 10]}, Closed]], 
               Cell[
                CellGroupData[{
                  Cell[
                   StyleData["SubsubsubsectionFirst"], 
                   CellMargins -> {{10, 4}, {0, 12}}, 
                   CellElementSpacings -> {"ClosedGroupTopMargin" -> 18}, 
                   StyleMenuListing -> None, FontSize -> 12, FontWeight -> 
                   "Bold"], 
                  Cell[
                   StyleData["SubsubsubsectionFirst", "Printout"], 
                   CellMargins -> {{2, 0}, {3, 3}}, FontSize -> 10], 
                  Cell[
                   StyleData["SubsubsubsectionFirst", "EnhancedPrintout"], 
                   CellMargins -> {{2, 0}, {3, 3}}, FontFamily -> "Palatino", 
                   FontSize -> 10], 
                  Cell[
                   StyleData[
                   "SubsubsubsectionFirst", "EnhancedPrintoutNonGray"], 
                   CellMargins -> {{2, 0}, {3, 3}}, FontFamily -> "Palatino", 
                   FontSize -> 10]}, Closed]], 
               Cell["Spacer Cell", "Text"], 
               Cell[
                CellGroupData[{
                  Cell[
                   StyleData["Spacer"], CellMargins -> {{10, 10}, {0, 0}}, 
                   CellElementSpacings -> {
                    "CellMinHeight" -> 2, "ClosedCellHeight" -> 1}, CellOpen -> 
                   False, StyleMenuListing -> None], 
                  Cell[
                   StyleData["Spacer", "Printout"], CellOpen -> True, 
                   FontSize -> 3]}, Closed]], 
               Cell[
                CellGroupData[{
                  Cell[
                   StyleData["DiscretionaryHyphen"], StyleMenuListing -> None,
                    FontSize -> 0.0625, FontColor -> GrayLevel[1]], 
                  Cell[
                   StyleData["DiscretionaryHyphen", "Printout"], FontSize -> 
                   10, FontColor -> GrayLevel[0]], 
                  Cell[
                   StyleData["DiscretionaryHyphen", "EnhancedPrintout"], 
                   FontSize -> 10, FontColor -> GrayLevel[0]], 
                  Cell[
                   StyleData[
                   "DiscretionaryHyphen", "EnhancedPrintoutNonGray"], 
                   FontSize -> 10, FontColor -> GrayLevel[0]]}, Closed]], 
               Cell[
                CellGroupData[{
                  Cell[
                   StyleData["PictureSmaller1"], 
                   CellMargins -> {{10, Inherited}, {4, 4}}, 
                   CellGroupingRules -> "GraphicsGrouping", 
                   CellHorizontalScrolling -> True, StyleMenuListing -> None], 
                  Cell[
                   StyleData["PictureSmaller1", "Printout"], 
                   CellMargins -> {{2, Inherited}, {4, 4}}, Magnification -> 
                   0.63], 
                  Cell[
                   StyleData["PictureSmaller1", "EnhancedPrintout"], 
                   CellMargins -> {{2, Inherited}, {4, 2}}, Magnification -> 
                   0.63], 
                  Cell[
                   StyleData["PictureSmaller1", "EnhancedPrintoutNonGray"], 
                   CellMargins -> {{2, Inherited}, {4, 2}}, Magnification -> 
                   0.63]}, Closed]], 
               Cell[
                CellGroupData[{
                  Cell[
                   StyleData["PictureSmaller2"], 
                   CellMargins -> {{10, Inherited}, {4, 4}}, 
                   CellGroupingRules -> "GraphicsGrouping", 
                   CellHorizontalScrolling -> True, StyleMenuListing -> None], 
                  Cell[
                   StyleData["PictureSmaller2", "Printout"], 
                   CellMargins -> {{2, Inherited}, {4, 4}}, Magnification -> 
                   0.61], 
                  Cell[
                   StyleData["PictureSmaller2", "EnhancedPrintout"], 
                   CellMargins -> {{2, Inherited}, {4, 2}}, Magnification -> 
                   0.61], 
                  Cell[
                   StyleData["PictureSmaller2", "EnhancedPrintoutNonGray"], 
                   CellMargins -> {{2, Inherited}, {4, 2}}, Magnification -> 
                   0.61]}, Closed]], 
               Cell[
                CellGroupData[{
                  Cell[
                   StyleData["PictureSmaller3"], 
                   CellMargins -> {{10, Inherited}, {4, 4}}, 
                   CellGroupingRules -> "GraphicsGrouping", 
                   CellHorizontalScrolling -> True, StyleMenuListing -> None], 
                  Cell[
                   StyleData["PictureSmaller3", "Printout"], 
                   CellMargins -> {{2, Inherited}, {4, 4}}, Magnification -> 
                   0.59], 
                  Cell[
                   StyleData["PictureSmaller3", "EnhancedPrintout"], 
                   CellMargins -> {{2, Inherited}, {4, 2}}, Magnification -> 
                   0.59], 
                  Cell[
                   StyleData["PictureSmaller3", "EnhancedPrintoutNonGray"], 
                   CellMargins -> {{2, Inherited}, {4, 2}}, Magnification -> 
                   0.59]}, Closed]], 
               Cell[
                CellGroupData[{
                  Cell[
                   StyleData["PictureSmaller4"], 
                   CellMargins -> {{10, Inherited}, {4, 4}}, 
                   CellGroupingRules -> "GraphicsGrouping", 
                   CellHorizontalScrolling -> True, StyleMenuListing -> None], 
                  Cell[
                   StyleData["PictureSmaller4", "Printout"], 
                   CellMargins -> {{2, Inherited}, {4, 4}}, Magnification -> 
                   0.57], 
                  Cell[
                   StyleData["PictureSmaller4", "EnhancedPrintout"], 
                   CellMargins -> {{2, Inherited}, {4, 2}}, Magnification -> 
                   0.57], 
                  Cell[
                   StyleData["PictureSmaller4", "EnhancedPrintoutNonGray"], 
                   CellMargins -> {{2, Inherited}, {4, 2}}, Magnification -> 
                   0.57]}, Closed]], 
               Cell[
                CellGroupData[{
                  Cell[
                   StyleData["PictureSmaller5"], 
                   CellMargins -> {{10, Inherited}, {4, 4}}, 
                   CellGroupingRules -> "GraphicsGrouping", 
                   CellHorizontalScrolling -> True, StyleMenuListing -> None], 
                  Cell[
                   StyleData["PictureSmaller5", "Printout"], 
                   CellMargins -> {{2, Inherited}, {4, 4}}, Magnification -> 
                   0.55], 
                  Cell[
                   StyleData["PictureSmaller5", "EnhancedPrintout"], 
                   CellMargins -> {{2, Inherited}, {4, 2}}, Magnification -> 
                   0.55], 
                  Cell[
                   StyleData["PictureSmaller5", "EnhancedPrintoutNonGray"], 
                   CellMargins -> {{2, Inherited}, {4, 2}}, Magnification -> 
                   0.55]}, Closed]], 
               Cell[
                CellGroupData[{
                  Cell[
                   StyleData["PictureSmaller6"], 
                   CellMargins -> {{10, Inherited}, {4, 4}}, 
                   CellGroupingRules -> "GraphicsGrouping", 
                   CellHorizontalScrolling -> True, StyleMenuListing -> None], 
                  Cell[
                   StyleData["PictureSmaller6", "Printout"], 
                   CellMargins -> {{2, Inherited}, {4, 4}}, Magnification -> 
                   0.53], 
                  Cell[
                   StyleData["PictureSmaller6", "EnhancedPrintout"], 
                   CellMargins -> {{2, Inherited}, {4, 2}}, Magnification -> 
                   0.53], 
                  Cell[
                   StyleData["PictureSmaller6", "EnhancedPrintoutNonGray"], 
                   CellMargins -> {{2, Inherited}, {4, 2}}, Magnification -> 
                   0.53]}, Closed]], 
               Cell[
                CellGroupData[{
                  Cell[
                   StyleData["ItemPicture"], 
                   CellMargins -> {{41, Inherited}, {4, 2}}, 
                   CellGroupingRules -> "GraphicsGrouping", 
                   CellHorizontalScrolling -> True, StyleMenuListing -> None], 
                  Cell[
                   StyleData["ItemPicture", "Printout"], 
                   CellMargins -> {{55, Inherited}, {8, -4}}, Magnification -> 
                   0.65], 
                  Cell[
                   StyleData["ItemPicture", "EnhancedPrintout"], 
                   CellMargins -> {{60, Inherited}, {10, -3}}, Magnification -> 
                   0.65], 
                  Cell[
                   StyleData["ItemPicture", "EnhancedPrintoutNonGray"], 
                   CellMargins -> {{60, Inherited}, {10, -3}}, Magnification -> 
                   0.65]}, Closed]], 
               Cell[
                CellGroupData[{
                  Cell[
                   StyleData["ItemPictureSmaller1"], 
                   CellMargins -> {{41, Inherited}, {4, 2}}, 
                   CellGroupingRules -> "GraphicsGrouping", 
                   CellHorizontalScrolling -> True, StyleMenuListing -> None], 
                  Cell[
                   StyleData["ItemPictureSmaller1", "Printout"], 
                   CellMargins -> {{56, Inherited}, {9, -3}}, Magnification -> 
                   0.63], 
                  Cell[
                   StyleData["ItemPictureSmaller1", "EnhancedPrintout"], 
                   CellMargins -> {{63, Inherited}, {10, -3}}, Magnification -> 
                   0.63], 
                  Cell[
                   StyleData[
                   "ItemPictureSmaller1", "EnhancedPrintoutNonGray"], 
                   CellMargins -> {{63, Inherited}, {10, -3}}, Magnification -> 
                   0.63]}, Closed]], 
               Cell[
                CellGroupData[{
                  Cell[
                   StyleData["ItemPictureSmaller2"], 
                   CellMargins -> {{41, Inherited}, {4, 2}}, 
                   CellGroupingRules -> "GraphicsGrouping", 
                   CellHorizontalScrolling -> True, StyleMenuListing -> None], 
                  Cell[
                   StyleData["ItemPictureSmaller2", "Printout"], 
                   CellMargins -> {{58, Inherited}, {8, -4}}, Magnification -> 
                   0.61], 
                  Cell[
                   StyleData["ItemPictureSmaller2", "EnhancedPrintout"], 
                   CellMargins -> {{65, Inherited}, {11, -3}}, Magnification -> 
                   0.61], 
                  Cell[
                   StyleData[
                   "ItemPictureSmaller2", "EnhancedPrintoutNonGray"], 
                   CellMargins -> {{65, Inherited}, {11, -3}}, Magnification -> 
                   0.61]}, Closed]], 
               Cell[
                CellGroupData[{
                  Cell[
                   StyleData["ItemPictureSmaller3"], 
                   CellMargins -> {{41, Inherited}, {4, 2}}, 
                   CellGroupingRules -> "GraphicsGrouping", 
                   CellHorizontalScrolling -> True, StyleMenuListing -> None], 
                  Cell[
                   StyleData["ItemPictureSmaller3", "Printout"], 
                   CellMargins -> {{61, Inherited}, {10, -2}}, Magnification -> 
                   0.59], 
                  Cell[
                   StyleData["ItemPictureSmaller3", "EnhancedPrintout"], 
                   CellMargins -> {{67, Inherited}, {11, -3}}, Magnification -> 
                   0.59], 
                  Cell[
                   StyleData[
                   "ItemPictureSmaller3", "EnhancedPrintoutNonGray"], 
                   CellMargins -> {{67, Inherited}, {11, -3}}, Magnification -> 
                   0.59]}, Closed]], 
               Cell[
                CellGroupData[{
                  Cell[
                   StyleData["ItemPictureSmaller4"], 
                   CellMargins -> {{41, Inherited}, {4, 2}}, 
                   CellGroupingRules -> "GraphicsGrouping", 
                   CellHorizontalScrolling -> True, StyleMenuListing -> None], 
                  Cell[
                   StyleData["ItemPictureSmaller4", "Printout"], 
                   CellMargins -> {{63, Inherited}, {10, -2}}, Magnification -> 
                   0.57], 
                  Cell[
                   StyleData["ItemPictureSmaller4", "EnhancedPrintout"], 
                   CellMargins -> {{69, Inherited}, {12, -4}}, Magnification -> 
                   0.57], 
                  Cell[
                   StyleData[
                   "ItemPictureSmaller4", "EnhancedPrintoutNonGray"], 
                   CellMargins -> {{69, Inherited}, {12, -4}}, Magnification -> 
                   0.57]}, Closed]], 
               Cell[
                CellGroupData[{
                  Cell[
                   StyleData["ItemPictureSmaller5"], 
                   CellMargins -> {{41, Inherited}, {4, 2}}, 
                   CellGroupingRules -> "GraphicsGrouping", 
                   CellHorizontalScrolling -> True, StyleMenuListing -> None], 
                  Cell[
                   StyleData["ItemPictureSmaller5", "Printout"], 
                   CellMargins -> {{65, Inherited}, {11, -2}}, Magnification -> 
                   0.55], 
                  Cell[
                   StyleData["ItemPictureSmaller5", "EnhancedPrintout"], 
                   CellMargins -> {{71, Inherited}, {13, -2}}, Magnification -> 
                   0.55], 
                  Cell[
                   StyleData[
                   "ItemPictureSmaller5", "EnhancedPrintoutNonGray"], 
                   CellMargins -> {{71, Inherited}, {13, -2}}, Magnification -> 
                   0.55]}, Closed]], 
               Cell[
                CellGroupData[{
                  Cell[
                   StyleData["ItemPictureSmaller6"], 
                   CellMargins -> {{41, Inherited}, {4, 2}}, 
                   CellGroupingRules -> "GraphicsGrouping", 
                   CellHorizontalScrolling -> True, StyleMenuListing -> None], 
                  Cell[
                   StyleData["ItemPictureSmaller6", "Printout"], 
                   CellMargins -> {{67, Inherited}, {12, -2}}, Magnification -> 
                   0.53], 
                  Cell[
                   StyleData["ItemPictureSmaller6", "EnhancedPrintout"], 
                   CellMargins -> {{74, Inherited}, {13, -3}}, Magnification -> 
                   0.53], 
                  Cell[
                   StyleData[
                   "ItemPictureSmaller6", "EnhancedPrintoutNonGray"], 
                   CellMargins -> {{74, Inherited}, {13, -3}}, Magnification -> 
                   0.53]}, Closed]], 
               Cell[
                CellGroupData[{
                  Cell[
                   StyleData["PictureBigger1"], 
                   CellMargins -> {{10, Inherited}, {4, 4}}, 
                   CellGroupingRules -> "GraphicsGrouping", 
                   CellHorizontalScrolling -> True, StyleMenuListing -> None], 
                  Cell[
                   StyleData["PictureBigger1", "Printout"], 
                   CellMargins -> {{2, Inherited}, {4, 4}}, Magnification -> 
                   0.68], 
                  Cell[
                   StyleData["PictureBigger1", "EnhancedPrintout"], 
                   CellMargins -> {{2, Inherited}, {4, 2}}, Magnification -> 
                   0.68], 
                  Cell[
                   StyleData["PictureBigger1", "EnhancedPrintoutNonGray"], 
                   CellMargins -> {{2, Inherited}, {4, 2}}, Magnification -> 
                   0.68]}, Closed]], 
               Cell[
                CellGroupData[{
                  Cell[
                   StyleData["PictureBigger2"], 
                   CellMargins -> {{10, Inherited}, {4, 4}}, 
                   CellGroupingRules -> "GraphicsGrouping", 
                   CellHorizontalScrolling -> True, StyleMenuListing -> None], 
                  Cell[
                   StyleData["PictureBigger2", "Printout"], 
                   CellMargins -> {{2, Inherited}, {4, 4}}, Magnification -> 
                   0.71], 
                  Cell[
                   StyleData["PictureBigger2", "EnhancedPrintout"], 
                   CellMargins -> {{2, Inherited}, {4, 2}}, Magnification -> 
                   0.71], 
                  Cell[
                   StyleData["PictureBigger2", "EnhancedPrintoutNonGray"], 
                   CellMargins -> {{2, Inherited}, {4, 2}}, Magnification -> 
                   0.71]}, Closed]], 
               Cell[
                CellGroupData[{
                  Cell[
                   StyleData["PictureBigger3"], 
                   CellMargins -> {{10, Inherited}, {4, 4}}, 
                   CellGroupingRules -> "GraphicsGrouping", 
                   CellHorizontalScrolling -> True, StyleMenuListing -> None], 
                  Cell[
                   StyleData["PictureBigger3", "Printout"], 
                   CellMargins -> {{2, Inherited}, {4, 4}}, Magnification -> 
                   0.74], 
                  Cell[
                   StyleData["PictureBigger3", "EnhancedPrintout"], 
                   CellMargins -> {{2, Inherited}, {4, 2}}, Magnification -> 
                   0.74], 
                  Cell[
                   StyleData["PictureBigger3", "EnhancedPrintoutNonGray"], 
                   CellMargins -> {{2, Inherited}, {4, 2}}, Magnification -> 
                   0.74]}, Closed]], 
               Cell[
                CellGroupData[{
                  Cell[
                   StyleData["PictureBigger4"], 
                   CellMargins -> {{10, Inherited}, {4, 4}}, 
                   CellGroupingRules -> "GraphicsGrouping", 
                   CellHorizontalScrolling -> True, StyleMenuListing -> None], 
                  Cell[
                   StyleData["PictureBigger4", "Printout"], 
                   CellMargins -> {{2, Inherited}, {4, 4}}, Magnification -> 
                   0.77], 
                  Cell[
                   StyleData["PictureBigger4", "EnhancedPrintout"], 
                   CellMargins -> {{2, Inherited}, {4, 2}}, Magnification -> 
                   0.77], 
                  Cell[
                   StyleData["PictureBigger4", "EnhancedPrintoutNonGray"], 
                   CellMargins -> {{2, Inherited}, {4, 2}}, Magnification -> 
                   0.77]}, Closed]], 
               Cell[
                CellGroupData[{
                  Cell[
                   StyleData["PictureBigger5"], 
                   CellMargins -> {{10, Inherited}, {4, 4}}, 
                   CellGroupingRules -> "GraphicsGrouping", 
                   CellHorizontalScrolling -> True, StyleMenuListing -> None], 
                  Cell[
                   StyleData["PictureBigger5", "Printout"], 
                   CellMargins -> {{2, Inherited}, {4, 4}}, Magnification -> 
                   0.8], 
                  Cell[
                   StyleData["PictureBigger5", "EnhancedPrintout"], 
                   CellMargins -> {{2, Inherited}, {4, 2}}, Magnification -> 
                   0.8], 
                  Cell[
                   StyleData["PictureBigger5", "EnhancedPrintoutNonGray"], 
                   CellMargins -> {{2, Inherited}, {4, 2}}, Magnification -> 
                   0.8]}, Closed]], 
               Cell[
                CellGroupData[{
                  Cell[
                   StyleData["PictureBigger6"], 
                   CellMargins -> {{10, Inherited}, {4, 4}}, 
                   CellGroupingRules -> "GraphicsGrouping", 
                   CellHorizontalScrolling -> True, StyleMenuListing -> None], 
                  Cell[
                   StyleData["PictureBigger6", "Printout"], 
                   CellMargins -> {{2, Inherited}, {4, 4}}, Magnification -> 
                   0.83], 
                  Cell[
                   StyleData["PictureBigger6", "EnhancedPrintout"], 
                   CellMargins -> {{2, Inherited}, {4, 2}}, Magnification -> 
                   0.83], 
                  Cell[
                   StyleData["PictureBigger6", "EnhancedPrintoutNonGray"], 
                   CellMargins -> {{2, Inherited}, {4, 2}}, Magnification -> 
                   0.83]}, Closed]], 
               Cell[
                CellGroupData[{
                  Cell[
                   StyleData["ItemPictureBigger1"], 
                   CellMargins -> {{41, Inherited}, {4, 2}}, 
                   CellGroupingRules -> "GraphicsGrouping", 
                   CellHorizontalScrolling -> True, StyleMenuListing -> None], 
                  Cell[
                   StyleData["ItemPictureBigger1", "Printout"], 
                   CellMargins -> {{50, Inherited}, {9, -3}}, Magnification -> 
                   0.68], 
                  Cell[
                   StyleData["ItemPictureBigger1", "EnhancedPrintout"], 
                   CellMargins -> {{57, Inherited}, {10, -3}}, Magnification -> 
                   0.68], 
                  Cell[
                   StyleData["ItemPictureBigger1", "EnhancedPrintoutNonGray"],
                    CellMargins -> {{57, Inherited}, {10, -3}}, Magnification -> 
                   0.68]}, Closed]], 
               Cell[
                CellGroupData[{
                  Cell[
                   StyleData["ItemPictureBigger2"], 
                   CellMargins -> {{41, Inherited}, {4, 2}}, 
                   CellGroupingRules -> "GraphicsGrouping", 
                   CellHorizontalScrolling -> True, StyleMenuListing -> None], 
                  Cell[
                   StyleData["ItemPictureBigger2", "Printout"], 
                   CellMargins -> {{48, Inherited}, {8, -4}}, Magnification -> 
                   0.71], 
                  Cell[
                   StyleData["ItemPictureBigger2", "EnhancedPrintout"], 
                   CellMargins -> {{54, Inherited}, {10, -3}}, Magnification -> 
                   0.71], 
                  Cell[
                   StyleData["ItemPictureBigger2", "EnhancedPrintoutNonGray"],
                    CellMargins -> {{54, Inherited}, {10, -3}}, Magnification -> 
                   0.71]}, Closed]], 
               Cell[
                CellGroupData[{
                  Cell[
                   StyleData["ItemPictureBigger3"], 
                   CellMargins -> {{41, Inherited}, {4, 2}}, 
                   CellGroupingRules -> "GraphicsGrouping", 
                   CellHorizontalScrolling -> True, StyleMenuListing -> None], 
                  Cell[
                   StyleData["ItemPictureBigger3", "Printout"], 
                   CellMargins -> {{46, Inherited}, {10, -2}}, Magnification -> 
                   0.74], 
                  Cell[
                   StyleData["ItemPictureBigger3", "EnhancedPrintout"], 
                   CellMargins -> {{52, Inherited}, {10, -3}}, Magnification -> 
                   0.74], 
                  Cell[
                   StyleData["ItemPictureBigger3", "EnhancedPrintoutNonGray"],
                    CellMargins -> {{52, Inherited}, {10, -3}}, Magnification -> 
                   0.74]}, Closed]], 
               Cell[
                CellGroupData[{
                  Cell[
                   StyleData["ItemPictureBigger4"], 
                   CellMargins -> {{41, Inherited}, {4, 2}}, 
                   CellGroupingRules -> "GraphicsGrouping", 
                   CellHorizontalScrolling -> True, StyleMenuListing -> None], 
                  Cell[
                   StyleData["ItemPictureBigger4", "Printout"], 
                   CellMargins -> {{45, Inherited}, {10, -2}}, Magnification -> 
                   0.77], 
                  Cell[
                   StyleData["ItemPictureBigger4", "EnhancedPrintout"], 
                   CellMargins -> {{50, Inherited}, {10, -3}}, Magnification -> 
                   0.77], 
                  Cell[
                   StyleData["ItemPictureBigger4", "EnhancedPrintoutNonGray"],
                    CellMargins -> {{50, Inherited}, {10, -3}}, Magnification -> 
                   0.77]}, Closed]], 
               Cell[
                CellGroupData[{
                  Cell[
                   StyleData["ItemPictureBigger5"], 
                   CellMargins -> {{41, Inherited}, {4, 2}}, 
                   CellGroupingRules -> "GraphicsGrouping", 
                   CellHorizontalScrolling -> True, StyleMenuListing -> None], 
                  Cell[
                   StyleData["ItemPictureBigger5", "Printout"], 
                   CellMargins -> {{43, Inherited}, {11, -2}}, Magnification -> 
                   0.8], 
                  Cell[
                   StyleData["ItemPictureBigger5", "EnhancedPrintout"], 
                   CellMargins -> {{49, Inherited}, {10, -3}}, Magnification -> 
                   0.8], 
                  Cell[
                   StyleData["ItemPictureBigger5", "EnhancedPrintoutNonGray"],
                    CellMargins -> {{49, Inherited}, {10, -3}}, Magnification -> 
                   0.8]}, Closed]], 
               Cell[
                CellGroupData[{
                  Cell[
                   StyleData["ItemPictureBigger6"], 
                   CellMargins -> {{41, Inherited}, {4, 2}}, 
                   CellGroupingRules -> "GraphicsGrouping", 
                   CellHorizontalScrolling -> True, StyleMenuListing -> None], 
                  Cell[
                   StyleData["ItemPictureBigger6", "Printout"], 
                   CellMargins -> {{43, Inherited}, {12, -2}}, Magnification -> 
                   0.83], 
                  Cell[
                   StyleData["ItemPictureBigger6", "EnhancedPrintout"], 
                   CellMargins -> {{46, Inherited}, {8, -2}}, Magnification -> 
                   0.83], 
                  Cell[
                   StyleData["ItemPictureBigger6", "EnhancedPrintoutNonGray"],
                    CellMargins -> {{46, Inherited}, {8, -2}}, Magnification -> 
                   0.83]}, Closed]], 
               Cell[
                CellGroupData[{
                  Cell[
                   StyleData["ScreenGraphic"], 
                   CellMargins -> {{12, Inherited}, {0, 8}}, 
                   CellHorizontalScrolling -> True, StyleMenuListing -> None], 
                  Cell[
                   StyleData["ScreenGraphic", "Printout"], 
                   CellMargins -> {{2, Inherited}, {0, 8}}], 
                  Cell[
                   StyleData["ScreenGraphic", "EnhancedPrintout"], 
                   CellMargins -> {{2, Inherited}, {0, 8}}, 
                   CellElementSpacings -> {
                    "CellMinHeight" -> 2, "ClosedCellHeight" -> 2}, CellOpen -> 
                   False], 
                  Cell[
                   StyleData["ScreenGraphic", "EnhancedPrintoutNonGray"], 
                   CellMargins -> {{2, Inherited}, {0, 8}}, 
                   CellElementSpacings -> {
                    "CellMinHeight" -> 2, "ClosedCellHeight" -> 2}, CellOpen -> 
                   False]}, Closed]], 
               Cell[
                CellGroupData[{
                  Cell[
                   StyleData["PrintGraphic"], 
                   CellMargins -> {{12, Inherited}, {0, 8}}, 
                   CellElementSpacings -> {
                    "CellMinHeight" -> 2, "ClosedCellHeight" -> 2}, CellOpen -> 
                   False, CellHorizontalScrolling -> True, StyleMenuListing -> 
                   None], 
                  Cell[
                   StyleData["PrintGraphic", "Printout"], 
                   CellMargins -> {{2, Inherited}, {0, 8}}, 
                   CellElementSpacings -> {
                    "CellMinHeight" -> 2, "ClosedCellHeight" -> 2}, CellOpen -> 
                   False], 
                  Cell[
                   StyleData["PrintGraphic", "EnhancedPrintout"], 
                   CellMargins -> {{2, Inherited}, {0, 8}}, 
                   CellElementSpacings -> {"CellMinHeight" -> 12}, CellOpen -> 
                   True], 
                  Cell[
                   StyleData["PrintGraphic", "EnhancedPrintoutNonGray"], 
                   CellMargins -> {{2, Inherited}, {0, 8}}, 
                   CellElementSpacings -> {"CellMinHeight" -> 12}, CellOpen -> 
                   True]}, Closed]], 
               Cell[
                CellGroupData[{
                  Cell[
                   StyleData["SmallTextSans"], 
                   CellMargins -> {{10, 4}, {8, 8}}, 
                   ConversionRules :> {
                    "HTML" -> {
                    "<FONT SIZE=\"-1\" FACE=\"Helvetica, Arial\">", 
                    "</FONT>\n"}}, TextJustification -> 1, Hyphenation -> 
                   True, LineSpacing -> {1, 2}, FontFamily -> "Helvetica", 
                   FontSize -> 9], 
                  Cell[
                   StyleData["SmallTextSans", "Printout"], 
                   CellMargins -> {{2, 0}, {0, 8}}, FontSize -> 7], 
                  Cell[
                   StyleData["SmallTextSans", "EnhancedPrintout"], 
                   CellMargins -> {{2, 0}, {0, 8}}, LineSpacing -> {1, 1}, 
                   ParagraphSpacing -> {0, -2}, FontFamily -> "Futura", 
                   FontSize -> 7]}, Closed]]}, Open]]}, Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["AuthorTools", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["BilateralCell"], CellMargins -> {{10, 4}, {0, 8}}, 
             StyleMenuListing -> None, FontSize -> 12, 
             GridBoxOptions -> {
              GridBoxAlignment -> {
                "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Top}}, "RowsIndexed" -> {}}, 
               GridBoxItemSize -> {"Columns" -> {
                   Scaled[0.33], {
                    Scaled[0.6]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
                 "RowsIndexed" -> {}}}], 
            Cell[
             StyleData["BilateralCell", "SlideShow"], 
             CellMargins -> {{36, 24}, {4, 4}}, Background -> 
             GrayLevel[0.900008]], 
            Cell[
             StyleData["BilateralCell", "Printout"], 
             CellMargins -> {{2, 2}, {6, 6}}, TextJustification -> 1, 
             FontSize -> 10], 
            Cell[
             StyleData["BilateralCell", "EnhancedPrintout"], 
             CellMargins -> {{2, 2}, {6, 6}}, TextJustification -> 1, 
             FontFamily -> "Palatino", FontSize -> 10], 
            Cell[
             StyleData["BilateralCell", "EnhancedPrintoutNonGray"], 
             CellMargins -> {{2, 2}, {6, 6}}, TextJustification -> 1, 
             FontFamily -> "Palatino", FontSize -> 10]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["RuledPageBreak"], CellFrame -> {{0, 0}, {0.25, 0}}, 
             CellMargins -> {{10, 4}, {12, 0}}, 
             CellFrameMargins -> {{0, 0}, {1, 0}}, FontSize -> 8], 
            Cell[
             StyleData["RuledPageBreak", "SlideShow"], 
             CellMargins -> {{36, 24}, {4, 4}}], 
            Cell[
             StyleData["RuledPageBreak", "Printout"], 
             CellMargins -> {{2, 2}, {6, 6}}, PageBreakBelow -> True, 
             FontSize -> 1], 
            Cell[
             StyleData["RuledPageBreak", "EnhancedPrintout"], 
             CellMargins -> {{2, 2}, {6, 6}}, PageBreakBelow -> True], 
            Cell[
             StyleData["RuledPageBreak", "EnhancedPrintoutNonGray"], 
             CellMargins -> {{2, 2}, {6, 6}}, PageBreakBelow -> True]}, 
           Closed]], 
         Cell[
          StyleData["PaletteTitle"], CellFrame -> {{0, 0}, {1, 0}}, 
          CellMargins -> {{4, 20}, {Inherited, 0}}, StyleMenuListing -> None, 
          ButtonStyleMenuListing -> None, FontFamily -> "Helvetica", FontSize -> 
          14, FontWeight -> "Bold", FontColor -> GrayLevel[1], Background -> 
          RGBColor[0, 0.32549, 0.537255], 
          ButtonBoxOptions -> {
           BaseStyle -> "PaletteButton", ButtonFunction :> (FrontEndExecute[{
               FrontEnd`HelpBrowserLookup["AddOns", #2]}]& ), ButtonMargins -> 
            3, Evaluator -> None}], 
         Cell[
          StyleData["PaletteButton"], StyleMenuListing -> None, 
          ButtonStyleMenuListing -> None, FontFamily -> "Helvetica", FontSize -> 
          12, FontWeight -> "Bold", FontColor -> GrayLevel[1], 
          ButtonBoxOptions -> {
           Active -> True, Background -> 
            RGBColor[0.329412, 0.584314, 0.694118], ButtonMargins -> 6, 
            Evaluator -> "Local"}], 
         Cell[
          StyleData["PaletteButton2"], StyleMenuListing -> None, 
          ButtonStyleMenuListing -> None, FontFamily -> "Helvetica", FontSize -> 
          12, FontWeight -> "Bold", FontColor -> GrayLevel[1], 
          ButtonBoxOptions -> {
           Active -> True, Background -> 
            RGBColor[0.537255, 0.72549, 0.843137], ButtonMargins -> 4, 
            Evaluator -> "Local"}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Outline Styles", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Outline1"], CellMargins -> {{12, 10}, {7, 7}}, 
             CellGroupingRules -> {"SectionGrouping", 50}, 
             ParagraphIndent -> -38, CounterIncrements -> "Outline1", 
             FontSize -> 18, FontWeight -> "Bold", 
             CounterBoxOptions -> {
              CounterFunction :> 
               Utilities`Notation`Private`CapitalRomanNumeral}], 
            Cell[
             StyleData["Outline1", "Printout"], 
             CounterBoxOptions -> {
              CounterFunction :> 
               Utilities`Notation`Private`CapitalRomanNumeral}]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Outline2"], CellMargins -> {{48, 10}, {6, 6}}, 
             CellGroupingRules -> {"SectionGrouping", 60}, 
             ParagraphIndent -> -27, CounterIncrements -> "Outline2", 
             FontSize -> 15, FontWeight -> "Bold", 
             CounterBoxOptions -> {CounterFunction :> (Part[
                 CharacterRange["A", "Z"], #]& )}], 
            Cell[
             StyleData["Outline2", "Printout"], 
             CounterBoxOptions -> {CounterFunction :> (Part[
                 CharacterRange["A", "Z"], #]& )}]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Outline3"], CellMargins -> {{84, 10}, {5, 5}}, 
             CellGroupingRules -> {"SectionGrouping", 70}, 
             ParagraphIndent -> -21, CounterIncrements -> "Outline3", 
             FontSize -> 12, 
             CounterBoxOptions -> {CounterFunction :> Identity}], 
            Cell[
             StyleData["Outline3", "Printout"], 
             CounterBoxOptions -> {CounterFunction :> Identity}]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Outline4"], CellMargins -> {{120, 10}, {4, 4}}, 
             CellGroupingRules -> {"SectionGrouping", 80}, 
             ParagraphIndent -> -18, CounterIncrements -> "Outline4", 
             FontSize -> 10, CounterBoxOptions -> {CounterFunction :> (Part[
                 CharacterRange["a", "z"], #]& )}], 
            Cell[
             StyleData["Outline4", "Printout"]]}, Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Slide Show Styles", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["SlideShowNavigationBar"], Editable -> False, 
             CellFrame -> True, CellMargins -> {{0, 0}, {3, 3}}, 
             CellElementSpacings -> {"CellMinHeight" -> 0.8125}, 
             CellGroupingRules -> {"SectionGrouping", 30}, CellFrameMargins -> 
             False, CellFrameColor -> GrayLevel[1], CellFrameLabelMargins -> 
             False, TextAlignment -> Center, CounterIncrements -> 
             "SlideShowNavigationBar", StyleMenuListing -> None, FontSize -> 
             10, Magnification -> 1, Background -> GrayLevel[0.8], 
             GridBoxOptions -> {
              BaselinePosition -> Center, 
               GridBoxAlignment -> {
                "Columns" -> {
                  Center, Center, Center, Center, Center, Center, Right, {
                   Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
                 "RowsIndexed" -> {}}, 
               GridBoxItemSize -> {
                "Columns" -> {3.5, 3.5, 3.5, 3.5, 13, 5, {4}}, 
                 "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
                 "RowsIndexed" -> {}}, GridBoxSpacings -> {"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}}], 
            Cell[
             StyleData["SlideShowNavigationBar", "SlideShow"], Deletable -> 
             False, ShowCellBracket -> False, 
             CellMargins -> {{-1, -1}, {-1, -1}}, PageBreakAbove -> True, 
             CellFrameMargins -> {{1, 1}, {0, 0}}], 
            Cell[
             StyleData["SlideShowNavigationBar", "Printout"], ShowCellBracket -> 
             False, CellMargins -> {{0, 0}, {0, 0}}, 
             CellElementSpacings -> {"ClosedCellHeight" -> 0}, CellOpen -> 
             False], 
            Cell[
             StyleData["SlideShowNavigationBar", "EnhancedPrintout"], 
             ShowCellBracket -> False, CellMargins -> {{0, 0}, {0, 0}}, 
             CellElementSpacings -> {"ClosedCellHeight" -> 0}, CellOpen -> 
             False]}, Open]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["SlideShowSection"], CellFrame -> {{0, 0}, {0, 0.5}}, 
             CellMargins -> {{0, 0}, {10, 0}}, 
             CellGroupingRules -> {"SectionGrouping", 40}, PageBreakBelow -> 
             False, CellFrameMargins -> {{12, 4}, {6, 12}}, 
             InputAutoReplacements -> {"TeX" -> StyleBox[
                 RowBox[{"T", 
                   AdjustmentBox[
                   "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                    BoxBaselineShift -> 0.5], "X"}]], "LaTeX" -> StyleBox[
                 RowBox[{"L", 
                   StyleBox[
                    AdjustmentBox[
                    "A", BoxMargins -> {{-0.36, -0.1}, {0, 0}}, 
                    BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
                   AdjustmentBox[
                   "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                    BoxBaselineShift -> 0.5], "X"}]], "mma" -> "Mathematica", 
               "Mma" -> "Mathematica", "MMA" -> "Mathematica", 
               "webMathematica" -> FormBox[
                 RowBox[{"web", 
                   AdjustmentBox[
                    StyleBox["Mathematica", FontSlant -> "Italic"], 
                    BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
               Inherited}, CounterIncrements -> "Section", 
             CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}}, 
             StyleMenuListing -> None, FontFamily -> "Helvetica", FontSize -> 
             18, FontWeight -> "Plain", FontColor -> GrayLevel[1], Background -> 
             RGBColor[0.408011, 0.440726, 0.8]], 
            Cell[
             StyleData["SlideShowSection", "SlideShow"], ShowCellBracket -> 
             False, PageBreakAbove -> True], 
            Cell[
             StyleData["SlideShowSection", "Printout"], 
             CellMargins -> {{18, 30}, {0, 30}}, CellFrameMargins -> 5, 
             FontSize -> 14]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["SlideHyperlink"], StyleMenuListing -> None, 
             ButtonStyleMenuListing -> Automatic, FontSize -> 26, FontColor -> 
             GrayLevel[0.400015], 
             ButtonBoxOptions -> {
              Active -> True, ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`NotebookLocate[#2]}]& ), ButtonMargins -> 0.5, 
               ButtonMinHeight -> 0.85, ButtonNote -> None}], 
            Cell[
             StyleData["SlideHyperlink", "SlideShow"]], 
            Cell[
             StyleData["SlideHyperlink", "Printout"], FontSize -> 10, 
             FontVariations -> {"Underline" -> False}, FontColor -> 
             GrayLevel[0]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["SlideTOCLink"], 
             CellMargins -> {{24, Inherited}, {Inherited, Inherited}}, 
             StyleMenuListing -> None, ButtonStyleMenuListing -> Automatic, 
             FontFamily -> "Helvetica", 
             ButtonBoxOptions -> {
              Active -> True, ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`NotebookLocate[#2]}]& ), ButtonMargins -> 1.5, 
               ButtonNote -> ButtonData}], 
            Cell[
             StyleData["SlideTOCLink", "SlideShow"]], 
            Cell[
             StyleData["SlideTOCLink", "Printout"], 
             FontVariations -> {"Underline" -> False}, FontColor -> 
             GrayLevel[0]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["SlideTOC"], CellDingbat -> "\[Bullet]", 
             CellMargins -> {{18, Inherited}, {Inherited, Inherited}}, 
             StyleMenuListing -> None, FontFamily -> "Helvetica"], 
            Cell[
             StyleData["SlideTOC", "SlideShow"], FontSize -> 14], 
            Cell[
             StyleData["SlideTOC", "Printout"], FontSize -> 10, FontColor -> 
             GrayLevel[0]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["1ColumnBox"], CellMargins -> {{10, 4}, {0, 8}}, 
             CellHorizontalScrolling -> True, LineIndent -> 0, 
             StyleMenuListing -> None, Background -> RGBColor[1, 0.6, 0.6], 
             FrameBoxOptions -> {
              BoxFrame -> 0.5, FrameMargins -> {{True, True}, {True, True}}}, 
             GridBoxOptions -> {GridBoxSpacings -> {"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.7]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}}], 
            Cell[
             StyleData["1ColumnBox", "Printout"], 
             CellMargins -> {{2, 0}, {0, 8}}, FontSize -> 10, Background -> 
             GrayLevel[0.900008]], 
            Cell[
             StyleData["1ColumnBox", "SlideShow"], 
             CellMargins -> {{36, 36}, {3, 6}}, Background -> 
             RGBColor[0.700008, 0.849989, 0.949996]], 
            Cell[
             StyleData["1ColumnBox", "EnhancedPrintout"], 
             CellMargins -> {{2, 0}, {0, 8}}, FontSize -> 10, Background -> 
             GrayLevel[0.900008]], 
            Cell[
             StyleData["1ColumnBox", "EnhancedPrintoutNonGray"], 
             CellMargins -> {{2, 0}, {3, 8}}, FontSize -> 10, Background -> 
             GrayLevel[1]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["2ColumnBox"], CellMargins -> {{10, 4}, {0, 8}}, 
             CellHorizontalScrolling -> True, LineIndent -> 0, 
             StyleMenuListing -> None, Background -> RGBColor[1, 0.6, 0.6], 
             FrameBoxOptions -> {
              BoxFrame -> 0.5, FrameMargins -> {{True, True}, {True, True}}}, 
             GridBoxOptions -> {GridBoxItemSize -> {"Columns" -> {
                   Scaled[0.31], {
                    Scaled[0.67]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
                 "RowsIndexed" -> {}}}], 
            Cell[
             StyleData["2ColumnBox", "Printout"], 
             CellMargins -> {{2, 0}, {0, 8}}, FontSize -> 9, Background -> 
             GrayLevel[0.900008]], 
            Cell[
             StyleData["2ColumnBox", "SlideShow"], 
             CellMargins -> {{36, 36}, {6, 6}}, Background -> 
             RGBColor[0.700008, 0.849989, 0.949996]], 
            Cell[
             StyleData["2ColumnBox", "EnhancedPrintout"], 
             CellMargins -> {{2, 0}, {0, 8}}, FontSize -> 9, Background -> 
             GrayLevel[0.900008]], 
            Cell[
             StyleData["2ColumnBox", "EnhancedPrintoutNonGray"], 
             CellMargins -> {{2, 0}, {0, 8}}, FontSize -> 9, Background -> 
             GrayLevel[1]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["DefinitionBox"], CellFrame -> 0.5, 
             CellMargins -> {{10, 4}, {0, 8}}, CellHorizontalScrolling -> 
             True, PageBreakWithin -> False, AutoIndent -> False, AutoSpacing -> 
             False, LineIndent -> 0, StyleMenuListing -> None, FontWeight -> 
             "Plain", Background -> RGBColor[1, 0.6, 0.6], 
             GridBoxOptions -> {
              GridBoxAlignment -> {
                "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}, 
               GridBoxItemSize -> {"Columns" -> {
                   Scaled[0.4], {
                    Scaled[0.6]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
                 "RowsIndexed" -> {}}, GridBoxSpacings -> {"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.7]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.6]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}}], 
            Cell[
             StyleData["DefinitionBox", "Printout"], 
             CellMargins -> {{2, 4}, {0, 8}}, FontSize -> 10, Background -> 
             GrayLevel[1]], 
            Cell[
             StyleData["DefinitionBox", "SlideShow"], 
             CellMargins -> {{36, 36}, {6, 6}}, Background -> 
             RGBColor[0.700008, 0.849989, 0.949996]], 
            Cell[
             StyleData["DefinitionBox", "EnhancedPrintout"], 
             CellMargins -> {{2, 4}, {0, 8}}, FontFamily -> "Palatino", 
             FontSize -> 10, Background -> GrayLevel[1]], 
            Cell[
             StyleData["DefinitionBox", "EnhancedPrintoutNonGray"], 
             CellMargins -> {{2, 4}, {0, 8}}, FontFamily -> "Palatino", 
             FontSize -> 10, Background -> GrayLevel[1]]}, Closed]]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell["Contents and Index", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["ContentsTitle"], CellMargins -> {{21, 4}, {12, 24}}, 
             FontFamily -> "Helvetica", FontSize -> 24, FontWeight -> "Bold"], 
            Cell[
             StyleData["ContentsTitle", "Printout"], 
             CellMargins -> {{12, 0}, {102, 89}}, PageBreakBelow -> False, 
             FontSize -> 30.5], 
            Cell[
             StyleData["ContentsTitle", "EnhancedPrintout"], 
             CellMargins -> {{24, 0}, {102, 89}}, PageBreakBelow -> False, 
             FontFamily -> "Futura", FontSize -> 30.5]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["ContentsSection"], ShowGroupOpener -> True, 
             CellMargins -> {{35, 4}, {3, 18}}, 
             CellGroupingRules -> {"SectionGrouping", 70}, StyleMenuListing -> 
             None, FontFamily -> "Helvetica", FontSize -> 12, FontWeight -> 
             "Bold"], 
            Cell[
             StyleData["ContentsSection", "Printout"], 
             CellMargins -> {{20, 0}, {3, 18}}, PageBreakBelow -> False, 
             FontSize -> 11], 
            Cell[
             StyleData["ContentsSection", "EnhancedPrintout"], 
             CellMargins -> {{20, 0}, {3, 18}}, PageBreakBelow -> False, 
             FontFamily -> "Futura", FontSize -> 11], 
            Cell[
             StyleData["ContentsSection", "EnhancedPrintoutNonGray"], 
             CellMargins -> {{20, 0}, {3, 18}}, PageBreakBelow -> False, 
             FontFamily -> "Futura", FontSize -> 11]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["IndexSection"], CellDingbat -> "\[FilledSquare]", 
             CellMargins -> {{20, 4}, {5, 20}}, StyleMenuListing -> None, 
             FontFamily -> "Helvetica", FontSize -> 12, FontWeight -> "Bold"], 
            Cell[
             StyleData["IndexSection", "Printout"], 
             CellMargins -> {{12, 0}, {5, 20}}, PageBreakBelow -> False, 
             FontSize -> 12]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Contents"], ShowGroupOpener -> False, 
             CellMargins -> {{50, 4}, {0, 5}}, 
             CellGroupingRules -> {"SectionGrouping", 90}, StyleMenuListing -> 
             None], 
            Cell[
             StyleData["Contents", "Printout"], 
             CellMargins -> {{40, 4}, {0, 5}}, FontSize -> 11], 
            Cell[
             StyleData["Contents", "EnhancedPrintout"], 
             CellMargins -> {{40, 5}, {0, 5}}, FontFamily -> "Palatino", 
             FontSize -> 11], 
            Cell[
             StyleData["Contents", "EnhancedPrintoutNonGray"], 
             CellMargins -> {{40, 5}, {0, 5}}, FontFamily -> "Palatino", 
             FontSize -> 11]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Index"], CellMargins -> {{21, 4}, {0, 0}}, 
             ParagraphIndent -> -48, StyleMenuListing -> None], 
            Cell[
             StyleData["Index", "Printout"], CellMargins -> {{13, 0}, {0, 0}},
              FontSize -> 9], 
            Cell[
             StyleData["Index", "EnhancedPrintout"], 
             CellMargins -> {{13, 0}, {0, 0}}, FontFamily -> "Palatino", 
             FontSize -> 9], 
            Cell[
             StyleData["Index", "EnhancedPrintoutNonGray"], 
             CellMargins -> {{13, 0}, {0, 0}}, FontFamily -> "Palatino", 
             FontSize -> 9]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["IndexSubentry"], CellMargins -> {{36, 4}, {0, 0}}, 
             ParagraphIndent -> -48], 
            Cell[
             StyleData["IndexSubentry", "Printout"], 
             CellMargins -> {{24, 0}, {0, 0}}, FontSize -> 9], 
            Cell[
             StyleData["IndexSubentry", "EnhancedPrintout"], 
             CellMargins -> {{24, 0}, {0, 0}}, FontFamily -> "Palatino", 
             FontSize -> 9]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Index2Column"], CellMargins -> {{21, 4}, {0, 8}}, 
             ParagraphIndent -> -20, TabSpacings -> 1, StyleMenuListing -> 
             None, FontSize -> 10, 
             GridBoxOptions -> {
              GridBoxAlignment -> {
                "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}, 
               GridBoxItemSize -> {"Columns" -> {{
                    Scaled[0.5]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
                 "RowsIndexed" -> {}}}], 
            Cell[
             StyleData["Index2Column", "Printout"], 
             CellMargins -> {{2, 2}, {6, 6}}, FontSize -> 8], 
            Cell[
             StyleData["Index2Column", "EnhancedPrintout"], 
             CellMargins -> {{2, 2}, {6, 6}}, FontFamily -> "Palatino", 
             FontSize -> 8], 
            Cell[
             StyleData["Index2Column", "EnhancedPrintoutNonGray"], 
             CellMargins -> {{2, 2}, {6, 6}}, FontFamily -> "Palatino", 
             FontSize -> 8]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Leader"], TabFilling -> ".", StyleMenuListing -> None,
              FontFamily -> "Times", FontSize -> 12, FontWeight -> "Plain"], 
            Cell[
             StyleData["Leader", "Printout"], FontSize -> 10], 
            Cell[
             StyleData["Leader", "EnhancedPrintout"], FontFamily -> 
             "Palatino", FontSize -> 10]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["LeaderNoDots"], TabFilling -> " ", StyleMenuListing -> 
             None, FontFamily -> "Times", FontSize -> 12, FontWeight -> 
             "Plain"], 
            Cell[
             StyleData["LeaderNoDots", "Printout"], FontSize -> 10], 
            Cell[
             StyleData["LeaderNoDots", "EnhancedPrintout"], FontFamily -> 
             "Palatino", FontSize -> 10]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["PageLink"], StyleMenuListing -> None, 
             ButtonStyleMenuListing -> Automatic, FontColor -> 
             RGBColor[0, 0, 1], 
             ButtonBoxOptions -> {
              Active -> True, Appearance -> {Automatic, None}, 
               ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`NotebookLocate[#2]}]& )}], 
            Cell[
             StyleData["PageLink", "Printout"], FontColor -> GrayLevel[0]], 
            Cell[
             StyleData["PageLink", "EnhancedPrintout"], FontColor -> 
             GrayLevel[0]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["TOCPage"], CellSize -> {22, Inherited}, TextAlignment -> 
             Right, StyleMenuListing -> None, FontSize -> 12, FontWeight -> 
             "Plain"], 
            Cell[
             StyleData["TOCPage", "Printout"], FontSize -> 10], 
            Cell[
             StyleData["TOCPage", "EnhancedPrintout"], FontFamily -> 
             "Palatino", FontSize -> 10]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["TOCTitle"], CellMargins -> {{20, 0}, {1, 8}}, 
             CellGroupingRules -> {"SectionGrouping", 70}, TabSpacings -> 46, 
             CounterIncrements -> "TOCTitle", 
             CounterAssignments -> {{"TOCSection", 0}}, FontFamily -> 
             "Helvetica", FontSize -> 12, FontWeight -> "Bold"], 
            Cell[
             StyleData["TOCTitle", "Printout"], 
             CellMargins -> {{12, 0}, {1, 8}}, PageBreakBelow -> False, 
             TabSpacings -> 47.4, FontSize -> 11], 
            Cell[
             StyleData["TOCTitle", "EnhancedPrintout"], 
             CellMargins -> {{2, 0}, {2, 10}}, PageBreakBelow -> False, 
             TabSpacings -> 49.3, FontFamily -> "Futura", FontSize -> 10]}, 
           Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["TOCSection"], CellMargins -> {{48, 0}, {1, 1}}, 
             CellGroupingRules -> {"SectionGrouping", 75}, TabSpacings -> 
             42.9, CounterIncrements -> "TOCSection", 
             CounterAssignments -> {{"TOCSubsection", 0}}, FontFamily -> 
             "Helvetica", FontSize -> 12], 
            Cell[
             StyleData["TOCSection", "Printout"], 
             CellMargins -> {{30, 0}, {1, 1}}, PageBreakBelow -> False, 
             FontSize -> 12], 
            Cell[
             StyleData["TOCSection", "EnhancedPrintout"], 
             CellMargins -> {{26, 0}, {1, 3}}, PageBreakBelow -> False, 
             TabSpacings -> 46.45, FontFamily -> "Futura", FontSize -> 9]}, 
           Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["TOCSubsection"], CellMargins -> {{76, 0}, {1, 1}}, 
             CellGroupingRules -> {"SectionGrouping", 80}, TabSpacings -> 
             39.8, CounterIncrements -> "TOCSubsection", 
             CounterAssignments -> {{"TOCSubsubsection", 0}}, FontSize -> 12], 
            Cell[
             StyleData["TOCSubsection", "Printout"], 
             CellMargins -> {{70, 0}, {1, 1}}, PageBreakBelow -> False, 
             FontSize -> 10], 
            Cell[
             StyleData["TOCSubsection", "EnhancedPrintout"], 
             CellMargins -> {{38, 0}, {1, 1}}, PageBreakBelow -> False, 
             TabSpacings -> 45.15, FontFamily -> "Palatino", FontSize -> 9]}, 
           Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["TOCSubsubsection"], CellMargins -> {{104, 0}, {1, 1}},
              CellGroupingRules -> {"SectionGrouping", 85}, TabSpacings -> 
             36.7, CounterIncrements -> "TOCSubsubsection", FontSize -> 12], 
            Cell[
             StyleData["TOCSubsubsection", "Printout"], 
             CellMargins -> {{96, 0}, {1, 1}}, PageBreakBelow -> False, 
             FontSize -> 9], 
            Cell[
             StyleData["TOCSubsubsection", "EnhancedPrintout"], 
             CellMargins -> {{96, 0}, {1, 1}}, PageBreakBelow -> False, 
             FontFamily -> "Palatino", FontSize -> 9]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["TOCTitleDingbat"], CellSize -> {34, Inherited}, 
             TextAlignment -> Right], 
            Cell[
             StyleData["TOCTitleDingbat", "EnhancedPrintout"], FontFamily -> 
             "Futura", FontSize -> 10]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["TOCSectionDingbat"], CellSize -> {38, Inherited}, 
             TextAlignment -> Right], 
            Cell[
             StyleData["TOCSectionDingbat", "EnhancedPrintout"], FontFamily -> 
             "Futura", FontSize -> 9]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["TOCSubsectionDingbat"], CellSize -> {54, Inherited}, 
             TextAlignment -> Right], 
            Cell[
             StyleData["TOCSubsectionDingbat", "EnhancedPrintout"], FontSize -> 
             9]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["TOCTitleCondensed"], CellMargins -> {{20, 0}, {1, 8}},
              CellGroupingRules -> {"SectionGrouping", 70}, TabSpacings -> 
             50.4, CounterIncrements -> "TOCTitleCondensed", 
             CounterAssignments -> {{"TOCSectionCondensed", 0}, {
               "TOCSubsectionCondensed", 0}}, FontFamily -> "Helvetica", 
             FontSize -> 12, FontWeight -> "Bold"], 
            Cell[
             StyleData["TOCTitleCondensed", "Printout"], 
             CellMargins -> {{12, 0}, {1, 8}}, PageBreakBelow -> False, 
             FontSize -> 11], 
            Cell[
             StyleData["TOCTitleCondensed", "EnhancedPrintout"], 
             CellMargins -> {{12, 0}, {1, 8}}, PageBreakBelow -> False, 
             FontFamily -> "Futura", FontSize -> 11]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["TOCSectionCondensed"], 
             CellMargins -> {{48, 0}, {1, 1}}, 
             CellGroupingRules -> {"SectionGrouping", 75}, TabSpacings -> 
             47.4, CounterIncrements -> "TOCSectionCondensed", 
             CounterAssignments -> {{"TOCSubsection", 0}}, FontFamily -> 
             "Helvetica", FontSize -> 10, FontWeight -> "Bold", FontColor -> 
             GrayLevel[0.2]], 
            Cell[
             StyleData["TOCSectionCondensed", "Printout"], 
             CellMargins -> {{36, 0}, {1, 1}}, PageBreakBelow -> False, 
             FontSize -> 11], 
            Cell[
             StyleData["TOCSectionCondensed", "EnhancedPrintout"], 
             CellMargins -> {{36, 0}, {1, 1}}, PageBreakBelow -> False, 
             FontFamily -> "Palatino", FontSize -> 11]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["TOCSubsectionCondensed"], PageWidth -> 470, 
             CellMargins -> {{76, 0}, {1, 1}}, 
             CellGroupingRules -> {"SectionGrouping", 80}, TextJustification -> 
             1, Hyphenation -> True, FontSize -> 12], 
            Cell[
             StyleData["TOCSubsectionCondensed", "Printout"], 
             CellMargins -> {{72, 0}, {1, 1}}, PageBreakBelow -> False, 
             FontSize -> 10], 
            Cell[
             StyleData["TOCSubsectionCondensed", "EnhancedPrintout"], 
             CellMargins -> {{72, 0}, {1, 1}}, PageBreakBelow -> False, 
             FontFamily -> "Palatino", FontSize -> 10]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["TOCSubsubsectionCondensed"], 
             CellMargins -> {{104, 0}, {1, 1}}, 
             CellGroupingRules -> {"SectionGrouping", 85}, TabSpacings -> 
             39.3, CounterIncrements -> "TOCSubsubsectionCondensed", FontSize -> 
             12], 
            Cell[
             StyleData["TOCSubsubsectionCondensed", "Printout"], 
             CellMargins -> {{96, 0}, {1, 1}}, PageBreakBelow -> False, 
             FontSize -> 9], 
            Cell[
             StyleData["TOCSubsubsectionCondensed", "EnhancedPrintout"], 
             CellMargins -> {{96, 0}, {1, 1}}, PageBreakBelow -> False, 
             FontFamily -> "Palatino", FontSize -> 9]}, Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Horizontal Lines", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Line1"], CellFrame -> {{0, 0}, {0, 0.5}}, 
             CellMargins -> {{10, 4}, {-16, 9}}, StyleMenuListing -> None, 
             FontSize -> 2], 
            Cell[
             StyleData["Line1", "Printout"], 
             CellMargins -> {{2, 0}, {-16, 9}}]}, Closed]], 
         Cell["\nThe item above is horizontal 0.5 pt line", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["ProgramTop"], CellFrame -> {{0.5, 0.5}, {0, 0.5}}, 
             CellMargins -> {{10, 4}, {-18, 18}}, LineSpacing -> {1, -4}, 
             StyleMenuListing -> None, FontSize -> 4], 
            Cell[
             StyleData["ProgramTop", "Printout"], 
             CellMargins -> {{2, 0}, {-18, 18}}]}, Closed]], 
         Cell["\nThe item above is a ProgramTop line\n", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["ProgramBottom"], CellFrame -> {{0.5, 0.5}, {0.5, 0}}, 
             CellMargins -> {{10, 4}, {-10, -2}}, LineSpacing -> {1, -4}, 
             StyleMenuListing -> None, FontSize -> 4], 
            Cell[
             StyleData["ProgramBottom", "Printout"], 
             CellMargins -> {{2, 0}, {-10, -2}}]}, Closed]], 
         Cell["\nThe item above is a ProgramBottom line\n", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["SessionLabel"], CellFrame -> {{0.5, 0}, {0, 0.5}}, 
             CellMargins -> {{10, 4}, {-4, 18}}, LineSpacing -> {1, -3}, 
             StyleMenuListing -> None, FontFamily -> "Helvetica", FontSize -> 
             9], 
            Cell[
             StyleData["SessionLabel", "Printout"], 
             CellMargins -> {{2, 0}, {-4, 18}}, FontSize -> 7]}, Closed]]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell["Page Headers and Footers", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["PageHeader"], CellMargins -> {{0, 0}, {2, 0}}, 
             StyleMenuListing -> None, FontSize -> 8, FontSlant -> "Italic"], 
            
            Cell[
             StyleData["PageHeader", "Printout"]], 
            Cell[
             StyleData["PageHeader", "EnhancedPrintout"], FontFamily -> 
             "Futura"], 
            Cell[
             StyleData["PageHeader", "EnhancedPrintoutNonGray"], FontFamily -> 
             "Futura"]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["PageNumber"], CellMargins -> {{0, 0}, {2, 0}}, 
             StyleMenuListing -> None, FontFamily -> "Helvetica", FontSize -> 
             8, FontWeight -> "Bold"], 
            Cell[
             StyleData["PageNumber", "Printout"]], 
            Cell[
             StyleData["PageNumber", "EnhancedPrintout"], FontFamily -> 
             "Futura"], 
            Cell[
             StyleData["PageNumber", "EnhancedPrintoutNonGray"], FontFamily -> 
             "Futura"]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["PageFooter"], StyleMenuListing -> None, FontFamily -> 
             "Helvetica", FontSize -> 6], 
            Cell[
             StyleData["PageFooter", "Printout"]], 
            Cell[
             StyleData["PageFooter", "EnhancedPrintout"], FontFamily -> 
             "Futura"], 
            Cell[
             StyleData["PageFooter", "EnhancedPrintoutNonGray"], FontFamily -> 
             "Futura"]}, Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Automatic Styles", "Section"], 
         Cell[
         "The cells below define styles that are used to affect the display \
of certain types of objects in typeset expressions.  For example, \
\"UnmatchedBracket\" style defines how unmatched bracket, curly bracket, and \
parenthesis characters are displayed (typically by coloring them to make them \
stand out).", "Text"], 
         Cell[
          StyleData["UnmatchedBracket"], StyleMenuListing -> None]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
         "Notation Package Styles", "Section", CellTags -> "NotationPackage"], 
         Cell[
         "The cells below define certain styles needed by the Notation \
package. These styles serve to make visible otherwise invisible tagboxes.", 
          "Text", CellTags -> "NotationPackage"], 
         Cell[
          StyleData["NotationTemplateStyle"], StyleMenuListing -> None, 
          Background -> RGBColor[1, 1, 0.850004], 
          TagBoxOptions -> {SyntaxForm -> "symbol"}, CellTags -> 
          "NotationPackage"], 
         Cell[
          StyleData["NotationPatternWrapperStyle"], StyleMenuListing -> None, 
          Background -> RGBColor[1, 0.900008, 0.979995], 
          TagBoxOptions -> {SyntaxForm -> "symbol"}, CellTags -> 
          "NotationPackage"], 
         Cell[
          StyleData["NotationMadeBoxesWrapperStyle"], StyleMenuListing -> 
          None, Background -> RGBColor[0.900008, 0.889998, 1], 
          TagBoxOptions -> {SyntaxForm -> "symbol"}, CellTags -> 
          "NotationPackage"]}, Closed]]}, Open]]}, Visible -> False, 
  FrontEndVersion -> "8.0 for Microsoft Windows (64-bit) (November 7, 2010)", 
  StyleDefinitions -> "Default.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Equal"->{
  Cell[3923, 150, 319, 11, 22, "Text",
   CellTags->{"Equal", "Listable"}]},
 "Listable"->{
  Cell[3923, 150, 319, 11, 22, "Text",
   CellTags->{"Equal", "Listable"}]},
 "LastSlide"->{
  Cell[679619, 11917, 79, 1, 49, "SectionTwo",
   CellTags->"LastSlide"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Equal", 977072, 18028},
 {"Listable", 977164, 18031},
 {"LastSlide", 977257, 18034}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[557, 20, 1284, 37, 31, "SlideShowNavigationBar"],
Cell[CellGroupData[{
Cell[1866, 61, 28, 0, 49, "Section"],
Cell[1897, 63, 440, 13, 157, "SubsectionIcon"],
Cell[CellGroupData[{
Cell[2362, 80, 33, 0, 33, "SubsectionIcon"],
Cell[2398, 82, 294, 5, 23, "Text"],
Cell[2695, 89, 273, 12, 23, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3005, 106, 36, 0, 2, "Subsection"],
Cell[CellGroupData[{
Cell[3066, 110, 33, 0, 33, "Subsubsection"],
Cell[3102, 112, 132, 4, 26, "Input",
 InitializationCell->True],
Cell[3237, 118, 209, 7, 26, "Input"],
Cell[3449, 127, 174, 6, 26, "Input",
 InitializationCell->True],
Cell[3626, 135, 223, 8, 26, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[3886, 148, 34, 0, 27, "Subsubsection"],
Cell[3923, 150, 319, 11, 22, "Text",
 CellTags->{"Equal", "Listable"}],
Cell[4245, 163, 166, 6, 26, "Input",
 InitializationCell->True],
Cell[4414, 171, 277, 9, 26, "Input",
 InitializationCell->True],
Cell[4694, 182, 454, 13, 44, "Input",
 InitializationCell->True],
Cell[5151, 197, 162, 5, 26, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[5350, 207, 34, 0, 27, "Subsubsection"],
Cell[5387, 209, 184, 5, 26, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[5608, 219, 33, 0, 27, "Subsubsection"],
Cell[5644, 221, 142, 4, 26, "Input",
 InitializationCell->True]
}, Closed]]
}, Closed]]
}, Open  ]],
Cell[5825, 230, 1284, 37, 20, "SlideShowNavigationBar"],
Cell[CellGroupData[{
Cell[7134, 271, 41, 0, 95, "Section"],
Cell[7178, 273, 166, 3, 74, "Text"],
Cell[7347, 278, 445, 15, 23, "Text"],
Cell[7795, 295, 258, 9, 53, "MathCaption"],
Cell[8056, 306, 1144, 36, 0, "HiddenInput"]
}, Open  ]],
Cell[9215, 345, 1284, 37, 20, "SlideShowNavigationBar"],
Cell[CellGroupData[{
Cell[10524, 386, 37, 0, 95, "Section"],
Cell[10564, 388, 175, 3, 74, "Text"],
Cell[10742, 393, 247, 11, 42, "MathCaption"],
Cell[10992, 406, 7502, 194, 0, "HiddenInput"],
Cell[18497, 602, 231, 6, 35, "Text"],
Cell[18731, 610, 437, 18, 35, "Text"],
Cell[19171, 630, 254, 10, 35, "Text"],
Cell[19428, 642, 385, 13, 72, "DisplayFormula"]
}, Open  ]],
Cell[19828, 658, 1284, 37, 20, "SlideShowNavigationBar"],
Cell[CellGroupData[{
Cell[21137, 699, 40, 0, 81, "SectionTwo"],
Cell[21180, 701, 117, 5, 42, "MathCaption"],
Cell[21300, 708, 3335, 91, 174, "Text"]
}, Open  ]],
Cell[24650, 802, 1284, 37, 20, "SlideShowNavigationBar"],
Cell[CellGroupData[{
Cell[25959, 843, 40, 0, 81, "SectionTwo"],
Cell[26002, 845, 724, 29, 42, "MathCaption"],
Cell[26729, 876, 1446, 41, 0, "HiddenInput"],
Cell[28178, 919, 612, 28, 39, "Warning"],
Cell[28793, 949, 638, 24, 57, "Text"],
Cell[29434, 975, 408, 16, 37, "BeginNumberedList"],
Cell[29845, 993, 591, 22, 37, "NumberedList"],
Cell[30439, 1017, 818, 31, 38, "NumberedList"]
}, Open  ]],
Cell[31272, 1051, 1284, 37, 20, "SlideShowNavigationBar"],
Cell[CellGroupData[{
Cell[32581, 1092, 52, 0, 81, "Section"],
Cell[32636, 1094, 347, 13, 42, "MathCaption"],
Cell[32986, 1109, 3870, 97, 0, "HiddenInput"]
}, Open  ]],
Cell[36871, 1209, 1284, 37, 20, "SlideShowNavigationBar"],
Cell[CellGroupData[{
Cell[38180, 1250, 55, 0, 81, "SectionTwo"],
Cell[38238, 1252, 330, 13, 42, "MathCaption"],
Cell[38571, 1267, 5929, 144, 0, "HiddenInput"],
Cell[44503, 1413, 186, 7, 35, "Text"]
}, Open  ]],
Cell[44704, 1423, 1284, 37, 20, "SlideShowNavigationBar"],
Cell[CellGroupData[{
Cell[46013, 1464, 38, 0, 81, "Section"],
Cell[46054, 1466, 104, 2, 42, "MathCaption"],
Cell[46161, 1470, 275, 9, 0, "HiddenInput"],
Cell[46439, 1481, 351, 10, 57, "Text"],
Cell[46793, 1493, 546, 18, 72, "DisplayFormula"],
Cell[47342, 1513, 385, 8, 79, "Text"]
}, Open  ]],
Cell[47742, 1524, 1284, 37, 20, "SlideShowNavigationBar"],
Cell[CellGroupData[{
Cell[49051, 1565, 41, 0, 81, "SectionTwo"],
Cell[49095, 1567, 204, 8, 35, "Text"],
Cell[49302, 1577, 570, 19, 72, "DisplayFormula"],
Cell[49875, 1598, 97, 2, 42, "MathCaption"],
Cell[49975, 1602, 1712, 52, 238, "Text"],
Cell[51690, 1656, 1046, 34, 106, "Text"]
}, Open  ]],
Cell[52751, 1693, 1284, 37, 20, "SlideShowNavigationBar"],
Cell[CellGroupData[{
Cell[54060, 1734, 41, 0, 81, "SectionTwo"],
Cell[54104, 1736, 1690, 65, 69, "MathCaption"],
Cell[55797, 1803, 299, 10, 0, "HiddenInput"],
Cell[56099, 1815, 1464, 46, 0, "HiddenInput"],
Cell[57566, 1863, 2742, 82, 0, "HiddenInput"]
}, Open  ]],
Cell[60323, 1948, 1284, 37, 20, "SlideShowNavigationBar"],
Cell[CellGroupData[{
Cell[61632, 1989, 41, 0, 81, "SectionTwo"],
Cell[61676, 1991, 765, 30, 72, "MathCaption"],
Cell[62444, 2023, 3157, 94, 0, "HiddenInput"],
Cell[65604, 2119, 203, 6, 39, "Warning"]
}, Open  ]],
Cell[65822, 2128, 1284, 37, 20, "SlideShowNavigationBar"],
Cell[CellGroupData[{
Cell[67131, 2169, 52, 0, 81, "Section"],
Cell[67186, 2171, 682, 17, 123, "Text"],
Cell[67871, 2190, 307, 5, 79, "Text"],
Cell[CellGroupData[{
Cell[68203, 2199, 144, 5, 39, "Quote",
 CellGroupingRules->"InputGrouping"],
Cell[68350, 2206, 595840, 9168, 325, "Output"]
}, Closed]],
Cell[664205, 11377, 272, 9, 36, "Quote"],
Cell[664480, 11388, 114, 3, 42, "MathCaption"],
Cell[664597, 11393, 275, 9, 0, "HiddenInput"]
}, Open  ]],
Cell[664887, 11405, 1284, 37, 20, "SlideShowNavigationBar"],
Cell[CellGroupData[{
Cell[666196, 11446, 55, 0, 81, "SectionTwo"],
Cell[666254, 11448, 451, 15, 57, "Text"],
Cell[666708, 11465, 675, 23, 72, "DisplayFormula"],
Cell[667386, 11490, 512, 17, 60, "Text"],
Cell[667901, 11509, 304, 12, 35, "Text"],
Cell[668208, 11523, 911, 28, 123, "DisplayFormula"],
Cell[669122, 11553, 22, 0, 35, "Text"],
Cell[669147, 11555, 1361, 40, 79, "DisplayFormula"],
Cell[670511, 11597, 19, 0, 35, "Text"],
Cell[670533, 11599, 721, 26, 76, "DisplayFormula"],
Cell[671257, 11627, 485, 19, 35, "Text"],
Cell[671745, 11648, 809, 28, 111, "DisplayFormula"],
Cell[672557, 11678, 60, 0, 35, "Text"],
Cell[672620, 11680, 449, 15, 106, "DisplayFormula"]
}, Open  ]],
Cell[673084, 11698, 1284, 37, 20, "SlideShowNavigationBar"],
Cell[CellGroupData[{
Cell[674393, 11739, 55, 0, 81, "SectionTwo"],
Cell[674451, 11741, 696, 30, 42, "MathCaption"],
Cell[675150, 11773, 1911, 54, 0, "HiddenInput"],
Cell[677064, 11829, 1231, 44, 41, "Text"]
}, Open  ]],
Cell[678310, 11876, 1284, 37, 31, "SlideShowNavigationBar"],
Cell[CellGroupData[{
Cell[679619, 11917, 79, 1, 49, "SectionTwo",
 CellTags->"LastSlide"],
Cell[679701, 11920, 648, 29, 27, "MathCaption"],
Cell[680352, 11951, 2417, 68, 2, "HiddenInput"],
Cell[682772, 12021, 585, 22, 23, "Text"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

