(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     20052,        691]*)
(*NotebookOutlinePosition[     47381,       1660]*)
(*  CellTagsIndexPosition[     46932,       1645]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Numerical Solution to the Schr\[ODoubleDot]dinger Equation", "Title"],

Cell[CellGroupData[{

Cell["Using NDSolve", "Section"],

Cell[BoxData[
    \(TraditionalForm\`Clear[Subscript]\)], "Input"],

Cell[TextData[{
  "Define the potential in ",
  Cell[BoxData[
      \(TraditionalForm\`\([0, 1]\)\)]],
  ":"
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`\(\[ScriptCapitalV](x_) = 0; \)\)], "Input"],

Cell["\<\
(Changing this value and re-executing this entire section will \
generate the new set of solutions.)\
\>", "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{\(soln(\[Epsilon]_)\), ":=", 
        RowBox[{
          RowBox[{"NDSolve", "(", 
            RowBox[{
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{
                      RowBox[{\(-\(1\/2\)\), " ", 
                        
                        FractionBox[\(\[PartialD]\^2\( \[Psi](x)\)\), 
                          \(\[PartialD]x\^2\),
                          MultilineFunction->None]}], "+", 
                      \(\(\[ScriptCapitalV](x)\)\ \(\[Psi](x)\)\)}], "==", 
                    \(\[Epsilon]\ \(\[Psi](x)\)\)}], ",", \(\[Psi](0) == 0\), 
                  ",", 
                  RowBox[{
                    RowBox[{
                      SuperscriptBox["\[Psi]", "\[Prime]",
                        MultilineFunction->None], "(", "0", ")"}], "==", 
                    "1"}]}], "}"}], ",", "\[Psi]", ",", \({x, 0, 1}\)}], 
            ")"}], "//", "First"}]}], TraditionalForm]], "Input"],

Cell[TextData[{
  "The eigenvalue is determined by satisfying the boundary condition ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi](1) = 0\)]],
  ".  The roots of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi](1)\)]],
  " as a function of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\)]],
  ";"
}], "Text"],

Cell[BoxData[
    \(TraditionalForm
    \`\(p = Plot[\[Psi][1] /. soln[\[Epsilon]], {\[Epsilon], 1, 200}]; \)\)], 
  "Input"],

Cell["\<\
yields the first few energy eigenvalues. After isolating the sign \
changes directly from this plot:\
\>", "Text"],

Cell[BoxData[
    \(TraditionalForm
    \`pts := Map(First, 
        Select(Split(Cases(First(p), Line({x__}) \[Rule] x, \[Infinity]), 
            sgn(Last(#2)) == \(-\(sgn(Last(#1))\)\)&), Length(#1) == 2&), {2})
        \)], "Input"],

Cell[TextData[{
  "we can find these eigenvalues using ",
  Cell[BoxData[
      FormBox[
        StyleBox["FindRoot",
          "Input"], TraditionalForm]]],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm
    \`\[Epsilon]s = 
      \(FindRoot[
            \((\[Psi][1] /. First[soln[\[Epsilon]]])\) \[Equal] 0, {
              \[Epsilon], ##}]&\)/@pts\)], "Input"],

Cell[BoxData[
    \(TraditionalForm
    \`{{\[Epsilon] \[Rule] 4.93479267862855497`}, {
        \[Epsilon] \[Rule] 19.7390260131000871`}, {
        \[Epsilon] \[Rule] 44.4132101743210228`}, {
        \[Epsilon] \[Rule] 78.9564262875534961`}, {
        \[Epsilon] \[Rule] 123.369437299192208`}, {
        \[Epsilon] \[Rule] 177.651664819247967`}}\)], "Output"]
}, Open  ]],

Cell["Introducing the shorthand notation,", "Text"],

Cell[BoxData[
    \(TraditionalForm
    \`\[Epsilon]\_n_ := 
      \(\[Epsilon]\_n = 
        \[Epsilon] /. 
          \[Epsilon]s\[LeftDoubleBracket]n\[RightDoubleBracket]\)\)], "Input"],

Cell["we can now define the corresponding normalisation factors,", "Text"],

Cell[BoxData[
    \(TraditionalForm
    \`\[ScriptCapitalN]\_n_ := 
      \(\[ScriptCapitalN]\_n = 
        1\/\@NIntegrate[
              Evaluate[\[Psi][x]\^2 /. soln[\[Epsilon]\_n]], {x, 0, 1}]\)\)], 
  "Input"],

Cell["and normalized eigenfunctions,", "Text"],

Cell[BoxData[
    \(TraditionalForm
    \`\[Psi]\_n_ := 
      \(\[Psi]\_n = 
        Function[{x}, 
          Evaluate[
            \[ScriptCapitalN]\_n\ \((\[Psi][x] /. soln[\[Epsilon]\_n])\)]]
          \)\)], "Input"],

Cell["\<\
Here is a plot of each normalized eigenfunctions shifted upwards by \
one-tenth of the energy eigenvalue:\
\>", "Text"],

Cell[BoxData[
    \(TraditionalForm
    \`\(Plot[Evaluate[
        Table[\[Psi]\_n[x] + \[Epsilon]\_n\/10, {n, Length[pts]}]], {x, 0, 
        1}, PlotStyle \[Rule] Table[Hue[i], {i, 0, 1, 1\/Length[pts]}]]; 
    \)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Variational (Finite element) Method", "Section"],

Cell["The eigenvalue problem", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(TraditionalForm
    \`L[y] = \((p\ y\^\[Prime])\)\^\[Prime] - q\ y - \[Lambda]\ y, \n
    \(L[y]\)[x] \[Equal] 0, \)], "NumberedEquation"],

Cell[TextData[{
  "with ",
  StyleBox["homogenous",
    FontSlant->"Italic"],
  " boundary conditions"
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(TraditionalForm\`\(y[x\_0] \[Equal] 0 \[Equal] y[x\_1], \)\)], 
  "NumberedEquation",
  CellTags->"boundary conditions"],

Cell[TextData[{
  "has the ",
  StyleBox["variational formulation",
    FontSlant->"Italic"],
  " "
}], "Text"],

Cell[BoxData[
    \(TraditionalForm
    \`J[y] = \(\[Integral]\_x\_0\%x\_1\((
              p[x]\ \(y\^\[Prime]\)[x]\^2 + q[x]\ y[x]\^2)\) 
            \[DifferentialD]x = \(minimum . \)\)\)], "NumberedEquation",
  CellTags->"variational formulation"],

Cell["We seek an approximate solution of the form", "Text"],

Cell[BoxData[
    \(TraditionalForm
    \`\(y \[TildeTilde] y\_n[x] = \[Sum]\+\(i = 1\)\%n\( c\_i\) v\_i[x], 
    \)\)], "NumberedEquation",
  CellTags->"approximate solution"],

Cell[TextData[{
  "which satisfies (",
  CounterBox["NumberedEquation", "boundary conditions"],
  ") and (",
  CounterBox["NumberedEquation", "variational formulation"],
  ") with a suitable choice of ",
  StyleBox["basis functions",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`v\_i[x]\)]],
  ". The Ritz-Galerkin (matrix) equation for the ",
  Cell[BoxData[
      \(TraditionalForm\`c\_i\)]],
  " reads"
}], "Text",
  CellTags->"basis functions"],

Cell[BoxData[
    \(TraditionalForm
    \`\(\[ScriptCapitalA] . c \[Equal] \[Lambda]\ \[ScriptCapitalB] . c, 
    \)\)], "NumberedEquation",
  CellTags->"generalized eigenvalue problem"],

Cell["where", "Text"],

Cell[BoxData[
    \(TraditionalForm
    \`\({\[ScriptCapitalA]}\_\(i, j\) = 
      \(\[Alpha]\_\(i, j\) = 
        \(\[Alpha]\_\(j, i\) = 
          \(-\(\[Integral]\_x\_0\%x\_1\((
                  p[x]\ v\_i\%\[Prime][x] v\_j\%\[Prime][x] + 
                    q[x]\ v\_i[x] v\_j[x])\) \[DifferentialD]x\)\)\)\), 
    \)\)], "NumberedEquation",
  CellTags->"Ritz matrix"],

Cell["and", "Text"],

Cell[BoxData[
    \(TraditionalForm
    \`{\[ScriptCapitalB]}\_\(i, j\) = 
      \(\[Beta]\_\(i, j\) = 
        \(\[Beta]\_\(j, i\) = 
          \[Integral]\_x\_0\%x\_1 v\_i[x] v\_j[x] 
              \(\[DifferentialD]x . \)\)\)\)], "NumberedEquation",
  CellTags->"overlap matrix"],

Cell[TextData[{
  "The generalized eigenvalue problem (",
  CounterBox["NumberedEquation", "generalized eigenvalue problem"],
  ") can be solved (for non-singular ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalB]\)]],
  ") using ",
  Cell[BoxData[
      \(TraditionalForm
      \`\((\[ScriptCapitalB]\^\(-1\) . \[ScriptCapitalA])\) . c = 
        \[Lambda]\ c\)]],
  "."
}], "Text"],

Cell["Consider solving the Schr\[ODoubleDot]dinger equation,", "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            RowBox[{\(-\(1\/2\)\), " ", 
              
              FractionBox[\(\[PartialD]\^2\( \[Psi](x)\)\), 
                \(\[PartialD]x\^2\),
                MultilineFunction->None]}], "+", 
            \(\(\[ScriptCapitalV](x)\)\ \(\[Psi](x)\)\)}], "==", 
          \(\[Epsilon]\ \(\[Psi](x)\)\)}], ","}], TraditionalForm]], 
  "NumberedEquation",
  CellTags->"eigenvalue problem"],

Cell["with", "Text"],

Cell[BoxData[
    \(TraditionalForm\`\[Psi](0) \[Equal] \[Psi](1) \[Equal] 0. \)], 
  "NumberedEquation",
  CellTags->"homogenous boundary conditions"],

Cell[TextData[{
  "For the trivial potential ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalV](x) = 0\)]],
  ", we can use ",
  Cell[BoxData[
      FormBox[
        StyleBox["DSolve",
          "Input"], TraditionalForm]]],
  " to solve the differential equation to determine a complete set of \
(orthogonal) basis functions:"
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`Clear[Subscript]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"DSolve", "(", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{
                  RowBox[{\(-\(1\/2\)\), " ", 
                    
                    FractionBox[\(\[PartialD]\^2\( \[Psi](x)\)\), 
                      \(\[PartialD]x\^2\),
                      MultilineFunction->None]}], "==", 
                  \(\[Epsilon]\ \(\[Psi](x)\)\)}], ",", 
                \(\[Psi](0) \[Equal] 0\)}], "}"}], ",", "\[Psi]", ",", "x"}], 
          ")"}], "//", "First"}], TraditionalForm]], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{"\[Psi]", "\[Rule]", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                SubscriptBox[
                  TagBox["c",
                    C], "1"], " ", \(sin(\@2\ \@\[Epsilon]\ #1)\)}], "&"}], 
            ")"}]}], "}"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
The second boundary condition determines the associated energy \
eigenvalues:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`\[Psi](1) == 0 /. %\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          SubscriptBox[
            TagBox["c",
              C], "1"], " ", \(sin(\@2\ \@\[Epsilon])\)}], "==", "0"}], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell["and implies that ", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm
    \`Solve[\@\(2  \[Epsilon]\) \[Equal] n\ \[Pi], \[Epsilon]] // First\)], 
  "Input"],

Cell[BoxData[
    \(TraditionalForm\`{\[Epsilon] \[Rule] \(n\^2\ \[Pi]\^2\)\/2}\)], "Output"]
}, Open  ]],

Cell["\<\
which also determines the corresponding (un-normalized) \
eigensolutions:\
\>", "Text",
  CellTags->"eigensolution"],

Cell[CellGroupData[{

Cell[BoxData[
    FormBox[
      RowBox[{\(\[Psi]\_n_[x_]\), "=", 
        RowBox[{\((\(\[Psi](x) /. %%%\) /. % // PowerExpand)\), "/.", 
          RowBox[{
            SubscriptBox[
              TagBox["c",
                C], "1"], "\[Rule]", "1"}]}]}], TraditionalForm]], "Input"],

Cell[BoxData[
    \(TraditionalForm\`sin(n\ \[Pi]\ x)\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "We can now use these basis functions to solve the Schr\[ODoubleDot]dinger \
equation for general ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalV](x)\)]],
  ". We implement the ",
  Cell[BoxData[
      \(TraditionalForm\`n\[Times]n\)]],
  " matrix (",
  CounterBox["NumberedEquation", "Ritz matrix"],
  "), which explicitly involves the potential as"
}], "Text"],

Cell[BoxData[
    \(TraditionalForm
    \`\[ScriptCapitalA]\_n_[\[ScriptCapitalV]_] := 
      Table(\[Alpha]\_\(i, j\)[\[ScriptCapitalV]], {i, n}, {j, n})\)], "Input"],

Cell[BoxData[
    \(TraditionalForm
    \`\[Alpha]\_\(i_, j_\)[\[ScriptCapitalV]_] := 
      \(\[Alpha]\_\(i, j\)[\[ScriptCapitalV]] = 
        \(\[Alpha]\_\(j, i\)[\[ScriptCapitalV]] = 
          NIntegrate(
              \[ScriptCapitalV]\ \(\(\[Psi]\_i\)(x)\)\ \(\(\[Psi]\_j\)(x)\) + 
                1, {x, 0, 1}) - 1\)\)\)], "Input"],

Cell[BoxData[
    \(TraditionalForm
    \`\[Alpha]\_\(i_, i_\)[\[ScriptCapitalV]_] := 
      \(\[Alpha]\_\(i, i\)[\[ScriptCapitalV]] = 
        \(i\^2\ \[Pi]\^2\)\/4 + 
          NIntegrate(
            \[ScriptCapitalV]\ \(\(\[Psi]\_i\)(x)\ \)\^2 + 1, {x, 0, 1}) - 1
          \)\)], "Input"],

Cell[TextData[{
  "This requires, in general, numerical integration (the trick of \
incrementing the integrand and then decrementing the result prevents ",
  Cell[BoxData[
      FormBox[
        StyleBox["NIntegrate",
          "Input"], TraditionalForm]]],
  " from complaining about numerical precision loss). Note that we have \
pre-computed the following two special cases:"
}], "Warning"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm
    \`\((\(-\(\[Integral]\_0\%1
                \((\(-1\)\/2\ \[Psi]\_i\%\[Prime][x] \[Psi]\_j\%\[Prime][x])
                  \) \[DifferentialD]x\)\) // TrigReduce)\) /. 
      sin(_) \[Rule] 0\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`0\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm
    \`\((\(-\(\[Integral]\_0\%1\((\(-1\)\/2\ \[Psi]\_i\%\[Prime][x]\^2)\) 
                \[DifferentialD]x\)\) // TrigReduce)\) /. 
      sin(_) \[Rule] 0\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`\(i\^2\ \[Pi]\^2\)\/4\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The overlap matrix (",
  CounterBox["NumberedEquation", "overlap matrix"],
  "),"
}], "Text"],

Cell[BoxData[
    \(TraditionalForm
    \`\[ScriptCapitalB]\_n_ := Table(\[Beta]\_\(i, j\), {i, n}, {j, n})\)], 
  "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm
    \`\[Beta]\_\(i_, j_\) = 
      \((\[Integral]\_0\%1 \[Psi]\_i[x] \[Psi]\_j[x] \[DifferentialD]x // 
            TrigReduce)\) /. sin(_) \[Rule] 0\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`0\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm
    \`\[Beta]\_\(i_, i_\) = 
      \((\[Integral]\_0\%1\( \[Psi]\_i[x]\^2\) \[DifferentialD]x // 
            TrigReduce)\) /. sin(_) \[Rule] 0\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`1\/2\)], "Output"]
}, Open  ]],

Cell["\<\
is immediate and diagonal (because our basis functions are \
orthogonal). This code will also work with non-orthogonal basis \
functions.\
\>", "Text"],

Cell[TextData[{
  "For the potential ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalV](x) = 0\)]],
  " we recover the eigenvalues obtained above:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          SuperscriptBox[\(\[ScriptCapitalB]\_5\), 
            TagBox[\(-1\),
              Inverse]], ".", \(\[ScriptCapitalA]\_5[0]\)}], "//", "Chop"}], 
      TraditionalForm]], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"4.93480220054467899`", "0", "0", "0", "0"},
            {"0", "19.7392088021787159`", "0", "0", "0"},
            {"0", "0", "44.4132198049021109`", "0", "0"},
            {"0", "0", "0", "78.9568352087148639`", "0"},
            {"0", "0", "0", "0", "123.370055013616974`"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Here is the set of (numerical) eigenvalues, ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Epsilon], \)\)]],
  " and corresponding eigenvectors, ",
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  ", of ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalB]\^\(-1\) . \[ScriptCapitalA]\)]],
  " computed with ",
  Cell[BoxData[
      \(TraditionalForm\`n = 8\)]],
  " for the potential ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalV](x) = 10  \[ExponentialE]\^x\)]],
  ":"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{\({\[Epsilon], c}\), "=", 
          SuperscriptBox[
            RowBox[{"Sort", "(", 
              SuperscriptBox[
                RowBox[{"Eigensystem", "(", 
                  RowBox[{
                    SuperscriptBox[\(\[ScriptCapitalB]\_8\), 
                      TagBox[\(-1\),
                        Inverse]], ".", 
                    \(\(\[ScriptCapitalA]\_8\)(10  \[ExponentialE]\^x)\)}], 
                  ")"}], "T"], ")"}], "T"]}], ";"}], TraditionalForm]], 
  "Input"],

Cell["The energies read", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`\[Epsilon]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm
    \`{21.1141680904087625`, 36.9538560599520682`, 61.6549618952972711`, 
      96.1805636106282335`, 140.581182507809954`, 194.8567594153306`, 
      259.004552583788427`, 333.162996273128442`}\)], "Output"]
}, Open  ]],

Cell["and the approximate normalized eigenfunctions are", "Text"],

Cell[BoxData[
    \(TraditionalForm
    \`\[CapitalPsi]\_n_[x_] := 
      c\[LeftDoubleBracket]n\[RightDoubleBracket] . 
          \(Table(\(\[Psi]\_i\)(x), {i, Length[c]})
            \)\/\@\(c\[LeftDoubleBracket]n\[RightDoubleBracket] . 
            \[ScriptCapitalB]\_8 . 
            c\[LeftDoubleBracket]n\[RightDoubleBracket]\)\)], "Input"],

Cell["For example,", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`NIntegrate[\[CapitalPsi]\_1[x]\^2, {x, 0, 1}]\)], 
  "Input"],

Cell[BoxData[
    \(TraditionalForm\`1.`\)], "Output"]
}, Open  ]],

Cell["Here is a plot of the associated eigenfunctions:", "Text"],

Cell[BoxData[
    \(TraditionalForm
    \`\(Plot[Evaluate[
        Table[\[CapitalPsi]\_n[x] + 
            \[Epsilon]\[LeftDoubleBracket]n\[RightDoubleBracket]\/10, {n, 
            Length[c]}]], {x, 0, 1}, 
      PlotStyle \[Rule] Table[Hue[i], {i, 0, 1, 1\/Length[c]}]]; \)\)], 
  "Input"],

Cell[TextData[{
  "It is also easy to check how well each approximate solution satisfies the \
eigenvalue problem (",
  CounterBox["NumberedEquation", "eigenvalue problem"],
  "). Here is a plot of the difference for the first eigenfunction:"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"Plot", "(", 
          RowBox[{
            RowBox[{"Evaluate", "[", 
              RowBox[{
                RowBox[{\(-\(1\/2\)\), " ", 
                  
                  FractionBox[\(\[PartialD]\^2\(\( \[CapitalPsi]\_1\)(x)\)\), 
                    \(\[PartialD]x\^2\),
                    MultilineFunction->None]}], "+", 
                \(10 \( \[ExponentialE]\^x\) \(\(\[CapitalPsi]\_1\)(x)\)\), 
                "-", \(\[Epsilon]\[LeftDoubleBracket]1\[RightDoubleBracket]\ 
                  \(\(\[CapitalPsi]\_1\)(x)\)\)}], "]"}], ",", \({x, 0, 1}\), 
            ",", \(PlotRange \[Rule] All\)}], ")"}], ";"}], 
      TraditionalForm]], "Input"]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"Macintosh 3.0",
ScreenRectangle->{{0, 800}, {0, 580}},
WindowSize->{732, 553},
WindowMargins->{{4, Automatic}, {Automatic, 1}},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.
Make modifications to any definition using commands in the Format menu.\
\>", 
    "SmallText"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    ShowCellBracket->True,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ShowCellTags->False,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    StyleMenuListing->None]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{10, Inherited}, {8, Inherited}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    CounterAssignments->{{"Chapter", 1}, {"Topic", 0}, {"Section", 0}, {
        "Equation", 0}, {"Figure", 0}},
    FontFamily->"Times",
    FontSize->36,
    FontWeight->"Bold"],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{14, Inherited}, {60, Inherited}},
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{10, Inherited}, {20, Inherited}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    CounterIncrements->"Chapter",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Times",
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{6, Inherited}, {120, Inherited}},
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{28, Inherited}, {6, Inherited}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    CounterIncrements->"Topic",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Times",
    FontSize->14,
    FontSlant->"Italic"],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{14, Inherited}, {6, Inherited}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->None,
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{28, Inherited}, {Inherited, 40}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}, {
        "NumberedBullet", 0}},
    FontFamily->"Times",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{14, Inherited}, {Inherited, 20}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{28, Inherited}, {Inherited, 28}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Times",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{14, Inherited}, {Inherited, 15}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->None,
    CellMargins->{{6, Inherited}, {Inherited, 12}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontFamily->"Times",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{14, Inherited}, {Inherited, 12}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{28, 10}, {7, 7}},
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 2}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellDingbat->"\[GrayCircle]",
    CellMargins->{{36, 10}, {6, 6}},
    LineSpacing->{1, 3},
    CounterIncrements->"SmallText",
    FontFamily->"Times",
    FontSize->10],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 2}, {5, 5}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{60, Inherited}, {Inherited, Inherited}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{30, Inherited}, {10, Inherited}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input3.5"],
    Evaluator->"math3.5",
    CellMargins->{{60, Inherited}, {Inherited, Inherited}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Input3.5", "Printout"],
    CellMargins->{{30, Inherited}, {10, Inherited}},
    FontSize->10,
    FontColor->GrayLevel[0.500008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{60, Inherited}, {Inherited, Inherited}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{30, Inherited}, {20, Inherited}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{60, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{30, Inherited}, {Inherited, Inherited}},
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{60, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{30, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Info"],
    CellMargins->{{60, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    StyleMenuListing->None],
  
  Cell[StyleData["Info", "Printout"],
    CellMargins->{{30, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    ImageMargins->{{35, Inherited}, {Inherited, 0}},
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Printout"],
    CellMargins->{{30, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Special Styles", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Equation"],
    CellMargins->{{72, 72}, {Inherited, Inherited}},
    DefaultFormatType->TraditionalForm,
    TextAlignment->Center,
    FormatTypeAutoConvert->True,
    FontFamily->"Times"],
  
  Cell[StyleData["Equation", "Printout"],
    CellMargins->{{72, 72}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BrightIdeaTop"],
    CellDingbat->"\[LightBulb]",
    CellMargins->{{28, Inherited}, {-5, 30}},
    FontSize->24,
    FontColor->RGBColor[0, 0, 0.6]],
  
  Cell[StyleData["BrightIdeaTop", "Printout"],
    CellMargins->{{14, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BrightIdea"],
    CellMargins->{{28, 10}, {12, 2}},
    LineSpacing->{1, 3},
    FontColor->RGBColor[0, 0, 0.6]],
  
  Cell[StyleData["BrightIdea", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["WarningTop"],
    CellFrame->1,
    CellMargins->{{6, Inherited}, {-10, 20}},
    CellFrameMargins->{{2, 0}, {8, 8}},
    CellFrameColor->GrayLevel[0.998993],
    CellFrameLabels->{{Cell[ 
            TextData[ 
              StyleBox[ 
              "\[WarningSign]", FontSize -> 24, FontColor -> RGBColor[ 
                0, 0, 0.6]]], "Text"], None}, {None, None}},
    FontSize->24,
    FontColor->RGBColor[0, 0, 0.6]],
  
  Cell[StyleData["WarningTop", "Printout"],
    CellMargins->{{14, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Warning"],
    CellFrame->1,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    CellFrameMargins->{{4, 0}, {2, 2}},
    CellFrameColor->GrayLevel[0.998993],
    CellFrameLabels->{{Cell[ 
            TextData[ 
              StyleBox[ 
              "\[WarningSign]", FontSize -> 24, FontColor -> RGBColor[ 
                0, 0, 0.6]]], "Text"], None}, {None, None}},
    CellFrameLabelMargins->2,
    FontFamily->"Times",
    FontColor->RGBColor[0, 0, 0.6],
    Background->None],
  
  Cell[StyleData["Warning", "Printout"],
    CellMargins->{{14, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Kernel"],
    CellDingbat->"\[KernelIcon]",
    CellMargins->{{18, Inherited}, {Inherited, Inherited}},
    FontFamily->"Times"],
  
  Cell[StyleData["Kernel", "Printout"],
    CellMargins->{{14, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FrontEnd"],
    CellDingbat->"\[MathematicaIcon]",
    CellMargins->{{18, Inherited}, {Inherited, Inherited}},
    FontFamily->"Times"],
  
  Cell[StyleData["FrontEnd", "Printout"],
    CellMargins->{{14, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Applications"],
    CellDingbat->"@@",
    CellMargins->{{18, Inherited}, {Inherited, Inherited}},
    FontFamily->"Times"],
  
  Cell[StyleData["Applications", "Printout"],
    CellMargins->{{14, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Packages"],
    CellDingbat->"\[Paragraph]",
    CellMargins->{{18, Inherited}, {Inherited, Inherited}},
    FontFamily->"Times"],
  
  Cell[StyleData["Packages", "Printout"],
    CellMargins->{{14, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Question"],
    CellDingbat->"??",
    CellMargins->{{36, Inherited}, {Inherited, Inherited}},
    FontFamily->"Times",
    FontSize->10,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Question", "Printout"],
    CellMargins->{{14, Inherited}, {Inherited, Inherited}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Reference"],
    CellMargins->{{30, Inherited}, {12, 0}},
    CellFrameLabels->{{Cell[ 
            TextData[ 
              StyleBox[ 
              "Ref: ", FontSize -> 10, FontColor -> RGBColor[ 0, 0, 0.6]]], 
            "Text"], None}, {None, None}},
    FontFamily->"Times",
    FontSize->10],
  
  Cell[StyleData["Reference", "Printout"],
    CellMargins->{{36, Inherited}, {Inherited, Inherited}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Menu"],
    CellMargins->{{17, Inherited}, {Inherited, Inherited}},
    FontFamily->"Chicago"],
  
  Cell[StyleData["Menu", "Printout"],
    CellMargins->{{14, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BLU"],
    FontColor->RGBColor[0, 0, 0.6]],
  
  Cell[StyleData["BLU", "Printout"],
    FontColor->GrayLevel[0.300008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Reset"],
    CellDingbat->"\[LeftArrow]",
    CellMargins->{{18, Inherited}, {Inherited, Inherited}},
    FontFamily->"Times"],
  
  Cell[StyleData["Reset", "Printout"],
    CellMargins->{{2, 2}, {6, 6}}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Automatic Numbering", "Section"],
  
  Cell["\<\
The following styles are useful for numbered equations, figures, \
etc.  They automatically give the cell a FrameLabel containing a reference to \
a particular counter, and also increment that counter.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{72, 72}, {Inherited, Inherited}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
    DefaultFormatType->TraditionalForm,
    TextAlignment->Center,
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->True,
    FontFamily->"Times"],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    CellMargins->{{72, 72}, {Inherited, Inherited}},
    TextAlignment->Center,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedTable"],
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Table ", 
              CounterBox[ "NumberedTable"]}]], None}},
    CounterIncrements->"NumberedTable",
    FormatTypeAutoConvert->False,
    FontFamily->"Times"],
  
  Cell[StyleData["NumberedTable", "Printout"],
    CellMargins->{{14, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedBullet"],
    CellMargins->{{36, 10}, {6, 6}},
    CellFrameLabels->{{Cell[ 
            TextData[ {
              CounterBox[ "NumberedBullet"], ". "}]], None}, {None, None}},
    LineSpacing->{1, 3},
    CounterIncrements->"NumberedBullet",
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["NumberedBullet", "Printout"],
    CellMargins->{{2, 2}, {5, 5}},
    FontSize->10]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["LeftHeader"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["Footer"],
    TextAlignment->Center,
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["LeftFooter"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    FormatType->InputForm,
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    FormatType->InputForm,
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder \
objects in palette templates.\
\>", "Text"],
  
  Cell[StyleData["Placeholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->True,
    StyleMenuListing->None],
  
  Cell[StyleData["SelectionPlaceholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->True,
    StyleMenuListing->None,
    DrawHighlighted->True]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles \
of most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12],
  
  Cell[StyleData["InputForm"],
    AllowInlineCells->False,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    PageWidth->Infinity,
    TextAlignment->Left,
    LineSpacing->{1, -5},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["TraditionalForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None]
  }, Closed]]
  }, Open  ]]
  }],
MacintoshSystemPageSetup->"\<\
00<0001804P000000c@2@?oeooH3?`990dL5N`?P0080001804P000000`d26P01
0000I00000400@410?l00BL?00400@0000000000000006P801T1T0000000h000
00000000007oo`00003oo`000o800000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "boundary conditions"->{
    Cell[6559, 223, 140, 3, 22, "NumberedEquation",
      CellTags->"boundary conditions"]},
  "variational formulation"->{
    Cell[6816, 235, 251, 5, 41, "NumberedEquation",
      CellTags->"variational formulation"]},
  "approximate solution"->{
    Cell[7132, 244, 176, 4, 46, "NumberedEquation",
      CellTags->"approximate solution"]},
  "basis functions"->{
    Cell[7311, 250, 477, 16, 32, "Text",
      CellTags->"basis functions"]},
  "generalized eigenvalue problem"->{
    Cell[7791, 268, 186, 4, 22, "NumberedEquation",
      CellTags->"generalized eigenvalue problem"]},
  "Ritz matrix"->{
    Cell[8004, 276, 374, 9, 41, "NumberedEquation",
      CellTags->"Ritz matrix"]},
  "overlap matrix"->{
    Cell[8403, 289, 282, 7, 41, "NumberedEquation",
      CellTags->"overlap matrix"]},
  "eigenvalue problem"->{
    Cell[9158, 314, 473, 13, 43, "NumberedEquation",
      CellTags->"eigenvalue problem"]},
  "homogenous boundary conditions"->{
    Cell[9657, 331, 151, 3, 22, "NumberedEquation",
      CellTags->"homogenous boundary conditions"]},
  "eigensolution"->{
    Cell[11937, 417, 126, 4, 30, "Text",
      CellTags->"eigensolution"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"boundary conditions", 45749, 1611},
  {"variational formulation", 45873, 1614},
  {"approximate solution", 45998, 1617},
  {"basis functions", 46115, 1620},
  {"generalized eigenvalue problem", 46231, 1623},
  {"Ritz matrix", 46354, 1626},
  {"overlap matrix", 46461, 1629},
  {"eigenvalue problem", 46575, 1632},
  {"homogenous boundary conditions", 46706, 1635},
  {"eigensolution", 46831, 1638}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 75, 0, 88, "Title"],

Cell[CellGroupData[{
Cell[1831, 55, 32, 0, 67, "Section"],
Cell[1866, 57, 66, 1, 24, "Input"],
Cell[1935, 60, 120, 5, 30, "Text"],
Cell[2058, 67, 81, 1, 24, "Input"],
Cell[2142, 70, 124, 3, 30, "Text"],
Cell[2269, 75, 1014, 23, 43, "Input"],
Cell[3286, 100, 324, 11, 30, "Text"],
Cell[3613, 113, 125, 3, 24, "Input"],
Cell[3741, 118, 124, 3, 30, "Text"],
Cell[3868, 123, 236, 5, 42, "Input"],
Cell[4107, 130, 175, 7, 30, "Text"],

Cell[CellGroupData[{
Cell[4307, 141, 195, 5, 24, "Input"],
Cell[4505, 148, 359, 7, 22, "Output"]
}, Open  ]],
Cell[4879, 158, 51, 0, 30, "Text"],
Cell[4933, 160, 187, 5, 25, "Input"],
Cell[5123, 167, 74, 0, 30, "Text"],
Cell[5200, 169, 214, 6, 49, "Input"],
Cell[5417, 177, 46, 0, 30, "Text"],
Cell[5466, 179, 221, 7, 25, "Input"],
Cell[5690, 188, 129, 3, 30, "Text"],
Cell[5822, 193, 228, 5, 41, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[6087, 203, 54, 0, 31, "Section"],
Cell[6144, 205, 86, 2, 30, "Text",
  Evaluatable->False],
Cell[6233, 209, 158, 3, 39, "NumberedEquation"],
Cell[6394, 214, 162, 7, 32, "Text",
  Evaluatable->False],
Cell[6559, 223, 140, 3, 22, "NumberedEquation",
  CellTags->"boundary conditions"],
Cell[6702, 228, 111, 5, 32, "Text"],
Cell[6816, 235, 251, 5, 41, "NumberedEquation",
  CellTags->"variational formulation"],
Cell[7070, 242, 59, 0, 30, "Text"],
Cell[7132, 244, 176, 4, 46, "NumberedEquation",
  CellTags->"approximate solution"],
Cell[7311, 250, 477, 16, 32, "Text",
  CellTags->"basis functions"],
Cell[7791, 268, 186, 4, 22, "NumberedEquation",
  CellTags->"generalized eigenvalue problem"],
Cell[7980, 274, 21, 0, 30, "Text"],
Cell[8004, 276, 374, 9, 41, "NumberedEquation",
  CellTags->"Ritz matrix"],
Cell[8381, 287, 19, 0, 30, "Text"],
Cell[8403, 289, 282, 7, 41, "NumberedEquation",
  CellTags->"overlap matrix"],
Cell[8688, 298, 394, 12, 31, "Text"],
Cell[9085, 312, 70, 0, 30, "Text"],
Cell[9158, 314, 473, 13, 43, "NumberedEquation",
  CellTags->"eigenvalue problem"],
Cell[9634, 329, 20, 0, 30, "Text"],
Cell[9657, 331, 151, 3, 22, "NumberedEquation",
  CellTags->"homogenous boundary conditions"],
Cell[9811, 336, 350, 11, 46, "Text"],
Cell[10164, 349, 66, 1, 24, "Input"],

Cell[CellGroupData[{
Cell[10255, 354, 599, 15, 43, "Input"],
Cell[10857, 371, 346, 10, 34, "Output"]
}, Open  ]],
Cell[11218, 384, 101, 3, 30, "Text"],

Cell[CellGroupData[{
Cell[11344, 391, 69, 1, 24, "Input"],
Cell[11416, 394, 214, 7, 34, "Output"]
}, Open  ]],
Cell[11645, 404, 33, 0, 30, "Text"],

Cell[CellGroupData[{
Cell[11703, 408, 123, 3, 27, "Input"],
Cell[11829, 413, 93, 1, 43, "Output"]
}, Open  ]],
Cell[11937, 417, 126, 4, 30, "Text",
  CellTags->"eigensolution"],

Cell[CellGroupData[{
Cell[12088, 425, 284, 7, 25, "Input"],
Cell[12375, 434, 67, 1, 22, "Output"]
}, Open  ]],
Cell[12457, 438, 393, 11, 46, "Text"],
Cell[12853, 451, 167, 3, 25, "Input"],
Cell[13023, 456, 338, 7, 25, "Input"],
Cell[13364, 465, 293, 7, 41, "Input"],
Cell[13660, 474, 393, 9, 42, "Warning"],

Cell[CellGroupData[{
Cell[14078, 487, 244, 5, 40, "Input"],
Cell[14325, 494, 52, 1, 22, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14414, 500, 205, 4, 40, "Input"],
Cell[14622, 506, 72, 1, 43, "Output"]
}, Open  ]],
Cell[14709, 510, 112, 4, 30, "Text"],
Cell[14824, 516, 123, 3, 25, "Input"],

Cell[CellGroupData[{
Cell[14972, 523, 198, 4, 40, "Input"],
Cell[15173, 529, 52, 1, 22, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15262, 535, 192, 4, 40, "Input"],
Cell[15457, 541, 55, 1, 40, "Output"]
}, Open  ]],
Cell[15527, 545, 161, 4, 30, "Text"],
Cell[15691, 551, 170, 5, 30, "Text"],

Cell[CellGroupData[{
Cell[15886, 560, 249, 7, 25, "Input"],
Cell[16138, 569, 435, 9, 98, "Output"]
}, Open  ]],
Cell[16588, 581, 526, 17, 47, "Text"],
Cell[17117, 600, 547, 14, 27, "Input"],
Cell[17667, 616, 33, 0, 30, "Text"],

Cell[CellGroupData[{
Cell[17725, 620, 60, 1, 24, "Input"],
Cell[17788, 623, 244, 4, 22, "Output"]
}, Open  ]],
Cell[18047, 630, 65, 0, 30, "Text"],
Cell[18115, 632, 346, 7, 43, "Input"],
Cell[18464, 641, 28, 0, 30, "Text"],

Cell[CellGroupData[{
Cell[18517, 645, 98, 2, 25, "Input"],
Cell[18618, 649, 54, 1, 22, "Output"]
}, Open  ]],
Cell[18687, 653, 64, 0, 30, "Text"],
Cell[18754, 655, 292, 7, 41, "Input"],
Cell[19049, 664, 254, 5, 46, "Text"],
Cell[19306, 671, 718, 16, 43, "Input"]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

