(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     12072,        424]
NotebookOptionsPosition[     10595,        376]
NotebookOutlinePosition[     11019,        394]
CellTagsIndexPosition[     10976,        391]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Local Extrema of f[x,y]", "Title"],

Cell["\<\
Therese Shelton and Kendall Richards
Southwestern University\
\>", "Subsubtitle"],

Cell["Reset", "Text",
 FontSize->16],

Cell[BoxData[{
 RowBox[{"Clear", "[", 
  RowBox[{
  "f", ",", "x", ",", "y", ",", "fx", ",", "fy", ",", "fxx", ",", "fyy", ",", 
   "fxy", ",", "CP", ",", "n", ",", "disc"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Clear", "[", 
  RowBox[{
  "p1", ",", "p2", ",", "xlo", ",", "xhi", ",", "ylo", ",", "yhi", ",", 
   "numCon", ",", "type"}], "]"}]}], "Input"],

Cell["Define a function of two variables.", "Text",
 FontSize->16],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"f", "[", 
    RowBox[{"x_", ",", "y_"}], "]"}], ":=", " ", 
   RowBox[{
    RowBox[{"2", 
     RowBox[{"x", "^", "3"}], " ", "y"}], "-", 
    RowBox[{"y", "^", "2"}], "-", 
    RowBox[{"3", "x", "*", "y"}]}]}], ";"}]], "Input"],

Cell["\<\
Note that the domain of this function is all of the real plane.\
\>", "Text"],

Cell["\<\
Calculate the 1st and 2nd order derivatives and the critical points just \
based on where the gradient is zero.\
\>", "Text",
 FontSize->16],

Cell["\<\
(Recall, you should also check where the gradient is undefined.)\
\>", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"fx", "[", 
   RowBox[{"x_", ",", "y_"}], "]"}], "=", 
  RowBox[{
   SubscriptBox["\[PartialD]", "x"], " ", 
   RowBox[{"f", "[", 
    RowBox[{"x", ",", "y"}], "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"fy", "[", 
   RowBox[{"x_", ",", "y_"}], "]"}], "=", 
  RowBox[{
   SubscriptBox["\[PartialD]", "y"], " ", 
   RowBox[{"f", "[", 
    RowBox[{"x", ",", "y"}], "]"}]}]}]}], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"fxx", "[", 
   RowBox[{"x_", ",", "y_"}], "]"}], "=", 
  RowBox[{
   SubscriptBox["\[PartialD]", 
    RowBox[{"x", ",", "x"}]], " ", 
   RowBox[{"f", "[", 
    RowBox[{"x", ",", "y"}], "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"fyy", "[", 
   RowBox[{"x_", ",", "y_"}], "]"}], "=", 
  RowBox[{
   SubscriptBox["\[PartialD]", 
    RowBox[{"y", ",", "y"}]], " ", 
   RowBox[{"f", "[", 
    RowBox[{"x", ",", "y"}], "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"fxy", "[", 
   RowBox[{"x_", ",", "y_"}], "]"}], "=", 
  RowBox[{
   SubscriptBox["\[PartialD]", 
    RowBox[{"x", ",", "y"}]], " ", 
   RowBox[{"f", "[", 
    RowBox[{"x", ",", "y"}], "]"}]}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"CP", "=", 
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"fx", "[", 
        RowBox[{"x", ",", "y"}], "]"}], "==", "0"}], ",", 
      RowBox[{
       RowBox[{"fy", "[", 
        RowBox[{"x", ",", "y"}], "]"}], "==", "0"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "y"}], "}"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"N", "[", "CP", "]"}]], "Input"],

Cell["\<\
All these points are contained between these values of x and of y:\
\>", "Text",
 FontSize->14],

Cell[BoxData[
 RowBox[{
  RowBox[{"xlo", "=", 
   RowBox[{"ylo", "=", 
    RowBox[{"-", "2"}]}]}], ";", " ", 
  RowBox[{"xhi", "=", 
   RowBox[{"yhi", "=", "2"}]}], ";"}]], "Input"],

Cell["\<\
We should double-check that these points are in the domain of f.  Critical \
points also include any points where f is defined but the gradient is not.  \
For this function, there are no other points, and all these points are in the \
domain of f.\
\>", "Text"],

Cell["\<\
This is the number of critical points, which are places in the domain where \
we might have extrema:\
\>", "Text",
 FontSize->16],

Cell[BoxData[
 RowBox[{"Length", "[", "CP", "]"}]], "Input"],

Cell["\<\
This is the \"discriminant of f\" or the determinant of the Hessian of f.\
\>", "Text",
 FontSize->16],

Cell[BoxData[
 RowBox[{
  RowBox[{"disc", "[", 
   RowBox[{"x_", ",", "y_"}], "]"}], " ", "=", " ", 
  RowBox[{"Det", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"fxx", "[", 
        RowBox[{"x", ",", "y"}], "]"}], ",", 
       RowBox[{"fxy", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"fxy", "[", 
        RowBox[{"x", ",", "y"}], "]"}], ",", 
       RowBox[{"fyy", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}], "}"}]}], "}"}], "]"}]}]], "Input"],

Cell["\<\
If there are any critical points, execute this next cell to see the values \
needed to determine if it is an extremum.\
\>", "Text",
 FontSize->16],

Cell[BoxData[{
 RowBox[{
  RowBox[{"n", "=", "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"type", "=", "\"\<no info\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"CP", "[", 
  RowBox[{"[", "n", "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"num1", "=", 
  RowBox[{
   RowBox[{"disc", "[", 
    RowBox[{"x", ",", "y"}], "]"}], "/.", 
   RowBox[{"CP", "[", 
    RowBox[{"[", "n", "]"}], "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"num2", "=", 
  RowBox[{
   RowBox[{"fxx", "[", 
    RowBox[{"x", ",", "y"}], "]"}], "/.", 
   RowBox[{"CP", "[", 
    RowBox[{"[", "n", "]"}], "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{"And", "[", 
     RowBox[{
      RowBox[{"num1", ">", "0"}], ",", 
      RowBox[{"num2", "<", "0"}]}], "]"}], ",", 
    RowBox[{"type", "=", "\"\<local max\>\""}]}], " ", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{"And", "[", 
     RowBox[{
      RowBox[{"num1", ">", "0"}], ",", 
      RowBox[{"num2", ">", "0"}]}], "]"}], ",", 
    RowBox[{"type", "=", "\"\<local min\>\""}]}], " ", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{"num1", "<", "0"}], ",", 
    RowBox[{"type", "=", "\"\<saddle point\>\""}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", "type", "]"}]}], "Input"],

Cell["\<\
Copy and paste the next cell, then execute, until you classify all critical \
points\
\>", "Text",
 FontSize->16],

Cell[BoxData[{
 RowBox[{
  RowBox[{"n", "=", 
   RowBox[{"n", "+", "1"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"type", "=", "\"\<no info\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"CP", "[", 
  RowBox[{"[", "n", "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"num1", "=", 
  RowBox[{
   RowBox[{"disc", "[", 
    RowBox[{"x", ",", "y"}], "]"}], "/.", 
   RowBox[{"CP", "[", 
    RowBox[{"[", "n", "]"}], "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"num2", "=", 
  RowBox[{
   RowBox[{"fxx", "[", 
    RowBox[{"x", ",", "y"}], "]"}], "/.", 
   RowBox[{"CP", "[", 
    RowBox[{"[", "n", "]"}], "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{"And", "[", 
     RowBox[{
      RowBox[{"num1", ">", "0"}], ",", 
      RowBox[{"num2", "<", "0"}]}], "]"}], ",", 
    RowBox[{"type", "=", "\"\<local max\>\""}]}], " ", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{"And", "[", 
     RowBox[{
      RowBox[{"num1", ">", "0"}], ",", 
      RowBox[{"num2", ">", "0"}]}], "]"}], ",", 
    RowBox[{"type", "=", "\"\<local min\>\""}]}], " ", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{"num1", "<", "0"}], ",", 
    RowBox[{"type", "=", "\"\<saddle point\>\""}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", "type", "]"}]}], "Input"],

Cell["Some graphs", "Text",
 FontSize->16],

Cell[BoxData[{
 RowBox[{
  RowBox[{"numCon", "=", "50"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"p1", "=", 
  RowBox[{"Plot3D", "[", 
   RowBox[{
    RowBox[{"f", "[", 
     RowBox[{"x", ",", "y"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "xlo", ",", "xhi"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", "ylo", ",", "yhi"}], "}"}], ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<x\>\"", ",", "\"\<y\>\"", ",", "\"\<z\>\""}], "}"}]}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"p2", "=", 
  RowBox[{"ContourPlot", "[", 
   RowBox[{
    RowBox[{"f", "[", 
     RowBox[{"x", ",", "y"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "xlo", ",", "xhi"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", "ylo", ",", "yhi"}], "}"}], ",", 
    RowBox[{"Contours", "\[Rule]", "numCon"}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.435207499375*^9, 3.4352075004375*^9}}],

Cell["\<\
Show the critical points on the surface and within the contour plot.\
\>", "Text",
 FontSize->16],

Cell[BoxData[
 RowBox[{"<<", "Graphics`Graphics3D`"}]], "Input",
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"Point", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"x", ",", "y", ",", 
       RowBox[{"f", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}], "}"}], "/.", 
     RowBox[{"CP", "[", 
      RowBox[{"[", "index", "]"}], "]"}]}], " ", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"index", ",", "1", ",", 
     RowBox[{"Length", "[", " ", "CP", " ", "]"}]}], "   ", "}"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"p1", ",", 
   RowBox[{"Graphics3D", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"PointSize", "[", "0.02", "]"}], ",", "%"}], "}"}], "]"}], ",", 
   
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], "Input",
 CellChangeTimes->{3.435207513421875*^9}],

Cell[BoxData[{
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"Point", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"x", ",", "y"}], "}"}], "/.", 
     RowBox[{"CP", "[", 
      RowBox[{"[", "index", "]"}], "]"}]}], " ", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"index", ",", "1", ",", 
     RowBox[{"Length", "[", " ", "CP", " ", "]"}]}], "   ", "}"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"p2", ",", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"PointSize", "[", "0.02", "]"}], ",", "%"}], "}"}], "]"}], ",", 
   
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], "Input",
 CellChangeTimes->{3.43520751440625*^9}]
}, Open  ]]
},
AutoGeneratedPackage->None,
WindowSize->{749, 644},
WindowMargins->{{1, Automatic}, {Automatic, 1}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
FrontEndVersion->"8.0 for Microsoft Windows (64-bit) (November 7, 2010)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 40, 0, 83, "Title"],
Cell[610, 24, 91, 3, 47, "Subsubtitle"],
Cell[704, 29, 36, 1, 33, "Text"],
Cell[743, 32, 359, 8, 52, "Input"],
Cell[1105, 42, 66, 1, 33, "Text"],
Cell[1174, 45, 274, 9, 31, "Input"],
Cell[1451, 56, 87, 2, 29, "Text"],
Cell[1541, 60, 150, 4, 33, "Text"],
Cell[1694, 66, 88, 2, 29, "Text"],
Cell[1785, 70, 431, 14, 52, "Input"],
Cell[2219, 86, 724, 24, 72, "Input"],
Cell[2946, 112, 390, 13, 31, "Input"],
Cell[3339, 127, 55, 1, 31, "Input"],
Cell[3397, 130, 105, 3, 30, "Text"],
Cell[3505, 135, 181, 6, 31, "Input"],
Cell[3689, 143, 271, 5, 47, "Text"],
Cell[3963, 150, 139, 4, 33, "Text"],
Cell[4105, 156, 60, 1, 31, "Input"],
Cell[4168, 159, 112, 3, 33, "Text"],
Cell[4283, 164, 557, 18, 31, "Input"],
Cell[4843, 184, 157, 4, 55, "Text"],
Cell[5003, 190, 1384, 43, 192, "Input"],
Cell[6390, 235, 123, 4, 33, "Text"],
Cell[6516, 241, 1408, 44, 192, "Input"],
Cell[7927, 287, 42, 1, 33, "Text"],
Cell[7972, 290, 942, 26, 72, "Input"],
Cell[8917, 318, 107, 3, 33, "Text"],
Cell[9027, 323, 91, 2, 31, "Input",
 InitializationCell->True],
Cell[9121, 327, 765, 23, 52, "Input"],
Cell[9889, 352, 690, 21, 52, "Input"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
