(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     45109,       1447]
NotebookOptionsPosition[     41938,       1341]
NotebookOutlinePosition[     42892,       1378]
CellTagsIndexPosition[     42821,       1373]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Lagrange Multipliers", "Title"],

Cell[CellGroupData[{

Cell["2D examples", "Subsection"],

Cell[BoxData[{
 RowBox[{"Clear", "[", 
  RowBox[{
  "f", ",", "g", ",", "fx", ",", "fy", ",", "gx", ",", "gy", ",", "x", ",", 
   "y", ",", "L", ",", "eqn", ",", "pts", ",", "nearPts"}], "]"}], "\n", 
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x_", ",", "y_"}], "]"}], ":=", " ", 
  RowBox[{
   SuperscriptBox["y", "2"], "-", 
   RowBox[{"4", " ", "x", "*", " ", "y"}], " ", "+", " ", 
   RowBox[{"4", " ", 
    SuperscriptBox["x", "2"]}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"fx", "[", 
   RowBox[{"x_", ",", "y_"}], "]"}], "=", 
  RowBox[{
   SubscriptBox["\[PartialD]", "x"], " ", 
   RowBox[{"f", "[", 
    RowBox[{"x", ",", "y"}], "]"}]}]}], "\n", 
 RowBox[{
  RowBox[{"fy", "[", 
   RowBox[{"x_", ",", "y_"}], "]"}], "=", 
  RowBox[{
   SubscriptBox["\[PartialD]", "y"], " ", 
   RowBox[{"f", "[", 
    RowBox[{"x", ",", "y"}], "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"g", "[", 
   RowBox[{"x_", ",", "y_"}], "]"}], ":=", " ", 
  RowBox[{
   SuperscriptBox["x", "2"], "+", "  ", 
   SuperscriptBox["y", "2"], " ", "-", " ", "1"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"gx", "[", 
   RowBox[{"x_", ",", "y_"}], "]"}], "=", 
  RowBox[{
   SubscriptBox["\[PartialD]", "x"], " ", 
   RowBox[{"g", "[", 
    RowBox[{"x", ",", "y"}], "]"}]}]}], "\n", 
 RowBox[{
  RowBox[{"gy", "[", 
   RowBox[{"x_", ",", "y_"}], "]"}], "=", 
  RowBox[{
   SubscriptBox["\[PartialD]", "y"], 
   RowBox[{"g", "[", 
    RowBox[{"x", ",", "y"}], "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"eqns", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"fx", "[", 
      RowBox[{"x", ",", "y"}], "]"}], " ", "==", " ", 
     RowBox[{"L", "*", " ", 
      RowBox[{"gx", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}]}], ",", 
    RowBox[{
     RowBox[{"fy", "[", 
      RowBox[{"x", ",", "y"}], "]"}], " ", "==", " ", 
     RowBox[{"L", "*", " ", 
      RowBox[{"gy", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}]}], ",", 
    RowBox[{
     RowBox[{"g", "[", 
      RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", "0"}]}], 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"pts", "=", 
  RowBox[{"Solve", "[", 
   RowBox[{"eqns", ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "y", ",", "L"}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "/.", "pts"}], "\[IndentingNewLine]", 
 RowBox[{"N", "[", 
  RowBox[{
   RowBox[{"f", "[", 
    RowBox[{"x", ",", "y"}], "]"}], "/.", "pts"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", "\"\<Beware if the gradient is zero!\>\"", 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"gx", "[", 
     RowBox[{"x", ",", "y"}], "]"}], ",", " ", 
    RowBox[{"gy", "[", 
     RowBox[{"x", ",", "y"}], "]"}]}], "}"}], "/.", 
  "pts"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", "\"\<Some points near the solutions\>\"", 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"nearPts", "=", 
  RowBox[{"N", "[", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"x", "+", 
         RowBox[{"a", "*", ".1"}]}], ",", 
        RowBox[{"y", "+", 
         RowBox[{"b", "*", ".1"}]}], ",", 
        RowBox[{"f", "[", 
         RowBox[{
          RowBox[{"x", "+", 
           RowBox[{"a", "*", ".1"}]}], ",", 
          RowBox[{"y", "+", 
           RowBox[{"b", "*", ".1"}]}]}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"a", ",", 
        RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"b", ",", 
        RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "]"}], "/.", "pts"}], 
   "]"}]}]}], "Input"],

Cell[CellGroupData[{

Cell["graph stuff", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"xlo", "=", 
   RowBox[{"ylo", "=", 
    RowBox[{"-", "2"}]}]}], ";", " ", 
  RowBox[{"xhi", "=", 
   RowBox[{"yhi", "=", "2"}]}], ";"}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"numCon", "=", "25"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"p1", "=", 
   RowBox[{"Plot3D", "[", 
    RowBox[{
     RowBox[{"f", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "xlo", ",", "xhi"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", "ylo", ",", "yhi"}], "}"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\"", ",", "\"\<z\>\""}], "}"}]}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"p2", "=", 
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{"f", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "xlo", ",", "xhi"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", "ylo", ",", "yhi"}], "}"}], ",", 
     RowBox[{"Contours", "\[Rule]", "numCon"}], ",", 
     RowBox[{"ContourShading", "\[Rule]", "False"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"ContourPlot", "[", 
  RowBox[{
   RowBox[{"g", "[", 
    RowBox[{"x", ",", "y"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "xlo", ",", "xhi"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", "ylo", ",", "yhi"}], "}"}], ",", 
   RowBox[{"Contours", "\[Rule]", "numCon"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"p2g", "=", 
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{"g", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "xlo", ",", "xhi"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", "ylo", ",", "yhi"}], "}"}], ",", 
     RowBox[{"Contours", "\[Rule]", "numCon"}], ",", 
     RowBox[{"ContourShading", "\[Rule]", "False"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"p2", ",", "p2g"}], "]"}]}], "Input",
 CellChangeTimes->{{3.428484477421875*^9, 3.42848448021875*^9}}],

Cell["<< Graphics`ImplicitPlot`", "Input",
 CellTags->"S5.35.1"],

Cell["p2ga=ImplicitPlot[g[x,y] == 0, {x,xlo,xhi}]", "Input",
 CellTags->"S5.35.1"],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"p2", ",", "p2ga"}], "]"}]], "Input",
 CellChangeTimes->{3.428484515109375*^9}],

Cell[BoxData[
 RowBox[{"<<", "Graphics`Graphics3D`"}]], "Input",
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"Point", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"x", ",", "y", ",", 
       RowBox[{"f", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}], "}"}], "/.", 
     RowBox[{"pts", "[", 
      RowBox[{"[", "index", "]"}], "]"}]}], " ", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"index", ",", "1", ",", 
     RowBox[{"Length", "[", " ", "pts", " ", "]"}]}], "   ", "}"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"p1", ",", 
   RowBox[{"Graphics3D", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"PointSize", "[", "0.2", "]"}], ",", "%"}], "}"}], "]"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], "Input",
 CellChangeTimes->{3.428484525015625*^9}],

Cell[BoxData[{
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"Point", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"x", ",", "y"}], "}"}], "/.", 
     RowBox[{"pts", "[", 
      RowBox[{"[", "index", "]"}], "]"}]}], " ", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"index", ",", "1", ",", 
     RowBox[{"Length", "[", " ", "pts", " ", "]"}]}], "   ", "}"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"p2", ",", "p2ga", ",", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"PointSize", "[", "0.02", "]"}], ",", "%"}], "}"}], "]"}], ",", 
   
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], "Input",
 CellChangeTimes->{3.42848452596875*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"xlo", "=", 
   RowBox[{"ylo", "=", 
    RowBox[{"-", "2"}]}]}], ";", " ", 
  RowBox[{"xhi", "=", 
   RowBox[{"yhi", "=", "2"}]}], ";"}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"numCon", "=", "25"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"p1", "=", 
   RowBox[{"Plot3D", "[", 
    RowBox[{
     RowBox[{"f", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "xlo", ",", "xhi"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", "ylo", ",", "yhi"}], "}"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\"", ",", "\"\<z\>\""}], "}"}]}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"p2", "=", 
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{"f", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "xlo", ",", "xhi"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", "ylo", ",", "yhi"}], "}"}], ",", 
     RowBox[{"Contours", "\[Rule]", "numCon"}], ",", 
     RowBox[{"ContourShading", "\[Rule]", "False"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"ContourPlot", "[", 
  RowBox[{
   RowBox[{"g", "[", 
    RowBox[{"x", ",", "y"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "xlo", ",", "xhi"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", "ylo", ",", "yhi"}], "}"}], ",", 
   RowBox[{"Contours", "\[Rule]", "numCon"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"p2g", "=", 
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{"g", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "xlo", ",", "xhi"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", "ylo", ",", "yhi"}], "}"}], ",", 
     RowBox[{"Contours", "\[Rule]", "numCon"}], ",", 
     RowBox[{"ContourShading", "\[Rule]", "False"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"p2", ",", "p2g"}], "]"}]}], "Input",
 CellChangeTimes->{{3.42848453771875*^9, 3.42848456725*^9}}],

Cell["<< Graphics`ImplicitPlot`", "Input",
 InitializationCell->True,
 CellTags->"S5.35.1"],

Cell["p2ga=ImplicitPlot[g[x,y] == 0, {x,xlo,xhi}]", "Input",
 CellTags->"S5.35.1"],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"p2", ",", "p2ga"}], "]"}]], "Input",
 CellChangeTimes->{3.428484577984375*^9}],

Cell[BoxData[
 RowBox[{"<<", "Graphics`Graphics3D`"}]], "Input",
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"Point", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"x", ",", "y", ",", 
       RowBox[{"f", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}], "}"}], "/.", 
     RowBox[{"pts", "[", 
      RowBox[{"[", "index", "]"}], "]"}]}], " ", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"index", ",", "1", ",", 
     RowBox[{"Length", "[", " ", "pts", " ", "]"}]}], "   ", "}"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"p1", ",", 
   RowBox[{"Graphics3D", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"PointSize", "[", "0.2", "]"}], ",", "%"}], "}"}], "]"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], "Input",
 CellChangeTimes->{3.4284845819375*^9}],

Cell[BoxData[{
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"Point", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"x", ",", "y"}], "}"}], "/.", 
     RowBox[{"pts", "[", 
      RowBox[{"[", "index", "]"}], "]"}]}], " ", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"index", ",", "1", ",", 
     RowBox[{"Length", "[", " ", "pts", " ", "]"}]}], "   ", "}"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"p2", ",", "p2ga", ",", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"PointSize", "[", "0.02", "]"}], ",", "%"}], "}"}], "]"}], ",", 
   
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], "Input",
 CellChangeTimes->{3.428484582671875*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["another 2D example", "Subsubsection"],

Cell[BoxData[{
 RowBox[{"Clear", "[", 
  RowBox[{
  "f", ",", "g", ",", "fx", ",", "fy", ",", "gx", ",", "gy", ",", "x", ",", 
   "y", ",", "L", ",", "eqn", ",", "pts", ",", "nearPts"}], "]"}], "\n", 
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x_", ",", "y_"}], "]"}], ":=", " ", 
  RowBox[{
   RowBox[{"2", " ", 
    SuperscriptBox["x", "2"]}], "+", " ", 
   RowBox[{"x", "*", " ", "y"}], " ", "-", " ", 
   SuperscriptBox["y", "2"], " ", "+", " ", "y"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"fx", "[", 
   RowBox[{"x_", ",", "y_"}], "]"}], "=", 
  RowBox[{
   SubscriptBox["\[PartialD]", "x"], " ", 
   RowBox[{"f", "[", 
    RowBox[{"x", ",", "y"}], "]"}]}]}], "\n", 
 RowBox[{
  RowBox[{"fy", "[", 
   RowBox[{"x_", ",", "y_"}], "]"}], "=", 
  RowBox[{
   SubscriptBox["\[PartialD]", "y"], " ", 
   RowBox[{"f", "[", 
    RowBox[{"x", ",", "y"}], "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"g", "[", 
    RowBox[{"x_", ",", "y_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"2", " ", "x"}], "+", " ", 
    RowBox[{"3", " ", "y"}], " ", "-", " ", "1"}]}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"gx", "[", 
   RowBox[{"x_", ",", "y_"}], "]"}], "=", 
  RowBox[{
   SubscriptBox["\[PartialD]", "x"], " ", 
   RowBox[{"g", "[", 
    RowBox[{"x", ",", "y"}], "]"}]}]}], "\n", 
 RowBox[{
  RowBox[{"gy", "[", 
   RowBox[{"x_", ",", "y_"}], "]"}], "=", 
  RowBox[{
   SubscriptBox["\[PartialD]", "y"], 
   RowBox[{"g", "[", 
    RowBox[{"x", ",", "y"}], "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"eqns", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"fx", "[", 
      RowBox[{"x", ",", "y"}], "]"}], " ", "==", " ", 
     RowBox[{"L", "*", " ", 
      RowBox[{"gx", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}]}], ",", 
    RowBox[{
     RowBox[{"fy", "[", 
      RowBox[{"x", ",", "y"}], "]"}], " ", "==", " ", 
     RowBox[{"L", "*", " ", 
      RowBox[{"gy", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}]}], ",", 
    RowBox[{
     RowBox[{"g", "[", 
      RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", "0"}]}], 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"pts", "=", 
  RowBox[{"Solve", "[", 
   RowBox[{"eqns", ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "y", ",", "L"}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "/.", "pts"}], "\[IndentingNewLine]", 
 RowBox[{"N", "[", 
  RowBox[{
   RowBox[{"f", "[", 
    RowBox[{"x", ",", "y"}], "]"}], "/.", "pts"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", "\"\<Beware if the gradient is zero!\>\"", 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"gx", "[", 
     RowBox[{"x", ",", "y"}], "]"}], ",", " ", 
    RowBox[{"gy", "[", 
     RowBox[{"x", ",", "y"}], "]"}]}], "}"}], "/.", 
  "pts"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", "\"\<Some points near the solutions\>\"", 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nearPts", "=", 
   RowBox[{"N", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"x", "+", 
          RowBox[{"a", "*", ".1"}]}], ",", 
         RowBox[{"y", "+", 
          RowBox[{"b", "*", ".1"}]}], ",", 
         RowBox[{"f", "[", 
          RowBox[{
           RowBox[{"x", "+", 
            RowBox[{"a", "*", ".1"}]}], ",", 
           RowBox[{"y", "+", 
            RowBox[{"b", "*", ".1"}]}]}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"a", ",", 
         RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"b", ",", 
         RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "]"}], "/.", "pts"}], 
    "]"}]}], "\[IndentingNewLine]"}], "\[IndentingNewLine]"}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["graph stuff", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"xlo", "=", 
   RowBox[{"ylo", "=", 
    RowBox[{"-", "2"}]}]}], ";", " ", 
  RowBox[{"xhi", "=", 
   RowBox[{"yhi", "=", "2"}]}], ";"}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"numCon", "=", "25"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"p1", "=", 
   RowBox[{"Plot3D", "[", 
    RowBox[{
     RowBox[{"f", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "xlo", ",", "xhi"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", "ylo", ",", "yhi"}], "}"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\"", ",", "\"\<z\>\""}], "}"}]}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"p2", "=", 
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{"f", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "xlo", ",", "xhi"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", "ylo", ",", "yhi"}], "}"}], ",", 
     RowBox[{"Contours", "\[Rule]", "numCon"}], ",", 
     RowBox[{"ContourShading", "\[Rule]", "False"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"ContourPlot", "[", 
  RowBox[{
   RowBox[{"g", "[", 
    RowBox[{"x", ",", "y"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "xlo", ",", "xhi"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", "ylo", ",", "yhi"}], "}"}], ",", 
   RowBox[{"Contours", "\[Rule]", "numCon"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"p2g", "=", 
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{"g", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "xlo", ",", "xhi"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", "ylo", ",", "yhi"}], "}"}], ",", 
     RowBox[{"Contours", "\[Rule]", "numCon"}], ",", 
     RowBox[{"ContourShading", "\[Rule]", "False"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"p2", ",", "p2g"}], "]"}]}], "Input",
 CellChangeTimes->{{3.42848460265625*^9, 3.428484605046875*^9}}],

Cell["<< Graphics`ImplicitPlot`", "Input",
 CellTags->"S5.35.1"],

Cell["p2ga=ImplicitPlot[g[x,y] == 0, {x,xlo,xhi}]", "Input",
 CellTags->"S5.35.1"],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"p2", ",", "p2ga"}], "]"}]], "Input",
 CellChangeTimes->{3.428484614359375*^9}],

Cell[BoxData[
 RowBox[{"<<", "Graphics`Graphics3D`"}]], "Input",
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"Point", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"x", ",", "y", ",", 
       RowBox[{"f", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}], "}"}], "/.", 
     RowBox[{"pts", "[", 
      RowBox[{"[", "index", "]"}], "]"}]}], " ", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"index", ",", "1", ",", 
     RowBox[{"Length", "[", " ", "pts", " ", "]"}]}], "   ", "}"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"p1", ",", 
   RowBox[{"Graphics3D", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"PointSize", "[", "0.2", "]"}], ",", "%"}], "}"}], "]"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], "Input",
 CellChangeTimes->{3.4284846185625*^9}],

Cell[BoxData[{
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"Point", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"x", ",", "y"}], "}"}], "/.", 
     RowBox[{"pts", "[", 
      RowBox[{"[", "index", "]"}], "]"}]}], " ", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"index", ",", "1", ",", 
     RowBox[{"Length", "[", " ", "pts", " ", "]"}]}], "   ", "}"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"p2", ",", "p2ga", ",", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"PointSize", "[", "0.02", "]"}], ",", "%"}], "}"}], "]"}], ",", 
   
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], "Input",
 CellChangeTimes->{3.428484622015625*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"xlo", "=", 
   RowBox[{"ylo", "=", 
    RowBox[{"-", "2"}]}]}], ";", " ", 
  RowBox[{"xhi", "=", 
   RowBox[{"yhi", "=", "2"}]}], ";"}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"numCon", "=", "25"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"p1", "=", 
   RowBox[{"Plot3D", "[", 
    RowBox[{
     RowBox[{"f", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "xlo", ",", "xhi"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", "ylo", ",", "yhi"}], "}"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\"", ",", "\"\<z\>\""}], "}"}]}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"p2", "=", 
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{"f", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "xlo", ",", "xhi"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", "ylo", ",", "yhi"}], "}"}], ",", 
     RowBox[{"Contours", "\[Rule]", "numCon"}], ",", 
     RowBox[{"ContourShading", "\[Rule]", "False"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"ContourPlot", "[", 
  RowBox[{
   RowBox[{"g", "[", 
    RowBox[{"x", ",", "y"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "xlo", ",", "xhi"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", "ylo", ",", "yhi"}], "}"}], ",", 
   RowBox[{"Contours", "\[Rule]", "numCon"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"p2g", "=", 
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{"g", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "xlo", ",", "xhi"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", "ylo", ",", "yhi"}], "}"}], ",", 
     RowBox[{"Contours", "\[Rule]", "numCon"}], ",", 
     RowBox[{"ContourShading", "\[Rule]", "False"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"p2", ",", "p2g"}], "]"}]}], "Input",
 CellChangeTimes->{{3.428484626453125*^9, 3.428484627578125*^9}}],

Cell["<< Graphics`ImplicitPlot`", "Input",
 CellTags->"S5.35.1"],

Cell["p2ga=ImplicitPlot[g[x,y] == 0, {x,xlo,xhi}]", "Input",
 CellChangeTimes->{{3.428484633640625*^9, 3.428484640484375*^9}},
 CellTags->"S5.35.1"],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"p2", ",", "p2ga"}], "]"}]], "Input",
 CellChangeTimes->{3.42848464553125*^9}],

Cell[BoxData[
 RowBox[{"<<", "Graphics`Graphics3D`"}]], "Input",
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"Point", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"x", ",", "y", ",", 
       RowBox[{"f", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}], "}"}], "/.", 
     RowBox[{"pts", "[", 
      RowBox[{"[", "index", "]"}], "]"}]}], " ", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"index", ",", "1", ",", 
     RowBox[{"Length", "[", " ", "pts", " ", "]"}]}], "   ", "}"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"p1", ",", 
   RowBox[{"Graphics3D", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"PointSize", "[", "0.2", "]"}], ",", "%"}], "}"}], "]"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], "Input",
 CellChangeTimes->{3.42848465375*^9}],

Cell[BoxData[{
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"Point", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"x", ",", "y"}], "}"}], "/.", 
     RowBox[{"pts", "[", 
      RowBox[{"[", "index", "]"}], "]"}]}], " ", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"index", ",", "1", ",", 
     RowBox[{"Length", "[", " ", "pts", " ", "]"}]}], "   ", "}"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"p2", ",", "p2ga", ",", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"PointSize", "[", "0.02", "]"}], ",", "%"}], "}"}], "]"}], ",", 
   
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], "Input",
 CellChangeTimes->{3.42848465284375*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["3D examples", "Subsection"],

Cell[BoxData[{
 RowBox[{"Clear", "[", 
  RowBox[{
  "f", ",", "g", ",", "fx", ",", "fy", ",", "fz", ",", "gx", ",", "gy", ",", 
   "gz", ",", "x", ",", "y", ",", "L", ",", "eqn", ",", "pts", ",", 
   "nearPts"}], "]"}], "\n", 
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x_", ",", "y_", ",", "z_"}], "]"}], ":=", " ", 
  RowBox[{
   SuperscriptBox["x", "2"], "+", 
   SuperscriptBox["y", "2"], "+", 
   SuperscriptBox["z", "2"]}]}], "\n", 
 RowBox[{
  RowBox[{"fx", "[", 
   RowBox[{"x_", ",", "y_", ",", "z_"}], "]"}], "=", 
  RowBox[{
   SubscriptBox["\[PartialD]", "x"], " ", 
   RowBox[{"f", "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}]}]}], "\n", 
 RowBox[{
  RowBox[{"fy", "[", 
   RowBox[{"x_", ",", "y_", ",", "z_"}], "]"}], "=", 
  RowBox[{
   SubscriptBox["\[PartialD]", "y"], " ", 
   RowBox[{"f", "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}]}]}], "\n", 
 RowBox[{
  RowBox[{"fz", "[", 
   RowBox[{"x_", ",", "y_", ",", "z_"}], "]"}], "=", 
  RowBox[{
   SubscriptBox["\[PartialD]", "z"], " ", 
   RowBox[{"f", "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}]}]}], "\n", 
 RowBox[{
  RowBox[{"g", "[", 
   RowBox[{"x_", ",", "y_", ",", "z_"}], "]"}], ":=", " ", 
  RowBox[{
  "x", " ", "+", " ", "y", " ", "+", " ", "z", " ", "-", " ", 
   "25"}]}], "\n", 
 RowBox[{
  RowBox[{"gx", "[", 
   RowBox[{"x_", ",", "y_", ",", "z_"}], "]"}], "=", 
  RowBox[{
   SubscriptBox["\[PartialD]", "x"], " ", 
   RowBox[{"g", "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}]}]}], "\n", 
 RowBox[{
  RowBox[{"gy", "[", 
   RowBox[{"x_", ",", "y_", ",", "z_"}], "]"}], "=", 
  RowBox[{
   SubscriptBox["\[PartialD]", "y"], 
   RowBox[{"g", "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}]}]}], "\n", 
 RowBox[{
  RowBox[{"gz", "[", 
   RowBox[{"x_", ",", "y_", ",", "z_"}], "]"}], "=", 
  RowBox[{
   SubscriptBox["\[PartialD]", "z"], 
   RowBox[{"g", "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}]}]}], "\n", 
 RowBox[{"eqns", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"fx", "[", 
      RowBox[{"x", ",", "y", ",", "z"}], "]"}], " ", "==", " ", 
     RowBox[{"L", "*", " ", 
      RowBox[{"gx", "[", 
       RowBox[{"x", ",", "y", ",", "z"}], "]"}]}]}], ",", 
    RowBox[{
     RowBox[{"fy", "[", 
      RowBox[{"x", ",", "y", ",", "z"}], "]"}], " ", "==", " ", 
     RowBox[{"L", "*", " ", 
      RowBox[{"gy", "[", 
       RowBox[{"x", ",", "y", ",", "z"}], "]"}]}]}], ",", 
    RowBox[{
     RowBox[{"fz", "[", 
      RowBox[{"x", ",", "y", ",", "z"}], "]"}], " ", "==", " ", 
     RowBox[{"L", "*", " ", 
      RowBox[{"gz", "[", 
       RowBox[{"x", ",", "y", ",", "z"}], "]"}]}]}], ",", 
    RowBox[{
     RowBox[{"g", "[", 
      RowBox[{"x", ",", "y", ",", "z"}], "]"}], "\[Equal]", "0"}]}], 
   "}"}]}], "\n", 
 RowBox[{"pts", "=", 
  RowBox[{"Solve", "[", 
   RowBox[{"eqns", ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "y", ",", "z", ",", "L"}], "}"}]}], "]"}]}], "\n", 
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y", ",", "z"}], "]"}], "/.", "pts"}], "\n", 
 RowBox[{"N", "[", 
  RowBox[{
   RowBox[{"f", "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}], "/.", "pts"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", "\"\<Beware if the gradient is zero!\>\"", 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"gx", "[", 
     RowBox[{"x", ",", "y", ",", "z"}], "]"}], ",", " ", 
    RowBox[{"gy", "[", 
     RowBox[{"x", ",", "y", ",", "z"}], "]"}], ",", " ", 
    RowBox[{"gz", "[", 
     RowBox[{"x", ",", "y", ",", "z"}], "]"}]}], "}"}], "/.", 
  "pts"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", "\"\<Some points near the solutions\>\"", 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nearPts", "=", 
   RowBox[{"N", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"x", "+", 
          RowBox[{"a", "*", ".1"}]}], ",", 
         RowBox[{"y", "+", 
          RowBox[{"b", "*", ".1"}]}], ",", 
         RowBox[{"z", "+", " ", 
          RowBox[{"c", "*", ".1"}]}], ",", 
         RowBox[{"f", "[", 
          RowBox[{
           RowBox[{"x", "+", 
            RowBox[{"a", "*", ".1"}]}], ",", 
           RowBox[{"y", "+", 
            RowBox[{"b", "*", ".1"}]}], ",", 
           RowBox[{"z", "+", 
            RowBox[{"c", "*", ".1"}]}]}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"a", ",", 
         RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"b", ",", 
         RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"c", ",", 
         RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "]"}], "/.", "pts"}], 
    "]"}]}], "\[IndentingNewLine]"}], "\[IndentingNewLine]"}], "Input"],

Cell[BoxData[{
 RowBox[{"Clear", "[", 
  RowBox[{
  "f", ",", "g", ",", "fx", ",", "fy", ",", "fz", ",", "gx", ",", "gy", ",", 
   "gz", ",", "x", ",", "y", ",", "L", ",", "eqn", ",", "pts", ",", 
   "nearPts"}], "]"}], "\n", 
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x_", ",", "y_", ",", "z_"}], "]"}], ":=", " ", 
  RowBox[{"z", " ", "-", " ", 
   SuperscriptBox["x", "2"], "+", 
   SuperscriptBox["y", "2"]}]}], "\n", 
 RowBox[{
  RowBox[{"fx", "[", 
   RowBox[{"x_", ",", "y_", ",", "z_"}], "]"}], "=", 
  RowBox[{
   SubscriptBox["\[PartialD]", "x"], " ", 
   RowBox[{"f", "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}]}]}], "\n", 
 RowBox[{
  RowBox[{"fy", "[", 
   RowBox[{"x_", ",", "y_", ",", "z_"}], "]"}], "=", 
  RowBox[{
   SubscriptBox["\[PartialD]", "y"], " ", 
   RowBox[{"f", "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}]}]}], "\n", 
 RowBox[{
  RowBox[{"fz", "[", 
   RowBox[{"x_", ",", "y_", ",", "z_"}], "]"}], "=", 
  RowBox[{
   SubscriptBox["\[PartialD]", "z"], " ", 
   RowBox[{"f", "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}]}]}], "\n", 
 RowBox[{
  RowBox[{"g", "[", 
   RowBox[{"x_", ",", "y_", ",", "z_"}], "]"}], ":=", " ", 
  RowBox[{
  "x", " ", "+", " ", "y", " ", "+", " ", "z", " ", "-", "1"}]}], "\n", 
 RowBox[{
  RowBox[{"gx", "[", 
   RowBox[{"x_", ",", "y_", ",", "z_"}], "]"}], "=", 
  RowBox[{
   SubscriptBox["\[PartialD]", "x"], " ", 
   RowBox[{"g", "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}]}]}], "\n", 
 RowBox[{
  RowBox[{"gy", "[", 
   RowBox[{"x_", ",", "y_", ",", "z_"}], "]"}], "=", 
  RowBox[{
   SubscriptBox["\[PartialD]", "y"], 
   RowBox[{"g", "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}]}]}], "\n", 
 RowBox[{
  RowBox[{"gz", "[", 
   RowBox[{"x_", ",", "y_", ",", "z_"}], "]"}], "=", 
  RowBox[{
   SubscriptBox["\[PartialD]", "z"], 
   RowBox[{"g", "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}]}]}], "\n", 
 RowBox[{"eqns", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"fx", "[", 
      RowBox[{"x", ",", "y", ",", "z"}], "]"}], " ", "==", " ", 
     RowBox[{"L", "*", " ", 
      RowBox[{"gx", "[", 
       RowBox[{"x", ",", "y", ",", "z"}], "]"}]}]}], ",", 
    RowBox[{
     RowBox[{"fy", "[", 
      RowBox[{"x", ",", "y", ",", "z"}], "]"}], " ", "==", " ", 
     RowBox[{"L", "*", " ", 
      RowBox[{"gy", "[", 
       RowBox[{"x", ",", "y", ",", "z"}], "]"}]}]}], ",", 
    RowBox[{
     RowBox[{"fz", "[", 
      RowBox[{"x", ",", "y", ",", "z"}], "]"}], " ", "==", " ", 
     RowBox[{"L", "*", " ", 
      RowBox[{"gz", "[", 
       RowBox[{"x", ",", "y", ",", "z"}], "]"}]}]}], ",", 
    RowBox[{
     RowBox[{"g", "[", 
      RowBox[{"x", ",", "y", ",", "z"}], "]"}], "\[Equal]", "0"}]}], 
   "}"}]}], "\n", 
 RowBox[{"pts", "=", 
  RowBox[{"Solve", "[", 
   RowBox[{"eqns", ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "y", ",", "z", ",", "L"}], "}"}]}], "]"}]}], "\n", 
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y", ",", "z"}], "]"}], "/.", "pts"}], "\n", 
 RowBox[{"N", "[", 
  RowBox[{
   RowBox[{"f", "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}], "/.", "pts"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", "\"\<Beware if the gradient is zero!\>\"", 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"gx", "[", 
     RowBox[{"x", ",", "y", ",", "z"}], "]"}], ",", " ", 
    RowBox[{"gy", "[", 
     RowBox[{"x", ",", "y", ",", "z"}], "]"}], ",", " ", 
    RowBox[{"gz", "[", 
     RowBox[{"x", ",", "y", ",", "z"}], "]"}]}], "}"}], "/.", 
  "pts"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", "\"\<Some points near the solutions\>\"", 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nearPts", "=", 
   RowBox[{"N", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"x", "+", 
          RowBox[{"a", "*", ".1"}]}], ",", 
         RowBox[{"y", "+", 
          RowBox[{"b", "*", ".1"}]}], ",", 
         RowBox[{"z", "+", " ", 
          RowBox[{"c", "*", ".1"}]}], ",", 
         RowBox[{"f", "[", 
          RowBox[{
           RowBox[{"x", "+", 
            RowBox[{"a", "*", ".1"}]}], ",", 
           RowBox[{"y", "+", 
            RowBox[{"b", "*", ".1"}]}], ",", 
           RowBox[{"z", "+", 
            RowBox[{"c", "*", ".1"}]}]}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"a", ",", 
         RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"b", ",", 
         RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"c", ",", 
         RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "]"}], "/.", "pts"}], 
    "]"}]}], "\[IndentingNewLine]"}], "\[IndentingNewLine]"}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["blank templates, ready to fill in", "Subsection"],

Cell[BoxData[{
 RowBox[{"Clear", "[", 
  RowBox[{
  "f", ",", "g", ",", "fx", ",", "fy", ",", "gx", ",", "gy", ",", "x", ",", 
   "y", ",", "L", ",", "eqn", ",", "pts", ",", "nearPts"}], "]"}], "\n", 
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x_", ",", "y_"}], "]"}], ":=", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"fx", "[", 
    RowBox[{"x_", ",", "y_"}], "]"}], "=", 
   RowBox[{
    SubscriptBox["\[PartialD]", "x"], " ", 
    RowBox[{"f", "[", 
     RowBox[{"x", ",", "y"}], "]"}]}]}]}], "\n", 
 RowBox[{
  RowBox[{"fy", "[", 
   RowBox[{"x_", ",", "y_"}], "]"}], "=", 
  RowBox[{
   SubscriptBox["\[PartialD]", "y"], " ", 
   RowBox[{"f", "[", 
    RowBox[{"x", ",", "y"}], "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"g", "[", 
   RowBox[{"x_", ",", "y_"}], "]"}], ":=", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"gx", "[", 
    RowBox[{"x_", ",", "y_"}], "]"}], "=", 
   RowBox[{
    SubscriptBox["\[PartialD]", "x"], " ", 
    RowBox[{"g", "[", 
     RowBox[{"x", ",", "y"}], "]"}]}]}]}], "\n", 
 RowBox[{
  RowBox[{"gy", "[", 
   RowBox[{"x_", ",", "y_"}], "]"}], "=", 
  RowBox[{
   SubscriptBox["\[PartialD]", "y"], 
   RowBox[{"g", "[", 
    RowBox[{"x", ",", "y"}], "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"eqns", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"fx", "[", 
      RowBox[{"x", ",", "y"}], "]"}], " ", "==", " ", 
     RowBox[{"L", "*", " ", 
      RowBox[{"gx", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}]}], ",", 
    RowBox[{
     RowBox[{"fy", "[", 
      RowBox[{"x", ",", "y"}], "]"}], " ", "==", " ", 
     RowBox[{"L", "*", " ", 
      RowBox[{"gy", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}]}], ",", 
    RowBox[{
     RowBox[{"g", "[", 
      RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", "0"}]}], 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"pts", "=", 
  RowBox[{"Solve", "[", 
   RowBox[{"eqns", ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "y", ",", "L"}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "/.", "pts"}], "\[IndentingNewLine]", 
 RowBox[{"N", "[", 
  RowBox[{
   RowBox[{"f", "[", 
    RowBox[{"x", ",", "y"}], "]"}], "/.", "pts"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", "\"\<Beware if the gradient is zero!\>\"", 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"gx", "[", 
     RowBox[{"x", ",", "y"}], "]"}], ",", " ", 
    RowBox[{"gy", "[", 
     RowBox[{"x", ",", "y"}], "]"}]}], "}"}], "/.", 
  "pts"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", "\"\<Some points near the solutions\>\"", 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"nearPts", "=", 
  RowBox[{"N", "[", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"x", "+", 
         RowBox[{"a", "*", ".1"}]}], ",", 
        RowBox[{"y", "+", 
         RowBox[{"b", "*", ".1"}]}], ",", 
        RowBox[{"f", "[", 
         RowBox[{
          RowBox[{"x", "+", 
           RowBox[{"a", "*", ".1"}]}], ",", 
          RowBox[{"y", "+", 
           RowBox[{"b", "*", ".1"}]}]}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"a", ",", 
        RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"b", ",", 
        RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "]"}], "/.", "pts"}], 
   "]"}]}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{3.4284846945*^9}],

Cell[BoxData[{
 RowBox[{"Clear", "[", 
  RowBox[{
  "f", ",", "g", ",", "fx", ",", "fy", ",", "fz", ",", "gx", ",", "gy", ",", 
   "gz", ",", "x", ",", "y", ",", "L", ",", "eqn", ",", "pts", ",", 
   "nearPts"}], "]"}], "\n", 
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x_", ",", "y_", ",", "z_"}], "]"}], ":=", "\n", 
  RowBox[{
   RowBox[{"fx", "[", 
    RowBox[{"x_", ",", "y_", ",", "z_"}], "]"}], "=", 
   RowBox[{
    SubscriptBox["\[PartialD]", "x"], " ", 
    RowBox[{"f", "[", 
     RowBox[{"x", ",", "y", ",", "z"}], "]"}]}]}]}], "\n", 
 RowBox[{
  RowBox[{"fy", "[", 
   RowBox[{"x_", ",", "y_", ",", "z_"}], "]"}], "=", 
  RowBox[{
   SubscriptBox["\[PartialD]", "y"], " ", 
   RowBox[{"f", "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}]}]}], "\n", 
 RowBox[{
  RowBox[{"fz", "[", 
   RowBox[{"x_", ",", "y_", ",", "z_"}], "]"}], "=", 
  RowBox[{
   SubscriptBox["\[PartialD]", "z"], " ", 
   RowBox[{"f", "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}]}]}], "\n", 
 RowBox[{
  RowBox[{"g", "[", 
   RowBox[{"x_", ",", "y_", ",", "z_"}], "]"}], ":=", " ", "\n", 
  RowBox[{
   RowBox[{"gx", "[", 
    RowBox[{"x_", ",", "y_", ",", "z_"}], "]"}], "=", 
   RowBox[{
    SubscriptBox["\[PartialD]", "x"], " ", 
    RowBox[{"g", "[", 
     RowBox[{"x", ",", "y", ",", "z"}], "]"}]}]}]}], "\n", 
 RowBox[{
  RowBox[{"gy", "[", 
   RowBox[{"x_", ",", "y_", ",", "z_"}], "]"}], "=", 
  RowBox[{
   SubscriptBox["\[PartialD]", "y"], 
   RowBox[{"g", "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}]}]}], "\n", 
 RowBox[{
  RowBox[{"gz", "[", 
   RowBox[{"x_", ",", "y_", ",", "z_"}], "]"}], "=", 
  RowBox[{
   SubscriptBox["\[PartialD]", "z"], 
   RowBox[{"g", "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}]}]}], "\n", 
 RowBox[{"eqns", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"fx", "[", 
      RowBox[{"x", ",", "y", ",", "z"}], "]"}], " ", "==", " ", 
     RowBox[{"L", "*", " ", 
      RowBox[{"gx", "[", 
       RowBox[{"x", ",", "y", ",", "z"}], "]"}]}]}], ",", 
    RowBox[{
     RowBox[{"fy", "[", 
      RowBox[{"x", ",", "y", ",", "z"}], "]"}], " ", "==", " ", 
     RowBox[{"L", "*", " ", 
      RowBox[{"gy", "[", 
       RowBox[{"x", ",", "y", ",", "z"}], "]"}]}]}], ",", 
    RowBox[{
     RowBox[{"fz", "[", 
      RowBox[{"x", ",", "y", ",", "z"}], "]"}], " ", "==", " ", 
     RowBox[{"L", "*", " ", 
      RowBox[{"gz", "[", 
       RowBox[{"x", ",", "y", ",", "z"}], "]"}]}]}], ",", 
    RowBox[{
     RowBox[{"g", "[", 
      RowBox[{"x", ",", "y", ",", "z"}], "]"}], "\[Equal]", "0"}]}], 
   "}"}]}], "\n", 
 RowBox[{"pts", "=", 
  RowBox[{"Solve", "[", 
   RowBox[{"eqns", ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "y", ",", "z", ",", "L"}], "}"}]}], "]"}]}], "\n", 
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y", ",", "z"}], "]"}], "/.", "pts"}], "\n", 
 RowBox[{"N", "[", 
  RowBox[{
   RowBox[{"f", "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}], "/.", "pts"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", "\"\<Beware if the gradient is zero!\>\"", 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"gx", "[", 
     RowBox[{"x", ",", "y", ",", "z"}], "]"}], ",", " ", 
    RowBox[{"gy", "[", 
     RowBox[{"x", ",", "y", ",", "z"}], "]"}], ",", " ", 
    RowBox[{"gz", "[", 
     RowBox[{"x", ",", "y", ",", "z"}], "]"}]}], "}"}], "/.", 
  "pts"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", "\"\<Some points near the solutions\>\"", 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nearPts", "=", 
   RowBox[{"N", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"x", "+", 
          RowBox[{"a", "*", ".1"}]}], ",", 
         RowBox[{"y", "+", 
          RowBox[{"b", "*", ".1"}]}], ",", 
         RowBox[{"z", "+", " ", 
          RowBox[{"c", "*", ".1"}]}], ",", 
         RowBox[{"f", "[", 
          RowBox[{
           RowBox[{"x", "+", 
            RowBox[{"a", "*", ".1"}]}], ",", 
           RowBox[{"y", "+", 
            RowBox[{"b", "*", ".1"}]}], ",", 
           RowBox[{"z", "+", 
            RowBox[{"c", "*", ".1"}]}]}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"a", ",", 
         RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"b", ",", 
         RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"c", ",", 
         RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "]"}], "/.", "pts"}], 
    "]"}]}], "\[IndentingNewLine]"}], "\[IndentingNewLine]"}], "Input"]
}, Open  ]]
}, Open  ]]
},
AutoGeneratedPackage->None,
WindowSize->{632, 624},
WindowMargins->{{9, Automatic}, {6, Automatic}},
FrontEndVersion->"8.0 for Microsoft Windows (64-bit) (November 7, 2010)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "S5.35.1"->{
  Cell[6492, 214, 64, 1, 31, "Input",
   CellTags->"S5.35.1"],
  Cell[6559, 217, 82, 1, 31, "Input",
   CellTags->"S5.35.1"],
  Cell[10457, 341, 91, 2, 31, "Input",
   InitializationCell->True,
   CellTags->"S5.35.1"],
  Cell[10551, 345, 82, 1, 31, "Input",
   CellTags->"S5.35.1"],
  Cell[18365, 599, 64, 1, 31, "Input",
   CellTags->"S5.35.1"],
  Cell[18432, 602, 82, 1, 31, "Input",
   CellTags->"S5.35.1"],
  Cell[22334, 726, 64, 1, 31, "Input",
   CellTags->"S5.35.1"],
  Cell[22401, 729, 148, 2, 31, "Input",
   CellTags->"S5.35.1"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"S5.35.1", 42257, 1352}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 37, 0, 83, "Title"],
Cell[CellGroupData[{
Cell[629, 26, 33, 0, 36, "Subsection"],
Cell[665, 28, 3642, 115, 352, "Input"],
Cell[CellGroupData[{
Cell[4332, 147, 36, 0, 27, "Subsubsection"],
Cell[4371, 149, 181, 6, 31, "Input"],
Cell[4555, 157, 1934, 55, 192, "Input"],
Cell[6492, 214, 64, 1, 31, "Input",
 CellTags->"S5.35.1"],
Cell[6559, 217, 82, 1, 31, "Input",
 CellTags->"S5.35.1"],
Cell[6644, 220, 126, 3, 31, "Input"],
Cell[6773, 225, 91, 2, 31, "Input",
 InitializationCell->True],
Cell[6867, 229, 762, 22, 52, "Input"],
Cell[7632, 253, 705, 21, 52, "Input"],
Cell[8340, 276, 181, 6, 31, "Input"],
Cell[8524, 284, 1930, 55, 132, "Input"],
Cell[10457, 341, 91, 2, 31, "Input",
 InitializationCell->True,
 CellTags->"S5.35.1"],
Cell[10551, 345, 82, 1, 31, "Input",
 CellTags->"S5.35.1"],
Cell[10636, 348, 126, 3, 31, "Input"],
Cell[10765, 353, 91, 2, 31, "Input",
 InitializationCell->True],
Cell[10859, 357, 760, 22, 52, "Input"],
Cell[11622, 381, 706, 21, 52, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12365, 407, 43, 0, 28, "Subsubsection"],
Cell[12411, 409, 3757, 118, 352, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[16205, 532, 36, 0, 28, "Subsubsection"],
Cell[16244, 534, 181, 6, 31, "Input"],
Cell[16428, 542, 1934, 55, 132, "Input"],
Cell[18365, 599, 64, 1, 31, "Input",
 CellTags->"S5.35.1"],
Cell[18432, 602, 82, 1, 31, "Input",
 CellTags->"S5.35.1"],
Cell[18517, 605, 126, 3, 31, "Input"],
Cell[18646, 610, 91, 2, 31, "Input",
 InitializationCell->True],
Cell[18740, 614, 760, 22, 52, "Input"],
Cell[19503, 638, 706, 21, 52, "Input"],
Cell[20212, 661, 181, 6, 31, "Input"],
Cell[20396, 669, 1935, 55, 132, "Input"],
Cell[22334, 726, 64, 1, 31, "Input",
 CellTags->"S5.35.1"],
Cell[22401, 729, 148, 2, 31, "Input",
 CellTags->"S5.35.1"],
Cell[22552, 733, 125, 3, 31, "Input"],
Cell[22680, 738, 91, 2, 31, "Input",
 InitializationCell->True],
Cell[22774, 742, 758, 22, 52, "Input"],
Cell[23535, 766, 705, 21, 52, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[24289, 793, 33, 0, 36, "Subsection"],
Cell[24325, 795, 4753, 144, 392, "Input"],
Cell[29081, 941, 4728, 142, 392, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[33846, 1088, 55, 0, 36, "Subsection"],
Cell[33904, 1090, 3440, 108, 332, "Input"],
Cell[37347, 1200, 4563, 137, 392, "Input"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
