(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      7505,        210]*)
(*NotebookOutlinePosition[      8354,        238]*)
(*  CellTagsIndexPosition[      8310,        234]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Labs with Parametric Plots", "Title"],

Cell[TextData[{
  StyleBox["Dr. Therese Shelton",
    FontSize->13],
  "\n",
  StyleBox["Southwestern University\nGeorgetown, TX",
    FontSize->16]
}], "Subsubtitle",
  FontSize->12],

Cell[CellGroupData[{

Cell["\<\
Reinforcing the links between component graphs
of parametric plots
in the dynamical systems mindset.\
\>", "Subtitle"],

Cell["\<\
Caution:  remember that you may have to tweak some things if you \
change functions or graphing windows.\
\>", "Text",
  CellDingbat->"\[HappySmiley]",
  CellMargins->{{91, Inherited}, {Inherited, Inherited}},
  FontFamily->"Courier",
  FontSize->14],

Cell["\<\
Suggestion:  Execute this notebook as-is.  Then change the \
functions and the graphing window and re-execute.  You can also change \
numberIntervals.\
\>", "Text"],

Cell[BoxData[{\(Clear[x, y, tmin, tmax, xmin, xmax, ymin, 
        ymax];\), "\[IndentingNewLine]", \(x[t_] := 
        Cos[t];\), "\[IndentingNewLine]", \(y[t_] := 
        Sin[t];\), "\[IndentingNewLine]", 
    RowBox[{\(tmin\  = \ 0.0;\), 
      " "}], "\[IndentingNewLine]", \(tmax\  = \ 
        2  \[Pi];\), "\[IndentingNewLine]", \(xmin\  = \ \(-1.25\);\), "\
\[IndentingNewLine]", \(xmax = 
        1.25;\), "\[IndentingNewLine]", \(ymin\  = \ \(-1.25\);\), "\
\[IndentingNewLine]", \(ymax = 1.25;\)}], "Input"],

Cell[BoxData[{
    \(\(\(Clear[colorx, colory, colorr, \ colx, coly, 
      colr]\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(colorr = RGBColor[0. ,  .79002,  .34007];\)\), "\n", 
    \(\(colorx = RGBColor[1. , 0. , 0. ];\)\ \), "\n", 
    \(\(\(colory = RGBColor[0. , 0. , 1. ];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(colx = "\<red\>";\)\), "\[IndentingNewLine]", 
    \(\(coly = "\<blue\>";\)\), "\[IndentingNewLine]", 
    \(\(\(colr = "\<green\>";\)\(\[IndentingNewLine]\)
    \)\)}], "Input"],

Cell[BoxData[{
    RowBox[{
      StyleBox[\(Clear[numberIntervals, deltat];\),
        Background->None], 
      StyleBox["\[IndentingNewLine]",
        Background->None]}], "\[IndentingNewLine]", 
    RowBox[{
      StyleBox[\(numberIntervals\  = \ 10;\),
        Background->None], 
      "\n"}], "\[IndentingNewLine]", \(deltat = \((tmax - tmin)\)/
        numberIntervals\)}], "Input"],

Cell["\<\
It may be beneficial to break up the following into smaller \
segments.  For example, combine just two plots at a time.\
\>", "Text",
  CellDingbat->"\[HappySmiley]",
  CellMargins->{{91, Inherited}, {Inherited, Inherited}},
  FontFamily->"Courier",
  FontSize->14],

Cell[BoxData[{
    \(Clear[q, p, pyINxy, pyINty, pxINxy, pxINtx]\), "\n", 
    \(p[q_] := \[IndentingNewLine]ParametricPlot[{{x[t], y[t]}, {x[q], 
            y[q]}}, {t, tmin, tmax}, 
        PlotStyle \[Rule] {{colorr, Thickness[ .015]}, {Thickness[ .04]}}, 
        PlotRange \[Rule] {{xmax, xmin}, {ymax, ymin}}, 
        AxesLabel \[Rule] {"\<x[t]\>", "\<y[t]\>"}, 
        AspectRatio \[Rule] 
          Automatic, \[IndentingNewLine]DisplayFunction \[Rule] 
          Identity]\), "\n", 
    \(pyINxy[
        q_] := \[IndentingNewLine]ParametricPlot[{{0, y[t]}, {0, y[q]}}, {t, 
          tmin, tmax}, 
        PlotStyle \[Rule] {{colory, Thickness[ .015]}, {Thickness[ .04]}}, 
        PlotRange \[Rule] {{xmax, xmin}, {ymax, ymin}}, 
        AxesLabel \[Rule] {"\<x[t]\>", "\<y[t]\>"}, \
\[IndentingNewLine]AspectRatio \[Rule] 
          Automatic, \[IndentingNewLine]DisplayFunction \[Rule] 
          Identity]\), "\n", 
    \(pyINty[
        q_] := \[IndentingNewLine]ParametricPlot[{{t, y[t]}, {q, y[q]}}, {t, 
          tmin, tmax}, 
        PlotStyle \[Rule] {{colory, Thickness[ .015]}, {Thickness[ .04]}}, 
        PlotRange \[Rule] {{tmax, tmin}, {ymax, ymin}}, 
        AxesLabel \[Rule] {"\<t\>", "\<y[t]\>"}, \
\[IndentingNewLine]DisplayFunction \[Rule] Identity]\), "\n", 
    \(pxINxy[
        q_] := \[IndentingNewLine]ParametricPlot[{{x[t], 0}, {x[q], 0}}, {t, 
          tmin, tmax}, 
        PlotStyle \[Rule] {{colorx, Thickness[ .015]}, {Thickness[ .04]}}, 
        PlotRange \[Rule] {{xmax, xmin}, {ymax, ymin}}, 
        AxesLabel \[Rule] {"\<x[t]\>", "\<y[t]\>"}, \
\[IndentingNewLine]AspectRatio \[Rule] 
          Automatic, \[IndentingNewLine]DisplayFunction \[Rule] 
          Identity]\), "\n", 
    \(pxINtx[
        q_] := \[IndentingNewLine]ParametricPlot[{{x[t], t}, {x[q], q}}, {t, 
          tmin, tmax}, 
        PlotStyle \[Rule] {{colorx, 
              Thickness[ .015]}, {Thickness[ .04]}}, \
\[IndentingNewLine]PlotRange \[Rule] {{xmax, xmin}, {tmax, 
              tmin}}, \[IndentingNewLine]AxesLabel \[Rule] {"\<x[t]\>", \
"\<t\>"}, \[IndentingNewLine]DisplayFunction \[Rule] Identity]\)}], "Input"],

Cell["\<\
parametric plot in x-y plane, then y[t] shadow in x-y plane, then \
y[t] vs t.
Note that the length of the y-axis (and hence the scale) is different on the \
t-y plot.\
\>", "Text",
  FontSize->15],

Cell[BoxData[
    \(Do[Show[\[IndentingNewLine]GraphicsArray[{p[q], pyINxy[q], 
            pyINty[q]\ }]\ ], \[IndentingNewLine]{q, tmin, tmax, 
        deltat}\[IndentingNewLine]]\)], "Input"],

Cell["\<\
parametric plot in x-y plane, then x[t] shadow in x-y plane, then \
x[t] vs t\
\>", "Text",
  FontSize->15],

Cell[BoxData[
    \(Do[Show[\[IndentingNewLine]GraphicsArray[{{p[q]}, {pxINxy[
                q]\ }, {pxINtx[q]}}]\ ], \[IndentingNewLine]{q, tmin, tmax, 
        deltat}\[IndentingNewLine]]\)], "Input"],

Cell["all together", "Text",
  FontSize->15],

Cell[BoxData[
    \(Do[Show[\[IndentingNewLine]GraphicsArray[{{p[q], pyINxy[q], 
              pyINty[q]\ }, \[IndentingNewLine]{pxINxy[q]\ }, {pxINtx[
                q]}}]\ ], \[IndentingNewLine]{q, tmin, tmax, 
        deltat}\[IndentingNewLine]]\)], "Input"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 746}},
WindowSize->{768, 706},
WindowMargins->{{Automatic, 44}, {8, Automatic}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
PrintingOptions->{"PrintingMargins"->{{54, 54}, {54, 54}},
"PrintCellBrackets"->False,
"PrintRegistrationMarks"->True,
"PrintMultipleHorizontalPages"->False}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 43, 0, 108, "Title"],
Cell[1773, 54, 183, 7, 86, "Subsubtitle"],

Cell[CellGroupData[{
Cell[1981, 65, 128, 4, 125, "Subtitle"],
Cell[2112, 71, 260, 7, 50, "Text"],
Cell[2375, 80, 174, 4, 32, "Text"],
Cell[2552, 86, 519, 9, 155, "Input"],
Cell[3074, 97, 531, 11, 171, "Input"],
Cell[3608, 110, 390, 10, 91, "Input"],
Cell[4001, 122, 275, 7, 50, "Text"],
Cell[4279, 131, 2152, 42, 491, "Input"],
Cell[6434, 175, 207, 6, 52, "Text"],
Cell[6644, 183, 194, 3, 75, "Input"],
Cell[6841, 188, 117, 4, 33, "Text"],
Cell[6961, 194, 204, 3, 75, "Input"],
Cell[7168, 199, 44, 1, 33, "Text"],
Cell[7215, 202, 262, 4, 91, "Input"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

