(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     14926,        483]*)
(*NotebookOutlinePosition[     15821,        513]*)
(*  CellTagsIndexPosition[     15777,        509]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Calculus I linked to Parametric Plots", "Title"],

Cell[TextData[{
  StyleBox["Dr. Therese Shelton",
    FontSize->13],
  "\n",
  StyleBox["Southwestern University\nGeorgetown, TX",
    FontSize->16]
}], "Subsubtitle",
  FontSize->12],

Cell[CellGroupData[{

Cell["\<\
Reinforcing the idea that 
\tfunctions
\t\tare graphs, 
\t\tare equations,
\t\tare numbers.
\
\>", "Subtitle"],

Cell["\<\
Caution:  remember that you may have to tweak some things if you \
change functions or graphing windows.\
\>", "Text",
  CellDingbat->"\[HappySmiley]",
  CellMargins->{{91, Inherited}, {Inherited, Inherited}},
  FontFamily->"Courier",
  FontSize->14],

Cell["\<\
Suggestion:  execute the notebook as-is.  Then change the \
functions, graphing window, and numberIntervals.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Set-up", "Section"],

Cell[BoxData[
    \(Clear[x, y, tmin, tmax, \ xmin, xmax, ymin, ymax, plotAll]\)], "Input"],

Cell[BoxData[{
    \(\(x[t_] := Cos[t];\)\), "\[IndentingNewLine]", 
    \(\ \(y[t_] := 3/50  t*Sin[t];\)\)}], "Input"],

Cell[BoxData[{
    \(tmin = \[Pi]\/2; \ tmax = \(9  \[Pi]\)\/2;\), "\[IndentingNewLine]", 
    \(xmin\  = \ \(-1.25\); \ xmax = 1.25;\), "\[IndentingNewLine]", 
    \(ymin = \(-1.25\); ymax = 1.25;\)}], "Input"],

Cell[BoxData[
    \(plotAll\  = 
      ParametricPlot[\ \ \ \ \ {x[t], y[t]}, \ \ \ \ \ \ \ \ \ \ \ {t, tmin, 
          tmax}, \[IndentingNewLine]\ 
        PlotRange \[Rule] {\ \ \ \ {xmin, xmax}, {ymin, 
              ymax}\ \ \ \ }\ \ , \[IndentingNewLine]AspectRatio \[Rule] 
          Automatic\ \ \ ]\)], "Input"],

Cell[BoxData[{
    \(\(\(Clear[colorx, colory, colorr, \ colx, coly, colorvec, 
      colv]\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(colorr = RGBColor[0, 0, 0];\)\), "\n", 
    \(\(colorx = RGBColor[1. , 0. , 0. ];\)\ \), "\n", 
    \(\(colory = RGBColor[0. , 0. , 1. ];\)\), "\[IndentingNewLine]", 
    \(\(\(colorvec = 
        RGBColor[0. ,  .79002,  .34007];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(colx = "\<red\>";\)\), "\[IndentingNewLine]", 
    \(\(coly = "\<blue\>";\)\), "\[IndentingNewLine]", 
    \(\(\(colv = "\<green\>";\)\(\[IndentingNewLine]\)
    \)\)}], "Input"],

Cell[BoxData[{
    RowBox[{
      StyleBox[\(Clear[numberIntervals, deltat];\),
        Background->None], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{\(numberIntervals\  = \ 65;\), 
      StyleBox["\[IndentingNewLine]",
        Background->RGBColor[1, 1, 
        0]]}], "\[IndentingNewLine]", \(deltat = \((tmax - tmin)\)/
        numberIntervals\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Relate Cal I Concerns to parametric curves", "Section"],

Cell["\<\
A goal:  students should be able to see the connection between \
x[t], y[t] and r[t].  Students should also be able to think of a parametric \
plot as a dynamic entity that models motion.  

Reason:  builds intuition about parametric functions --  from a graphical, a \
numerical, and an equational sense -- and their relationship to the \
components.\
\>", "Text",
  FontSize->15],

Cell[CellGroupData[{

Cell["\<\
Lab:
Link the rectangular behavior of the x[t] function to the movement in the \
x-direction on the parametric plot.  Then do the same for y[t].\
\>", \
"Subsection"],

Cell["\<\
Preliminary graphs.
The student can work from just these and do a lot of handwork.\
\>", "Text",
  CellDingbat->"\[HappySmiley]",
  CellMargins->{{91, 84}, {Inherited, Inherited}},
  FontFamily->"Courier",
  FontSize->15],

Cell[BoxData[
    \(Plot[x[t], {t, tmin, tmax}, 
      PlotStyle \[Rule] {colorx}, \[IndentingNewLine]AxesLabel \[Rule] {"\<   \
 t\>", "\<x[t]\>"}]\)], "Input"],

Cell[BoxData[
    \(Plot[y[t], {t, tmin, tmax}, 
      PlotStyle \[Rule] {colory}, \[IndentingNewLine]AxesLabel \[Rule] {"\<   \
 t\>", "\<y[t]\>"}]\)], "Input"],

Cell[CellGroupData[{

Cell["Questions for students", "Subsubsection",
  FontSize->15],

Cell["\<\
Explain the relationship between the rectangular graphs of x[t] and \
y[t] and the parametric plot.  In particular, notice the zeroes, max, min, \
intervals of increase and decrease of x[t] and how these are reflected in the \
parametric plot.  Do the same for y[t].

Use the increase, decrease intervals of x[t] and of y[t] to indicate a \
direction on the paremetric plots.\
\>", "Text",
  FontSize->15]
}, Open  ]],

Cell[CellGroupData[{

Cell["Sample answer:", "Subsubsection",
  FontSize->15],

Cell[BoxData[
    \(Clear[zerox, zeroy, cvx, cvy, bothx, bothy, allxy]\)], "Input"],

Cell["Find the zeroes of x", "Text",
  FontWeight->"Bold"],

Cell[BoxData[
    \(x[t]\)], "Input"],

Cell["\<\
zeroes of x[t] occur at \[Pi]/2 + k\[Pi], k an integer.  The \
previous x[t] graph shows 5 zeroes.  These are the times on the parametric \
plot when the plot crosses the x-axis.\
\>", "Text",
  FontSize->15],

Cell[BoxData[
    \(zerox = Table[\[Pi]/2 + k\ \[Pi], {k, 0, 4}]\)], "Input"],

Cell[BoxData[
    \(\(x'\)[t]\)], "Input"],

Cell["Find the critical values of x", "Text",
  FontWeight->"Bold"],

Cell["\<\
critical values for x[t] are k \[Pi] , k an integer.
x[t] decreases, then increases, then decreases, then increases, then \
decreases.
This corresponds to times when the parametric plot moves left, then right, \
then left, then right, then left.  When x[t] increases, the parametric plot \
moves to the right.\
\>", "Text",
  FontSize->15],

Cell[BoxData[
    \(cvx\  = \ Table[k\ \[Pi], {k, 0, 5}]\)], "Input"],

Cell[BoxData[{
    \(\(bothx\  = \ Union[N[cvx], N[zerox]];\)\), "\[IndentingNewLine]", 
    \(bothx = Round[bothx*10]/10.0\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Clear[xplot];\)\), "\[IndentingNewLine]", 
    \(xplot\  = \ 
      Plot[x[t], {t, tmin, tmax}, 
        PlotStyle \[Rule] {colorx}, \[IndentingNewLine]AxesLabel \[Rule] {"\< \
   t\>", "\<x[t]\>"}, Ticks \[Rule] {bothx, Automatic}]\)}], "Input"],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[BoxData[{
    \(\(Clear[xpoints];\)\), "\[IndentingNewLine]", 
    \(xpoints = \ 
      ListPlot[\ 
        Table[{t, x[t]} /. t \[Rule] bothx[\([i]\)]\ \ , {i, 1, \ 
            Length[bothx]}], \[IndentingNewLine]PlotJoined \[Rule] False, 
        PlotStyle \[Rule] {PointSize[ .02], colorx}, 
        Ticks \[Rule] {bothx, Automatic}]\)}], "Input"],

Cell[BoxData[
    \(Show[xplot, xpoints]\)], "Input"],

Cell[BoxData[
    \(Clear[zeroy, cvy, bothy]\)], "Input"],

Cell["Find the zeroes of y", "Text",
  FontWeight->"Bold"],

Cell[BoxData[
    \(y[t]\)], "Input"],

Cell["\<\
zeroes of y occur at k \[Pi], k an integer.  The y[t] graph shows 6 \
zeroes.  These are the times on the parametric plot when the plot crosses the \
y-axis.\
\>", "Text",
  FontSize->15],

Cell[BoxData[
    \(zeroy = \ Table[k\ \[Pi], {k, 0, 5}]\)], "Input"],

Cell["Find the critical values of y", "Text",
  FontWeight->"Bold"],

Cell[BoxData[
    \(\(y'\)[t]\)], "Input"],

Cell[BoxData[
    \(Solve[\(y'\)[t] \[Equal] 0, t]\)], "Input"],

Cell["\<\
Since this can't be solved nicely, we can use numerical \
approximations.\
\>", "Text",
  FontSize->15],

Cell[BoxData[
    \(Plot[\(y'\)[t], {t, tmin, 
        tmax}, \[IndentingNewLine]AxesLabel \[Rule] {"\<    t\>", \
"\<y'[t]\>"}]\)], "Input"],

Cell[TextData[StyleBox["Click on the graph above.  Hold the command key and \
move the mouse over the graph to see coordinates.  Alternatively, use some \
sort of root solver; see below.\nThis can be a little tricky, but the efforts \
are beneficial, especially if the student has any experience with numerical \
solvers.",
  FontSize->13,
  FontSlant->"Italic"]], "Text",
  FontSize->15],

Cell[BoxData[
    \(FindRoot[\(y'\)[t], {t, tmin, tmax}]\)], "Input"],

Cell[BoxData[
    \(FindRoot[\(y'\)[t], {t, 1, tmax}]\)], "Input"],

Cell[BoxData[
    \(FindRoot[\(y'\)[t], {t, 4.5, tmax}]\)], "Input"],

Cell[BoxData[
    \(FindRoot[\(y'\)[t], {t, 7.5, tmax}]\)], "Input"],

Cell[BoxData[
    \(FindRoot[\(y'\)[t], {t, 10.5, 8, tmax}]\)], "Input"],

Cell[BoxData[
    \(FindRoot[\(y'\)[t], {t, 13.5, 13, tmax}]\)], "Input"],

Cell["\<\
Alternatively, the roots of y[t] are the intersection points of the \
functions below.\
\>", "Text"],

Cell[BoxData[
    \(Plot[{t\ Cos[t], Sin[t]}, {t, tmin, tmax}]\)], "Input"],

Cell[BoxData[
    \(cvy = {0, 2.028757686923175, 4.913180792621565, 7.978664682408253, 
        11.085538449284982, 14.207436725370405}\)], "Input"],

Cell["\<\
critical values for y[t] are estimated above.
y[t] increases, then decreases, then increases, then decreases, then \
increases, then decreases.
The intervals of increase for y[t] correspond to times when the parametric \
plot moves up.  The intervals of decrease for y[t] correspond to times when \
the parametric plot moves down.\
\>", "Text",
  FontSize->15],

Cell[BoxData[{
    \(\(bothy = Union[N[cvy], N[zeroy]];\)\), "\[IndentingNewLine]", 
    \(bothy = Round[bothy*10]/10.0\)}], "Input"],

Cell[BoxData[""], "Input"],

Cell[BoxData[{
    \(\(Clear[yplot];\)\), "\[IndentingNewLine]", 
    \(yplot\  = \ 
      Plot[y[t], {t, tmin, tmax}, 
        PlotStyle \[Rule] {colory}, \[IndentingNewLine]AxesLabel \[Rule] {"\< \
   t\>", "\<y[t]\>"}, Ticks \[Rule] {bothy, Automatic}]\)}], "Input"],

Cell[BoxData[{
    \(\(Clear[ypoints];\)\), "\[IndentingNewLine]", 
    \(ypoints = \ 
      ListPlot[\ 
        Table[{t, y[t]} /. t \[Rule] bothy[\([i]\)]\ , {i, 1, \ 
            Length[bothy]}], \[IndentingNewLine]PlotJoined \[Rule] False, 
        PlotStyle \[Rule] {PointSize[ .02], colory}, 
        Ticks \[Rule] {bothy, Automatic}]\)}], "Input"],

Cell[BoxData[
    \(Show[yplot, ypoints]\)], "Input"],

Cell["Analysis", "Text",
  FontWeight->"Bold"],

Cell["\<\
Combine the points of interest into a single list.  To avoid \
listing decimal values separate from multiples of \[Pi], get numerical \
estimates.  To show the values on the t-axis, round to one decimal.  Enlarge \
the graph as needed to try to distinguish t-values.  Even so, some t-values \
are just too close together.\
\>", "Text"],

Cell[BoxData[
    \(allxy = Union[bothx, bothy]\)], "Input"],

Cell[BoxData[{
    \(\(Clear[xyplot];\)\), "\[IndentingNewLine]", 
    \(xyplot\  = \ 
      Plot[{x[t], y[t]}, {t, tmin, 
          tmax}, \[IndentingNewLine]PlotStyle \[Rule] {{colorx, \ 
              Dashing[{ .01,  .01}]}, {colory}}, \[IndentingNewLine]AxesLabel \
\[Rule] {"\<    t\>", "\<\>"}, 
        Ticks \[Rule] {allxy, 
            Automatic}, \[IndentingNewLine]PlotLabel \[Rule] \ 
          StringJoin[colx, "\< and dashed is x[t], \>", 
            coly, "\< is y[t]\>"]\ \ ]\)}], "Input"],

Cell[TextData[{
  "Sample answer should be something like this in part:",
  StyleBox["\nt value or interval",
    FontVariations->{"Underline"->True}],
  "\t",
  StyleBox["parametric curve behavior\n",
    FontVariations->{"Underline"->True}],
  "\n0\t\t\tcrosses x axis\n(0,2)\t\tmoves from right to left \n\t\t\t(since \
x is decreasing) \n\t\t\tand up (y is increasing)\n1.6\t\t\tcrosses y-axis\n\
(2,3.1)\t\tmoves right to left and down\n(3.1, 4.9)\tmoves left to right and \
down\n4.7\t\t\tcrosses y-axis\n\netc.\n"
}], "Text",
  CellDingbat->"\[HappySmiley]",
  CellMargins->{{89, 85}, {Inherited, Inherited}},
  FontFamily->"Courier",
  FontSize->14],

Cell["Here are some other useful plots and a table.", "Text",
  FontWeight->"Bold"],

Cell["\<\
A plot highlighting zeros and extrema of x on the x graph along \
with those for the y graph.\
\>", "Text",
  FontSize->15],

Cell[BoxData[
    \(Show[xpoints, ypoints, 
      xyplot, \[IndentingNewLine]AxesLabel \[Rule] {"\<    t\>", "\<\>"}, 
      Ticks \[Rule] {allxy, 
          Automatic}, \[IndentingNewLine]PlotLabel \[Rule] \ 
        StringJoin[colx, "\< and dashed is x[t], \>", 
          coly, "\< is y[t]\>"]]\)], "Input"],

Cell["\<\
From this table, we can focus on {t, x[t]}, {t, y[t]},  or {x[t], \
y[t]} pairs to connect the graph above the table with the graph below.\
\>", \
"Text",
  FontSize->15],

Cell["\<\
Students should be able to (by hand) label corresponding intervals \
on the graph above and the graph below the table.\
\>", "Text",
  CellDingbat->"\[HappySmiley]",
  CellMargins->{{89, Inherited}, {Inherited, Inherited}},
  FontFamily->"Courier",
  FontSize->15],

Cell[BoxData[
    \(TableForm[
      Table[{t, x[t], y[t]} /. t \[Rule] allxy[\([i]\)], {i, 1, \ 
          Length[allxy]}]]\)], "Input"],

Cell[BoxData[
    \(\(\(\[IndentingNewLine]\)\(Show[{plotAll, \[IndentingNewLine]Table[\ \ \
\ \ \ Graphics[\ \ \[IndentingNewLine]\ {\ \ PointSize[ .02], 
              Point[\ {x[\ allxy[\([i]\)]\ ], 
                  y[\ allxy[\([i]\)]\ ]}\ ]\ \ \ \ \ \ \ }\ \ \ \ ], \ {i, 1, 
            Length[\ 
              allxy\ ]}\ \ \ \ ]}, \[IndentingNewLine]\ \ \ PlotRange \[Rule] \
\ {{xmin, xmax}, {ymin, ymax}}, \[IndentingNewLine]\ \ \ Axes \[Rule] 
        Automatic, \[IndentingNewLine]\ \ \ AspectRatio \[Rule] 
        Automatic, \[IndentingNewLine]\ \ \ AxesLabel \[Rule] {"\<    \
x[t]\>", "\<y[t]\>"}]\)\(\ \ \ \ \)\)\)], "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 746}},
WindowToolbars->"RulerBar",
WindowSize->{778, 699},
WindowMargins->{{36, Automatic}, {Automatic, 4}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
PrintingOptions->{"PrintingMargins"->{{54, 54}, {54, 54}},
"PrintCellBrackets"->False,
"PrintRegistrationMarks"->True,
"PrintMultipleHorizontalPages"->False},
Magnification->1
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 54, 0, 108, "Title"],
Cell[1784, 54, 183, 7, 86, "Subsubtitle"],

Cell[CellGroupData[{
Cell[1992, 65, 120, 7, 215, "Subtitle"],
Cell[2115, 74, 260, 7, 50, "Text"],
Cell[2378, 83, 132, 3, 32, "Text"],

Cell[CellGroupData[{
Cell[2535, 90, 25, 0, 56, "Section"],
Cell[2563, 92, 91, 1, 27, "Input"],
Cell[2657, 95, 119, 2, 43, "Input"],
Cell[2779, 99, 211, 3, 76, "Input"],
Cell[2993, 104, 320, 6, 59, "Input"],
Cell[3316, 112, 617, 13, 187, "Input"],
Cell[3936, 127, 379, 8, 91, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4352, 140, 61, 0, 56, "Section"],
Cell[4416, 142, 391, 9, 109, "Text"],

Cell[CellGroupData[{
Cell[4832, 155, 176, 5, 82, "Subsection"],
Cell[5011, 162, 231, 7, 71, "Text"],
Cell[5245, 171, 161, 3, 43, "Input"],
Cell[5409, 176, 161, 3, 43, "Input"],

Cell[CellGroupData[{
Cell[5595, 183, 63, 1, 43, "Subsubsection"],
Cell[5661, 186, 415, 9, 109, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6113, 200, 55, 1, 43, "Subsubsection"],
Cell[6171, 203, 83, 1, 27, "Input"],
Cell[6257, 206, 58, 1, 32, "Text"],
Cell[6318, 209, 37, 1, 27, "Input"],
Cell[6358, 212, 218, 5, 52, "Text"],
Cell[6579, 219, 77, 1, 27, "Input"],
Cell[6659, 222, 42, 1, 27, "Input"],
Cell[6704, 225, 67, 1, 32, "Text"],
Cell[6774, 228, 349, 8, 90, "Text"],
Cell[7126, 238, 69, 1, 27, "Input"],
Cell[7198, 241, 137, 2, 43, "Input"],

Cell[CellGroupData[{
Cell[7360, 247, 269, 5, 59, "Input"],
Cell[7632, 254, 130, 3, 27, "Output"]
}, Open  ]],
Cell[7777, 260, 356, 7, 59, "Input"],
Cell[8136, 269, 53, 1, 27, "Input"],
Cell[8192, 272, 57, 1, 27, "Input"],
Cell[8252, 275, 58, 1, 32, "Text"],
Cell[8313, 278, 37, 1, 27, "Input"],
Cell[8353, 281, 197, 5, 52, "Text"],
Cell[8553, 288, 69, 1, 27, "Input"],
Cell[8625, 291, 67, 1, 32, "Text"],
Cell[8695, 294, 42, 1, 27, "Input"],
Cell[8740, 297, 63, 1, 27, "Input"],
Cell[8806, 300, 113, 4, 33, "Text"],
Cell[8922, 306, 141, 3, 43, "Input"],
Cell[9066, 311, 388, 7, 65, "Text"],
Cell[9457, 320, 69, 1, 27, "Input"],
Cell[9529, 323, 66, 1, 27, "Input"],
Cell[9598, 326, 68, 1, 27, "Input"],
Cell[9669, 329, 68, 1, 27, "Input"],
Cell[9740, 332, 72, 1, 27, "Input"],
Cell[9815, 335, 73, 1, 27, "Input"],
Cell[9891, 338, 110, 3, 32, "Text"],
Cell[10004, 343, 75, 1, 27, "Input"],
Cell[10082, 346, 148, 2, 43, "Input"],
Cell[10233, 350, 370, 8, 90, "Text"],
Cell[10606, 360, 133, 2, 43, "Input"],
Cell[10742, 364, 26, 0, 27, "Input"],
Cell[10771, 366, 269, 5, 59, "Input"],
Cell[11043, 373, 354, 7, 59, "Input"],
Cell[11400, 382, 53, 1, 27, "Input"],
Cell[11456, 385, 46, 1, 32, "Text"],
Cell[11505, 388, 345, 6, 68, "Text"],
Cell[11853, 396, 60, 1, 27, "Input"],
Cell[11916, 399, 506, 10, 91, "Input"],
Cell[12425, 411, 657, 15, 266, "Text"],
Cell[13085, 428, 83, 1, 32, "Text"],
Cell[13171, 431, 133, 4, 33, "Text"],
Cell[13307, 437, 310, 6, 59, "Input"],
Cell[13620, 445, 180, 5, 52, "Text"],
Cell[13803, 452, 274, 7, 52, "Text"],
Cell[14080, 461, 137, 3, 27, "Input"],
Cell[14220, 466, 642, 10, 155, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

