(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     10019,        307]*)
(*NotebookOutlinePosition[     11252,        346]*)
(*  CellTagsIndexPosition[     11208,        342]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Arclength as a function", "Title"],

Cell[TextData[{
  StyleBox["Dr. Therese Shelton",
    FontSize->13],
  "\n",
  StyleBox["Southwestern University\nGeorgetown, TX",
    FontSize->16]
}], "Subsubtitle",
  FontSize->12],

Cell["\<\
Caution:  remember that you may have to tweak some things if you \
change functions or windows.\
\>", "Text",
  CellDingbat->"\[HappySmiley]",
  CellMargins->{{91, Inherited}, {Inherited, Inherited}},
  FontFamily->"Courier",
  FontSize->14],

Cell[CellGroupData[{

Cell["Set-up", "Section"],

Cell["Remember, the curve should be a simple smooth path.", "Text",
  CellDingbat->"\[HappySmiley]",
  CellMargins->{{91, Inherited}, {Inherited, Inherited}},
  FontFamily->"Courier",
  FontSize->14],

Cell[BoxData[{
    \(\(Clear[x, y, tmin, tmax, \ xmin, xmax, ymin, ymax];\)\), "\n", 
    \(\(x[t_] := Cos[t];\)\), "\n", 
    \(\ \(y[t_] := Sin[t];\)\), "\n", 
    \(tmin = 0.0; \ tmax = 6.0;\), "\n", 
    \(xmin\  = \ \(-1.25\); \ xmax = 1.25;\), "\n", 
    \(ymin = \(-1.25\); \ \ ymax = 1.25;\ \ \ \), "\n", 
    \(Clear[colorr]\), "\n", 
    \(\(colorr = RGBColor[1. , 0. , 0. ];\)\ \)}], "Input"],

Cell[BoxData[{
    \(\(Clear[plotAll];\)\), "\[IndentingNewLine]", 
    \(plotAll\  = 
      ParametricPlot[\ \ \ \ \ {x[t], y[t]}, \ \ \ \ \ \ \ \ \ \ \ {t, tmin, 
          tmax}, \[IndentingNewLine]\ 
        PlotRange \[Rule] {\ \ \ \ {xmin, xmax}, {ymin, 
              ymax}\ \ \ \ }\ \ , \[IndentingNewLine]AspectRatio \[Rule] 
          Automatic, PlotStyle \[Rule] {colorr}\ \ \ ]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["arclength, as a function", "Section"],

Cell[BoxData[
    \(Clear[arclength, speed]\)], "Input"],

Cell[BoxData[
    \(arclength[
        t_] := \ \[Integral]\_tmin\%t\(\@\(\((\(x'\)[u])\)\^2\  + \ \
\((\(y'\)[u])\)\^2\)\) \[DifferentialD]u\)], "Input"],

Cell[BoxData[
    \(\[Integral]\_tmin\%t\(\@\(\((\(x'\)[u])\)\^2\  + \ \((\(y'\)[u])\)\^2\)\
\) \[DifferentialD]u\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["numerical and visual aid", "Section"],

Cell[BoxData[{
    RowBox[{
      StyleBox[\(Clear[numberIntervals, deltat];\),
        Background->None], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{\(numberIntervals\  = \ 10;\), 
      StyleBox["\[IndentingNewLine]",
        Background->RGBColor[1, 1, 
        0]]}], "\[IndentingNewLine]", \(deltat = \((tmax - tmin)\)/
        numberIntervals\)}], "Input"],

Cell[BoxData[
    \(Table[{t, arclength[t]}, \ {t, \ tmin, \ tmax, deltat}] // 
      TableForm\)], "Input"],

Cell["\<\
Since arclength is a non-decreasing function, its largest value \
will occur at the largest t-value\
\>", "Text",
  FontSize->15],

Cell[BoxData[{
    \(\(Clear[ybig];\)\), "\[IndentingNewLine]", 
    \(ybig\  = \ arclength[tmax]\)}], "Input"],

Cell[BoxData[{
    \(Clear[p1, p2]\), "\[IndentingNewLine]", 
    \(p1\  = \ 
      Plot[\[IndentingNewLine]arclength[t], {t, tmin, 
          tmax}, \[IndentingNewLine]PlotRange \[Rule] \ {{tmin, tmax}, {0, 
              ybig}}, Axes \[Rule] Automatic, 
        AxesLabel \[Rule] {"\< t\>", "\< arclength[t]\>"}\[IndentingNewLine]\ \
\ \ \ \ \ \ \ ]\)}], "Input"],

Cell[BoxData[
    \(p2\  = \ 
      Plot[\[IndentingNewLine]arclength[t], {t, tmin, 
          tmax}, \[IndentingNewLine]PlotRange \[Rule] \ {{tmin, tmax}, {0, 
              ybig}}, Axes \[Rule] 
          Automatic\[IndentingNewLine]\ \ \ \ \ \ \ \ ]\)], "Input"],

Cell[BoxData[{
    \(\(Clear[dots, curve];\)\), "\n", 
    \(dots[q_] := 
      Show[\[IndentingNewLine]p1, \[IndentingNewLine]Graphics[{\ \ {colorr, 
              PointSize[ .04], 
              Point[{q, 
                  arclength[
                    q]}]\ }\ \ \ \ }], \[IndentingNewLine]PlotRange \[Rule] \ \
{{tmin, tmax}, {0, ybig}}, Axes \[Rule] Automatic, 
        AxesLabel \[Rule] {"\< t\>", "\< arclength[t]\>"}, \
\[IndentingNewLine]DisplayFunction \[Rule] 
          Identity\[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ ]\[IndentingNewLine]\), "\n", 
    \(curve[q_] := 
      ParametricPlot[\ \[IndentingNewLine]{x[t], y[t]}, {t, tmin, 
          q}, \[IndentingNewLine]PlotStyle \[Rule] \ {\ {\ colorr, 
              Thickness[ .02]\ }\ }, \[IndentingNewLine]PlotRange \[Rule] \ \
{{xmin, xmax}, {ymin, ymax}}, Axes \[Rule] Automatic, 
        AspectRatio \[Rule] 
          Automatic, \[IndentingNewLine]AxesLabel \[Rule] {"\< x[t]\>", \
"\<y[t]\>"}, 
        DisplayFunction \[Rule] 
          Identity\[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ ]\)}], "Input"],

Cell[BoxData[
    \(Do[\[IndentingNewLine]Show[
        GraphicsArray[\ {curve[q], 
            dots[q]}], \[IndentingNewLine]DisplayFunction \[Rule] \
$DisplayFunction], \[IndentingNewLine]{q, tmin\  + \ deltat, \ tmax, \ 
        deltat}]\)], "Input"],

Cell[TextData[{
  "Do the circle first, since most of us know the circumference.  Then use \
other functions that we are less familiar with and are more interesting, such \
as {Cos[t], 3/50t*Sin[t]} and {",
  Cell[BoxData[
      \(\(t\^3\  - \ t\)\/\(t\^4\  + \ 1\)\)]],
  ", ",
  Cell[BoxData[
      \(\(\(\ \)\(t\)\)\/\(t\^4\  + \ 1\)\)]],
  "} ."
}], "Text",
  CellDingbat->"\[HappySmiley]",
  CellMargins->{{91, Inherited}, {Inherited, Inherited}},
  FontFamily->"Courier",
  FontSize->14]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
relate graph of the arclength function to its derivative, \
speed\
\>", "Section"],

Cell[TextData[{
  "Barr, ",
  StyleBox["Vector Calculus",
    FontVariations->{"Underline"->True}],
  ", 2nd Ed., Prentice Hall, Ch 5, Sec. 1, p276.\n \"For each smooth path C \
there is a special parameterization that is occassionally important.  Given \
[vector valued function] ",
  StyleBox["f",
    FontWeight->"Bold"],
  "[t], a\[LessEqual]t\[LessEqual]b for C, we define the pathlength function \
to be L[t]= ",
  Cell[BoxData[
      RowBox[{\(\[Integral]\_a\%t\), 
        RowBox[{"||", 
          RowBox[{
            RowBox[{
              StyleBox["f",
                FontWeight->"Bold"], "'"}], "[", "t", "]"}], 
          "||", \(\[DifferentialD]t\)}]}]]],
  ", a\[LessEqual]t\[LessEqual]b.  Since f is smooth, the integral is \
continuous, and by the Fundamental Theorem of Calculus, L'[t]=||",
  StyleBox["f",
    FontWeight->"Bold"],
  "'[t]||. ... The letter s is often used to represent the arclength \
function: s=",
  Cell[BoxData[
      RowBox[{\(\[Integral]\_a\%t\), 
        RowBox[{"||", 
          RowBox[{
            RowBox[{
              StyleBox["f",
                FontWeight->"Bold"], "'"}], "[", "t", "]"}], 
          "||", \(\[DifferentialD]t\)}]}]]],
  ".  This means that ",
  Cell[BoxData[
      \(ds\/dt\)]],
  "= ||",
  StyleBox["f",
    FontWeight->"Bold"],
  "'[t]||, which can be interpreted physically as saying that the rate of \
change in the distance traveled by a particle with position function ",
  StyleBox["f",
    FontWeight->"Bold"],
  " is its speed.\""
}], "Text",
  CellDingbat->"\[HappySmiley]",
  CellMargins->{{91, Inherited}, {Inherited, Inherited}},
  FontFamily->"Courier",
  FontSize->14],

Cell[BoxData[
    \(D[arclength[t], t]\)], "Input"],

Cell[BoxData[
    \(speed[
        t_] := \@\(\((\(x'\)[t])\)\^2\  + \ \((\(y'\)[t])\)\^2\)\)], "Input"],

Cell[BoxData[
    \(\@\(\((\(x'\)[t])\)\^2\  + \ \((\(y'\)[t])\)\^2\)\)], "Input"],

Cell[BoxData[
    \(TrigExpand[Cos[t]\^2 + Sin[t]\^2]\)], "Input"],

Cell[BoxData[{
    \(\(Clear[p3];\)\), "\[IndentingNewLine]", 
    \(p3 = 
      Plot[\[IndentingNewLine]speed[t], {t, tmin, 
          tmax}, \[IndentingNewLine]PlotRange \[Rule] \ {{tmin, tmax}, {0, 
              ybig}}, Axes \[Rule] 
          Automatic, \[IndentingNewLine]PlotStyle \[Rule] {{Dashing[{ .05,  \
.05}]}}\[IndentingNewLine]\ \ \ \ \ \ \ \ ]\)}], "Input"],

Cell["\<\
Use Cal I concepts to relate arclength to its dashed derivative, \
speed.  For instance, the arclength is non-decreasing, so the speed is always \
positive. \
\>", "Text",
  CellDingbat->"\[HappySmiley]",
  CellMargins->{{91, Inherited}, {Inherited, Inherited}},
  FontFamily->"Courier",
  FontSize->14],

Cell[BoxData[
    \(Show[p2, p3, 
      PlotLabel \[Rule] "\<solid is arclength; dashed is speed\>"]\)], "Input"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 746}},
WindowToolbars->"RulerBar",
WindowSize->{686, 679},
WindowMargins->{{37, Automatic}, {Automatic, 17}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
PageHeaders->{{Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
        TextData[ {
          ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
        TextData[ {
          ValueBox[ "FileName"]}], "Header"], Inherited, Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"]}},
PrintingOptions->{"PrintingMargins"->{{54, 54}, {54, 54}},
"PrintCellBrackets"->False,
"PrintRegistrationMarks"->True,
"PrintMultipleHorizontalPages"->False},
Magnification->1
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 40, 0, 108, "Title"],
Cell[1770, 54, 183, 7, 86, "Subsubtitle"],
Cell[1956, 63, 251, 7, 50, "Text"],

Cell[CellGroupData[{
Cell[2232, 74, 25, 0, 56, "Section"],
Cell[2260, 76, 199, 4, 32, "Text"],
Cell[2462, 82, 403, 8, 139, "Input"],
Cell[2868, 92, 403, 7, 75, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3308, 104, 43, 0, 56, "Section"],
Cell[3354, 106, 56, 1, 27, "Input"],
Cell[3413, 109, 154, 3, 43, "Input"],
Cell[3570, 114, 126, 2, 43, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3733, 121, 43, 0, 56, "Section"],
Cell[3779, 123, 379, 8, 91, "Input"],
Cell[4161, 133, 108, 2, 27, "Input"],
Cell[4272, 137, 139, 4, 33, "Text"],
Cell[4414, 143, 111, 2, 43, "Input"],
Cell[4528, 147, 365, 7, 107, "Input"],
Cell[4896, 156, 265, 5, 75, "Input"],
Cell[5164, 163, 1166, 23, 267, "Input"],
Cell[6333, 188, 253, 5, 75, "Input"],
Cell[6589, 195, 493, 14, 74, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7119, 214, 92, 3, 56, "Section"],
Cell[7214, 219, 1654, 48, 200, "Text"],
Cell[8871, 269, 51, 1, 27, "Input"],
Cell[8925, 272, 104, 2, 35, "Input"],
Cell[9032, 276, 82, 1, 35, "Input"],
Cell[9117, 279, 66, 1, 31, "Input"],
Cell[9186, 282, 373, 7, 107, "Input"],
Cell[9562, 291, 313, 8, 68, "Text"],
Cell[9878, 301, 113, 2, 27, "Input"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

