(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     14937,        458]*)
(*NotebookOutlinePosition[     16171,        497]*)
(*  CellTagsIndexPosition[     16127,        493]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["other functions with arclength, speed", "Title"],

Cell[TextData[{
  StyleBox["Dr. Therese Shelton",
    FontSize->13],
  "\n",
  StyleBox["Southwestern University\nGeorgetown, TX",
    FontSize->16]
}], "Subsubtitle",
  FontSize->12],

Cell["\<\
Caution:  remember that you may have to tweak some things if you \
change functions or windows.\
\>", "Text",
  CellDingbat->"\[HappySmiley]",
  CellMargins->{{91, Inherited}, {Inherited, Inherited}},
  FontFamily->"Courier",
  FontSize->14],

Cell[CellGroupData[{

Cell["a second function", "Subtitle"],

Cell[CellGroupData[{

Cell["Set-up", "Section"],

Cell["Remember, the curve should be a simple smooth path.", "Text",
  CellDingbat->"\[HappySmiley]",
  CellMargins->{{91, Inherited}, {Inherited, Inherited}},
  FontFamily->"Courier",
  FontSize->14],

Cell[BoxData[
    \(\(\(\(Clear[x, y, tmin, tmax, \ xmin, xmax, ymin, ymax];\)\n
    \(x[t_] := Cos[t];\)\n
    \ \(y[t_] := 3/50  t*Sin[t];\)\n
    \(tmin = 1.25;\)\ \n
    \(tmax = 9.0;\)\n
    xmin\  = \ \(-1.25\); \ xmax = 1.25;\n
    ymin = \(-1.25\); ymax = 1.25;\ \ \n
    Clear[colorr]\n
    \(colorr = RGBColor[1. , 0. , 0. ];\)\)\(\ \)\)\)], "Input"],

Cell[BoxData[{
    \(\(Clear[plotAll];\)\), "\[IndentingNewLine]", 
    \(plotAll\  = 
      ParametricPlot[\ \ \ \ \ {x[t], y[t]}, \ \ \ \ \ \ \ \ \ \ \ {t, tmin, 
          tmax}, \[IndentingNewLine]\ 
        PlotRange \[Rule] {\ \ \ \ {xmin, xmax}, {ymin, 
              ymax}\ \ \ \ }\ \ , \[IndentingNewLine]AspectRatio \[Rule] 
          Automatic, PlotStyle \[Rule] {colorr}\ \ \ ]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["arclength, as a function", "Section"],

Cell["Caution:  some of these take a long time", "Text",
  CellDingbat->"\[HappySmiley]",
  CellMargins->{{91, Inherited}, {Inherited, Inherited}},
  FontFamily->"Courier",
  FontSize->14],

Cell[BoxData[{
    \(Clear[arclength]\), "\n", 
    \(arclength[
        t_] := \ \[Integral]\_tmin\%t\(\@\(\((\(x'\)[u])\)\^2\  + \ \
\((\(y'\)[u])\)\^2\)\) \[DifferentialD]u\)}], "Input"],

Cell[BoxData[
    \(\[Integral]\_tmin\%t\(\@\(\((\(x'\)[u])\)\^2\  + \ \((\(y'\)[u])\)\^2\)\
\) \[DifferentialD]u\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["numerical and visual aid", "Section"],

Cell[BoxData[{
    RowBox[{
      StyleBox[\(Clear[numberIntervals, deltat];\),
        Background->None], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{\(numberIntervals\  = \ 10;\), 
      StyleBox["\[IndentingNewLine]",
        Background->None]}], "\n", \(deltat = \((tmax - tmin)\)/
        numberIntervals\)}], "Input"],

Cell["\<\
skip  
\tTable[{t,arclength[t]}, {t, tmin, tmax,deltat}]//TableForm
since it takes too long.  replace with numerical integration\
\>", "Text",
  FontSize->15],

Cell[BoxData[{
    \(\(Clear[NumArclength];\)\), "\[IndentingNewLine]", 
    \(NumArclength[t_] := 
      NIntegrate[\ \@\(\((\(x'\)[u])\)\^2\  + \ \((\(y'\)[u])\)\^2\), \ {u, 
          tmin, t}]\)}], "Input"],

Cell[BoxData[
    \(Table[{t, NumArclength[t]}, \ {t, \ tmin, \ tmax, deltat}] // 
      TableForm\)], "Input"],

Cell["\<\
Since arclength is a non-decreasing function, its largest value \
will occur at the largest t-value\
\>", "Text",
  FontSize->15],

Cell[BoxData[{
    \(\(Clear[ybig];\)\), "\[IndentingNewLine]", 
    \(ybig\  = \ NumArclength[tmax]\)}], "Input"],

Cell[BoxData[{
    \(Clear[p1, p2]\), "\[IndentingNewLine]", 
    \(p1\  = \ 
      Plot[\[IndentingNewLine]NumArclength[t], {t, tmin, 
          tmax}, \[IndentingNewLine]PlotRange \[Rule] \ {{tmin, tmax}, {0, 
              ybig}}, Axes \[Rule] Automatic, 
        AxesLabel \[Rule] {"\< t\>", "\< arclength[t]\>"}, 
        AxesOrigin \[Rule] {0, 
            0}\[IndentingNewLine]\ \ \ \ \ \ \ \ ]\)}], "Input"],

Cell[BoxData[
    \(p2\  = \ 
      Plot[\[IndentingNewLine]NumArclength[t], {t, tmin, 
          tmax}, \[IndentingNewLine]PlotRange \[Rule] \ {{tmin, tmax}, {0, 
              ybig}}, Axes \[Rule] Automatic, 
        AxesOrigin \[Rule] {0, 
            0}\[IndentingNewLine]\ \ \ \ \ \ \ \ ]\)], "Input"],

Cell[BoxData[{
    \(\(Clear[dots, curve];\)\), "\n", 
    \(\(dots[q_] := 
        Show[\[IndentingNewLine]p1, \[IndentingNewLine]Graphics[{\ \ {colorr, 
                PointSize[ .04], 
                Point[{q, 
                    NumArclength[
                      q]}]\ }\ \ \ \ }], \[IndentingNewLine]PlotRange \[Rule] \
\ {{tmin, tmax}, {0, ybig}}, Axes \[Rule] Automatic, 
          AxesLabel \[Rule] {"\< t\>", "\< arclength[t]\>"}, \
\[IndentingNewLine]DisplayFunction \[Rule] 
            Identity\[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ ];\)\)}], "Input"],

Cell[BoxData[
    \(\(\(\n\)\(curve[q_] := 
      ParametricPlot[\ \[IndentingNewLine]{x[t], y[t]}, {t, tmin, 
          q}, \[IndentingNewLine]PlotStyle \[Rule] \ {\ {\ colorr, 
              Thickness[ .02]\ }\ }, \[IndentingNewLine]PlotRange \[Rule] \ \
{{xmin, xmax}, {ymin, ymax}}, Axes \[Rule] Automatic, 
        AspectRatio \[Rule] 
          Automatic, \[IndentingNewLine]AxesLabel \[Rule] {"\< x[t]\>", \
"\<y[t]\>"}, 
        DisplayFunction \[Rule] 
          Identity\[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ ]\)\)\)], "Input"],

Cell[BoxData[
    \(Do[\[IndentingNewLine]Show[
        GraphicsArray[\ {curve[q], 
            dots[q]}], \[IndentingNewLine]DisplayFunction \[Rule] \
$DisplayFunction], \[IndentingNewLine]{q, tmin\  + \ deltat, \ tmax, \ 
        deltat}]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
relate graph of the arclength function to its derivative, \
speed\
\>", "Section"],

Cell[BoxData[
    \(D[arclength[t], t]\)], "Input"],

Cell[BoxData[
    \(speed[
        t_] := \@\(\((\(x'\)[t])\)\^2\  + \ \((\(y'\)[t])\)\^2\)\)], "Input"],

Cell[BoxData[
    \(\@\(\((\(x'\)[t])\)\^2\  + \ \((\(y'\)[t])\)\^2\)\)], "Input"],

Cell[BoxData[{
    \(\(Clear[p3];\)\), "\[IndentingNewLine]", 
    \(p3 = 
      Plot[\[IndentingNewLine]speed[t], {t, tmin, 
          tmax}, \[IndentingNewLine]PlotRange \[Rule] \ {{tmin, tmax}, {0, 
              ybig}}, Axes \[Rule] 
          Automatic, \[IndentingNewLine]PlotStyle \[Rule] {{\ \ \ Dashing[{ \
.05,  .05}]\ \ \ }}, 
        AxesOrigin \[Rule] {0, 
            0}\[IndentingNewLine]\ \ \ \ \ \ \ \ ]\)}], "Input"],

Cell["\<\
Use Cal I concepts to relate arclength to its dashed derivative, \
speed.  For instance, the arclength is non-decreasing, so the speed is always \
positive. \
\>", "Text",
  CellDingbat->"\[HappySmiley]",
  CellMargins->{{91, Inherited}, {Inherited, Inherited}},
  FontFamily->"Courier",
  FontSize->14],

Cell[BoxData[
    \(Show[p2, p3, 
      PlotLabel \[Rule] "\<solid is arclength; dashed is speed\>"]\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["a third function", "Subtitle"],

Cell[CellGroupData[{

Cell["Set-up", "Section"],

Cell["Remember, the curve should be a simple smooth path.", "Text",
  CellDingbat->"\[HappySmiley]",
  CellMargins->{{91, Inherited}, {Inherited, Inherited}},
  FontFamily->"Courier",
  FontSize->14],

Cell[BoxData[
    \(\(\(\(Clear[x, y, tmin, tmax, \ xmin, xmax, ymin, ymax];\)\n
    \(x[t_] := \(t\^3\  - \ t\)\/\(t\^4\  + \ 1\);\)\n
    \ \(y[t_] := \(\(\ \)\(t\)\)\/\(t\^4\  + \ 1\);\)\n
    tmin = \(-10.0\); \ \ \ \ \ tmax = 10.0;\[IndentingNewLine]
    xmin\  = \ \(-0.5\); \ xmax = 0.5;\[IndentingNewLine]
    ymin = \(-0.6\); \ \ \ ymax = 0.6;\n
    Clear[colorr]\n
    \(colorr = RGBColor[1. , 0. , 0. ];\)\)\(\ \)\)\)], "Input"],

Cell[BoxData[{
    \(\(Clear[plotAll];\)\), "\[IndentingNewLine]", 
    \(plotAll\  = 
      ParametricPlot[\ \ \ \ \ {x[t], y[t]}, \ \ \ \ \ \ \ \ \ \ \ {t, tmin, 
          tmax}, \[IndentingNewLine]\ 
        PlotRange \[Rule] {\ \ \ \ {xmin, xmax}, {ymin, 
              ymax}\ \ \ \ }\ \ , \[IndentingNewLine]AspectRatio \[Rule] 
          Automatic, PlotStyle \[Rule] {colorr}\ \ \ ]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["arclength, as a function", "Section"],

Cell["Caution:  some of these take a long time", "Text",
  CellDingbat->"\[HappySmiley]",
  CellMargins->{{91, Inherited}, {Inherited, Inherited}},
  FontFamily->"Courier",
  FontSize->14],

Cell[BoxData[{
    \(Clear[arclength]\), "\n", 
    \(arclength[
        t_] := \ \[Integral]\_tmin\%t\(\@\(\((\(x'\)[u])\)\^2\  + \ \
\((\(y'\)[u])\)\^2\)\) \[DifferentialD]u\)}], "Input"],

Cell[BoxData[
    \(\[Integral]\_tmin\%t\(\@\(\((\(x'\)[u])\)\^2\  + \ \((\(y'\)[u])\)\^2\)\
\) \[DifferentialD]u\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["numerical and visual aid", "Section"],

Cell[BoxData[{
    RowBox[{
      StyleBox[\(Clear[numberIntervals, deltat];\),
        Background->None], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{\(numberIntervals\  = \ 10;\), 
      StyleBox["\[IndentingNewLine]",
        Background->None]}], "\n", \(deltat = \((tmax - tmin)\)/
        numberIntervals\)}], "Input"],

Cell["\<\
skip  
\tTable[{t,arclength[t]}, {t, tmin, tmax,deltat}]//TableForm
since it takes too long.  replace with numerical integration\
\>", "Text",
  FontSize->15],

Cell[BoxData[{
    \(\(Clear[NumArclength];\)\), "\[IndentingNewLine]", 
    \(NumArclength[t_] := 
      NIntegrate[\ \@\(\((\(x'\)[u])\)\^2\  + \ \((\(y'\)[u])\)\^2\), \ {u, 
          tmin, t}]\)}], "Input"],

Cell[BoxData[
    \(Table[{t, NumArclength[t]}, \ {t, \ tmin, \ tmax, deltat}] // 
      TableForm\)], "Input"],

Cell["\<\
Since arclength is a non-decreasing function, its largest value \
will occur at the largest t-value\
\>", "Text",
  FontSize->15],

Cell[BoxData[{
    \(\(Clear[ybig];\)\), "\[IndentingNewLine]", 
    \(ybig\  = \ NumArclength[tmax]\)}], "Input"],

Cell[BoxData[{
    \(Clear[p1, p2]\), "\[IndentingNewLine]", 
    \(p1\  = \ 
      Plot[\[IndentingNewLine]NumArclength[t], {t, tmin, 
          tmax}, \[IndentingNewLine]PlotRange \[Rule] \ {{tmin, tmax}, {0, 
              ybig}}, Axes \[Rule] Automatic, 
        AxesLabel \[Rule] {"\< t\>", "\< arclength[t]\>"}, 
        AxesOrigin \[Rule] {0, 
            0}\[IndentingNewLine]\ \ \ \ \ \ \ \ ]\)}], "Input"],

Cell[BoxData[
    \(p2\  = \ 
      Plot[\[IndentingNewLine]NumArclength[t], {t, tmin, 
          tmax}, \[IndentingNewLine]PlotRange \[Rule] \ {{tmin, tmax}, {0, 
              ybig}}, Axes \[Rule] Automatic, 
        AxesOrigin \[Rule] {0, 
            0}\[IndentingNewLine]\ \ \ \ \ \ \ \ ]\)], "Input"],

Cell[BoxData[{
    \(\(Clear[dots, curve];\)\), "\n", 
    \(\(dots[q_] := 
        Show[\[IndentingNewLine]p1, \[IndentingNewLine]Graphics[{\ \ {colorr, 
                PointSize[ .04], 
                Point[{q, 
                    NumArclength[
                      q]}]\ }\ \ \ \ }], \[IndentingNewLine]PlotRange \[Rule] \
\ {{tmin, tmax}, {0, ybig}}, Axes \[Rule] Automatic, 
          AxesLabel \[Rule] {"\< t\>", "\< arclength[t]\>"}, \
\[IndentingNewLine]DisplayFunction \[Rule] 
            Identity\[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ ];\)\)}], "Input"],

Cell[BoxData[
    \(\(\(\n\)\(curve[q_] := 
      ParametricPlot[\ \[IndentingNewLine]{x[t], y[t]}, {t, tmin, 
          q}, \[IndentingNewLine]PlotStyle \[Rule] \ {\ {\ colorr, 
              Thickness[ .02]\ }\ }, \[IndentingNewLine]PlotRange \[Rule] \ \
{{xmin, xmax}, {ymin, ymax}}, Axes \[Rule] Automatic, 
        AspectRatio \[Rule] 
          Automatic, \[IndentingNewLine]AxesLabel \[Rule] {"\< x[t]\>", \
"\<y[t]\>"}, 
        DisplayFunction \[Rule] 
          Identity\[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ ]\)\)\)], "Input"],

Cell[BoxData[
    \(Do[\[IndentingNewLine]Show[
        GraphicsArray[\ {curve[q], 
            dots[q]}], \[IndentingNewLine]DisplayFunction \[Rule] \
$DisplayFunction], \[IndentingNewLine]{q, tmin\  + \ deltat, \ tmax, \ 
        deltat}]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
relate graph of the arclength function to its derivative, \
speed\
\>", "Section"],

Cell[BoxData[
    \(D[arclength[t], t]\)], "Input"],

Cell[BoxData[
    \(speed[
        t_] := \@\(\((\(x'\)[t])\)\^2\  + \ \((\(y'\)[t])\)\^2\)\)], "Input"],

Cell[BoxData[
    \(\@\(\((\(x'\)[t])\)\^2\  + \ \((\(y'\)[t])\)\^2\)\)], "Input"],

Cell[BoxData[{
    \(\(Clear[p3];\)\), "\[IndentingNewLine]", 
    \(p3 = 
      Plot[\[IndentingNewLine]speed[t], {t, tmin, 
          tmax}, \[IndentingNewLine]PlotRange \[Rule] \ {{tmin, tmax}, {0, 
              ybig}}, Axes \[Rule] 
          Automatic, \[IndentingNewLine]PlotStyle \[Rule] {{\ \ \ Dashing[{ \
.03,  .03}]\ \ \ }}, 
        AxesOrigin \[Rule] {0, 
            0}\[IndentingNewLine]\ \ \ \ \ \ \ \ ]\)}], "Input"],

Cell["\<\
Use Cal I concepts to relate arclength to its dashed derivative, \
speed.  For instance, the arclength is non-decreasing, so the speed is always \
positive. \
\>", "Text",
  CellDingbat->"\[HappySmiley]",
  CellMargins->{{91, Inherited}, {Inherited, Inherited}},
  FontFamily->"Courier",
  FontSize->14],

Cell[BoxData[
    \(Show[p2, p3, 
      PlotLabel \[Rule] "\<solid is arclength; dashed is speed\>"]\)], "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 746}},
WindowToolbars->"RulerBar",
WindowSize->{686, 679},
WindowMargins->{{142, Automatic}, {Automatic, 18}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
PageHeaders->{{Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
        TextData[ {
          ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
        TextData[ {
          ValueBox[ "FileName"]}], "Header"], Inherited, Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"]}},
PrintingOptions->{"PrintingMargins"->{{54, 54}, {54, 54}},
"PrintCellBrackets"->False,
"PrintRegistrationMarks"->True,
"PrintMultipleHorizontalPages"->False},
Magnification->1
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 54, 0, 156, "Title"],
Cell[1784, 54, 183, 7, 86, "Subsubtitle"],
Cell[1970, 63, 251, 7, 50, "Text"],

Cell[CellGroupData[{
Cell[2246, 74, 37, 0, 65, "Subtitle"],

Cell[CellGroupData[{
Cell[2308, 78, 25, 0, 56, "Section"],
Cell[2336, 80, 199, 4, 32, "Text"],
Cell[2538, 86, 360, 9, 155, "Input"],
Cell[2901, 97, 403, 7, 75, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3341, 109, 43, 0, 56, "Section"],
Cell[3387, 111, 188, 4, 32, "Text"],
Cell[3578, 117, 189, 4, 61, "Input"],
Cell[3770, 123, 126, 2, 43, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3933, 130, 43, 0, 56, "Section"],
Cell[3979, 132, 340, 7, 91, "Input"],
Cell[4322, 141, 168, 5, 71, "Text"],
Cell[4493, 148, 210, 4, 53, "Input"],
Cell[4706, 154, 111, 2, 27, "Input"],
Cell[4820, 158, 139, 4, 33, "Text"],
Cell[4962, 164, 114, 2, 43, "Input"],
Cell[5079, 168, 415, 8, 107, "Input"],
Cell[5497, 178, 306, 6, 91, "Input"],
Cell[5806, 186, 610, 12, 139, "Input"],
Cell[6419, 200, 589, 11, 139, "Input"],
Cell[7011, 213, 253, 5, 75, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7301, 223, 92, 3, 56, "Section"],
Cell[7396, 228, 51, 1, 27, "Input"],
Cell[7450, 231, 104, 2, 35, "Input"],
Cell[7557, 235, 82, 1, 35, "Input"],
Cell[7642, 238, 434, 9, 107, "Input"],
Cell[8079, 249, 313, 8, 68, "Text"],
Cell[8395, 259, 113, 2, 27, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[8557, 267, 36, 0, 65, "Subtitle"],

Cell[CellGroupData[{
Cell[8618, 271, 25, 0, 56, "Section"],
Cell[8646, 273, 199, 4, 32, "Text"],
Cell[8848, 279, 439, 8, 179, "Input"],
Cell[9290, 289, 403, 7, 75, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9730, 301, 43, 0, 56, "Section"],
Cell[9776, 303, 188, 4, 32, "Text"],
Cell[9967, 309, 189, 4, 61, "Input"],
Cell[10159, 315, 126, 2, 43, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10322, 322, 43, 0, 56, "Section"],
Cell[10368, 324, 340, 7, 91, "Input"],
Cell[10711, 333, 168, 5, 71, "Text"],
Cell[10882, 340, 210, 4, 53, "Input"],
Cell[11095, 346, 111, 2, 27, "Input"],
Cell[11209, 350, 139, 4, 33, "Text"],
Cell[11351, 356, 114, 2, 43, "Input"],
Cell[11468, 360, 415, 8, 107, "Input"],
Cell[11886, 370, 306, 6, 91, "Input"],
Cell[12195, 378, 610, 12, 139, "Input"],
Cell[12808, 392, 589, 11, 139, "Input"],
Cell[13400, 405, 253, 5, 75, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13690, 415, 92, 3, 56, "Section"],
Cell[13785, 420, 51, 1, 27, "Input"],
Cell[13839, 423, 104, 2, 35, "Input"],
Cell[13946, 427, 82, 1, 35, "Input"],
Cell[14031, 430, 434, 9, 107, "Input"],
Cell[14468, 441, 313, 8, 68, "Text"],
Cell[14784, 451, 113, 2, 27, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

