(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    119348,       2465]
NotebookOptionsPosition[    115707,       2334]
NotebookOutlinePosition[    116617,       2370]
CellTagsIndexPosition[    116574,       2367]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Arclength", "Title"],

Cell[TextData[{
 StyleBox["Dr. Therese Shelton",
  FontSize->13],
 "\n",
 StyleBox["Southwestern University\nGeorgetown, TX",
  FontSize->16]
}], "Subsubtitle",
 FontSize->12],

Cell["\<\
Caution:  remember that you may have to tweak some things if you change \
functions or windows.\
\>", "Text",
 CellDingbat->"\[HappySmiley]",
 CellMargins->{{91, Inherited}, {Inherited, Inherited}},
 FontFamily->"Courier",
 FontSize->14],

Cell[CellGroupData[{

Cell["Set-up", "Section"],

Cell["Remember, the curve should be a simple smooth path.", "Text",
 CellDingbat->"\[HappySmiley]",
 CellMargins->{{91, Inherited}, {Inherited, Inherited}},
 FontFamily->"Courier",
 FontSize->14],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{
     "x", ",", "y", ",", "tmin", ",", "tmax", ",", " ", "xmin", ",", "xmax", 
      ",", "ymin", ",", "ymax"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "t_", "]"}], ":=", 
     RowBox[{"Cos", "[", "t", "]"}]}], ";"}], "\n", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"y", "[", "t_", "]"}], ":=", 
     RowBox[{"Sin", "[", "t", "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"tmin", "=", "0"}], ";", " ", 
    RowBox[{"tmax", "=", 
     RowBox[{"2", " ", "\[Pi]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"xmin", " ", "=", " ", 
     RowBox[{"-", "1.25"}]}], ";", " ", 
    RowBox[{"xmax", "=", "1.25"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"ymin", "=", 
     RowBox[{"-", "1.25"}]}], ";", "  ", 
    RowBox[{"ymax", "=", "1.25"}], ";"}]}], "   "}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"colorr", ",", "colors", ",", "colr", ",", "cols"}], "]"}], 
  "\[IndentingNewLine]"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"colorr", "=", 
    RowBox[{"RGBColor", "[", 
     RowBox[{"1.", ",", "0.", ",", "0."}], "]"}]}], ";"}], " "}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"colors", "=", 
    RowBox[{"RGBColor", "[", 
     RowBox[{"0.", ",", "0.", ",", "1."}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"colr", "=", "\"\<red\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"cols", "=", "\"\<blue\>\""}], ";"}], 
  "\[IndentingNewLine]"}]}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", "plotAll", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"plotAll", " ", "=", 
  RowBox[{"ParametricPlot", "[", "     ", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"x", "[", "t", "]"}], ",", 
      RowBox[{"y", "[", "t", "]"}]}], "}"}], ",", "           ", 
    RowBox[{"{", 
     RowBox[{"t", ",", "tmin", ",", "tmax"}], "}"}], ",", 
    "\[IndentingNewLine]", " ", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", "    ", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"xmin", ",", "xmax"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"ymin", ",", "ymax"}], "}"}]}], "    ", "}"}]}], "  ", ",", 
    "\[IndentingNewLine]", 
    RowBox[{"AspectRatio", "\[Rule]", "Automatic"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", "colorr", "}"}]}]}], "   ", "]"}]}]}], "Input"],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[1., 0., 0.], LineBox[CompressedData["
1:eJw123c81W/YB3CiFAmpVCo00FIo7S6hYWREaf2yUkJmJaKkpFDZeySyZe9x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     "]]}},
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{-1.25, 1.25}, {-1.25, 1.25}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.4284874088125*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["arclength", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"arclength", " ", "=", " ", 
  RowBox[{
   SubsuperscriptBox["\[Integral]", "tmin", "tmax"], 
   RowBox[{
    SqrtBox[
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"x", "'"}], "[", "u", "]"}], ")"}], "2"], " ", "+", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"y", "'"}], "[", "u", "]"}], ")"}], "2"]}]], 
    RowBox[{"\[DifferentialD]", "u"}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"2", " ", "\[Pi]"}]], "Output",
 CellChangeTimes->{3.4284874111875*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "[", "%", "]"}]], "Input"],

Cell[BoxData["6.283185307179586`"], "Output",
 CellChangeTimes->{3.428487412734375*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["gross approximation", "Section"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  StyleBox[
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"numberIntervals", ",", "deltat"}], "]"}], ";"}],
   Background->None], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"numberIntervals", " ", "=", " ", "4"}], ";"}], 
  "\n"}], "\[IndentingNewLine]", 
 RowBox[{"deltat", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"tmax", "-", "tmin"}], ")"}], "/", 
   "numberIntervals"}]}]}], "Input"],

Cell[BoxData[
 FractionBox["\[Pi]", "2"]], "Output",
 CellChangeTimes->{3.428487415421875*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"total", ",", "plist", ",", "u1", ",", "u2"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"total", "=", "0."}], "\[IndentingNewLine]", 
 RowBox[{"plist", "=", 
  RowBox[{"{", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x", "[", "tmin", "]"}], ",", 
     RowBox[{"y", "[", "tmin", "]"}]}], "}"}], 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"For", "[", " ", 
   RowBox[{
    RowBox[{"i", "=", "1"}], ",", " ", 
    RowBox[{"i", " ", "\[LessEqual]", "numberIntervals"}], ",", " ", 
    RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"u1", " ", "=", " ", 
      RowBox[{"tmin", " ", "+", " ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"i", "-", "1"}], ")"}], " ", "*", " ", "deltat"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"u2", " ", "=", " ", 
      RowBox[{"tmin", " ", "+", " ", 
       RowBox[{"i", " ", "*", " ", "deltat"}]}]}], ";", "\[IndentingNewLine]",
      
     RowBox[{"total", " ", "=", " ", 
      RowBox[{"total", "+", " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"x", "[", "u2", "]"}], "-", 
            RowBox[{"x", "[", "u1", "]"}]}], ")"}], "2"], " ", "+", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"y", "[", "u2", "]"}], "-", 
            RowBox[{"y", "[", "u1", "]"}]}], ")"}], "2"]}]]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"AppendTo", "[", 
      RowBox[{"plist", ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"x", "[", "u2", "]"}], ",", " ", 
         RowBox[{"y", "[", "u2", "]"}]}], "}"}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Print", "[", 
      RowBox[{
      "\"\<i = \>\"", ",", " ", "i", ",", " ", "\"\<  u2 = \>\"", ",", " ", 
       "u2", ",", " ", "\"\<  total= \>\"", ",", "total", ",", " ", 
       "\"\<    plist:  \>\"", ",", 
       RowBox[{"N", "[", "plist", "]"}]}], "]"}]}]}], "\[IndentingNewLine]", 
   "      ", "]"}], ";"}], "\[IndentingNewLine]", "total"}], "Input"],

Cell[BoxData["0.`"], "Output",
 CellChangeTimes->{3.428487417671875*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"1", ",", "0"}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.42848741771875*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i = \"\>", "\[InvisibleSpace]", "1", 
   "\[InvisibleSpace]", "\<\"  u2 = \"\>", "\[InvisibleSpace]", 
   FractionBox["\[Pi]", "2"], "\[InvisibleSpace]", "\<\"  total= \"\>", 
   "\[InvisibleSpace]", "1.4142135623730951`", 
   "\[InvisibleSpace]", "\<\"    plist:  \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1.`", ",", "0.`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.`", ",", "1.`"}], "}"}]}], "}"}]}],
  SequenceForm[
  "i = ", 1, "  u2 = ", Rational[1, 2] Pi, "  total= ", 1.4142135623730951`, 
   "    plist:  ", {{1., 0.}, {0., 1.}}],
  Editable->False]], "Print",
 CellChangeTimes->{3.428487417765625*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i = \"\>", "\[InvisibleSpace]", "2", 
   "\[InvisibleSpace]", "\<\"  u2 = \"\>", "\[InvisibleSpace]", "\[Pi]", 
   "\[InvisibleSpace]", "\<\"  total= \"\>", "\[InvisibleSpace]", 
   "2.8284271247461903`", "\[InvisibleSpace]", "\<\"    plist:  \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1.`", ",", "0.`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.`", ",", "1.`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1.`"}], ",", "0.`"}], "}"}]}], "}"}]}],
  SequenceForm[
  "i = ", 2, "  u2 = ", Pi, "  total= ", 2.8284271247461903`, 
   "    plist:  ", {{1., 0.}, {0., 1.}, {-1., 0.}}],
  Editable->False]], "Print",
 CellChangeTimes->{3.428487417796875*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i = \"\>", "\[InvisibleSpace]", "3", 
   "\[InvisibleSpace]", "\<\"  u2 = \"\>", "\[InvisibleSpace]", 
   FractionBox[
    RowBox[{"3", " ", "\[Pi]"}], "2"], 
   "\[InvisibleSpace]", "\<\"  total= \"\>", "\[InvisibleSpace]", 
   "4.242640687119286`", "\[InvisibleSpace]", "\<\"    plist:  \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1.`", ",", "0.`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.`", ",", "1.`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1.`"}], ",", "0.`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.`", ",", 
       RowBox[{"-", "1.`"}]}], "}"}]}], "}"}]}],
  SequenceForm[
  "i = ", 3, "  u2 = ", Rational[3, 2] Pi, "  total= ", 4.242640687119286, 
   "    plist:  ", {{1., 0.}, {0., 1.}, {-1., 0.}, {0., -1.}}],
  Editable->False]], "Print",
 CellChangeTimes->{3.42848741784375*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i = \"\>", "\[InvisibleSpace]", "4", 
   "\[InvisibleSpace]", "\<\"  u2 = \"\>", "\[InvisibleSpace]", 
   RowBox[{"2", " ", "\[Pi]"}], "\[InvisibleSpace]", "\<\"  total= \"\>", 
   "\[InvisibleSpace]", "5.656854249492381`", 
   "\[InvisibleSpace]", "\<\"    plist:  \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1.`", ",", "0.`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.`", ",", "1.`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1.`"}], ",", "0.`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.`", ",", 
       RowBox[{"-", "1.`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1.`", ",", "0.`"}], "}"}]}], "}"}]}],
  SequenceForm[
  "i = ", 4, "  u2 = ", 2 Pi, "  total= ", 5.656854249492381, 
   "    plist:  ", {{1., 0.}, {0., 1.}, {-1., 0.}, {0., -1.}, {1., 0.}}],
  Editable->False]], "Print",
 CellChangeTimes->{3.428487417890625*^9}]
}, Open  ]],

Cell[BoxData["5.656854249492381`"], "Output",
 CellChangeTimes->{3.4284874179375*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "[", "plist", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1.`", ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "1.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.`"}], ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", 
     RowBox[{"-", "1.`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "0.`"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.428487419453125*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"p1", "=", 
  RowBox[{"ListPlot", "[", 
   RowBox[{"plist", ",", 
    RowBox[{"PlotJoined", "\[Rule]", "True"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", "colors", "}"}]}]}], "]"}]}]], "Input"],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[0., 0., 1.], 
    LineBox[{{1., 0.}, {0., 1.}, {-1., 0.}, {0., -1.}, {1., 0.}}]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{-1., 1.}, {-1., 1.}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.428487420625*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"p1", ",", "plotAll", ",", 
   RowBox[{"AspectRatio", "\[Rule]", "Automatic"}]}], "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {RGBColor[0., 0., 1.], 
     LineBox[{{1., 0.}, {0., 1.}, {-1., 0.}, {0., -1.}, {1., 
      0.}}]}}, {{}, {}, 
    {RGBColor[1., 0., 0.], LineBox[CompressedData["
1:eJw123c81W/YB3CiFAmpVCo00FIo7S6hYWREaf2yUkJmJaKkpFDZeySyZe9x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      "]]}}},
  AspectRatio->Automatic,
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{-1., 1.}, {-1., 1.}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.42848742178125*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["better approximation", "Section",
 FontSize->13],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\n", 
  RowBox[{
   StyleBox[
    RowBox[{
     RowBox[{"Clear", "[", 
      RowBox[{"numberIntervals", ",", "deltat"}], "]"}], ";"}],
    Background->None], "\n", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"numberIntervals", " ", "=", " ", "10"}], ";"}], 
   StyleBox["\[IndentingNewLine]",
    Background->None], "\[IndentingNewLine]", 
   RowBox[{"deltat", "=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"tmax", "-", "tmin"}], ")"}], "/", "numberIntervals"}]}], "\n", 
   
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"total", ",", "plist", ",", "u1", ",", "u2"}], "]"}], ";"}], 
   "\n", 
   RowBox[{
    RowBox[{"total", "=", "0."}], ";"}], "\n", 
   RowBox[{
    RowBox[{"plist", "=", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"x", "[", "tmin", "]"}], ",", 
        RowBox[{"y", "[", "tmin", "]"}]}], "}"}], "}"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"For", "[", " ", 
     RowBox[{
      RowBox[{"i", "=", "1"}], ",", " ", 
      RowBox[{"i", " ", "\[LessEqual]", "numberIntervals"}], ",", " ", 
      RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"u1", " ", "=", " ", 
        RowBox[{"tmin", " ", "+", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"i", "-", "1"}], ")"}], " ", "*", " ", "deltat"}]}]}], ";",
        "\[IndentingNewLine]", 
       RowBox[{"u2", " ", "=", " ", 
        RowBox[{"tmin", " ", "+", " ", 
         RowBox[{"i", " ", "*", " ", "deltat"}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"total", " ", "=", " ", 
        RowBox[{"total", "+", " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"x", "[", "u2", "]"}], "-", 
              RowBox[{"x", "[", "u1", "]"}]}], ")"}], "2"], " ", "+", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"y", "[", "u2", "]"}], "-", 
              RowBox[{"y", "[", "u1", "]"}]}], ")"}], "2"]}]]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"AppendTo", "[", 
        RowBox[{"plist", ",", " ", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"x", "[", "u2", "]"}], ",", " ", 
           RowBox[{"y", "[", "u2", "]"}]}], "}"}]}], "]"}], ";"}]}], 
     "\[IndentingNewLine]", "      ", "]"}], ";"}], "\n", 
   "total"}]}]], "Input"],

Cell[BoxData[
 FractionBox["\[Pi]", "5"]], "Output",
 CellChangeTimes->{3.42848742403125*^9}],

Cell[BoxData["6.180339887498948`"], "Output",
 CellChangeTimes->{3.4284874240625*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "[", "plist", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1.`", ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.8090169943749475`", ",", "0.5877852522924731`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.30901699437494745`", ",", "0.9510565162951535`"}], "}"}], ",", 
   
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.30901699437494745`"}], ",", "0.9510565162951535`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.8090169943749475`"}], ",", "0.5877852522924731`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.`"}], ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.8090169943749475`"}], ",", 
     RowBox[{"-", "0.5877852522924731`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.30901699437494745`"}], ",", 
     RowBox[{"-", "0.9510565162951535`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.30901699437494745`", ",", 
     RowBox[{"-", "0.9510565162951535`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.8090169943749475`", ",", 
     RowBox[{"-", "0.5877852522924731`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "0.`"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.4284874261875*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"p1", "=", 
  RowBox[{"ListPlot", "[", 
   RowBox[{"plist", ",", 
    RowBox[{"PlotJoined", "\[Rule]", "True"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", "colors", "}"}]}]}], "]"}]}]], "Input"],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[0., 0., 1.], 
    LineBox[{{1., 0.}, {0.8090169943749475, 0.5877852522924731}, {
     0.30901699437494745`, 0.9510565162951535}, {-0.30901699437494745`, 
     0.9510565162951535}, {-0.8090169943749475, 0.5877852522924731}, {-1., 
     0.}, {-0.8090169943749475, -0.5877852522924731}, {-0.30901699437494745`, \
-0.9510565162951535}, {0.30901699437494745`, -0.9510565162951535}, {
     0.8090169943749475, -0.5877852522924731}, {1., 0.}}]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{-1., 1.}, {-0.9510565162951535, 0.9510565162951535}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.428487427046875*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"p1", ",", "plotAll", ",", 
   RowBox[{"AspectRatio", "\[Rule]", "Automatic"}]}], "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {RGBColor[0., 0., 1.], 
     LineBox[{{1., 0.}, {0.8090169943749475, 0.5877852522924731}, {
      0.30901699437494745`, 0.9510565162951535}, {-0.30901699437494745`, 
      0.9510565162951535}, {-0.8090169943749475, 0.5877852522924731}, {-1., 
      0.}, {-0.8090169943749475, -0.5877852522924731}, \
{-0.30901699437494745`, -0.9510565162951535}, {
      0.30901699437494745`, -0.9510565162951535}, {
      0.8090169943749475, -0.5877852522924731}, {1., 0.}}]}}, {{}, {}, 
    {RGBColor[1., 0., 0.], LineBox[CompressedData["
1:eJw123c81W/YB3CiFAmpVCo00FIo7S6hYWREaf2yUkJmJaKkpFDZeySyZe9x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      "]]}}},
  AspectRatio->Automatic,
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{-1., 1.}, {-0.9510565162951535, 0.9510565162951535}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.42848742796875*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["very good approximation", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\n", 
  RowBox[{
   StyleBox[
    RowBox[{
     RowBox[{"Clear", "[", 
      RowBox[{"numberIntervals", ",", "deltat"}], "]"}], ";"}],
    Background->None], "\n", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"numberIntervals", " ", "=", " ", "20"}], ";"}], 
   StyleBox["\[IndentingNewLine]",
    Background->None], 
   StyleBox["\[IndentingNewLine]",
    Background->RGBColor[1, 1, 0]], 
   RowBox[{"deltat", "=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"tmax", "-", "tmin"}], ")"}], "/", "numberIntervals"}]}], "\n", 
   
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"total", ",", "plist", ",", "u1", ",", "u2"}], "]"}], ";"}], 
   "\n", 
   RowBox[{
    RowBox[{"total", "=", "0."}], ";"}], "\n", 
   RowBox[{
    RowBox[{"plist", "=", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"x", "[", "tmin", "]"}], ",", 
        RowBox[{"y", "[", "tmin", "]"}]}], "}"}], "}"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"For", "[", " ", 
     RowBox[{
      RowBox[{"i", "=", "1"}], ",", " ", 
      RowBox[{"i", " ", "\[LessEqual]", "numberIntervals"}], ",", " ", 
      RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"u1", " ", "=", " ", 
        RowBox[{"tmin", " ", "+", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"i", "-", "1"}], ")"}], " ", "*", " ", "deltat"}]}]}], ";",
        "\[IndentingNewLine]", 
       RowBox[{"u2", " ", "=", " ", 
        RowBox[{"tmin", " ", "+", " ", 
         RowBox[{"i", " ", "*", " ", "deltat"}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"total", " ", "=", " ", 
        RowBox[{"total", "+", " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"x", "[", "u2", "]"}], "-", 
              RowBox[{"x", "[", "u1", "]"}]}], ")"}], "2"], " ", "+", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"y", "[", "u2", "]"}], "-", 
              RowBox[{"y", "[", "u1", "]"}]}], ")"}], "2"]}]]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"AppendTo", "[", 
        RowBox[{"plist", ",", " ", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"x", "[", "u2", "]"}], ",", " ", 
           RowBox[{"y", "[", "u2", "]"}]}], "}"}]}], "]"}], ";"}]}], 
     "\[IndentingNewLine]", "      ", "]"}], ";"}], "\n", 
   "total"}]}]], "Input"],

Cell[BoxData[
 FractionBox["\[Pi]", "10"]], "Output",
 CellChangeTimes->{3.428487431015625*^9}],

Cell[BoxData["6.257378601609233`"], "Output",
 CellChangeTimes->{3.4284874310625*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "[", "plist", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1.`", ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.9510565162951535`", ",", "0.30901699437494745`"}], "}"}], ",", 
   
   RowBox[{"{", 
    RowBox[{"0.8090169943749475`", ",", "0.5877852522924731`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.5877852522924731`", ",", "0.8090169943749475`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.30901699437494745`", ",", "0.9510565162951535`"}], "}"}], ",", 
   
   RowBox[{"{", 
    RowBox[{"0.`", ",", "1.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.30901699437494745`"}], ",", "0.9510565162951535`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.5877852522924731`"}], ",", "0.8090169943749475`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.8090169943749475`"}], ",", "0.5877852522924731`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.9510565162951535`"}], ",", "0.30901699437494745`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.`"}], ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.9510565162951535`"}], ",", 
     RowBox[{"-", "0.30901699437494745`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.8090169943749475`"}], ",", 
     RowBox[{"-", "0.5877852522924731`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.5877852522924731`"}], ",", 
     RowBox[{"-", "0.8090169943749475`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.30901699437494745`"}], ",", 
     RowBox[{"-", "0.9510565162951535`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", 
     RowBox[{"-", "1.`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.30901699437494745`", ",", 
     RowBox[{"-", "0.9510565162951535`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.5877852522924731`", ",", 
     RowBox[{"-", "0.8090169943749475`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.8090169943749475`", ",", 
     RowBox[{"-", "0.5877852522924731`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.9510565162951535`", ",", 
     RowBox[{"-", "0.30901699437494745`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "0.`"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.4284874319375*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"p1", "=", 
  RowBox[{"ListPlot", "[", 
   RowBox[{"plist", ",", 
    RowBox[{"PlotJoined", "\[Rule]", "True"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", "colors", "}"}]}]}], "]"}]}]], "Input"],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[0., 0., 1.], 
    LineBox[{{1., 0.}, {0.9510565162951535, 0.30901699437494745`}, {
     0.8090169943749475, 0.5877852522924731}, {0.5877852522924731, 
     0.8090169943749475}, {0.30901699437494745`, 0.9510565162951535}, {0., 
     1.}, {-0.30901699437494745`, 0.9510565162951535}, {-0.5877852522924731, 
     0.8090169943749475}, {-0.8090169943749475, 
     0.5877852522924731}, {-0.9510565162951535, 0.30901699437494745`}, {-1., 
     0.}, {-0.9510565162951535, -0.30901699437494745`}, {-0.8090169943749475, \
-0.5877852522924731}, {-0.5877852522924731, -0.8090169943749475}, \
{-0.30901699437494745`, -0.9510565162951535}, {0., -1.}, {
     0.30901699437494745`, -0.9510565162951535}, {
     0.5877852522924731, -0.8090169943749475}, {
     0.8090169943749475, -0.5877852522924731}, {
     0.9510565162951535, -0.30901699437494745`}, {1., 0.}}]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{-1., 1.}, {-1., 1.}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.428487432640625*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"p1", ",", "plotAll", ",", 
   RowBox[{"AspectRatio", "\[Rule]", "Automatic"}]}], "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {RGBColor[0., 0., 1.], 
     LineBox[{{1., 0.}, {0.9510565162951535, 0.30901699437494745`}, {
      0.8090169943749475, 0.5877852522924731}, {0.5877852522924731, 
      0.8090169943749475}, {0.30901699437494745`, 0.9510565162951535}, {0., 
      1.}, {-0.30901699437494745`, 0.9510565162951535}, {-0.5877852522924731, 
      0.8090169943749475}, {-0.8090169943749475, 
      0.5877852522924731}, {-0.9510565162951535, 0.30901699437494745`}, {-1., 
      0.}, {-0.9510565162951535, -0.30901699437494745`}, \
{-0.8090169943749475, -0.5877852522924731}, {-0.5877852522924731, \
-0.8090169943749475}, {-0.30901699437494745`, -0.9510565162951535}, {
      0., -1.}, {0.30901699437494745`, -0.9510565162951535}, {
      0.5877852522924731, -0.8090169943749475}, {
      0.8090169943749475, -0.5877852522924731}, {
      0.9510565162951535, -0.30901699437494745`}, {1., 0.}}]}}, {{}, {}, 
    {RGBColor[1., 0., 0.], LineBox[CompressedData["
1:eJw123c81W/YB3CiFAmpVCo00FIo7S6hYWREaf2yUkJmJaKkpFDZeySyZe9x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      "]]}}},
  AspectRatio->Automatic,
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{-1., 1.}, {-1., 1.}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.428487433484375*^9},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowToolbars->"RulerBar",
WindowSize->{747, 678},
WindowMargins->{{37, Automatic}, {Automatic, 17}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
PageHeaders->{{
   Cell[
    TextData[{
      CounterBox["Page"]}], "PageNumber"], Inherited, 
   Cell[
    TextData[{
      ValueBox["FileName"]}], "Header"]}, {
   Cell[
    TextData[{
      ValueBox["FileName"]}], "Header"], Inherited, 
   Cell[
    TextData[{
      CounterBox["Page"]}], "PageNumber"]}},
PrintingOptions->{"PrintCellBrackets"->False,
"PrintMultipleHorizontalPages"->False,
"PrintRegistrationMarks"->True,
"PrintingMargins"->{{54, 54}, {54, 54}}},
Magnification->1,
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (April 28, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[590, 23, 26, 0, 83, "Title"],
Cell[619, 25, 175, 7, 64, "Subsubtitle"],
Cell[797, 34, 247, 7, 51, "Text"],
Cell[CellGroupData[{
Cell[1069, 45, 25, 0, 71, "Section"],
Cell[1097, 47, 195, 4, 31, "Text"],
Cell[1295, 53, 896, 27, 132, "Input"],
Cell[2194, 82, 685, 21, 172, "Input"],
Cell[CellGroupData[{
Cell[2904, 107, 873, 23, 92, "Input"],
Cell[3780, 132, 19256, 320, 375, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[23085, 458, 28, 0, 71, "Section"],
Cell[CellGroupData[{
Cell[23138, 462, 468, 15, 46, "Input"],
Cell[23609, 479, 94, 2, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23740, 486, 54, 1, 31, "Input"],
Cell[23797, 489, 87, 1, 30, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[23933, 496, 38, 0, 71, "Section"],
Cell[CellGroupData[{
Cell[23996, 500, 462, 15, 112, "Input"],
Cell[24461, 517, 94, 2, 43, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[24592, 524, 2141, 58, 254, "Input"],
Cell[26736, 584, 72, 1, 30, "Output"],
Cell[26811, 587, 138, 4, 30, "Output"],
Cell[CellGroupData[{
Cell[26974, 595, 719, 17, 36, "Print"],
Cell[27696, 614, 787, 20, 23, "Print"],
Cell[28486, 636, 946, 25, 38, "Print"],
Cell[29435, 663, 984, 25, 23, "Print"]
}, Open  ]],
Cell[30434, 691, 85, 1, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[30556, 697, 58, 1, 31, "Input"],
Cell[30617, 700, 452, 15, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[31106, 720, 236, 6, 31, "Input"],
Cell[31345, 728, 404, 12, 237, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[31786, 745, 145, 3, 31, "Input"],
Cell[31934, 750, 19410, 326, 365, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[51393, 1082, 54, 1, 63, "Section"],
Cell[CellGroupData[{
Cell[51472, 1087, 2409, 69, 354, "Input"],
Cell[53884, 1158, 93, 2, 43, "Output"],
Cell[53980, 1162, 85, 1, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[54102, 1168, 58, 1, 31, "Input"],
Cell[54163, 1171, 1249, 37, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[55449, 1213, 236, 6, 31, "Input"],
Cell[55688, 1221, 796, 17, 231, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[56521, 1243, 145, 3, 31, "Input"],
Cell[56669, 1248, 19803, 331, 347, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[76521, 1585, 42, 0, 71, "Section"],
Cell[CellGroupData[{
Cell[76588, 1589, 2458, 71, 354, "Input"],
Cell[79049, 1662, 95, 2, 43, "Output"],
Cell[79147, 1666, 85, 1, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[79269, 1672, 58, 1, 31, "Input"],
Cell[79330, 1675, 2342, 69, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[81709, 1749, 236, 6, 31, "Input"],
Cell[81948, 1757, 1175, 24, 237, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[83160, 1786, 145, 3, 31, "Input"],
Cell[83308, 1791, 32359, 538, 365, 20140, 336, "CachedBoxData", "BoxData", \
"Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

