(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     56008,       1995]*)
(*NotebookOutlinePosition[     56858,       2024]*)
(*  CellTagsIndexPosition[     56814,       2020]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Series Solutions", "Title",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " commands used:\nSum, O, D, LogicalExpand, Solve, Collect, Table\n\
Coefficient, Denominator, Factor Integer, Factorial\t\t\t\t\t\t\t\t\t"
}], "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Series solutions near an ordinary point for a second order, linear, \
homogenous DE
    (1-x) y'' + y = 0\
\>", "Section",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["3 terms in each of 2 linearly independent solns", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
First state the form of the solution to a desired number of \
terms.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(Clear[y, a, y1, y2, i, x, lhs, \ ysoln]\)], "Input"],

Cell[CellGroupData[{

Cell["y=Sum[a[i] x^i, {i,0,6}] + O[x]^7", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    InterpretationBox[
      RowBox[{\(a[0]\), "+", \(a[1]\ x\), "+", \(a[2]\ x\^2\), 
        "+", \(a[3]\ x\^3\), "+", \(a[4]\ x\^4\), "+", \(a[5]\ x\^5\), 
        "+", \(a[6]\ x\^6\), "+", 
        InterpretationBox[\(O[x]\^7\),
          SeriesData[ x, 0, {}, 0, 7, 1]]}],
      SeriesData[ x, 0, {
        a[ 0], 
        a[ 1], 
        a[ 2], 
        a[ 3], 
        a[ 4], 
        a[ 5], 
        a[ 6]}, 0, 7, 1]]], "Output"]
}, Open  ]],

Cell["Calculate the necessary derivatives", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["y1=D[y,x]", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    InterpretationBox[
      RowBox[{\(a[1]\), "+", \(2\ a[2]\ x\), "+", \(3\ a[3]\ x\^2\), 
        "+", \(4\ a[4]\ x\^3\), "+", \(5\ a[5]\ x\^4\), 
        "+", \(6\ a[6]\ x\^5\), "+", 
        InterpretationBox[\(O[x]\^6\),
          SeriesData[ x, 0, {}, 0, 6, 1]]}],
      SeriesData[ x, 0, {
        a[ 1], 
        Times[ 2, 
          a[ 2]], 
        Times[ 3, 
          a[ 3]], 
        Times[ 4, 
          a[ 4]], 
        Times[ 5, 
          a[ 5]], 
        Times[ 6, 
          a[ 6]]}, 0, 6, 1]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["y2=D[y1,x]", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    InterpretationBox[
      RowBox[{\(2\ a[2]\), "+", \(6\ a[3]\ x\), "+", \(12\ a[4]\ x\^2\), 
        "+", \(20\ a[5]\ x\^3\), "+", \(30\ a[6]\ x\^4\), "+", 
        InterpretationBox[\(O[x]\^5\),
          SeriesData[ x, 0, {}, 0, 5, 1]]}],
      SeriesData[ x, 0, {
        Times[ 2, 
          a[ 2]], 
        Times[ 6, 
          a[ 3]], 
        Times[ 12, 
          a[ 4]], 
        Times[ 20, 
          a[ 5]], 
        Times[ 30, 
          a[ 6]]}, 0, 5, 1]]], "Output"]
}, Open  ]],

Cell["\<\
Substitute y and its derivatives into the differential \
equation.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["lhs=Expand[(1-x)*y2+y]", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    InterpretationBox[
      RowBox[{\((a[0] + 2\ a[2])\), 
        "+", \(\((a[1] - 2\ a[2] + 6\ a[3])\)\ x\), 
        "+", \(\((a[2] - 6\ a[3] + 12\ a[4])\)\ x\^2\), 
        "+", \(\((a[3] - 12\ a[4] + 20\ a[5])\)\ x\^3\), 
        "+", \(\((a[4] - 20\ a[5] + 30\ a[6])\)\ x\^4\), "+", 
        InterpretationBox[\(O[x]\^5\),
          SeriesData[ x, 0, {}, 0, 5, 1]]}],
      SeriesData[ x, 0, {
        Plus[ 
          a[ 0], 
          Times[ 2, 
            a[ 2]]], 
        Plus[ 
          a[ 1], 
          Times[ -2, 
            a[ 2]], 
          Times[ 6, 
            a[ 3]]], 
        Plus[ 
          a[ 2], 
          Times[ -6, 
            a[ 3]], 
          Times[ 12, 
            a[ 4]]], 
        Plus[ 
          a[ 3], 
          Times[ -12, 
            a[ 4]], 
          Times[ 20, 
            a[ 5]]], 
        Plus[ 
          a[ 4], 
          Times[ -20, 
            a[ 5]], 
          Times[ 30, 
            a[ 6]]]}, 0, 5, 1]]], "Output"]
}, Open  ]],

Cell["Equate the coefficients for corresponding powers of x.", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["LogicalExpand[lhs==0]", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(a[0] + 2\ a[2] == 0 && a[1] - 2\ a[2] + 6\ a[3] == 0 && 
      a[2] - 6\ a[3] + 12\ a[4] == 0 && a[3] - 12\ a[4] + 20\ a[5] == 0 && 
      a[4] - 20\ a[5] + 30\ a[6] == 0\)], "Output"]
}, Open  ]],

Cell["\<\
Since this is second order, we should be able to solve for all but \
the first two terms in the series solution.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["Solve[%,{a[2],a[3],a[4],a[5],a[6]}]", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \({{a[2] \[Rule] \(-\(a[0]\/2\)\), 
        a[3] \[Rule] 1\/6\ \((\(-a[0]\) - a[1])\), 
        a[4] \[Rule] 1\/24\ \((\(-a[0]\) - 2\ a[1])\), 
        a[5] \[Rule] 1\/120\ \((\(-2\)\ a[0] - 5\ a[1])\), 
        a[6] \[Rule] 1\/720\ \((\(-7\)\ a[0] - 18\ a[1])\)}}\)], "Output"]
}, Open  ]],

Cell["Substitute these back into y.", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["{ysoln}=y/.%", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    RowBox[{"{", 
      InterpretationBox[
        RowBox[{\(a[0]\), "+", \(a[1]\ x\), "-", \(1\/2\ a[0]\ x\^2\), 
          "+", \(1\/6\ \((\(-a[0]\) - a[1])\)\ x\^3\), 
          "+", \(1\/24\ \((\(-a[0]\) - 2\ a[1])\)\ x\^4\), 
          "+", \(1\/120\ \((\(-2\)\ a[0] - 5\ a[1])\)\ x\^5\), 
          "+", \(1\/720\ \((\(-7\)\ a[0] - 18\ a[1])\)\ x\^6\), "+", 
          InterpretationBox[\(O[x]\^7\),
            SeriesData[ x, 0, {}, 0, 7, 1]]}],
        SeriesData[ x, 0, {
          a[ 0], 
          a[ 1], 
          Times[ 
            Rational[ -1, 2], 
            a[ 0]], 
          Times[ 
            Rational[ 1, 6], 
            Plus[ 
              Times[ -1, 
                a[ 0]], 
              Times[ -1, 
                a[ 1]]]], 
          Times[ 
            Rational[ 1, 24], 
            Plus[ 
              Times[ -1, 
                a[ 0]], 
              Times[ -2, 
                a[ 1]]]], 
          Times[ 
            Rational[ 1, 120], 
            Plus[ 
              Times[ -2, 
                a[ 0]], 
              Times[ -5, 
                a[ 1]]]], 
          Times[ 
            Rational[ 1, 720], 
            Plus[ 
              Times[ -7, 
                a[ 0]], 
              Times[ -18, 
                a[ 1]]]]}, 0, 7, 1]], "}"}]], "Output"]
}, Open  ]],

Cell["\<\
Collect the terms for the two linearly independent series \
solutions.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["ysoln=Collect[ysoln,{a[0],a[1]}]", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(\((1 - x\^2\/2 - x\^3\/6 - x\^4\/24 - x\^5\/60 - \(7\ x\^6\)\/720)\)\ a[
          0] + \((x - x\^3\/6 - x\^4\/12 - x\^5\/24 - x\^6\/40)\)\ a[
          1]\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell["Aiding in handwork.", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[
      a[k + 2]\  == 
        k/\((k + 2)\)\ *\ a[k + 1]\  - \ 
          1/\((\((k + 1)\)*\((k + 2)\))\)\ a[k], {k, 1, 4}]\)], "Input"],

Cell[BoxData[
    \({a[3] == \(-\(a[1]\/6\)\) + a[2]\/3, 
      a[4] == \(-\(a[2]\/12\)\) + a[3]\/2, 
      a[5] == \(-\(a[3]\/20\)\) + \(3\ a[4]\)\/5, 
      a[6] == \(-\(a[4]\/30\)\) + \(2\ a[5]\)\/3}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(a[3] == \(-\(a[1]\/6\)\) + a[2]\/3 /. 
      a[2] \[Rule] \(-1\)/2\ a[0]\)], "Input"],

Cell[BoxData[
    \(a[3] == \(-\(a[0]\/6\)\) - a[1]\/6\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(a[4] == \(-\(a[2]\/12\)\) + 
          a[3]\/2\  /. {a[3] \[Rule] \(-\ \(a[0]\/6\)\) - a[1]\/6, 
        a[2] \[Rule] \ \(-a[0]\)/2}\)], "Input"],

Cell[BoxData[
    \(a[4] == a[0]\/24 + 1\/2\ \((\(-\(a[0]\/6\)\) - a[1]\/6)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simplify[%]\)], "Input"],

Cell[BoxData[
    \(1\/24\ \((a[0] + 2\ a[1])\) + a[4] == 0\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Solve[%, a[4]]\)], "Input"],

Cell[BoxData[
    \({{a[4] \[Rule] 1\/24\ \((\(-a[0]\) - 2\ a[1])\)}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(a[5] == \(-\(a[3]\/20\)\) + \(3\ a[4]\)\/5 /. {a[
            3] \[Rule] \ \(-\(a[0]\/6\)\) - a[1]\/6, 
        a[4] \[Rule] \ 1\/24\ \((\(-a[0]\) - 2\ a[1])\)}\)], "Input"],

Cell[BoxData[
    \(a[5] == 
      1\/40\ \((\(-a[0]\) - 2\ a[1])\) + 
        1\/20\ \((a[0]\/6 + a[1]\/6)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simplify[%]\)], "Input"],

Cell[BoxData[
    \(a[0]\/60 + a[1]\/24 + a[5] == 0\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Solve[%, a[5]]\)], "Input"],

Cell[BoxData[
    \({{a[5] \[Rule] 1\/120\ \((\(-2\)\ a[0] - 5\ a[1])\)}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(a[6] == \(-\(a[4]\/30\)\) + \(2\ a[5]\)\/3 /. {a[5] \[Rule] 
          1\/120\ \((\(-2\)\ a[0] - 5\ a[1])\), 
        a[4] \[Rule] \ 1\/24\ \((\(-a[0]\) - 2\ a[1])\)}\)], "Input"],

Cell[BoxData[
    \(a[6] == 
      1\/180\ \((\(-2\)\ a[0] - 5\ a[1])\) + 
        1\/720\ \((a[0] + 2\ a[1])\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simplify[%]\)], "Input"],

Cell[BoxData[
    \(\(7\ a[0]\)\/720 + a[1]\/40 + a[6] == 0\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Solve[%, a[6]]\)], "Input"],

Cell[BoxData[
    \({{a[6] \[Rule] 1\/720\ \((\(-7\)\ a[0] - 18\ a[1])\)}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["10 terms in each solution", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Of course, this same technique is used if we wish to take these to \
10 terms each.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(Clear[y, a, y1, y2, i, x, lhs, \ ysoln, \ eqnset, \ varset, \ u1, \ 
      u2]\)], "Input"],

Cell[CellGroupData[{

Cell["y=Sum[a[i] x^i, {i,0,20}] + O[x]^21", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    InterpretationBox[
      RowBox[{\(a[0]\), "+", \(a[1]\ x\), "+", \(a[2]\ x\^2\), 
        "+", \(a[3]\ x\^3\), "+", \(a[4]\ x\^4\), "+", \(a[5]\ x\^5\), 
        "+", \(a[6]\ x\^6\), "+", \(a[7]\ x\^7\), "+", \(a[8]\ x\^8\), 
        "+", \(a[9]\ x\^9\), "+", \(a[10]\ x\^10\), "+", \(a[11]\ x\^11\), 
        "+", \(a[12]\ x\^12\), "+", \(a[13]\ x\^13\), "+", \(a[14]\ x\^14\), 
        "+", \(a[15]\ x\^15\), "+", \(a[16]\ x\^16\), "+", \(a[17]\ x\^17\), 
        "+", \(a[18]\ x\^18\), "+", \(a[19]\ x\^19\), "+", \(a[20]\ x\^20\), 
        "+", 
        InterpretationBox[\(O[x]\^21\),
          SeriesData[ x, 0, {}, 0, 21, 1]]}],
      SeriesData[ x, 0, {
        a[ 0], 
        a[ 1], 
        a[ 2], 
        a[ 3], 
        a[ 4], 
        a[ 5], 
        a[ 6], 
        a[ 7], 
        a[ 8], 
        a[ 9], 
        a[ 10], 
        a[ 11], 
        a[ 12], 
        a[ 13], 
        a[ 14], 
        a[ 15], 
        a[ 16], 
        a[ 17], 
        a[ 18], 
        a[ 19], 
        a[ 20]}, 0, 21, 1]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["y1=D[y,x]", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    InterpretationBox[
      RowBox[{\(a[1]\), "+", \(2\ a[2]\ x\), "+", \(3\ a[3]\ x\^2\), 
        "+", \(4\ a[4]\ x\^3\), "+", \(5\ a[5]\ x\^4\), 
        "+", \(6\ a[6]\ x\^5\), "+", \(7\ a[7]\ x\^6\), 
        "+", \(8\ a[8]\ x\^7\), "+", \(9\ a[9]\ x\^8\), 
        "+", \(10\ a[10]\ x\^9\), "+", \(11\ a[11]\ x\^10\), 
        "+", \(12\ a[12]\ x\^11\), "+", \(13\ a[13]\ x\^12\), 
        "+", \(14\ a[14]\ x\^13\), "+", \(15\ a[15]\ x\^14\), 
        "+", \(16\ a[16]\ x\^15\), "+", \(17\ a[17]\ x\^16\), 
        "+", \(18\ a[18]\ x\^17\), "+", \(19\ a[19]\ x\^18\), 
        "+", \(20\ a[20]\ x\^19\), "+", 
        InterpretationBox[\(O[x]\^20\),
          SeriesData[ x, 0, {}, 0, 20, 1]]}],
      SeriesData[ x, 0, {
        a[ 1], 
        Times[ 2, 
          a[ 2]], 
        Times[ 3, 
          a[ 3]], 
        Times[ 4, 
          a[ 4]], 
        Times[ 5, 
          a[ 5]], 
        Times[ 6, 
          a[ 6]], 
        Times[ 7, 
          a[ 7]], 
        Times[ 8, 
          a[ 8]], 
        Times[ 9, 
          a[ 9]], 
        Times[ 10, 
          a[ 10]], 
        Times[ 11, 
          a[ 11]], 
        Times[ 12, 
          a[ 12]], 
        Times[ 13, 
          a[ 13]], 
        Times[ 14, 
          a[ 14]], 
        Times[ 15, 
          a[ 15]], 
        Times[ 16, 
          a[ 16]], 
        Times[ 17, 
          a[ 17]], 
        Times[ 18, 
          a[ 18]], 
        Times[ 19, 
          a[ 19]], 
        Times[ 20, 
          a[ 20]]}, 0, 20, 1]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["y2=D[y1,x]", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    InterpretationBox[
      RowBox[{\(2\ a[2]\), "+", \(6\ a[3]\ x\), "+", \(12\ a[4]\ x\^2\), 
        "+", \(20\ a[5]\ x\^3\), "+", \(30\ a[6]\ x\^4\), 
        "+", \(42\ a[7]\ x\^5\), "+", \(56\ a[8]\ x\^6\), 
        "+", \(72\ a[9]\ x\^7\), "+", \(90\ a[10]\ x\^8\), 
        "+", \(110\ a[11]\ x\^9\), "+", \(132\ a[12]\ x\^10\), 
        "+", \(156\ a[13]\ x\^11\), "+", \(182\ a[14]\ x\^12\), 
        "+", \(210\ a[15]\ x\^13\), "+", \(240\ a[16]\ x\^14\), 
        "+", \(272\ a[17]\ x\^15\), "+", \(306\ a[18]\ x\^16\), 
        "+", \(342\ a[19]\ x\^17\), "+", \(380\ a[20]\ x\^18\), "+", 
        InterpretationBox[\(O[x]\^19\),
          SeriesData[ x, 0, {}, 0, 19, 1]]}],
      SeriesData[ x, 0, {
        Times[ 2, 
          a[ 2]], 
        Times[ 6, 
          a[ 3]], 
        Times[ 12, 
          a[ 4]], 
        Times[ 20, 
          a[ 5]], 
        Times[ 30, 
          a[ 6]], 
        Times[ 42, 
          a[ 7]], 
        Times[ 56, 
          a[ 8]], 
        Times[ 72, 
          a[ 9]], 
        Times[ 90, 
          a[ 10]], 
        Times[ 110, 
          a[ 11]], 
        Times[ 132, 
          a[ 12]], 
        Times[ 156, 
          a[ 13]], 
        Times[ 182, 
          a[ 14]], 
        Times[ 210, 
          a[ 15]], 
        Times[ 240, 
          a[ 16]], 
        Times[ 272, 
          a[ 17]], 
        Times[ 306, 
          a[ 18]], 
        Times[ 342, 
          a[ 19]], 
        Times[ 380, 
          a[ 20]]}, 0, 19, 1]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["lhs=Expand[(1-x)*y2+y]", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    InterpretationBox[
      RowBox[{\((a[0] + 2\ a[2])\), 
        "+", \(\((a[1] - 2\ a[2] + 6\ a[3])\)\ x\), 
        "+", \(\((a[2] - 6\ a[3] + 12\ a[4])\)\ x\^2\), 
        "+", \(\((a[3] - 12\ a[4] + 20\ a[5])\)\ x\^3\), 
        "+", \(\((a[4] - 20\ a[5] + 30\ a[6])\)\ x\^4\), 
        "+", \(\((a[5] - 30\ a[6] + 42\ a[7])\)\ x\^5\), 
        "+", \(\((a[6] - 42\ a[7] + 56\ a[8])\)\ x\^6\), 
        "+", \(\((a[7] - 56\ a[8] + 72\ a[9])\)\ x\^7\), 
        "+", \(\((a[8] - 72\ a[9] + 90\ a[10])\)\ x\^8\), 
        "+", \(\((a[9] - 90\ a[10] + 110\ a[11])\)\ x\^9\), 
        "+", \(\((a[10] - 110\ a[11] + 132\ a[12])\)\ x\^10\), 
        "+", \(\((a[11] - 132\ a[12] + 156\ a[13])\)\ x\^11\), 
        "+", \(\((a[12] - 156\ a[13] + 182\ a[14])\)\ x\^12\), 
        "+", \(\((a[13] - 182\ a[14] + 210\ a[15])\)\ x\^13\), 
        "+", \(\((a[14] - 210\ a[15] + 240\ a[16])\)\ x\^14\), 
        "+", \(\((a[15] - 240\ a[16] + 272\ a[17])\)\ x\^15\), 
        "+", \(\((a[16] - 272\ a[17] + 306\ a[18])\)\ x\^16\), 
        "+", \(\((a[17] - 306\ a[18] + 342\ a[19])\)\ x\^17\), 
        "+", \(\((a[18] - 342\ a[19] + 380\ a[20])\)\ x\^18\), "+", 
        InterpretationBox[\(O[x]\^19\),
          SeriesData[ x, 0, {}, 0, 19, 1]]}],
      SeriesData[ x, 0, {
        Plus[ 
          a[ 0], 
          Times[ 2, 
            a[ 2]]], 
        Plus[ 
          a[ 1], 
          Times[ -2, 
            a[ 2]], 
          Times[ 6, 
            a[ 3]]], 
        Plus[ 
          a[ 2], 
          Times[ -6, 
            a[ 3]], 
          Times[ 12, 
            a[ 4]]], 
        Plus[ 
          a[ 3], 
          Times[ -12, 
            a[ 4]], 
          Times[ 20, 
            a[ 5]]], 
        Plus[ 
          a[ 4], 
          Times[ -20, 
            a[ 5]], 
          Times[ 30, 
            a[ 6]]], 
        Plus[ 
          a[ 5], 
          Times[ -30, 
            a[ 6]], 
          Times[ 42, 
            a[ 7]]], 
        Plus[ 
          a[ 6], 
          Times[ -42, 
            a[ 7]], 
          Times[ 56, 
            a[ 8]]], 
        Plus[ 
          a[ 7], 
          Times[ -56, 
            a[ 8]], 
          Times[ 72, 
            a[ 9]]], 
        Plus[ 
          a[ 8], 
          Times[ -72, 
            a[ 9]], 
          Times[ 90, 
            a[ 10]]], 
        Plus[ 
          a[ 9], 
          Times[ -90, 
            a[ 10]], 
          Times[ 110, 
            a[ 11]]], 
        Plus[ 
          a[ 10], 
          Times[ -110, 
            a[ 11]], 
          Times[ 132, 
            a[ 12]]], 
        Plus[ 
          a[ 11], 
          Times[ -132, 
            a[ 12]], 
          Times[ 156, 
            a[ 13]]], 
        Plus[ 
          a[ 12], 
          Times[ -156, 
            a[ 13]], 
          Times[ 182, 
            a[ 14]]], 
        Plus[ 
          a[ 13], 
          Times[ -182, 
            a[ 14]], 
          Times[ 210, 
            a[ 15]]], 
        Plus[ 
          a[ 14], 
          Times[ -210, 
            a[ 15]], 
          Times[ 240, 
            a[ 16]]], 
        Plus[ 
          a[ 15], 
          Times[ -240, 
            a[ 16]], 
          Times[ 272, 
            a[ 17]]], 
        Plus[ 
          a[ 16], 
          Times[ -272, 
            a[ 17]], 
          Times[ 306, 
            a[ 18]]], 
        Plus[ 
          a[ 17], 
          Times[ -306, 
            a[ 18]], 
          Times[ 342, 
            a[ 19]]], 
        Plus[ 
          a[ 18], 
          Times[ -342, 
            a[ 19]], 
          Times[ 380, 
            a[ 20]]]}, 0, 19, 1]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["eqnset=LogicalExpand[lhs==0]", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(a[0] + 2\ a[2] == 0 && a[1] - 2\ a[2] + 6\ a[3] == 0 && 
      a[2] - 6\ a[3] + 12\ a[4] == 0 && a[3] - 12\ a[4] + 20\ a[5] == 0 && 
      a[4] - 20\ a[5] + 30\ a[6] == 0 && a[5] - 30\ a[6] + 42\ a[7] == 0 && 
      a[6] - 42\ a[7] + 56\ a[8] == 0 && a[7] - 56\ a[8] + 72\ a[9] == 0 && 
      a[8] - 72\ a[9] + 90\ a[10] == 0 && a[9] - 90\ a[10] + 110\ a[11] == 0 && 
      a[10] - 110\ a[11] + 132\ a[12] == 0 && 
      a[11] - 132\ a[12] + 156\ a[13] == 0 && 
      a[12] - 156\ a[13] + 182\ a[14] == 0 && 
      a[13] - 182\ a[14] + 210\ a[15] == 0 && 
      a[14] - 210\ a[15] + 240\ a[16] == 0 && 
      a[15] - 240\ a[16] + 272\ a[17] == 0 && 
      a[16] - 272\ a[17] + 306\ a[18] == 0 && 
      a[17] - 306\ a[18] + 342\ a[19] == 0 && 
      a[18] - 342\ a[19] + 380\ a[20] == 0\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["varset=Table[a[i],{i,2,20}]", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \({a[2], a[3], a[4], a[5], a[6], a[7], a[8], a[9], a[10], a[11], a[12], 
      a[13], a[14], a[15], a[16], a[17], a[18], a[19], a[20]}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Solve[eqnset,varset]", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \({{a[2] \[Rule] \(-\(a[0]\/2\)\), 
        a[3] \[Rule] 1\/6\ \((\(-a[0]\) - a[1])\), 
        a[4] \[Rule] 1\/24\ \((\(-a[0]\) - 2\ a[1])\), 
        a[5] \[Rule] 1\/120\ \((\(-2\)\ a[0] - 5\ a[1])\), 
        a[6] \[Rule] 1\/720\ \((\(-7\)\ a[0] - 18\ a[1])\), 
        a[7] \[Rule] \(\(-33\)\ a[0] - 85\ a[1]\)\/5040, 
        a[8] \[Rule] \(\(-191\)\ a[0] - 492\ a[1]\)\/40320, 
        a[9] \[Rule] \(\(-1304\)\ a[0] - 3359\ a[1]\)\/362880, 
        a[10] \[Rule] \(\(-10241\)\ a[0] - 26380\ a[1]\)\/3628800, 
        a[11] \[Rule] \(\(-90865\)\ a[0] - 234061\ a[1]\)\/39916800, 
        a[12] \[Rule] \(\(-898409\)\ a[0] - 2314230\ a[1]\)\/479001600, 
        a[13] \[Rule] \(\(-9791634\)\ a[0] - 25222469\ a[1]\)\/6227020800, 
        a[14] \[Rule] \(\(-116601199\)\ a[0] - 300355398\ \
a[1]\)\/87178291200, 
        a[15] \[Rule] \(\(-1506023953\)\ a[0] - 3879397705\ \
a[1]\)\/1307674368000, 
        a[16] \[Rule] \(\(-20967734143\)\ a[0] - 54011212472\ \
a[1]\)\/20922789888000, 
        a[17] \[Rule] \(\(-313009988192\)\ a[0] - 806288789375\ \
a[1]\)\/355687428096000, 
        a[18] \[Rule] \(\(-4987192076929\)\ a[0] - 12846609417528\ \
a[1]\)\/6402373705728000, 
        a[19] \[Rule] \(\(-84469255319601\)\ a[0] - 217586071308601\ \
a[1]\)\/121645100408832000, 
        a[20] \[Rule] \(\(-1515459403675889\)\ a[0] - 3903702674137290\ \
a[1]\)\/2432902008176640000}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["{ysoln}=y/.%", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    RowBox[{"{", 
      InterpretationBox[
        RowBox[{\(a[0]\), "+", \(a[1]\ x\), "-", \(1\/2\ a[0]\ x\^2\), 
          "+", \(1\/6\ \((\(-a[0]\) - a[1])\)\ x\^3\), 
          "+", \(1\/24\ \((\(-a[0]\) - 2\ a[1])\)\ x\^4\), 
          "+", \(1\/120\ \((\(-2\)\ a[0] - 5\ a[1])\)\ x\^5\), 
          "+", \(1\/720\ \((\(-7\)\ a[0] - 18\ a[1])\)\ x\^6\), 
          "+", \(\(\((\(-33\)\ a[0] - 85\ a[1])\)\ x\^7\)\/5040\), 
          "+", \(\(\((\(-191\)\ a[0] - 492\ a[1])\)\ x\^8\)\/40320\), 
          "+", \(\(\((\(-1304\)\ a[0] - 3359\ a[1])\)\ x\^9\)\/362880\), 
          "+", \(\(\((\(-10241\)\ a[0] - 26380\ a[1])\)\ x\^10\)\/3628800\), 
          "+", \(\(\((\(-90865\)\ a[0] - 234061\ a[1])\)\ x\^11\)\/39916800\),
           "+", \(\(\((\(-898409\)\ a[0] - 
                    2314230\ a[1])\)\ x\^12\)\/479001600\), 
          "+", \(\(\((\(-9791634\)\ a[0] - 
                    25222469\ a[1])\)\ x\^13\)\/6227020800\), 
          "+", \(\(\((\(-116601199\)\ a[0] - 
                    300355398\ a[1])\)\ x\^14\)\/87178291200\), 
          "+", \(\(\((\(-1506023953\)\ a[0] - 
                    3879397705\ a[1])\)\ x\^15\)\/1307674368000\), 
          "+", \(\(\((\(-20967734143\)\ a[0] - 
                    54011212472\ a[1])\)\ x\^16\)\/20922789888000\), 
          "+", \(\(\((\(-313009988192\)\ a[0] - 
                    806288789375\ a[1])\)\ x\^17\)\/355687428096000\), 
          "+", \(\(\((\(-4987192076929\)\ a[0] - 
                    12846609417528\ a[1])\)\ x\^18\)\/6402373705728000\), 
          "+", \(\(\((\(-84469255319601\)\ a[0] - 
                    217586071308601\ a[1])\)\ x\^19\)\/121645100408832000\), 
          "+", \(\(\((\(-1515459403675889\)\ a[0] - 
                    3903702674137290\ a[1])\)\ x\^20\)\/2432902008176640000\),
           "+", 
          InterpretationBox[\(O[x]\^21\),
            SeriesData[ x, 0, {}, 0, 21, 1]]}],
        SeriesData[ x, 0, {
          a[ 0], 
          a[ 1], 
          Times[ 
            Rational[ -1, 2], 
            a[ 0]], 
          Times[ 
            Rational[ 1, 6], 
            Plus[ 
              Times[ -1, 
                a[ 0]], 
              Times[ -1, 
                a[ 1]]]], 
          Times[ 
            Rational[ 1, 24], 
            Plus[ 
              Times[ -1, 
                a[ 0]], 
              Times[ -2, 
                a[ 1]]]], 
          Times[ 
            Rational[ 1, 120], 
            Plus[ 
              Times[ -2, 
                a[ 0]], 
              Times[ -5, 
                a[ 1]]]], 
          Times[ 
            Rational[ 1, 720], 
            Plus[ 
              Times[ -7, 
                a[ 0]], 
              Times[ -18, 
                a[ 1]]]], 
          Times[ 
            Rational[ 1, 5040], 
            Plus[ 
              Times[ -33, 
                a[ 0]], 
              Times[ -85, 
                a[ 1]]]], 
          Times[ 
            Rational[ 1, 40320], 
            Plus[ 
              Times[ -191, 
                a[ 0]], 
              Times[ -492, 
                a[ 1]]]], 
          Times[ 
            Rational[ 1, 362880], 
            Plus[ 
              Times[ -1304, 
                a[ 0]], 
              Times[ -3359, 
                a[ 1]]]], 
          Times[ 
            Rational[ 1, 3628800], 
            Plus[ 
              Times[ -10241, 
                a[ 0]], 
              Times[ -26380, 
                a[ 1]]]], 
          Times[ 
            Rational[ 1, 39916800], 
            Plus[ 
              Times[ -90865, 
                a[ 0]], 
              Times[ -234061, 
                a[ 1]]]], 
          Times[ 
            Rational[ 1, 479001600], 
            Plus[ 
              Times[ -898409, 
                a[ 0]], 
              Times[ -2314230, 
                a[ 1]]]], 
          Times[ 
            Rational[ 1, 6227020800], 
            Plus[ 
              Times[ -9791634, 
                a[ 0]], 
              Times[ -25222469, 
                a[ 1]]]], 
          Times[ 
            Rational[ 1, 87178291200], 
            Plus[ 
              Times[ -116601199, 
                a[ 0]], 
              Times[ -300355398, 
                a[ 1]]]], 
          Times[ 
            Rational[ 1, 1307674368000], 
            Plus[ 
              Times[ -1506023953, 
                a[ 0]], 
              Times[ -3879397705, 
                a[ 1]]]], 
          Times[ 
            Rational[ 1, 20922789888000], 
            Plus[ 
              Times[ -20967734143, 
                a[ 0]], 
              Times[ -54011212472, 
                a[ 1]]]], 
          Times[ 
            Rational[ 1, 355687428096000], 
            Plus[ 
              Times[ -313009988192, 
                a[ 0]], 
              Times[ -806288789375, 
                a[ 1]]]], 
          Times[ 
            Rational[ 1, 6402373705728000], 
            Plus[ 
              Times[ -4987192076929, 
                a[ 0]], 
              Times[ -12846609417528, 
                a[ 1]]]], 
          Times[ 
            Rational[ 1, 121645100408832000], 
            Plus[ 
              Times[ -84469255319601, 
                a[ 0]], 
              Times[ -217586071308601, 
                a[ 1]]]], 
          Times[ 
            Rational[ 1, 2432902008176640000], 
            Plus[ 
              Times[ -1515459403675889, 
                a[ 0]], 
              Times[ -3903702674137290, 
                a[ 1]]]]}, 0, 21, 1]], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ysoln=Collect[ysoln,{a[0],a[1]}]", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(\((1 - x\^2\/2 - x\^3\/6 - x\^4\/24 - 
            x\^5\/60 - \(7\ x\^6\)\/720 - \(11\ x\^7\)\/1680 - \(191\ \
x\^8\)\/40320 - \(163\ x\^9\)\/45360 - \(1463\ x\^10\)\/518400 - \(18173\ \
x\^11\)\/7983360 - \(898409\ x\^12\)\/479001600 - \(1631939\ \
x\^13\)\/1037836800 - \(815393\ x\^14\)\/609638400 - \(215146279\ \
x\^15\)\/186810624000 - \(20967734143\ x\^16\)\/20922789888000 - \(889232921\ \
x\^17\)\/1010475648000 - \(4987192076929\ x\^18\)\/6402373705728000 - \
\(164657417777\ x\^19\)\/237124952064000 - \(30927742932161\ \
x\^20\)\/49651061391360000)\)\ a[
          0] + \((x - x\^3\/6 - x\^4\/12 - x\^5\/24 - 
            x\^6\/40 - \(17\ x\^7\)\/1008 - \(41\ x\^8\)\/3360 - \(3359\ x\^9\
\)\/362880 - \(1319\ x\^10\)\/181440 - \(234061\ x\^11\)\/39916800 - \(77141\ \
x\^12\)\/15966720 - \(25222469\ x\^13\)\/6227020800 - \(113513\ \
x\^14\)\/32947200 - \(775879541\ x\^15\)\/261534873600 - \(964485937\ x\^16\)\
\/373621248000 - \(6450310315\ x\^17\)\/2845499424768 - \(178425130799\ x\^18\
\)\/88921857024000 - \(217586071308601\ x\^19\)\/121645100408832000 - \
\(2282867060899\ x\^20\)\/1422749712384000)\)\ a[1]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["u1=Coefficient[ysoln,a[0]]", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(1 - x\^2\/2 - x\^3\/6 - x\^4\/24 - 
      x\^5\/60 - \(7\ x\^6\)\/720 - \(11\ x\^7\)\/1680 - \(191\ x\^8\)\/40320 \
- \(163\ x\^9\)\/45360 - \(1463\ x\^10\)\/518400 - \(18173\ x\^11\)\/7983360 \
- \(898409\ x\^12\)\/479001600 - \(1631939\ x\^13\)\/1037836800 - \(815393\ x\
\^14\)\/609638400 - \(215146279\ x\^15\)\/186810624000 - \(20967734143\ x\^16\
\)\/20922789888000 - \(889232921\ x\^17\)\/1010475648000 - \(4987192076929\ x\
\^18\)\/6402373705728000 - \(164657417777\ x\^19\)\/237124952064000 - \
\(30927742932161\ x\^20\)\/49651061391360000\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["u2=Coefficient[ysoln,a[1]]", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(x - x\^3\/6 - x\^4\/12 - x\^5\/24 - 
      x\^6\/40 - \(17\ x\^7\)\/1008 - \(41\ x\^8\)\/3360 - \(3359\ \
x\^9\)\/362880 - \(1319\ x\^10\)\/181440 - \(234061\ x\^11\)\/39916800 - \
\(77141\ x\^12\)\/15966720 - \(25222469\ x\^13\)\/6227020800 - \(113513\ \
x\^14\)\/32947200 - \(775879541\ x\^15\)\/261534873600 - \(964485937\ x\^16\)\
\/373621248000 - \(6450310315\ x\^17\)\/2845499424768 - \(178425130799\ x\^18\
\)\/88921857024000 - \(217586071308601\ x\^19\)\/121645100408832000 - \
\(2282867060899\ x\^20\)\/1422749712384000\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell["\<\
Series solutions near an ordinary point for a second order, linear, \
homogenous DE
    y'' + y = 0\
\>", "Section",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["3 terms in each of 2 linearly independent solns", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
First state the form of the solution to a desired number of \
terms.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(Clear[y, a, y1, y2, i, x, lhs, \ ysoln]\)], "Input"],

Cell[CellGroupData[{

Cell["y=Sum[a[i] x^i, {i,0,6}] + O[x]^7", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
SeriesData[x, 0, {a[0], a[1], a[2], a[3], a[4], \
a[5], 
 
   a[6]}, 0, 7, 1]\
\>", "\<\
                      2         3         4     \
    5
a[0] + a[1] x + a[2] x  + a[3] x  + a[4] x  + a[5] x  + 
 
        6       7
  a[6] x  + O[x]\
\>"], "Output",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell["Calculate the necessary derivatives", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["y1=D[y,x]", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
SeriesData[x, 0, {a[1], 2*a[2], 3*a[3], 4*a[4], \
5*a[5], 
 
   6*a[6]}, 0, 6, 1]\
\>", "\<\
                          2           3       \
    4
a[1] + 2 a[2] x + 3 a[3] x  + 4 a[4] x  + 5 a[5] x  + 
 
          5       6
  6 a[6] x  + O[x]\
\>"], "Output",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["y2=D[y1,x]", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
SeriesData[x, 0, {2*a[2], 6*a[3], 12*a[4], 20*a[5], 
 
   30*a[6]}, 0, 5, 1]\
\>", "\<\
                             2            3  \
          4
2 a[2] + 6 a[3] x + 12 a[4] x  + 20 a[5] x  + 30 a[6] x  + 
 
      5
  O[x]\
\>"], "Output",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell["\<\
Substitute y and its derivatives into the differential \
equation.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["lhs=y2+y", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
SeriesData[x, 0, {a[0] + 2*a[2], a[1] + 6*a[3], 
 
   a[2] + 12*a[4], a[3] + 20*a[5], a[4] + 30*a[6]}, 0, 5, 1]\
\>", "\<\
      \
                                                  2
(a[0] + 2 a[2]) + (a[1] + 6 a[3]) x + (a[2] + 12 a[4]) x  + 
 
                    3                     4       5
  (a[3] + 20 a[5]) x  + (a[4] + 30 a[6]) x  + O[x]\
\>"], "Output",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell["Equate the coefficients for corresponding powers of x.", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["LogicalExpand[lhs==0]", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
a[0] + 2*a[2] == 0 && a[1] + 6*a[3] == 0 && 
 
  a[2] + 12*a[4] == 0 && a[3] + 20*a[5] == 0 && 
 
  a[4] + 30*a[6] == 0\
\>", "\<\
a[0] + 2 a[2] == 0 && a[1] + 6 a[3] == 0 && 
 
  a[2] + 12 a[4] == 0 && a[3] + 20 a[5] == 0 && 
 
  a[4] + 30 a[6] == 0\
\>"], "Output",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell["\<\
Since this is second order, we should be able to solve for all but \
the first two terms in the series solution.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["Solve[%,{a[2],a[3],a[4],a[5],a[6]}]", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
{{a[5] -> a[1]/120, a[6] -> -a[0]/720, a[2] -> \
-a[0]/2, 
 
   a[3] -> -a[1]/6, a[4] -> a[0]/24}}\
\>", "\<\
          a[1]          \
-a[0]          -a[0]          -a[1]
{{a[5] -> ----, a[6] -> -----, a[2] -> -----, a[3] -> -----, 
          120            720             2              6
 
           a[0]
   a[4] -> ----}}
            24\
\>"], "Output",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell["Substitute these back into y.", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["{ysoln}=y/.%", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
{SeriesData[x, 0, {a[0], a[1], -a[0]/2, -a[1]/6, \
a[0]/24, 
 
    a[1]/120, -a[0]/720}, 0, 7, 1]}\
\>", "\<\
                       2       \
  3         4         5
                 a[0] x    a[1] x    a[0] x    a[1] x
{a[0] + a[1] x - ------- - ------- + ------- + ------- - 
                    2         6        24        120
 
         6
   a[0] x        7
   ------- + O[x] }
     720\
\>"], "Output",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell["\<\
Collect the terms for the two linearly independent series \
solutions.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["ysoln=Collect[ysoln,{a[0],a[1]}]", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
(1 - x^2/2 + x^4/24 - x^6/720)*a[0] + (x - x^3/6 + \
x^5/120)*a[1]\
\>", "\<\
      2    4    6                3    5
     x    x    x                x    x
(1 - -- + -- - ---) a[0] + (x - -- + ---) a[1]
     2    24   720              6    120\
\>"], "Output",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["10 terms in each solution", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Of course, this same technique is used if we wish to take these to \
10 terms each.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(Clear[y, a, y1, y2, i, x, lhs, \ ysoln, \ eqnset, \ varset, \ u1, \ 
      u2]\)], "Input"],

Cell[CellGroupData[{

Cell["y=Sum[a[i] x^i, {i,0,20}] + O[x]^21", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
SeriesData[x, 0, {a[0], a[1], a[2], a[3], a[4], \
a[5], a[6], 
 
   a[7], a[8], a[9], a[10], a[11], a[12], a[13], a[14], a[15], 
 
   a[16], a[17], a[18], a[19], a[20]}, 0, 21, 1]\
\>", "\<\
                  \
    2         3         4         5
a[0] + a[1] x + a[2] x  + a[3] x  + a[4] x  + a[5] x  + 
 
        6         7         8         9          10
  a[6] x  + a[7] x  + a[8] x  + a[9] x  + a[10] x   + 
 
         11          12          13          14          15
  a[11] x   + a[12] x   + a[13] x   + a[14] x   + a[15] x   + 
 
         16          17          18          19          20
  a[16] x   + a[17] x   + a[18] x   + a[19] x   + a[20] x   + 
 
      21
  O[x]\
\>"], "Output",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["y1=D[y,x]", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
SeriesData[x, 0, {a[1], 2*a[2], 3*a[3], 4*a[4], \
5*a[5], 6*a[6], 
 
   7*a[7], 8*a[8], 9*a[9], 10*a[10], 11*a[11], 12*a[12], 
 
   13*a[13], 14*a[14], 15*a[15], 16*a[16], 17*a[17], 18*a[18], 
 
   19*a[19], 20*a[20]}, 0, 20, 1]\
\>", "\<\
                          2      \
     3           4
a[1] + 2 a[2] x + 3 a[3] x  + 4 a[4] x  + 5 a[5] x  + 
 
          5           6           7           8             9
  6 a[6] x  + 7 a[7] x  + 8 a[8] x  + 9 a[9] x  + 10 a[10] x  + 
 
            10             11             12             13
  11 a[11] x   + 12 a[12] x   + 13 a[13] x   + 14 a[14] x   + 
 
            14             15             16             17
  15 a[15] x   + 16 a[16] x   + 17 a[17] x   + 18 a[18] x   + 
 
            18             19       20
  19 a[19] x   + 20 a[20] x   + O[x]\
\>"], "Output",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["y2=D[y1,x]", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
SeriesData[x, 0, {2*a[2], 6*a[3], 12*a[4], 20*a[5], \
30*a[6], 
 
   42*a[7], 56*a[8], 72*a[9], 90*a[10], 110*a[11], 132*a[12], 
 
   156*a[13], 182*a[14], 210*a[15], 240*a[16], 272*a[17], 
 
   306*a[18], 342*a[19], 380*a[20]}, 0, 19, 1]\
\>", "\<\
                    \
         2            3            4
2 a[2] + 6 a[3] x + 12 a[4] x  + 20 a[5] x  + 30 a[6] x  + 
 
           5            6            7             8
  42 a[7] x  + 56 a[8] x  + 72 a[9] x  + 90 a[10] x  + 
 
             9              10              11              12
  110 a[11] x  + 132 a[12] x   + 156 a[13] x   + 182 a[14] x   + 
 
             13              14              15
  210 a[15] x   + 240 a[16] x   + 272 a[17] x   + 
 
             16              17              18       19
  306 a[18] x   + 342 a[19] x   + 380 a[20] x   + O[x]\
\>"], "Output",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["lhs=y2+y", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
SeriesData[x, 0, {a[0] + 2*a[2], a[1] + 6*a[3], a[2] \
+ 12*a[4], 
 
   a[3] + 20*a[5], a[4] + 30*a[6], a[5] + 42*a[7], 
 
   a[6] + 56*a[8], a[7] + 72*a[9], a[8] + 90*a[10], 
 
   a[9] + 110*a[11], a[10] + 132*a[12], a[11] + 156*a[13], 
 
   a[12] + 182*a[14], a[13] + 210*a[15], a[14] + 240*a[16], 
 
   a[15] + 272*a[17], a[16] + 306*a[18], a[17] + 342*a[19], 
 
   a[18] + 380*a[20]}, 0, 19, 1]\
\>", "\<\
                                  \
                      2
(a[0] + 2 a[2]) + (a[1] + 6 a[3]) x + (a[2] + 12 a[4]) x  + 
 
                    3                     4
  (a[3] + 20 a[5]) x  + (a[4] + 30 a[6]) x  + 
 
                    5                     6
  (a[5] + 42 a[7]) x  + (a[6] + 56 a[8]) x  + 
 
                    7                      8
  (a[7] + 72 a[9]) x  + (a[8] + 90 a[10]) x  + 
 
                      9                        10
  (a[9] + 110 a[11]) x  + (a[10] + 132 a[12]) x   + 
 
                       11                        12
  (a[11] + 156 a[13]) x   + (a[12] + 182 a[14]) x   + 
 
                       13                        14
  (a[13] + 210 a[15]) x   + (a[14] + 240 a[16]) x   + 
 
                       15                        16
  (a[15] + 272 a[17]) x   + (a[16] + 306 a[18]) x   + 
 
                       17                        18       19
  (a[17] + 342 a[19]) x   + (a[18] + 380 a[20]) x   + O[x]\
\>"], "Output",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["eqnset=LogicalExpand[lhs==0]", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
a[0] + 2*a[2] == 0 && a[1] + 6*a[3] == 0 && 
 
  a[2] + 12*a[4] == 0 && a[3] + 20*a[5] == 0 && 
 
  a[4] + 30*a[6] == 0 && a[5] + 42*a[7] == 0 && 
 
  a[6] + 56*a[8] == 0 && a[7] + 72*a[9] == 0 && 
 
  a[8] + 90*a[10] == 0 && a[9] + 110*a[11] == 0 && 
 
  a[10] + 132*a[12] == 0 && a[11] + 156*a[13] == 0 && 
 
  a[12] + 182*a[14] == 0 && a[13] + 210*a[15] == 0 && 
 
  a[14] + 240*a[16] == 0 && a[15] + 272*a[17] == 0 && 
 
  a[16] + 306*a[18] == 0 && a[17] + 342*a[19] == 0 && 
 
  a[18] + 380*a[20] == 0\
\>", "\<\
a[0] + 2 a[2] == 0 && a[1] + 6 a[3] == 0 \
&& 
 
  a[2] + 12 a[4] == 0 && a[3] + 20 a[5] == 0 && 
 
  a[4] + 30 a[6] == 0 && a[5] + 42 a[7] == 0 && 
 
  a[6] + 56 a[8] == 0 && a[7] + 72 a[9] == 0 && 
 
  a[8] + 90 a[10] == 0 && a[9] + 110 a[11] == 0 && 
 
  a[10] + 132 a[12] == 0 && a[11] + 156 a[13] == 0 && 
 
  a[12] + 182 a[14] == 0 && a[13] + 210 a[15] == 0 && 
 
  a[14] + 240 a[16] == 0 && a[15] + 272 a[17] == 0 && 
 
  a[16] + 306 a[18] == 0 && a[17] + 342 a[19] == 0 && 
 
  a[18] + 380 a[20] == 0\
\>"], "Output",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["varset=Table[a[i],{i,2,20}]", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
{a[2], a[3], a[4], a[5], a[6], a[7], a[8], a[9], \
a[10], a[11], 
 
  a[12], a[13], a[14], a[15], a[16], a[17], a[18], a[19], a[20]}\
\>", \
"\<\
{a[2], a[3], a[4], a[5], a[6], a[7], a[8], a[9], a[10], a[11], 
 
  a[12], a[13], a[14], a[15], a[16], a[17], a[18], a[19], a[20]}\
\>"], \
"Output",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Solve[eqnset,varset]", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
{{a[19] -> -a[1]/121645100408832000, 
 
   a[20] -> a[0]/2432902008176640000, a[2] -> -a[0]/2, 
 
   a[3] -> -a[1]/6, a[4] -> a[0]/24, a[5] -> a[1]/120, 
 
   a[6] -> -a[0]/720, a[7] -> -a[1]/5040, a[8] -> a[0]/40320, 
 
   a[9] -> a[1]/362880, a[10] -> -a[0]/3628800, 
 
   a[11] -> -a[1]/39916800, a[12] -> a[0]/479001600, 
 
   a[13] -> a[1]/6227020800, a[14] -> -a[0]/87178291200, 
 
   a[15] -> -a[1]/1307674368000, a[16] -> a[0]/20922789888000, 
 
   a[17] -> a[1]/355687428096000, a[18] -> -a[0]/6402373705728000}
 
   }\
\>", "\<\
                 -a[1]                         a[0]
{{a[19] -> ------------------, a[20] -> -------------------, 
           121645100408832000           2432902008176640000
 
           -a[0]          -a[1]          a[0]          a[1]
   a[2] -> -----, a[3] -> -----, a[4] -> ----, a[5] -> ----, 
             2              6             24           120
 
           -a[0]          -a[1]          a[0]            a[1]
   a[6] -> -----, a[7] -> -----, a[8] -> -----, a[9] -> ------, 
            720           5040           40320          362880
 
             -a[0]             -a[1]               a[0]
   a[10] -> -------, a[11] -> --------, a[12] -> ---------, 
            3628800           39916800           479001600
 
               a[1]                 -a[0]
   a[13] -> ----------, a[14] -> -----------, 
            6227020800           87178291200
 
                -a[1]                    a[0]
   a[15] -> -------------, a[16] -> --------------, 
            1307674368000           20922789888000
 
                 a[1]                      -a[0]
   a[17] -> ---------------, a[18] -> ----------------}}
            355687428096000           6402373705728000\
\>"], "Output",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["{ysoln}=y/.%", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
{SeriesData[x, 0, {a[0], a[1], -a[0]/2, -a[1]/6, \
a[0]/24, 
 
    a[1]/120, -a[0]/720, -a[1]/5040, a[0]/40320, a[1]/362880, 
 
    -a[0]/3628800, -a[1]/39916800, a[0]/479001600, 
 
    a[1]/6227020800, -a[0]/87178291200, -a[1]/1307674368000, 
 
    a[0]/20922789888000, a[1]/355687428096000, 
 
    -a[0]/6402373705728000, -a[1]/121645100408832000, 
 
    a[0]/2432902008176640000}, 0, 21, 1]}\
\>", "\<\
                       2 \
        3         4         5
                 a[0] x    a[1] x    a[0] x    a[1] x
{a[0] + a[1] x - ------- - ------- + ------- + ------- - 
                    2         6        24        120
 
         6         7         8         9         10         11
   a[0] x    a[1] x    a[0] x    a[1] x    a[0] x     a[1] x
   ------- - ------- + ------- + ------- - -------- - -------- + 
     720      5040      40320    362880    3628800    39916800
 
         12           13           14             15
   a[0] x       a[1] x       a[0] x         a[1] x
   --------- + ---------- - ----------- - ------------- + 
   479001600   6227020800   87178291200   1307674368000
 
            16               17                 18
      a[0] x           a[1] x             a[0] x
   -------------- + --------------- - ---------------- - 
   20922789888000   355687428096000   6402373705728000
 
              19                   20
        a[1] x               a[0] x               21
   ------------------ + ------------------- + O[x]  }
   121645100408832000   2432902008176640000\
\>"], "Output",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["ysoln=Collect[ysoln,{a[0],a[1]}]", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
(1 - x^2/2 + x^4/24 - x^6/720 + x^8/40320 - \
x^10/3628800 + 
 
     x^12/479001600 - x^14/87178291200 + x^16/20922789888000 - 
 
     x^18/6402373705728000 + x^20/2432902008176640000)*a[0] + 
 
  (x - x^3/6 + x^5/120 - x^7/5040 + x^9/362880 - x^11/39916800 + 
 
     x^13/6227020800 - x^15/1307674368000 + 
 
     x^17/355687428096000 - x^19/121645100408832000)*a[1]\
\>", "\<\
      2  \
  4    6      8        10         12           14
     x    x    x      x        x          x            x
(1 - -- + -- - --- + ----- - ------- + --------- - ----------- + 
     2    24   720   40320   3628800   479001600   87178291200
 
           16                18                   20
          x                 x                    x
     -------------- - ---------------- + -------------------) a[0]
     20922789888000   6402373705728000   2432902008176640000
 
            3    5      7       9        11          13
           x    x      x       x        x           x
    + (x - -- + --- - ---- + ------ - -------- + ---------- - 
           6    120   5040   362880   39916800   6227020800
 
           15               17                 19
          x                x                  x
     ------------- + --------------- - ------------------) a[1]
     1307674368000   355687428096000   121645100408832000\
\>"], "Output",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["u1=Coefficient[ysoln,a[0]]", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
1 - x^2/2 + x^4/24 - x^6/720 + x^8/40320 - \
x^10/3628800 + 
 
  x^12/479001600 - x^14/87178291200 + x^16/20922789888000 - 
 
  x^18/6402373705728000 + x^20/2432902008176640000\
\>", "\<\
     2    4    \
6      8        10         12           14
    x    x    x      x        x          x            x
1 - -- + -- - --- + ----- - ------- + --------- - ----------- + 
    2    24   720   40320   3628800   479001600   87178291200
 
        16                18                   20
       x                 x                    x
  -------------- - ---------------- + -------------------
  20922789888000   6402373705728000   2432902008176640000\
\>"], "Output",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["u2=Coefficient[ysoln,a[1]]", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
x - x^3/6 + x^5/120 - x^7/5040 + x^9/362880 - \
x^11/39916800 + 
 
  x^13/6227020800 - x^15/1307674368000 + x^17/355687428096000 - 
 
  x^19/121645100408832000\
\>", "\<\
     3    5      7       9        11     \
     13
    x    x      x       x        x           x
x - -- + --- - ---- + ------ - -------- + ---------- - 
    6    120   5040   362880   39916800   6227020800
 
        15               17                 19
       x                x                  x
  ------------- + --------------- - ------------------
  1307674368000   355687428096000   121645100408832000\
\>"], "Output",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Looking for patterns in the coefficients", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
 Let's look at u1.  An obvious pattern is (-1) * something x^(2n).  \
Maybe factoring the coefficients will show something.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["t=Table[Coefficient[u1,x^(2n)],{n,0,10}]", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
{1, -1/2, 1/24, -1/720, 1/40320, -1/3628800, \
1/479001600, 
 
  -1/87178291200, 1/20922789888000, -1/6402373705728000, 
 
  1/2432902008176640000}\
\>", "\<\
      1   1      1      1         1       \
   1
{1, -(-), --, -(---), -----, -(-------), ---------, 
      2   24    720   40320    3628800   479001600
 
         1              1                  1
  -(-----------), --------------, -(----------------), 
    87178291200   20922789888000    6402373705728000
 
           1
  -------------------}
  2432902008176640000\
\>"], "Output",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["dlist=Denominator[t]", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
{1, 2, 24, 720, 40320, 3628800, 479001600, \
87178291200, 
 
  20922789888000, 6402373705728000, 2432902008176640000}\
\>", "\<\
{1, 2, \
24, 720, 40320, 3628800, 479001600, 87178291200, 
 
  20922789888000, 6402373705728000, 2432902008176640000}\
\>"], "Output",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell["\<\
One thing you can try is getting prime factors.  In the following, \
we see that 24 = 2^3 * 3; 720=2^4 * 3^2 * 5, etc.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["flist=FactorInteger[dlist]", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
{{}, {{2, 1}}, {{2, 3}, {3, 1}}, {{2, 4}, {3, 2}, \
{5, 1}}, 
 
  {{2, 7}, {3, 2}, {5, 1}, {7, 1}}, 
 
  {{2, 8}, {3, 4}, {5, 2}, {7, 1}}, 
 
  {{2, 10}, {3, 5}, {5, 2}, {7, 1}, {11, 1}}, 
 
  {{2, 11}, {3, 5}, {5, 2}, {7, 2}, {11, 1}, {13, 1}}, 
 
  {{2, 15}, {3, 6}, {5, 3}, {7, 2}, {11, 1}, {13, 1}}, 
 
  {{2, 16}, {3, 8}, {5, 3}, {7, 2}, {11, 1}, {13, 1}, {17, 1}}, 
 
  {{2, 18}, {3, 8}, {5, 4}, {7, 2}, {11, 1}, {13, 1}, {17, 1}, 
 
   {19, 1}}}\
\>", "\<\
{{}, {{2, 1}}, {{2, 3}, {3, 1}}, {{2, 4}, {3, 2}, {5, \
1}}, 
 
  {{2, 7}, {3, 2}, {5, 1}, {7, 1}}, 
 
  {{2, 8}, {3, 4}, {5, 2}, {7, 1}}, 
 
  {{2, 10}, {3, 5}, {5, 2}, {7, 1}, {11, 1}}, 
 
  {{2, 11}, {3, 5}, {5, 2}, {7, 2}, {11, 1}, {13, 1}}, 
 
  {{2, 15}, {3, 6}, {5, 3}, {7, 2}, {11, 1}, {13, 1}}, 
 
  {{2, 16}, {3, 8}, {5, 3}, {7, 2}, {11, 1}, {13, 1}, {17, 1}}, 
 
  {{2, 18}, {3, 8}, {5, 4}, {7, 2}, {11, 1}, {13, 1}, {17, 1}, 
 
   {19, 1}}}\
\>"], "Output",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell["You might try successive quotients.", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["flist2=Table[dlist[[i+1]]/dlist[[i]],{i,1,10}]", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
{2, 12, 30, 56, 90, 132, 182, 240, 306, 380}\
\>", "\
\<\
{2, 12, 30, 56, 90, 132, 182, 240, 306, 380}\
\>"], "Output",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["FactorInteger[%]", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
{{{2, 1}}, {{2, 2}, {3, 1}}, {{2, 1}, {3, 1}, {5, \
1}}, 
 
  {{2, 3}, {7, 1}}, {{2, 1}, {3, 2}, {5, 1}}, 
 
  {{2, 2}, {3, 1}, {11, 1}}, {{2, 1}, {7, 1}, {13, 1}}, 
 
  {{2, 4}, {3, 1}, {5, 1}}, {{2, 1}, {3, 2}, {17, 1}}, 
 
  {{2, 2}, {5, 1}, {19, 1}}}\
\>", "\<\
{{{2, 1}}, {{2, 2}, {3, 1}}, {{2, 1}, \
{3, 1}, {5, 1}}, 
 
  {{2, 3}, {7, 1}}, {{2, 1}, {3, 2}, {5, 1}}, 
 
  {{2, 2}, {3, 1}, {11, 1}}, {{2, 1}, {7, 1}, {13, 1}}, 
 
  {{2, 4}, {3, 1}, {5, 1}}, {{2, 1}, {3, 2}, {17, 1}}, 
 
  {{2, 2}, {5, 1}, {19, 1}}}\
\>"], "Output",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell["And you can always look for factorials.", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["Table[Factorial[n],{n,2,20}]", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
{2, 6, 24, 120, 720, 5040, 40320, 362880, 3628800, \
39916800, 
 
  479001600, 6227020800, 87178291200, 1307674368000, 
 
  20922789888000, 355687428096000, 6402373705728000, 
 
  121645100408832000, 2432902008176640000}\
\>", "\<\
{2, 6, 24, 120, 720, \
5040, 40320, 362880, 3628800, 39916800, 
 
  479001600, 6227020800, 87178291200, 1307674368000, 
 
  20922789888000, 355687428096000, 6402373705728000, 
 
  121645100408832000, 2432902008176640000}\
\>"], "Output",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell["\<\
From this one can see that the even powers of x get even factorials \
and the odd powers get odd factorials.  This can be double checked.\
\>", \
"Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["v1=Sum[(-1)^n/Factorial[2n] x^(2n),{n,0,10}]", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
1 - x^2/2 + x^4/24 - x^6/720 + x^8/40320 - \
x^10/3628800 + 
 
  x^12/479001600 - x^14/87178291200 + x^16/20922789888000 - 
 
  x^18/6402373705728000 + x^20/2432902008176640000\
\>", "\<\
     2    4    \
6      8        10         12           14
    x    x    x      x        x          x            x
1 - -- + -- - --- + ----- - ------- + --------- - ----------- + 
    2    24   720   40320   3628800   479001600   87178291200
 
        16                18                   20
       x                 x                    x
  -------------- - ---------------- + -------------------
  20922789888000   6402373705728000   2432902008176640000\
\>"], "Output",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["v2=Sum[(-1)^n/Factorial[2n+1] x^(2n+1),{n,0,10}]", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
x - x^3/6 + x^5/120 - x^7/5040 + x^9/362880 - \
x^11/39916800 + 
 
  x^13/6227020800 - x^15/1307674368000 + x^17/355687428096000 - 
 
  x^19/121645100408832000 + x^21/51090942171709440000\
\>", "\<\
     3    5  \
    7       9        11          13
    x    x      x       x        x           x
x - -- + --- - ---- + ------ - -------- + ---------- - 
    6    120   5040   362880   39916800   6227020800
 
        15               17                 19
       x                x                  x
  ------------- + --------------- - ------------------ + 
  1307674368000   355687428096000   121645100408832000
 
           21
          x
  --------------------
  51090942171709440000\
\>"], "Output",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["u1-v1", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
0\
\>", "\<\
0\
\>"], "Output",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["u2-v2", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
-x^21/51090942171709440000\
\>", "\<\
          21
        -x
--------------------
51090942171709440000\
\>"], "Output",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 746}},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{613, 596},
WindowMargins->{{17, Automatic}, {Automatic, 41}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 66, 1, 108, "Title"],
Cell[1796, 55, 254, 6, 68, "Text"],
Cell[2053, 63, 165, 5, 104, "Section"],

Cell[CellGroupData[{
Cell[2243, 72, 102, 1, 46, "Subsection"],
Cell[2348, 75, 125, 4, 32, "Text"],
Cell[2476, 81, 72, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[2573, 86, 83, 1, 27, "Input"],
Cell[2659, 89, 451, 14, 29, "Output"]
}, Open  ]],
Cell[3125, 106, 84, 1, 32, "Text"],

Cell[CellGroupData[{
Cell[3234, 111, 59, 1, 27, "Input"],
Cell[3296, 114, 539, 18, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3872, 137, 60, 1, 27, "Input"],
Cell[3935, 140, 499, 16, 29, "Output"]
}, Open  ]],
Cell[4449, 159, 123, 4, 30, "Text"],

Cell[CellGroupData[{
Cell[4597, 167, 72, 1, 27, "Input"],
Cell[4672, 170, 993, 37, 45, "Output"]
}, Open  ]],
Cell[5680, 210, 103, 1, 30, "Text"],

Cell[CellGroupData[{
Cell[5808, 215, 71, 1, 27, "Input"],
Cell[5882, 218, 204, 3, 41, "Output"]
}, Open  ]],
Cell[6101, 224, 169, 4, 30, "Text"],

Cell[CellGroupData[{
Cell[6295, 232, 85, 1, 27, "Input"],
Cell[6383, 235, 296, 5, 73, "Output"]
}, Open  ]],
Cell[6694, 243, 78, 1, 30, "Text"],

Cell[CellGroupData[{
Cell[6797, 248, 62, 1, 27, "Input"],
Cell[6862, 251, 1319, 43, 72, "Output"]
}, Open  ]],
Cell[8196, 297, 127, 4, 30, "Text"],

Cell[CellGroupData[{
Cell[8348, 305, 82, 1, 27, "Input"],
Cell[8433, 308, 189, 3, 44, "Output"]
}, Open  ]]
}, Open  ]],
Cell[8649, 315, 41, 0, 46, "Subsection"],

Cell[CellGroupData[{
Cell[8715, 319, 162, 4, 43, "Input"],
Cell[8880, 325, 216, 4, 74, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9133, 334, 105, 2, 42, "Input"],
Cell[9241, 338, 68, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9346, 344, 165, 3, 42, "Input"],
Cell[9514, 349, 91, 1, 42, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9642, 355, 44, 1, 27, "Input"],
Cell[9689, 358, 73, 1, 40, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9799, 364, 47, 1, 27, "Input"],
Cell[9849, 367, 83, 1, 40, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9969, 373, 193, 3, 76, "Input"],
Cell[10165, 378, 123, 3, 42, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10325, 386, 44, 1, 27, "Input"],
Cell[10372, 389, 65, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10474, 395, 47, 1, 27, "Input"],
Cell[10524, 398, 87, 1, 40, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10648, 404, 199, 3, 76, "Input"],
Cell[10850, 409, 125, 3, 40, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11012, 417, 44, 1, 27, "Input"],
Cell[11059, 420, 73, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11169, 426, 47, 1, 27, "Input"],
Cell[11219, 429, 88, 1, 40, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11344, 435, 80, 1, 46, "Subsection"],
Cell[11427, 438, 140, 4, 30, "Text"],
Cell[11570, 444, 111, 2, 43, "Input"],

Cell[CellGroupData[{
Cell[11706, 450, 85, 1, 27, "Input"],
Cell[11794, 453, 1050, 33, 62, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12881, 491, 59, 1, 27, "Input"],
Cell[12943, 494, 1527, 53, 79, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14507, 552, 60, 1, 27, "Input"],
Cell[14570, 555, 1512, 51, 79, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16119, 611, 72, 1, 27, "Input"],
Cell[16194, 614, 3609, 135, 164, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[19840, 754, 78, 1, 27, "Input"],
Cell[19921, 757, 820, 14, 146, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[20778, 776, 77, 1, 27, "Input"],
Cell[20858, 779, 166, 2, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[21061, 786, 70, 1, 27, "Input"],
Cell[21134, 789, 1415, 26, 436, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[22586, 820, 62, 1, 27, "Input"],
Cell[22651, 823, 5513, 165, 467, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[28201, 993, 82, 1, 27, "Input"],
Cell[28286, 996, 1162, 17, 299, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[29485, 1018, 76, 1, 27, "Input"],
Cell[29564, 1021, 582, 8, 115, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[30183, 1034, 76, 1, 27, "Input"],
Cell[30262, 1037, 562, 8, 151, "Output"]
}, Open  ]]
}, Open  ]],
Cell[30851, 1049, 159, 5, 86, "Section"],

Cell[CellGroupData[{
Cell[31035, 1058, 102, 1, 46, "Subsection"],
Cell[31140, 1061, 125, 4, 30, "Text"],
Cell[31268, 1067, 72, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[31365, 1072, 83, 1, 27, "Input"],
Cell[31451, 1075, 313, 13, 57, "Output"]
}, Open  ]],
Cell[31779, 1091, 84, 1, 30, "Text"],

Cell[CellGroupData[{
Cell[31888, 1096, 59, 1, 27, "Input"],
Cell[31950, 1099, 317, 13, 57, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[32304, 1117, 60, 1, 27, "Input"],
Cell[32367, 1120, 298, 12, 57, "Output"]
}, Open  ]],
Cell[32680, 1135, 123, 4, 30, "Text"],

Cell[CellGroupData[{
Cell[32828, 1143, 58, 1, 27, "Input"],
Cell[32889, 1146, 423, 12, 57, "Output"]
}, Open  ]],
Cell[33327, 1161, 103, 1, 30, "Text"],

Cell[CellGroupData[{
Cell[33455, 1166, 71, 1, 27, "Input"],
Cell[33529, 1169, 325, 13, 57, "Output"]
}, Open  ]],
Cell[33869, 1185, 169, 4, 30, "Text"],

Cell[CellGroupData[{
Cell[34063, 1193, 85, 1, 27, "Input"],
Cell[34151, 1196, 417, 15, 74, "Output"]
}, Open  ]],
Cell[34583, 1214, 78, 1, 30, "Text"],

Cell[CellGroupData[{
Cell[34686, 1219, 62, 1, 27, "Input"],
Cell[34751, 1222, 467, 17, 90, "Output"]
}, Open  ]],
Cell[35233, 1242, 127, 4, 30, "Text"],

Cell[CellGroupData[{
Cell[35385, 1250, 82, 1, 27, "Input"],
Cell[35470, 1253, 319, 9, 49, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[35838, 1268, 80, 1, 46, "Subsection"],
Cell[35921, 1271, 140, 4, 30, "Text"],
Cell[36064, 1277, 111, 2, 43, "Input"],

Cell[CellGroupData[{
Cell[36200, 1283, 85, 1, 27, "Input"],
Cell[36288, 1286, 755, 24, 131, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[37080, 1315, 59, 1, 27, "Input"],
Cell[37142, 1318, 880, 26, 131, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[38059, 1349, 60, 1, 27, "Input"],
Cell[38122, 1352, 900, 26, 131, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[39059, 1383, 58, 1, 27, "Input"],
Cell[39120, 1386, 1440, 44, 229, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[40597, 1435, 78, 1, 27, "Input"],
Cell[40678, 1438, 1101, 42, 172, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[41816, 1485, 77, 1, 27, "Input"],
Cell[41896, 1488, 353, 12, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[42286, 1505, 70, 1, 27, "Input"],
Cell[42359, 1508, 1791, 49, 237, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[44187, 1562, 62, 1, 27, "Input"],
Cell[44252, 1565, 1584, 42, 213, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[45873, 1612, 82, 1, 27, "Input"],
Cell[45958, 1615, 1391, 35, 172, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[47386, 1655, 76, 1, 27, "Input"],
Cell[47465, 1658, 721, 19, 90, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[48223, 1682, 76, 1, 27, "Input"],
Cell[48302, 1685, 656, 19, 90, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[49007, 1710, 95, 1, 46, "Subsection"],
Cell[49105, 1713, 180, 4, 46, "Text"],

Cell[CellGroupData[{
Cell[49310, 1721, 90, 1, 27, "Input"],
Cell[49403, 1724, 602, 21, 106, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[50042, 1750, 70, 1, 27, "Input"],
Cell[50115, 1753, 321, 11, 41, "Output"]
}, Open  ]],
Cell[50451, 1767, 175, 4, 30, "Text"],

Cell[CellGroupData[{
Cell[50651, 1775, 76, 1, 27, "Input"],
Cell[50730, 1778, 991, 39, 155, "Output"]
}, Open  ]],
Cell[51736, 1820, 84, 1, 30, "Text"],

Cell[CellGroupData[{
Cell[51845, 1825, 96, 1, 27, "Input"],
Cell[51944, 1828, 177, 6, 24, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[52158, 1839, 66, 1, 27, "Input"],
Cell[52227, 1842, 595, 23, 90, "Output"]
}, Open  ]],
Cell[52837, 1868, 88, 1, 30, "Text"],

Cell[CellGroupData[{
Cell[52950, 1873, 78, 1, 27, "Input"],
Cell[53031, 1876, 527, 19, 74, "Output"]
}, Open  ]],
Cell[53573, 1898, 196, 5, 46, "Text"],

Cell[CellGroupData[{
Cell[53794, 1907, 94, 1, 27, "Input"],
Cell[53891, 1910, 721, 19, 90, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[54649, 1934, 98, 1, 27, "Input"],
Cell[54750, 1937, 761, 24, 131, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[55548, 1966, 55, 1, 27, "Input"],
Cell[55606, 1969, 89, 5, 24, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[55732, 1979, 55, 1, 27, "Input"],
Cell[55790, 1982, 178, 8, 49, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

